Class: Google::Apis::ComputeV1::AddressList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of addresses.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressList

Returns a new instance of AddressList.



1133
1134
1135
# File 'lib/google/apis/compute_v1/classes.rb', line 1133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


1100
1101
1102
# File 'lib/google/apis/compute_v1/classes.rb', line 1100

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Address>

A list of Address resources. Corresponds to the JSON property items



1105
1106
1107
# File 'lib/google/apis/compute_v1/classes.rb', line 1105

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#addressList for lists of addresses. Corresponds to the JSON property kind

Returns:

  • (String)


1111
1112
1113
# File 'lib/google/apis/compute_v1/classes.rb', line 1111

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1121
1122
1123
# File 'lib/google/apis/compute_v1/classes.rb', line 1121

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1126
1127
1128
# File 'lib/google/apis/compute_v1/classes.rb', line 1126

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::AddressList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



1131
1132
1133
# File 'lib/google/apis/compute_v1/classes.rb', line 1131

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/google/apis/compute_v1/classes.rb', line 1138

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end