Class: Google::Apis::ComputeV1::AllocationResourceStatusSpecificSkuAllocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains Properties set for the reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationResourceStatusSpecificSkuAllocation

Returns a new instance of AllocationResourceStatusSpecificSkuAllocation.



1576
1577
1578
# File 'lib/google/apis/compute_v1/classes.rb', line 1576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_instance_template_idString

ID of the instance template used to populate reservation properties. Corresponds to the JSON property sourceInstanceTemplateId

Returns:

  • (String)


1568
1569
1570
# File 'lib/google/apis/compute_v1/classes.rb', line 1568

def source_instance_template_id
  @source_instance_template_id
end

#utilizationsHash<String,Fixnum>

Per service utilization breakdown. The Key is the Google Cloud managed service name. Corresponds to the JSON property utilizations

Returns:

  • (Hash<String,Fixnum>)


1574
1575
1576
# File 'lib/google/apis/compute_v1/classes.rb', line 1574

def utilizations
  @utilizations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1581
1582
1583
1584
# File 'lib/google/apis/compute_v1/classes.rb', line 1581

def update!(**args)
  @source_instance_template_id = args[:source_instance_template_id] if args.key?(:source_instance_template_id)
  @utilizations = args[:utilizations] if args.key?(:utilizations)
end