Class: Google::Apis::ComputeV1::AuditLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Provides the configuration for logging a type of permissions. Example: "audit_log_configs": [ "log_type": "DATA_READ", "exempted_members": [ "user:jose@example.com" ] , "log_type": "DATA_WRITE" ] This enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting jose@example.com from DATA_READ logging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuditLogConfig

Returns a new instance of AuditLogConfig.



2275
2276
2277
# File 'lib/google/apis/compute_v1/classes.rb', line 2275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exempted_membersArray<String>

Specifies the identities that do not cause logging for this type of permission. Follows the same format of Binding.members. Corresponds to the JSON property exemptedMembers

Returns:

  • (Array<String>)


2268
2269
2270
# File 'lib/google/apis/compute_v1/classes.rb', line 2268

def exempted_members
  @exempted_members
end

#log_typeString

The log type that this config enables. Corresponds to the JSON property logType

Returns:

  • (String)


2273
2274
2275
# File 'lib/google/apis/compute_v1/classes.rb', line 2273

def log_type
  @log_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2280
2281
2282
2283
# File 'lib/google/apis/compute_v1/classes.rb', line 2280

def update!(**args)
  @exempted_members = args[:exempted_members] if args.key?(:exempted_members)
  @log_type = args[:log_type] if args.key?(:log_type)
end