Class: Google::Apis::ComputeV1::AutoscalerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerAggregatedList

Returns a new instance of AutoscalerAggregatedList.



2475
2476
2477
# File 'lib/google/apis/compute_v1/classes.rb', line 2475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2435
2436
2437
# File 'lib/google/apis/compute_v1/classes.rb', line 2435

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::AutoscalersScopedList>

A list of AutoscalersScopedList resources. Corresponds to the JSON property items



2440
2441
2442
# File 'lib/google/apis/compute_v1/classes.rb', line 2440

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# autoscalerAggregatedList for aggregated lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2447
2448
2449
# File 'lib/google/apis/compute_v1/classes.rb', line 2447

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2457
2458
2459
# File 'lib/google/apis/compute_v1/classes.rb', line 2457

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2462
2463
2464
# File 'lib/google/apis/compute_v1/classes.rb', line 2462

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


2468
2469
2470
# File 'lib/google/apis/compute_v1/classes.rb', line 2468

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::AutoscalerAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



2473
2474
2475
# File 'lib/google/apis/compute_v1/classes.rb', line 2473

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2480
2481
2482
2483
2484
2485
2486
2487
2488
# File 'lib/google/apis/compute_v1/classes.rb', line 2480

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end