Class: Google::Apis::ComputeV1::BackendBackendOrchestrationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A message containing information about the resource or system that manages the backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBackendOrchestrationInfo

Returns a new instance of BackendBackendOrchestrationInfo.



3357
3358
3359
# File 'lib/google/apis/compute_v1/classes.rb', line 3357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_uriString

The URI of the resource or system that manages the backend. Corresponds to the JSON property resourceUri

Returns:

  • (String)


3355
3356
3357
# File 'lib/google/apis/compute_v1/classes.rb', line 3355

def resource_uri
  @resource_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3362
3363
3364
# File 'lib/google/apis/compute_v1/classes.rb', line 3362

def update!(**args)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
end