Class: Google::Apis::ComputeV1::BackendBucket

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Cloud Storage Bucket resource. This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, readBackend Buckets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucket

Returns a new instance of BackendBucket.



3553
3554
3555
# File 'lib/google/apis/compute_v1/classes.rb', line 3553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_nameString

Cloud Storage bucket name. Corresponds to the JSON property bucketName

Returns:

  • (String)


3458
3459
3460
# File 'lib/google/apis/compute_v1/classes.rb', line 3458

def bucket_name
  @bucket_name
end

#cdn_policyGoogle::Apis::ComputeV1::BackendBucketCdnPolicy

Message containing Cloud CDN configuration for a backend bucket. Corresponds to the JSON property cdnPolicy



3463
3464
3465
# File 'lib/google/apis/compute_v1/classes.rb', line 3463

def cdn_policy
  @cdn_policy
end

#compression_modeString

Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header. Corresponds to the JSON property compressionMode

Returns:

  • (String)


3469
3470
3471
# File 'lib/google/apis/compute_v1/classes.rb', line 3469

def compression_mode
  @compression_mode
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


3475
3476
3477
# File 'lib/google/apis/compute_v1/classes.rb', line 3475

def creation_timestamp
  @creation_timestamp
end

#custom_response_headersArray<String>

Headers that the Application Load Balancer should add to proxied responses. Corresponds to the JSON property customResponseHeaders

Returns:

  • (Array<String>)


3480
3481
3482
# File 'lib/google/apis/compute_v1/classes.rb', line 3480

def custom_response_headers
  @custom_response_headers
end

#descriptionString

An optional textual description of the resource; provided by the client when the resource is created. Corresponds to the JSON property description

Returns:

  • (String)


3486
3487
3488
# File 'lib/google/apis/compute_v1/classes.rb', line 3486

def description
  @description
end

#edge_security_policyString

[Output Only] The resource URL for the edge security policy associated with this backend bucket. Corresponds to the JSON property edgeSecurityPolicy

Returns:

  • (String)


3492
3493
3494
# File 'lib/google/apis/compute_v1/classes.rb', line 3492

def edge_security_policy
  @edge_security_policy
end

#enable_cdnBoolean Also known as: enable_cdn?

If true, enable Cloud CDN for this BackendBucket. Corresponds to the JSON property enableCdn

Returns:

  • (Boolean)


3497
3498
3499
# File 'lib/google/apis/compute_v1/classes.rb', line 3497

def enable_cdn
  @enable_cdn
end

#idFixnum

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


3503
3504
3505
# File 'lib/google/apis/compute_v1/classes.rb', line 3503

def id
  @id
end

#kindString

Output only. Type of the resource. Corresponds to the JSON property kind

Returns:

  • (String)


3508
3509
3510
# File 'lib/google/apis/compute_v1/classes.rb', line 3508

def kind
  @kind
end

#load_balancing_schemeString

The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer. If loadBalancingScheme is not specified, the backend bucket can be used by classic global external load balancers, or global application external load balancers, or both. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


3517
3518
3519
# File 'lib/google/apis/compute_v1/classes.rb', line 3517

def load_balancing_scheme
  @load_balancing_scheme
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


3528
3529
3530
# File 'lib/google/apis/compute_v1/classes.rb', line 3528

def name
  @name
end

#paramsGoogle::Apis::ComputeV1::BackendBucketParams

Additional Backend Bucket parameters. Corresponds to the JSON property params



3533
3534
3535
# File 'lib/google/apis/compute_v1/classes.rb', line 3533

def params
  @params
end

#regionString

Output only. [Output Only] URL of the region where the regional backend bucket resides. This field is not applicable to global backend buckets. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


3541
3542
3543
# File 'lib/google/apis/compute_v1/classes.rb', line 3541

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3546
3547
3548
# File 'lib/google/apis/compute_v1/classes.rb', line 3546

def self_link
  @self_link
end

#used_byArray<Google::Apis::ComputeV1::BackendBucketUsedBy>

Output only. [Output Only] List of resources referencing that backend bucket. Corresponds to the JSON property usedBy



3551
3552
3553
# File 'lib/google/apis/compute_v1/classes.rb', line 3551

def used_by
  @used_by
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/google/apis/compute_v1/classes.rb', line 3558

def update!(**args)
  @bucket_name = args[:bucket_name] if args.key?(:bucket_name)
  @cdn_policy = args[:cdn_policy] if args.key?(:cdn_policy)
  @compression_mode = args[:compression_mode] if args.key?(:compression_mode)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @custom_response_headers = args[:custom_response_headers] if args.key?(:custom_response_headers)
  @description = args[:description] if args.key?(:description)
  @edge_security_policy = args[:edge_security_policy] if args.key?(:edge_security_policy)
  @enable_cdn = args[:enable_cdn] if args.key?(:enable_cdn)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @used_by = args[:used_by] if args.key?(:used_by)
end