Class: Google::Apis::ComputeV1::BackendBucketCdnPolicyCacheKeyPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendBucketCdnPolicyCacheKeyPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Message containing what to include in the cache key for a request for Cloud CDN.
Instance Attribute Summary collapse
-
#include_http_headers ⇒ Array<String>
Allows HTTP request headers (by name) to be used in the cache key.
-
#query_string_whitelist ⇒ Array<String>
Names of query string parameters to include in cache keys.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketCdnPolicyCacheKeyPolicy
constructor
A new instance of BackendBucketCdnPolicyCacheKeyPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketCdnPolicyCacheKeyPolicy
Returns a new instance of BackendBucketCdnPolicyCacheKeyPolicy.
3857 3858 3859 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#include_http_headers ⇒ Array<String>
Allows HTTP request headers (by name) to be used in the cache key.
Corresponds to the JSON property includeHttpHeaders
3848 3849 3850 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3848 def include_http_headers @include_http_headers end |
#query_string_whitelist ⇒ Array<String>
Names of query string parameters to include in cache keys. Default
parameters are always included. '&' and '=' will be percent encoded
and not treated as delimiters.
Corresponds to the JSON property queryStringWhitelist
3855 3856 3857 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3855 def query_string_whitelist @query_string_whitelist end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3862 3863 3864 3865 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3862 def update!(**args) @include_http_headers = args[:include_http_headers] if args.key?(:include_http_headers) @query_string_whitelist = args[:query_string_whitelist] if args.key?(:query_string_whitelist) end |