Class: Google::Apis::ComputeV1::BackendBucketList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of BackendBucket resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketList

Returns a new instance of BackendBucketList.



3997
3998
3999
# File 'lib/google/apis/compute_v1/classes.rb', line 3997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


3965
3966
3967
# File 'lib/google/apis/compute_v1/classes.rb', line 3965

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



3970
3971
3972
# File 'lib/google/apis/compute_v1/classes.rb', line 3970

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


3975
3976
3977
# File 'lib/google/apis/compute_v1/classes.rb', line 3975

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3985
3986
3987
# File 'lib/google/apis/compute_v1/classes.rb', line 3985

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3990
3991
3992
# File 'lib/google/apis/compute_v1/classes.rb', line 3990

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendBucketList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



3995
3996
3997
# File 'lib/google/apis/compute_v1/classes.rb', line 3995

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4002
4003
4004
4005
4006
4007
4008
4009
# File 'lib/google/apis/compute_v1/classes.rb', line 4002

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end