Class: Google::Apis::ComputeV1::BackendCustomMetric
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendCustomMetric
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Custom Metrics are used for CUSTOM_METRICS balancing_mode.
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
(also: #dry_run?)
If true, the metric data is collected and reported to Cloud Monitoring, but is not used for load balancing.
-
#max_utilization ⇒ Float
Optional parameter to define a target utilization for the Custom Metrics balancing mode.
-
#name ⇒ String
Name of a custom utilization signal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendCustomMetric
constructor
A new instance of BackendCustomMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendCustomMetric
Returns a new instance of BackendCustomMetric.
3921 3922 3923 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dry_run ⇒ Boolean Also known as: dry_run?
If true, the metric data is collected and reported to Cloud
Monitoring, but is not used for load balancing.
Corresponds to the JSON property dryRun
3898 3899 3900 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3898 def dry_run @dry_run end |
#max_utilization ⇒ Float
Optional parameter to define a target utilization for the Custom Metrics
balancing mode. The valid range is [0.0, 1.0].
Corresponds to the JSON property maxUtilization
3905 3906 3907 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3905 def max_utilization @max_utilization end |
#name ⇒ String
Name of a custom utilization signal. The name must be 1-64 characters
long and match the regular expression
[a-z]([-_.a-z0-9]*[a-z0-9])? which means that the
first character must be a lowercase letter, and all following
characters must be a dash, period, underscore, lowercase letter, or
digit, except the last character, which cannot be a dash, period, or
underscore. For usage guidelines, see Custom Metrics balancing mode. This
field can only be used for a global or regional backend service with the
loadBalancingScheme set to EXTERNAL_MANAGED,INTERNAL_MANAGED
INTERNAL_SELF_MANAGED.
Corresponds to the JSON property name
3919 3920 3921 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3919 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3926 3927 3928 3929 3930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3926 def update!(**args) @dry_run = args[:dry_run] if args.key?(:dry_run) @max_utilization = args[:max_utilization] if args.key?(:max_utilization) @name = args[:name] if args.key?(:name) end |