Class: Google::Apis::ComputeV1::BackendServiceCdnPolicyBypassCacheOnRequestHeader

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Bypass the cache when the specified request headers are present, e.g. Pragma or Authorization headers. Values are case insensitive. The presence of such a header overrides the cache_mode setting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceCdnPolicyBypassCacheOnRequestHeader

Returns a new instance of BackendServiceCdnPolicyBypassCacheOnRequestHeader.



4831
4832
4833
# File 'lib/google/apis/compute_v1/classes.rb', line 4831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_nameString

The header field name to match on when bypassing cache. Values are case-insensitive. Corresponds to the JSON property headerName

Returns:

  • (String)


4829
4830
4831
# File 'lib/google/apis/compute_v1/classes.rb', line 4829

def header_name
  @header_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4836
4837
4838
# File 'lib/google/apis/compute_v1/classes.rb', line 4836

def update!(**args)
  @header_name = args[:header_name] if args.key?(:header_name)
end