Class: Google::Apis::ComputeV1::BackendServiceCustomMetric
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceCustomMetric
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Custom Metrics are used for WEIGHTED_ROUND_ROBIN locality_lb_policy.
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
(also: #dry_run?)
If true, the metric data is not used for load balancing.
-
#name ⇒ String
Name of a custom utilization signal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceCustomMetric
constructor
A new instance of BackendServiceCustomMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceCustomMetric
Returns a new instance of BackendServiceCustomMetric.
4981 4982 4983 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4981 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dry_run ⇒ Boolean Also known as: dry_run?
If true, the metric data is not used for load balancing.
Corresponds to the JSON property dryRun
4964 4965 4966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4964 def dry_run @dry_run end |
#name ⇒ String
Name of a custom utilization signal. The name must be 1-64 characters
long and match the regular expression
[a-z]([-_.a-z0-9]*[a-z0-9])? which means that the
first character must be a lowercase letter, and all following
characters must be a dash, period, underscore, lowercase letter, or
digit, except the last character, which cannot be a dash, period, or
underscore. For usage guidelines, see Custom Metrics balancing mode. This
field can only be used for a global or regional backend service with the
loadBalancingScheme set to EXTERNAL_MANAGED,INTERNAL_MANAGED
INTERNAL_SELF_MANAGED.
Corresponds to the JSON property name
4979 4980 4981 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4979 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4986 4987 4988 4989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4986 def update!(**args) @dry_run = args[:dry_run] if args.key?(:dry_run) @name = args[:name] if args.key?(:name) end |