Class: Google::Apis::ComputeV1::BackendServiceLocalityLoadBalancingPolicyConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Container for either a built-in LB policy supported by gRPC or Envoy or a custom one implemented by the end user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLocalityLoadBalancingPolicyConfig

Returns a new instance of BackendServiceLocalityLoadBalancingPolicyConfig.



6033
6034
6035
# File 'lib/google/apis/compute_v1/classes.rb', line 6033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_policyGoogle::Apis::ComputeV1::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy

The configuration for a custom policy implemented by the user and deployed with the client. Corresponds to the JSON property customPolicy



6026
6027
6028
# File 'lib/google/apis/compute_v1/classes.rb', line 6026

def custom_policy
  @custom_policy
end

#policyGoogle::Apis::ComputeV1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy

The configuration for a built-in load balancing policy. Corresponds to the JSON property policy



6031
6032
6033
# File 'lib/google/apis/compute_v1/classes.rb', line 6031

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6038
6039
6040
6041
# File 'lib/google/apis/compute_v1/classes.rb', line 6038

def update!(**args)
  @custom_policy = args[:custom_policy] if args.key?(:custom_policy)
  @policy = args[:policy] if args.key?(:policy)
end