Class: Google::Apis::ComputeV1::BackendServiceOrchestrationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceOrchestrationInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A message containing information about the resource or system that manages the backend service.
Instance Attribute Summary collapse
-
#resource_uri ⇒ String
The resource URI of the resource or system that manages the backend service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceOrchestrationInfo
constructor
A new instance of BackendServiceOrchestrationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceOrchestrationInfo
Returns a new instance of BackendServiceOrchestrationInfo.
6246 6247 6248 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6246 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_uri ⇒ String
The resource URI of the resource or system that manages the backend
service.
Corresponds to the JSON property resourceUri
6244 6245 6246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6244 def resource_uri @resource_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6251 6252 6253 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6251 def update!(**args) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) end |