Class: Google::Apis::ComputeV1::BackendServiceTlsSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceTlsSettings

Returns a new instance of BackendServiceTlsSettings.



6403
6404
6405
# File 'lib/google/apis/compute_v1/classes.rb', line 6403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_configString

Reference to the BackendAuthenticationConfig resource from the networksecurity.googleapis.com namespace. Can be used in authenticating TLS connections to the backend, as specified by the authenticationMode field. Can only be specified if authenticationMode is not NONE. Corresponds to the JSON property authenticationConfig

Returns:

  • (String)


6377
6378
6379
# File 'lib/google/apis/compute_v1/classes.rb', line 6377

def authentication_config
  @authentication_config
end

#sniString

Server Name Indication - see RFC3546 section 3.1. If set, the load balancer sends this string as the SNI hostname in the TLS connection to the backend, and requires that this string match a Subject Alternative Name (SAN) in the backend's server certificate. With a Regional Internet NEG backend, if the SNI is specified here, the load balancer uses it regardless of whether the Regional Internet NEG is specified with FQDN or IP address and port. When both sni and subjectAltNames[] are specified, the load balancer matches the backend certificate's SAN only to subjectAltNames[]. Corresponds to the JSON property sni

Returns:

  • (String)


6390
6391
6392
# File 'lib/google/apis/compute_v1/classes.rb', line 6390

def sni
  @sni
end

#subject_alt_namesArray<Google::Apis::ComputeV1::BackendServiceTlsSettingsSubjectAltName>

A list of Subject Alternative Names (SANs) that the Load Balancer verifies during a TLS handshake with the backend. When the server presents its X.509 certificate to the Load Balancer, the Load Balancer inspects the certificate's SAN field, and requires that at least one SAN match one of the subjectAltNames in the list. This field is limited to 5 entries. When both sni and subjectAltNames[] are specified, the load balancer matches the backend certificate's SAN only to subjectAltNames[]. Corresponds to the JSON property subjectAltNames



6401
6402
6403
# File 'lib/google/apis/compute_v1/classes.rb', line 6401

def subject_alt_names
  @subject_alt_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6408
6409
6410
6411
6412
# File 'lib/google/apis/compute_v1/classes.rb', line 6408

def update!(**args)
  @authentication_config = args[:authentication_config] if args.key?(:authentication_config)
  @sni = args[:sni] if args.key?(:sni)
  @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names)
end