Class: Google::Apis::ComputeV1::BfdStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BfdStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Next free: 15
Instance Attribute Summary collapse
-
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
-
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
-
#control_packet_counts ⇒ Google::Apis::ComputeV1::BfdStatusPacketCounts
Control packet counts for the current BFD session.
-
#control_packet_intervals ⇒ Array<Google::Apis::ComputeV1::PacketIntervals>
Inter-packet time interval statistics for control packets.
-
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#local_state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
-
#rx_packet ⇒ Google::Apis::ComputeV1::BfdPacket
The most recent Rx control packet for this BFD session.
-
#tx_packet ⇒ Google::Apis::ComputeV1::BfdPacket
The most recent Tx control packet for this BFD session.
-
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatus
constructor
A new instance of BfdStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatus
Returns a new instance of BfdStatus.
6751 6752 6753 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer.
Corresponds to the JSON property bfdSessionInitializationMode
6700 6701 6702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6700 def bfd_session_initialization_mode @bfd_session_initialization_mode end |
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
Corresponds to the JSON property configUpdateTimestampMicros
6705 6706 6707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6705 def @config_update_timestamp_micros end |
#control_packet_counts ⇒ Google::Apis::ComputeV1::BfdStatusPacketCounts
Control packet counts for the current BFD session.
Corresponds to the JSON property controlPacketCounts
6710 6711 6712 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6710 def control_packet_counts @control_packet_counts end |
#control_packet_intervals ⇒ Array<Google::Apis::ComputeV1::PacketIntervals>
Inter-packet time interval statistics for control packets.
Corresponds to the JSON property controlPacketIntervals
6715 6716 6717 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6715 def control_packet_intervals @control_packet_intervals end |
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property localDiagnostic
6723 6724 6725 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6723 def local_diagnostic @local_diagnostic end |
#local_state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property localState
6729 6730 6731 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6729 def local_state @local_state end |
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
Corresponds to the JSON property negotiatedLocalControlTxIntervalMs
6734 6735 6736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6734 def negotiated_local_control_tx_interval_ms @negotiated_local_control_tx_interval_ms end |
#rx_packet ⇒ Google::Apis::ComputeV1::BfdPacket
The most recent Rx control packet for this BFD session.
Corresponds to the JSON property rxPacket
6739 6740 6741 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6739 def rx_packet @rx_packet end |
#tx_packet ⇒ Google::Apis::ComputeV1::BfdPacket
The most recent Tx control packet for this BFD session.
Corresponds to the JSON property txPacket
6744 6745 6746 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6744 def tx_packet @tx_packet end |
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds. Value will be 0 if session is not up.
Corresponds to the JSON property uptimeMs
6749 6750 6751 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6749 def uptime_ms @uptime_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6756 6757 6758 6759 6760 6761 6762 6763 6764 6765 6766 6767 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6756 def update!(**args) @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode) @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros) @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts) @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals) @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic) @local_state = args[:local_state] if args.key?(:local_state) @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms) @rx_packet = args[:rx_packet] if args.key?(:rx_packet) @tx_packet = args[:tx_packet] if args.key?(:tx_packet) @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms) end |