Class: Google::Apis::ComputeV1::BfdStatusPacketCounts
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BfdStatusPacketCounts
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#num_rx ⇒ Fixnum
Number of packets received since the beginning of the current BFD session.
-
#num_rx_rejected ⇒ Fixnum
Number of packets received that were rejected because of errors since the beginning of the current BFD session.
-
#num_rx_successful ⇒ Fixnum
Number of packets received that were successfully processed since the beginning of the current BFD session.
-
#num_tx ⇒ Fixnum
Number of packets transmitted since the beginning of the current BFD session.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatusPacketCounts
constructor
A new instance of BfdStatusPacketCounts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatusPacketCounts
Returns a new instance of BfdStatusPacketCounts.
6792 6793 6794 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#num_rx ⇒ Fixnum
Number of packets received since the beginning of the current BFD
session.
Corresponds to the JSON property numRx
6772 6773 6774 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6772 def num_rx @num_rx end |
#num_rx_rejected ⇒ Fixnum
Number of packets received that were rejected because of errors since the
beginning of the current BFD session.
Corresponds to the JSON property numRxRejected
6778 6779 6780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6778 def num_rx_rejected @num_rx_rejected end |
#num_rx_successful ⇒ Fixnum
Number of packets received that were successfully processed since the
beginning of the current BFD session.
Corresponds to the JSON property numRxSuccessful
6784 6785 6786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6784 def num_rx_successful @num_rx_successful end |
#num_tx ⇒ Fixnum
Number of packets transmitted since the beginning of the current BFD
session.
Corresponds to the JSON property numTx
6790 6791 6792 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6790 def num_tx @num_tx end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6797 6798 6799 6800 6801 6802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6797 def update!(**args) @num_rx = args[:num_rx] if args.key?(:num_rx) @num_rx_rejected = args[:num_rx_rejected] if args.key?(:num_rx_rejected) @num_rx_successful = args[:num_rx_successful] if args.key?(:num_rx_successful) @num_tx = args[:num_tx] if args.key?(:num_tx) end |