Class: Google::Apis::ComputeV1::BundledLocalSsds
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BundledLocalSsds
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#default_interface ⇒ String
The default disk interface if the interface is not specified.
-
#partition_count ⇒ Fixnum
The number of partitions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BundledLocalSsds
constructor
A new instance of BundledLocalSsds.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BundledLocalSsds
Returns a new instance of BundledLocalSsds.
7232 7233 7234 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7232 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_interface ⇒ String
The default disk interface if the interface is not specified.
Corresponds to the JSON property defaultInterface
7225 7226 7227 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7225 def default_interface @default_interface end |
#partition_count ⇒ Fixnum
The number of partitions.
Corresponds to the JSON property partitionCount
7230 7231 7232 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7230 def partition_count @partition_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7237 7238 7239 7240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7237 def update!(**args) @default_interface = args[:default_interface] if args.key?(:default_interface) @partition_count = args[:partition_count] if args.key?(:partition_count) end |