Class: Google::Apis::ComputeV1::CompositeHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a composite health check. A composite health check resource specifies the health source resources and the health destination resource to which the aggregated health result from the health source resources is delivered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheck

Returns a new instance of CompositeHealthCheck.



8532
8533
8534
# File 'lib/google/apis/compute_v1/classes.rb', line 8532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


8450
8451
8452
# File 'lib/google/apis/compute_v1/classes.rb', line 8450

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


8456
8457
8458
# File 'lib/google/apis/compute_v1/classes.rb', line 8456

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a CompositeHealthCheck. An up-to-date fingerprint must be provided in order to patch the CompositeHealthCheck; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the CompositeHealthCheck. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


8468
8469
8470
# File 'lib/google/apis/compute_v1/classes.rb', line 8468

def fingerprint
  @fingerprint
end

#health_destinationString

URL to the destination resource. Must be set. Must be aForwardingRule. The ForwardingRule must have load balancing scheme INTERNAL orINTERNAL_MANAGED and must be regional and in the same region as the CompositeHealthCheck (cross-region deployment forINTERNAL_MANAGED is not supported). Can be mutated. Corresponds to the JSON property healthDestination

Returns:

  • (String)


8478
8479
8480
# File 'lib/google/apis/compute_v1/classes.rb', line 8478

def health_destination
  @health_destination
end

#health_sourcesArray<String>

URLs to the HealthSource resources whose results are AND'ed. I.e. he aggregated result is is HEALTHY only if all sources are HEALTHY. Must have at least 1. Must not have more than 10. Must be regional and in the same region as theCompositeHealthCheck. Can be mutated. Corresponds to the JSON property healthSources

Returns:

  • (Array<String>)


8487
8488
8489
# File 'lib/google/apis/compute_v1/classes.rb', line 8487

def health_sources
  @health_sources
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


8494
8495
8496
# File 'lib/google/apis/compute_v1/classes.rb', line 8494

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# compositeHealthCheck for composite health checks. Corresponds to the JSON property kind

Returns:

  • (String)


8500
8501
8502
# File 'lib/google/apis/compute_v1/classes.rb', line 8500

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


8511
8512
8513
# File 'lib/google/apis/compute_v1/classes.rb', line 8511

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the composite health check resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


8520
8521
8522
# File 'lib/google/apis/compute_v1/classes.rb', line 8520

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8525
8526
8527
# File 'lib/google/apis/compute_v1/classes.rb', line 8525

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL with id for the resource. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


8530
8531
8532
# File 'lib/google/apis/compute_v1/classes.rb', line 8530

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
# File 'lib/google/apis/compute_v1/classes.rb', line 8537

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @health_destination = args[:health_destination] if args.key?(:health_destination)
  @health_sources = args[:health_sources] if args.key?(:health_sources)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end