Class: Google::Apis::ComputeV1::CompositeHealthChecksScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CompositeHealthChecksScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#composite_health_checks ⇒ Array<Google::Apis::ComputeV1::CompositeHealthCheck>
A list of CompositeHealthChecks contained in this scope.
-
#warning ⇒ Google::Apis::ComputeV1::CompositeHealthChecksScopedList::Warning
Informational warning which replaces the list of composite health checks when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthChecksScopedList
constructor
A new instance of CompositeHealthChecksScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthChecksScopedList
Returns a new instance of CompositeHealthChecksScopedList.
8804 8805 8806 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8804 def initialize(**args) update!(**args) end |
Instance Attribute Details
#composite_health_checks ⇒ Array<Google::Apis::ComputeV1::CompositeHealthCheck>
A list of CompositeHealthChecks contained in this scope.
Corresponds to the JSON property compositeHealthChecks
8796 8797 8798 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8796 def composite_health_checks @composite_health_checks end |
#warning ⇒ Google::Apis::ComputeV1::CompositeHealthChecksScopedList::Warning
Informational warning which replaces the list of composite health checks
when the list is empty.
Corresponds to the JSON property warning
8802 8803 8804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8802 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8809 8810 8811 8812 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8809 def update!(**args) @composite_health_checks = args[:composite_health_checks] if args.key?(:composite_health_checks) @warning = args[:warning] if args.key?(:warning) end |