Class: Google::Apis::ComputeV1::ConfidentialInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ConfidentialInstanceConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A set of Confidential Instance options.
Instance Attribute Summary collapse
-
#confidential_instance_type ⇒ String
Defines the type of technology used by the confidential instance.
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Defines whether the instance should have confidential compute enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfidentialInstanceConfig
constructor
A new instance of ConfidentialInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfidentialInstanceConfig
Returns a new instance of ConfidentialInstanceConfig.
7697 7698 7699 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidential_instance_type ⇒ String
Defines the type of technology used by the confidential instance.
Corresponds to the JSON property confidentialInstanceType
7689 7690 7691 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7689 def confidential_instance_type @confidential_instance_type end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Defines whether the instance should have confidential compute enabled.
Corresponds to the JSON property enableConfidentialCompute
7694 7695 7696 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7694 def enable_confidential_compute @enable_confidential_compute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7702 7703 7704 7705 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7702 def update!(**args) @confidential_instance_type = args[:confidential_instance_type] if args.key?(:confidential_instance_type) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) end |