Class: Google::Apis::ComputeV1::CrossSiteNetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A resource that represents a cross-site network. You can use cross-site networks to connect your on-premises networks to each other through Interconnect connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetwork

Returns a new instance of CrossSiteNetwork.



9148
9149
9150
# File 'lib/google/apis/compute_v1/classes.rb', line 9148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


9112
9113
9114
# File 'lib/google/apis/compute_v1/classes.rb', line 9112

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of the cross-site network. Corresponds to the JSON property description

Returns:

  • (String)


9117
9118
9119
# File 'lib/google/apis/compute_v1/classes.rb', line 9117

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


9124
9125
9126
# File 'lib/google/apis/compute_v1/classes.rb', line 9124

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


9130
9131
9132
# File 'lib/google/apis/compute_v1/classes.rb', line 9130

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


9141
9142
9143
# File 'lib/google/apis/compute_v1/classes.rb', line 9141

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9146
9147
9148
# File 'lib/google/apis/compute_v1/classes.rb', line 9146

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9153
9154
9155
9156
9157
9158
9159
9160
# File 'lib/google/apis/compute_v1/classes.rb', line 9153

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
end