Class: Google::Apis::ComputeV1::CrossSiteNetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request that contains a list of cross-site networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetworkList

Returns a new instance of CrossSiteNetworkList.



9276
9277
9278
# File 'lib/google/apis/compute_v1/classes.rb', line 9276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


9232
9233
9234
# File 'lib/google/apis/compute_v1/classes.rb', line 9232

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9237
9238
9239
# File 'lib/google/apis/compute_v1/classes.rb', line 9237

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::CrossSiteNetwork>

A list of CrossSiteNetwork resources. Corresponds to the JSON property items



9242
9243
9244
# File 'lib/google/apis/compute_v1/classes.rb', line 9242

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


9248
9249
9250
# File 'lib/google/apis/compute_v1/classes.rb', line 9248

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9258
9259
9260
# File 'lib/google/apis/compute_v1/classes.rb', line 9258

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9263
9264
9265
# File 'lib/google/apis/compute_v1/classes.rb', line 9263

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


9269
9270
9271
# File 'lib/google/apis/compute_v1/classes.rb', line 9269

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::CrossSiteNetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9274
9275
9276
# File 'lib/google/apis/compute_v1/classes.rb', line 9274

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9281
9282
9283
9284
9285
9286
9287
9288
9289
9290
# File 'lib/google/apis/compute_v1/classes.rb', line 9281

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end