Class: Google::Apis::ComputeV1::CustomErrorResponsePolicyCustomErrorResponseRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CustomErrorResponsePolicyCustomErrorResponseRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specifies the mapping between the response code that will be returned along with the custom error content and the response code returned by the backend service.
Instance Attribute Summary collapse
-
#match_response_codes ⇒ Array<String>
Valid values include:.
-
#override_response_code ⇒ Fixnum
The HTTP status code returned with the response containing the custom error content.
-
#path ⇒ String
The full path to a file within backendBucket .
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomErrorResponsePolicyCustomErrorResponseRule
constructor
A new instance of CustomErrorResponsePolicyCustomErrorResponseRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomErrorResponsePolicyCustomErrorResponseRule
Returns a new instance of CustomErrorResponsePolicyCustomErrorResponseRule.
9398 9399 9400 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#match_response_codes ⇒ Array<String>
Valid values include:
- A number between 400 and 599: For example 401 or 503, in which case the load balancer applies the policy if the error code exactly matches this value.
- 5xx: Load Balancer will apply the policy if the backend service responds with any response code in the range of 500 to 599.
- 4xx: Load
Balancer will apply the policy if the backend service responds with any
response code in the range of 400 to
499.
Values must be unique within matchResponseCodes and across
allerrorResponseRules ofCustomErrorResponsePolicy.
Corresponds to the JSON property
matchResponseCodes
9375 9376 9377 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9375 def match_response_codes @match_response_codes end |
#override_response_code ⇒ Fixnum
The HTTP status code returned with the response containing the custom
error content. If overrideResponseCode is not supplied, the
same response code returned by the original backend bucket or backend
service is returned to the client.
Corresponds to the JSON property overrideResponseCode
9383 9384 9385 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9383 def override_response_code @override_response_code end |
#path ⇒ String
The full path to a file within backendBucket . For example:/errors/
defaultError.html
path must start
with a leading slash. path cannot have trailing slashes.
If the file is not available in backendBucket or the
load balancer cannot reach the BackendBucket, a simpleNot Found Error is
returned to the client.
The value must
be from 1 to 1024 characters
Corresponds to the JSON property path
9396 9397 9398 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9396 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9403 9404 9405 9406 9407 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9403 def update!(**args) @match_response_codes = args[:match_response_codes] if args.key?(:match_response_codes) @override_response_code = args[:override_response_code] if args.key?(:override_response_code) @path = args[:path] if args.key?(:path) end |