Class: Google::Apis::ComputeV1::Date
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Date
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:
- A full date, with non-zero year, month, and day values.
- A month and day, with a zero year (for example, an anniversary).
- A year on its own, with a zero month and a zero day.
- A year and month, with a zero day (for example, a credit card expiration date). Related types:
- google.type.TimeOfDay
- google.type.DateTime
- google.protobuf.Timestamp
Instance Attribute Summary collapse
-
#day ⇒ Fixnum
Day of a month.
-
#month ⇒ Fixnum
Month of a year.
-
#year ⇒ Fixnum
Year of the date.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Date
constructor
A new instance of Date.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Date
Returns a new instance of Date.
8335 8336 8337 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ Fixnum
Day of a month. Must be from 1 to 31 and valid for the year and month, or 0
to specify a year by itself or a year and month where the day isn't
significant.
Corresponds to the JSON property day
8321 8322 8323 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8321 def day @day end |
#month ⇒ Fixnum
Month of a year. Must be from 1 to 12, or 0 to specify a year without a
month and day.
Corresponds to the JSON property month
8327 8328 8329 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8327 def month @month end |
#year ⇒ Fixnum
Year of the date. Must be from 1 to 9999, or 0 to specify a date without
a year.
Corresponds to the JSON property year
8333 8334 8335 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8333 def year @year end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8340 8341 8342 8343 8344 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8340 def update!(**args) @day = args[:day] if args.key?(:day) @month = args[:month] if args.key?(:month) @year = args[:year] if args.key?(:year) end |