Class: Google::Apis::ComputeV1::DateTime

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:

  • When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
  • When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
  • When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DateTime

Returns a new instance of DateTime.



9650
9651
9652
# File 'lib/google/apis/compute_v1/classes.rb', line 9650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayFixnum

Optional. Day of month. Must be from 1 to 31 and valid for the year and month, or 0 if specifying a datetime without a day. Corresponds to the JSON property day

Returns:

  • (Fixnum)


9599
9600
9601
# File 'lib/google/apis/compute_v1/classes.rb', line 9599

def day
  @day
end

#hoursFixnum

Optional. Hours of day in 24 hour format. Should be from 0 to 23, defaults to 0 (midnight). An API may choose to allow the value "24:00:00" for scenarios like business closing time. Corresponds to the JSON property hours

Returns:

  • (Fixnum)


9606
9607
9608
# File 'lib/google/apis/compute_v1/classes.rb', line 9606

def hours
  @hours
end

#minutesFixnum

Optional. Minutes of hour of day. Must be from 0 to 59, defaults to 0. Corresponds to the JSON property minutes

Returns:

  • (Fixnum)


9611
9612
9613
# File 'lib/google/apis/compute_v1/classes.rb', line 9611

def minutes
  @minutes
end

#monthFixnum

Optional. Month of year. Must be from 1 to 12, or 0 if specifying a datetime without a month. Corresponds to the JSON property month

Returns:

  • (Fixnum)


9617
9618
9619
# File 'lib/google/apis/compute_v1/classes.rb', line 9617

def month
  @month
end

#nanosFixnum

Optional. Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999, defaults to 0. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


9623
9624
9625
# File 'lib/google/apis/compute_v1/classes.rb', line 9623

def nanos
  @nanos
end

#secondsFixnum

Optional. Seconds of minutes of the time. Must normally be from 0 to 59, defaults to 0. An API may allow the value 60 if it allows leap-seconds. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


9629
9630
9631
# File 'lib/google/apis/compute_v1/classes.rb', line 9629

def seconds
  @seconds
end

#time_zoneGoogle::Apis::ComputeV1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



9635
9636
9637
# File 'lib/google/apis/compute_v1/classes.rb', line 9635

def time_zone
  @time_zone
end

#utc_offsetString

UTC offset. Must be whole seconds, between -18 hours and +18 hours. For example, a UTC offset of -4:00 would be represented as seconds: -14400. Corresponds to the JSON property utcOffset

Returns:

  • (String)


9642
9643
9644
# File 'lib/google/apis/compute_v1/classes.rb', line 9642

def utc_offset
  @utc_offset
end

#yearFixnum

Optional. Year of date. Must be from 1 to 9999, or 0 if specifying a datetime without a year. Corresponds to the JSON property year

Returns:

  • (Fixnum)


9648
9649
9650
# File 'lib/google/apis/compute_v1/classes.rb', line 9648

def year
  @year
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
9665
# File 'lib/google/apis/compute_v1/classes.rb', line 9655

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @hours = args[:hours] if args.key?(:hours)
  @minutes = args[:minutes] if args.key?(:minutes)
  @month = args[:month] if args.key?(:month)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @utc_offset = args[:utc_offset] if args.key?(:utc_offset)
  @year = args[:year] if args.key?(:year)
end