Class: Google::Apis::ComputeV1::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



10348
10349
10350
# File 'lib/google/apis/compute_v1/classes.rb', line 10348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10309
10310
10311
# File 'lib/google/apis/compute_v1/classes.rb', line 10309

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



10314
10315
10316
# File 'lib/google/apis/compute_v1/classes.rb', line 10314

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


10321
10322
10323
# File 'lib/google/apis/compute_v1/classes.rb', line 10321

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10331
10332
10333
# File 'lib/google/apis/compute_v1/classes.rb', line 10331

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10336
10337
10338
# File 'lib/google/apis/compute_v1/classes.rb', line 10336

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10341
10342
10343
# File 'lib/google/apis/compute_v1/classes.rb', line 10341

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10346
10347
10348
# File 'lib/google/apis/compute_v1/classes.rb', line 10346

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10353
10354
10355
10356
10357
10358
10359
10360
10361
# File 'lib/google/apis/compute_v1/classes.rb', line 10353

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end