Class: Google::Apis::ComputeV1::DisksScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DisksScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeV1::Disk>
[Output Only] A list of disks contained in this scope.
-
#warning ⇒ Google::Apis::ComputeV1::DisksScopedList::Warning
[Output Only] Informational warning which replaces the list of disks when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DisksScopedList
constructor
A new instance of DisksScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DisksScopedList
Returns a new instance of DisksScopedList.
11163 11164 11165 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeV1::Disk>
[Output Only] A list of disks contained in this scope.
Corresponds to the JSON property disks
11155 11156 11157 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11155 def disks @disks end |
#warning ⇒ Google::Apis::ComputeV1::DisksScopedList::Warning
[Output Only] Informational warning which replaces the list of disks when
the list is empty.
Corresponds to the JSON property warning
11161 11162 11163 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11161 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11168 11169 11170 11171 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11168 def update!(**args) @disks = args[:disks] if args.key?(:disks) @warning = args[:warning] if args.key?(:warning) end |