Class: Google::Apis::ComputeV1::ExchangedPeeringRoute

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoute

Returns a new instance of ExchangedPeeringRoute.



11646
11647
11648
# File 'lib/google/apis/compute_v1/classes.rb', line 11646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_rangeString

The destination range of the route. Corresponds to the JSON property destRange

Returns:

  • (String)


11619
11620
11621
# File 'lib/google/apis/compute_v1/classes.rb', line 11619

def dest_range
  @dest_range
end

#importedBoolean Also known as: imported?

True if the peering route has been imported from a peer. The actual import happens if the field networkPeering.importCustomRoutes is true for this network, and networkPeering.exportCustomRoutes is true for the peer network, and the import does not result in a route conflict. Corresponds to the JSON property imported

Returns:

  • (Boolean)


11628
11629
11630
# File 'lib/google/apis/compute_v1/classes.rb', line 11628

def imported
  @imported
end

#next_hop_regionString

The region of peering route next hop, only applies to dynamic routes. Corresponds to the JSON property nextHopRegion

Returns:

  • (String)


11634
11635
11636
# File 'lib/google/apis/compute_v1/classes.rb', line 11634

def next_hop_region
  @next_hop_region
end

#priorityFixnum

The priority of the peering route. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


11639
11640
11641
# File 'lib/google/apis/compute_v1/classes.rb', line 11639

def priority
  @priority
end

#typeString

The type of the peering route. Corresponds to the JSON property type

Returns:

  • (String)


11644
11645
11646
# File 'lib/google/apis/compute_v1/classes.rb', line 11644

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11651
11652
11653
11654
11655
11656
11657
# File 'lib/google/apis/compute_v1/classes.rb', line 11651

def update!(**args)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @imported = args[:imported] if args.key?(:imported)
  @next_hop_region = args[:next_hop_region] if args.key?(:next_hop_region)
  @priority = args[:priority] if args.key?(:priority)
  @type = args[:type] if args.key?(:type)
end