Class: Google::Apis::ComputeV1::ExternalVpnGateway

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an external VPN gateway. External VPN gateway is the on-premises VPN gateway(s) or another cloud provider's VPN gateway that connects to your Google Cloud VPN gateway. To create a highly available VPN from Google Cloud Platform to your VPN gateway or another cloud provider's VPN gateway, you must create a external VPN gateway resource with information about the other gateway. For more information about using external VPN gateways, see Creating an HA VPN gateway and tunnel pair to a peer VPN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGateway

Returns a new instance of ExternalVpnGateway.



12001
12002
12003
# File 'lib/google/apis/compute_v1/classes.rb', line 12001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


11923
11924
11925
# File 'lib/google/apis/compute_v1/classes.rb', line 11923

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


11929
11930
11931
# File 'lib/google/apis/compute_v1/classes.rb', line 11929

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


11936
11937
11938
# File 'lib/google/apis/compute_v1/classes.rb', line 11936

def id
  @id
end

#interfacesArray<Google::Apis::ComputeV1::ExternalVpnGatewayInterface>

A list of interfaces for this external VPN gateway. If your peer-side gateway is an on-premises gateway and non-AWS cloud providers' gateway, at most two interfaces can be provided for an external VPN gateway. If your peer side is an AWS virtual private gateway, four interfaces should be provided for an external VPN gateway. Corresponds to the JSON property interfaces



11945
11946
11947
# File 'lib/google/apis/compute_v1/classes.rb', line 11945

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# externalVpnGateway for externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


11951
11952
11953
# File 'lib/google/apis/compute_v1/classes.rb', line 11951

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this ExternalVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an ExternalVpnGateway. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


11964
11965
11966
# File 'lib/google/apis/compute_v1/classes.rb', line 11964

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11971
11972
11973
# File 'lib/google/apis/compute_v1/classes.rb', line 11971

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


11982
11983
11984
# File 'lib/google/apis/compute_v1/classes.rb', line 11982

def name
  @name
end

#paramsGoogle::Apis::ComputeV1::ExternalVpnGatewayParams

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload. Corresponds to the JSON property params



11989
11990
11991
# File 'lib/google/apis/compute_v1/classes.rb', line 11989

def params
  @params
end

#redundancy_typeString

Indicates the user-supplied redundancy type of this external VPN gateway. Corresponds to the JSON property redundancyType

Returns:

  • (String)


11994
11995
11996
# File 'lib/google/apis/compute_v1/classes.rb', line 11994

def redundancy_type
  @redundancy_type
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11999
12000
12001
# File 'lib/google/apis/compute_v1/classes.rb', line 11999

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12006
12007
12008
12009
12010
12011
12012
12013
12014
12015
12016
12017
12018
# File 'lib/google/apis/compute_v1/classes.rb', line 12006

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @redundancy_type = args[:redundancy_type] if args.key?(:redundancy_type)
  @self_link = args[:self_link] if args.key?(:self_link)
end