Class: Google::Apis::ComputeV1::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



12583
12584
12585
# File 'lib/google/apis/compute_v1/classes.rb', line 12583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12550
12551
12552
# File 'lib/google/apis/compute_v1/classes.rb', line 12550

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



12555
12556
12557
# File 'lib/google/apis/compute_v1/classes.rb', line 12555

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


12561
12562
12563
# File 'lib/google/apis/compute_v1/classes.rb', line 12561

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12571
12572
12573
# File 'lib/google/apis/compute_v1/classes.rb', line 12571

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12576
12577
12578
# File 'lib/google/apis/compute_v1/classes.rb', line 12576

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12581
12582
12583
# File 'lib/google/apis/compute_v1/classes.rb', line 12581

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12588
12589
12590
12591
12592
12593
12594
12595
# File 'lib/google/apis/compute_v1/classes.rb', line 12588

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end