Class: Google::Apis::ComputeV1::FirewallLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The available logging options for a firewall rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallLogConfig

Returns a new instance of FirewallLogConfig.



12686
12687
12688
# File 'lib/google/apis/compute_v1/classes.rb', line 12686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

This field denotes whether to enable logging for a particular firewall rule. Corresponds to the JSON property enable

Returns:

  • (Boolean)


12676
12677
12678
# File 'lib/google/apis/compute_v1/classes.rb', line 12676

def enable
  @enable
end

#metadataString

This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs. Corresponds to the JSON property metadata

Returns:

  • (String)


12684
12685
12686
# File 'lib/google/apis/compute_v1/classes.rb', line 12684

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12691
12692
12693
12694
# File 'lib/google/apis/compute_v1/classes.rb', line 12691

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @metadata = args[:metadata] if args.key?(:metadata)
end