Class: Google::Apis::ComputeV1::ForwardingRuleAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleAggregatedList

Returns a new instance of ForwardingRuleAggregatedList.



14216
14217
14218
# File 'lib/google/apis/compute_v1/classes.rb', line 14216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14178
14179
14180
# File 'lib/google/apis/compute_v1/classes.rb', line 14178

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>

A list of ForwardingRulesScopedList resources. Corresponds to the JSON property items



14183
14184
14185
# File 'lib/google/apis/compute_v1/classes.rb', line 14183

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# forwardingRuleAggregatedList for lists of forwarding rules. Corresponds to the JSON property kind

Returns:

  • (String)


14189
14190
14191
# File 'lib/google/apis/compute_v1/classes.rb', line 14189

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14199
14200
14201
# File 'lib/google/apis/compute_v1/classes.rb', line 14199

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14204
14205
14206
# File 'lib/google/apis/compute_v1/classes.rb', line 14204

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


14209
14210
14211
# File 'lib/google/apis/compute_v1/classes.rb', line 14209

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14214
14215
14216
# File 'lib/google/apis/compute_v1/classes.rb', line 14214

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14221
14222
14223
14224
14225
14226
14227
14228
14229
# File 'lib/google/apis/compute_v1/classes.rb', line 14221

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end