Class: Google::Apis::ComputeV1::ForwardingRuleList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of ForwardingRule resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleList

Returns a new instance of ForwardingRuleList.



14360
14361
14362
# File 'lib/google/apis/compute_v1/classes.rb', line 14360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14328
14329
14330
# File 'lib/google/apis/compute_v1/classes.rb', line 14328

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ForwardingRule>

A list of ForwardingRule resources. Corresponds to the JSON property items



14333
14334
14335
# File 'lib/google/apis/compute_v1/classes.rb', line 14333

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


14338
14339
14340
# File 'lib/google/apis/compute_v1/classes.rb', line 14338

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14348
14349
14350
# File 'lib/google/apis/compute_v1/classes.rb', line 14348

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14353
14354
14355
# File 'lib/google/apis/compute_v1/classes.rb', line 14353

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ForwardingRuleList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14358
14359
14360
# File 'lib/google/apis/compute_v1/classes.rb', line 14358

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14365
14366
14367
14368
14369
14370
14371
14372
# File 'lib/google/apis/compute_v1/classes.rb', line 14365

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end