Class: Google::Apis::ComputeV1::FutureReservationStatusExistingMatchingUsageInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] Represents the existing matching usage for the future reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusExistingMatchingUsageInfo

Returns a new instance of FutureReservationStatusExistingMatchingUsageInfo.



14931
14932
14933
# File 'lib/google/apis/compute_v1/classes.rb', line 14931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. Count to represent min(FR total_count, matching_reserved_capacity+matching_unreserved_instances) Corresponds to the JSON property count

Returns:

  • (Fixnum)


14924
14925
14926
# File 'lib/google/apis/compute_v1/classes.rb', line 14924

def count
  @count
end

#timestampString

Output only. Timestamp when the matching usage was calculated Corresponds to the JSON property timestamp

Returns:

  • (String)


14929
14930
14931
# File 'lib/google/apis/compute_v1/classes.rb', line 14929

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14936
14937
14938
14939
# File 'lib/google/apis/compute_v1/classes.rb', line 14936

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end