Class: Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The properties of the last known good state for the Future Reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

Returns a new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.



15080
15081
15082
# File 'lib/google/apis/compute_v1/classes.rb', line 15080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#share_settingsGoogle::Apis::ComputeV1::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



15067
15068
15069
# File 'lib/google/apis/compute_v1/classes.rb', line 15067

def share_settings
  @share_settings
end

#specific_sku_propertiesGoogle::Apis::ComputeV1::FutureReservationSpecificSkuProperties

Output only. [Output Only] The previous instance related properties of the Future Reservation. Corresponds to the JSON property specificSkuProperties



15073
15074
15075
# File 'lib/google/apis/compute_v1/classes.rb', line 15073

def specific_sku_properties
  @specific_sku_properties
end

#time_windowGoogle::Apis::ComputeV1::FutureReservationTimeWindow

Output only. [Output Only] The previous time window of the Future Reservation. Corresponds to the JSON property timeWindow



15078
15079
15080
# File 'lib/google/apis/compute_v1/classes.rb', line 15078

def time_window
  @time_window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15085
15086
15087
15088
15089
# File 'lib/google/apis/compute_v1/classes.rb', line 15085

def update!(**args)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @time_window = args[:time_window] if args.key?(:time_window)
end