Class: Google::Apis::ComputeV1::FutureReservationsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsScopedList

Returns a new instance of FutureReservationsScopedList.



15207
15208
15209
# File 'lib/google/apis/compute_v1/classes.rb', line 15207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#future_reservationsArray<Google::Apis::ComputeV1::FutureReservation>

A list of future reservations contained in this scope. Corresponds to the JSON property futureReservations



15199
15200
15201
# File 'lib/google/apis/compute_v1/classes.rb', line 15199

def future_reservations
  @future_reservations
end

#warningGoogle::Apis::ComputeV1::FutureReservationsScopedList::Warning

Informational warning which replaces the list of future reservations when the list is empty. Corresponds to the JSON property warning



15205
15206
15207
# File 'lib/google/apis/compute_v1/classes.rb', line 15205

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15212
15213
15214
15215
# File 'lib/google/apis/compute_v1/classes.rb', line 15212

def update!(**args)
  @future_reservations = args[:future_reservations] if args.key?(:future_reservations)
  @warning = args[:warning] if args.key?(:warning)
end