Class: Google::Apis::ComputeV1::FutureResourcesRecommendationOtherLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureResourcesRecommendationOtherLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Information about recommendation status for locations that were allowed but not used by the response.
Instance Attribute Summary collapse
-
#details ⇒ String
Details (human readable) describing the situation.
-
#status ⇒ String
Status of recommendation in this location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation
constructor
A new instance of FutureResourcesRecommendationOtherLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation
Returns a new instance of FutureResourcesRecommendationOtherLocation.
15381 15382 15383 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ String
Details (human readable) describing the situation.
For example, if status is CONDITION_NOT_MET, then
details contain information about the parameters of the time window
that did not meet the required conditions.
Corresponds to the JSON property details
15374 15375 15376 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15374 def details @details end |
#status ⇒ String
Status of recommendation in this location.
Corresponds to the JSON property status
15379 15380 15381 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15379 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15386 15387 15388 15389 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15386 def update!(**args) @details = args[:details] if args.key?(:details) @status = args[:status] if args.key?(:status) end |