Class: Google::Apis::ComputeV1::GetVersionOperationMetadataSbomInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::GetVersionOperationMetadataSbomInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#current_component_versions ⇒ Hash<String,String>
A mapping of components to their currently-applied versions or other appropriate identifiers.
-
#target_component_versions ⇒ Hash<String,String>
A mapping of components to their target versions or other appropriate identifiers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo
constructor
A new instance of GetVersionOperationMetadataSbomInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo
Returns a new instance of GetVersionOperationMetadataSbomInfo.
15916 15917 15918 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_component_versions ⇒ Hash<String,String>
A mapping of components to their currently-applied versions or other
appropriate identifiers.
Corresponds to the JSON property currentComponentVersions
15908 15909 15910 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15908 def current_component_versions @current_component_versions end |
#target_component_versions ⇒ Hash<String,String>
A mapping of components to their target versions or other appropriate
identifiers.
Corresponds to the JSON property targetComponentVersions
15914 15915 15916 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15914 def target_component_versions @target_component_versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15921 15922 15923 15924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15921 def update!(**args) @current_component_versions = args[:current_component_versions] if args.key?(:current_component_versions) @target_component_versions = args[:target_component_versions] if args.key?(:target_component_versions) end |