Class: Google::Apis::ComputeV1::GroupMaintenanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::GroupMaintenanceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Maintenance Info for ReservationBlocks.
Instance Attribute Summary collapse
-
#instance_maintenance_ongoing_count ⇒ Fixnum
Describes number of instances that have ongoing maintenance.
-
#instance_maintenance_pending_count ⇒ Fixnum
Describes number of instances that have pending maintenance.
-
#maintenance_ongoing_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
-
#maintenance_pending_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
-
#scheduling_type ⇒ String
The type of maintenance for the reservation.
-
#subblock_infra_maintenance_ongoing_count ⇒ Fixnum
Describes number of subblock Infrastructure that has ongoing maintenance.
-
#subblock_infra_maintenance_pending_count ⇒ Fixnum
Describes number of subblock Infrastructure that has pending maintenance.
-
#upcoming_group_maintenance ⇒ Google::Apis::ComputeV1::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupMaintenanceInfo
constructor
A new instance of GroupMaintenanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupMaintenanceInfo
Returns a new instance of GroupMaintenanceInfo.
16828 16829 16830 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_maintenance_ongoing_count ⇒ Fixnum
Describes number of instances that have ongoing maintenance.
Corresponds to the JSON property instanceMaintenanceOngoingCount
16783 16784 16785 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16783 def instance_maintenance_ongoing_count @instance_maintenance_ongoing_count end |
#instance_maintenance_pending_count ⇒ Fixnum
Describes number of instances that have pending maintenance.
Corresponds to the JSON property instanceMaintenancePendingCount
16788 16789 16790 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16788 def instance_maintenance_pending_count @instance_maintenance_pending_count end |
#maintenance_ongoing_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have ongoing maintenance.
Corresponds to the JSON property maintenanceOngoingCount
16794 16795 16796 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16794 def maintenance_ongoing_count @maintenance_ongoing_count end |
#maintenance_pending_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have pending maintenance.
Corresponds to the JSON property maintenancePendingCount
16800 16801 16802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16800 def maintenance_pending_count @maintenance_pending_count end |
#scheduling_type ⇒ String
The type of maintenance for the reservation.
Corresponds to the JSON property schedulingType
16805 16806 16807 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16805 def scheduling_type @scheduling_type end |
#subblock_infra_maintenance_ongoing_count ⇒ Fixnum
Describes number of subblock Infrastructure that has ongoing maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family(e.g. NVLink
Domains). Not all VM Families will support this field.
Corresponds to the JSON property subblockInfraMaintenanceOngoingCount
16813 16814 16815 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16813 def subblock_infra_maintenance_ongoing_count @subblock_infra_maintenance_ongoing_count end |
#subblock_infra_maintenance_pending_count ⇒ Fixnum
Describes number of subblock Infrastructure that has pending maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family (e.g. NVLink
Domains). Not all VM Families will support this field.
Corresponds to the JSON property subblockInfraMaintenancePendingCount
16821 16822 16823 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16821 def subblock_infra_maintenance_pending_count @subblock_infra_maintenance_pending_count end |
#upcoming_group_maintenance ⇒ Google::Apis::ComputeV1::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingGroupMaintenance
16826 16827 16828 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16826 def upcoming_group_maintenance @upcoming_group_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16833 16834 16835 16836 16837 16838 16839 16840 16841 16842 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16833 def update!(**args) @instance_maintenance_ongoing_count = args[:instance_maintenance_ongoing_count] if args.key?(:instance_maintenance_ongoing_count) @instance_maintenance_pending_count = args[:instance_maintenance_pending_count] if args.key?(:instance_maintenance_pending_count) @maintenance_ongoing_count = args[:maintenance_ongoing_count] if args.key?(:maintenance_ongoing_count) @maintenance_pending_count = args[:maintenance_pending_count] if args.key?(:maintenance_pending_count) @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type) @subblock_infra_maintenance_ongoing_count = args[:subblock_infra_maintenance_ongoing_count] if args.key?(:subblock_infra_maintenance_ongoing_count) @subblock_infra_maintenance_pending_count = args[:subblock_infra_maintenance_pending_count] if args.key?(:subblock_infra_maintenance_pending_count) @upcoming_group_maintenance = args[:upcoming_group_maintenance] if args.key?(:upcoming_group_maintenance) end |