Class: Google::Apis::ComputeV1::HealthAggregationPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthAggregationPoliciesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList

Returns a new instance of HealthAggregationPolicyAggregatedList.



17544
17545
17546
# File 'lib/google/apis/compute_v1/classes.rb', line 17544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17507
17508
17509
# File 'lib/google/apis/compute_v1/classes.rb', line 17507

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthAggregationPoliciesScopedList>

A list of HealthAggregationPoliciesScopedList resources. Corresponds to the JSON property items



17512
17513
17514
# File 'lib/google/apis/compute_v1/classes.rb', line 17512

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17517
17518
17519
# File 'lib/google/apis/compute_v1/classes.rb', line 17517

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17527
17528
17529
# File 'lib/google/apis/compute_v1/classes.rb', line 17527

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17532
17533
17534
# File 'lib/google/apis/compute_v1/classes.rb', line 17532

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17537
17538
17539
# File 'lib/google/apis/compute_v1/classes.rb', line 17537

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthAggregationPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17542
17543
17544
# File 'lib/google/apis/compute_v1/classes.rb', line 17542

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17549
17550
17551
17552
17553
17554
17555
17556
17557
# File 'lib/google/apis/compute_v1/classes.rb', line 17549

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end