Class: Google::Apis::ComputeV1::HealthAggregationPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthAggregationPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyList
constructor
A new instance of HealthAggregationPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyList
Returns a new instance of HealthAggregationPolicyList.
17671 17672 17673 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17637 17638 17639 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17637 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
Corresponds to the JSON property items
17642 17643 17644 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17642 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
healthAggregationPolicy for health aggregation
policies.
Corresponds to the JSON property kind
17649 17650 17651 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17649 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17659 17660 17661 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17659 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17664 17665 17666 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17664 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17669 17670 17671 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17669 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17676 17677 17678 17679 17680 17681 17682 17683 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17676 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |