Class: Google::Apis::ComputeV1::HealthCheckServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthCheckServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HealthCheckServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
constructor
A new instance of HealthCheckServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
Returns a new instance of HealthCheckServiceAggregatedList.
18300 18301 18302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18263 18264 18265 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18263 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
Corresponds to the JSON property items
18268 18269 18270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18268 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18273 18274 18275 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18273 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18283 18284 18285 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18283 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18288 18289 18290 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18288 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18293 18294 18295 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18293 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18298 18299 18300 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18298 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18305 18306 18307 18308 18309 18310 18311 18312 18313 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18305 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |