Class: Google::Apis::ComputeV1::HealthChecksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthChecksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthChecksAggregatedList
constructor
A new instance of HealthChecksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthChecksAggregatedList
Returns a new instance of HealthChecksAggregatedList.
18681 18682 18683 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18644 18645 18646 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18644 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
Corresponds to the JSON property items
18649 18650 18651 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18649 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18654 18655 18656 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18654 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18664 18665 18666 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18664 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18669 18670 18671 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18669 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18674 18675 18676 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18674 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18679 18680 18681 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18679 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18686 18687 18688 18689 18690 18691 18692 18693 18694 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18686 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |