Class: Google::Apis::ComputeV1::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatusForNetworkEndpoint

Returns a new instance of HealthStatusForNetworkEndpoint.



19346
19347
19348
# File 'lib/google/apis/compute_v1/classes.rb', line 19346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceGoogle::Apis::ComputeV1::BackendServiceReference

URL of the backend service associated with the health state of the network endpoint. Corresponds to the JSON property backendService



19303
19304
19305
# File 'lib/google/apis/compute_v1/classes.rb', line 19303

def backend_service
  @backend_service
end

#forwarding_ruleGoogle::Apis::ComputeV1::ForwardingRuleReference

URL of the forwarding rule associated with the health state of the network endpoint. Corresponds to the JSON property forwardingRule



19309
19310
19311
# File 'lib/google/apis/compute_v1/classes.rb', line 19309

def forwarding_rule
  @forwarding_rule
end

#health_checkGoogle::Apis::ComputeV1::HealthCheckReference

A full or valid partial URL to a health check. For example, the following are valid URLs:



19320
19321
19322
# File 'lib/google/apis/compute_v1/classes.rb', line 19320

def health_check
  @health_check
end

#health_check_serviceGoogle::Apis::ComputeV1::HealthCheckServiceReference

A full or valid partial URL to a health check service. For example, the following are valid URLs:



19332
19333
19334
# File 'lib/google/apis/compute_v1/classes.rb', line 19332

def health_check_service
  @health_check_service
end

#health_stateString

Health state of the network endpoint determined based on the health checks configured. Corresponds to the JSON property healthState

Returns:

  • (String)


19338
19339
19340
# File 'lib/google/apis/compute_v1/classes.rb', line 19338

def health_state
  @health_state
end

#ipv6_health_stateString

Health state of the ipv6 network endpoint determined based on the health checks configured. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


19344
19345
19346
# File 'lib/google/apis/compute_v1/classes.rb', line 19344

def ipv6_health_state
  @ipv6_health_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19351
19352
19353
19354
19355
19356
19357
19358
# File 'lib/google/apis/compute_v1/classes.rb', line 19351

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @health_check = args[:health_check] if args.key?(:health_check)
  @health_check_service = args[:health_check_service] if args.key?(:health_check_service)
  @health_state = args[:health_state] if args.key?(:health_state)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
end