Class: Google::Apis::ComputeV1::HttpHeaderAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpHeaderAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The request and response header transformations that take effect before the request is passed along to the selected backendService.
Instance Attribute Summary collapse
-
#request_headers_to_add ⇒ Array<Google::Apis::ComputeV1::HttpHeaderOption>
Headers to add to a matching request before forwarding the request to thebackendService.
-
#request_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the request before forwarding the request to the backendService.
-
#response_headers_to_add ⇒ Array<Google::Apis::ComputeV1::HttpHeaderOption>
Headers to add the response before sending the response back to the client.
-
#response_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the response before sending the response back to the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderAction
constructor
A new instance of HttpHeaderAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderAction
Returns a new instance of HttpHeaderAction.
20102 20103 20104 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_headers_to_add ⇒ Array<Google::Apis::ComputeV1::HttpHeaderOption>
Headers to add to a matching request before forwarding the request to
thebackendService.
Corresponds to the JSON property requestHeadersToAdd
20082 20083 20084 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20082 def request_headers_to_add @request_headers_to_add end |
#request_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the
request before forwarding the request to the backendService.
Corresponds to the JSON property requestHeadersToRemove
20088 20089 20090 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20088 def request_headers_to_remove @request_headers_to_remove end |
#response_headers_to_add ⇒ Array<Google::Apis::ComputeV1::HttpHeaderOption>
Headers to add the response before sending the response back to the
client.
Corresponds to the JSON property responseHeadersToAdd
20094 20095 20096 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20094 def response_headers_to_add @response_headers_to_add end |
#response_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the
response before sending the response back to the client.
Corresponds to the JSON property responseHeadersToRemove
20100 20101 20102 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20100 def response_headers_to_remove @response_headers_to_remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20107 20108 20109 20110 20111 20112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20107 def update!(**args) @request_headers_to_add = args[:request_headers_to_add] if args.key?(:request_headers_to_add) @request_headers_to_remove = args[:request_headers_to_remove] if args.key?(:request_headers_to_remove) @response_headers_to_add = args[:response_headers_to_add] if args.key?(:response_headers_to_add) @response_headers_to_remove = args[:response_headers_to_remove] if args.key?(:response_headers_to_remove) end |