Class: Google::Apis::ComputeV1::HttpRedirectAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specifies settings for an HTTP redirect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRedirectAction

Returns a new instance of HttpRedirectAction.



20237
20238
20239
# File 'lib/google/apis/compute_v1/classes.rb', line 20237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#host_redirectString

The host that is used in the redirect response instead of the one that was supplied in the request. The value must be from 1 to 255 characters. Corresponds to the JSON property hostRedirect

Returns:

  • (String)


20177
20178
20179
# File 'lib/google/apis/compute_v1/classes.rb', line 20177

def host_redirect
  @host_redirect
end

#https_redirectBoolean Also known as: https_redirect?

If set to true, the URL scheme in the redirected request is set to HTTPS. If set to false, the URL scheme of the redirected request remains the same as that of the request. This must only be set for URL maps used inTargetHttpProxys. Setting this true forTargetHttpsProxy is not permitted. The default is set to false. Corresponds to the JSON property httpsRedirect

Returns:

  • (Boolean)


20188
20189
20190
# File 'lib/google/apis/compute_v1/classes.rb', line 20188

def https_redirect
  @https_redirect
end

#path_redirectString

The path that is used in the redirect response instead of the one that was supplied in the request. pathRedirect cannot be supplied together withprefixRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect. The value must be from 1 to 1024 characters. Corresponds to the JSON property pathRedirect

Returns:

  • (String)


20199
20200
20201
# File 'lib/google/apis/compute_v1/classes.rb', line 20199

def path_redirect
  @path_redirect
end

#prefix_redirectString

The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request. prefixRedirect cannot be supplied together withpathRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect. The value must be from 1 to 1024 characters. Corresponds to the JSON property prefixRedirect

Returns:

  • (String)


20210
20211
20212
# File 'lib/google/apis/compute_v1/classes.rb', line 20210

def prefix_redirect
  @prefix_redirect
end

#redirect_response_codeString

The HTTP Status code to use for this RedirectAction. Supported values are:

  • MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds to 301.
  • FOUND, which corresponds to 302.
  • SEE_OTHER which corresponds to 303.
  • TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request method is retained.
  • PERMANENT_REDIRECT, which corresponds to 308. In this case, the request method is retained. Corresponds to the JSON property redirectResponseCode

Returns:

  • (String)


20225
20226
20227
# File 'lib/google/apis/compute_v1/classes.rb', line 20225

def redirect_response_code
  @redirect_response_code
end

#strip_queryBoolean Also known as: strip_query?

If set to true, any accompanying query portion of the original URL is removed before redirecting the request. If set to false, the query portion of the original URL is retained. The default is set to false. Corresponds to the JSON property stripQuery

Returns:

  • (Boolean)


20234
20235
20236
# File 'lib/google/apis/compute_v1/classes.rb', line 20234

def strip_query
  @strip_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20242
20243
20244
20245
20246
20247
20248
20249
# File 'lib/google/apis/compute_v1/classes.rb', line 20242

def update!(**args)
  @host_redirect = args[:host_redirect] if args.key?(:host_redirect)
  @https_redirect = args[:https_redirect] if args.key?(:https_redirect)
  @path_redirect = args[:path_redirect] if args.key?(:path_redirect)
  @prefix_redirect = args[:prefix_redirect] if args.key?(:prefix_redirect)
  @redirect_response_code = args[:redirect_response_code] if args.key?(:redirect_response_code)
  @strip_query = args[:strip_query] if args.key?(:strip_query)
end