Class: Google::Apis::ComputeV1::HttpsHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpsHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HttpsHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpsHealthCheckList
constructor
A new instance of HttpsHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpsHealthCheckList
Returns a new instance of HttpsHealthCheckList.
21171 21172 21173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21139 21140 21141 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21139 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
Corresponds to the JSON property items
21144 21145 21146 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21144 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
21149 21150 21151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21149 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21159 21160 21161 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21159 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21164 21165 21166 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21164 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21169 21170 21171 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21169 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21176 21177 21178 21179 21180 21181 21182 21183 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21176 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |