Class: Google::Apis::ComputeV1::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
22286 22287 22288 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22247 22248 22249 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22247 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
22252 22253 22254 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22252 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
22259 22260 22261 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22259 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22269 22270 22271 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22269 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22274 22275 22276 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22274 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
22279 22280 22281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22279 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22284 22285 22286 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22284 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22291 22292 22293 22294 22295 22296 22297 22298 22299 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22291 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |