Class: Google::Apis::ComputeV1::InstanceFlexibilityPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A flexible specification of machine types for instances to create.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceFlexibilityPolicy

Returns a new instance of InstanceFlexibilityPolicy.



19286
19287
19288
# File 'lib/google/apis/compute_v1/classes.rb', line 19286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_selectionsHash<String,Google::Apis::ComputeV1::InstanceFlexibilityPolicyInstanceSelection>

Specification of alternative, flexible instance subsets. One of them will be selected to create the instances based on various criteria, like:

  • ranks,
  • location policy,
  • current capacity,
  • available reservations (you can specify affinity in InstanceProperties),
  • SWAN/GOOSE limitations. Key is an arbitrary, unique RFC1035 string that identifies the instance selection. Corresponds to the JSON property instanceSelections


19284
19285
19286
# File 'lib/google/apis/compute_v1/classes.rb', line 19284

def instance_selections
  @instance_selections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19291
19292
19293
# File 'lib/google/apis/compute_v1/classes.rb', line 19291

def update!(**args)
  @instance_selections = args[:instance_selections] if args.key?(:instance_selections)
end