Class: Google::Apis::ComputeV1::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



23345
23346
23347
# File 'lib/google/apis/compute_v1/classes.rb', line 23345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23306
23307
23308
# File 'lib/google/apis/compute_v1/classes.rb', line 23306

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



23311
23312
23313
# File 'lib/google/apis/compute_v1/classes.rb', line 23311

def items
  @items
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


23318
23319
23320
# File 'lib/google/apis/compute_v1/classes.rb', line 23318

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23328
23329
23330
# File 'lib/google/apis/compute_v1/classes.rb', line 23328

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23333
23334
23335
# File 'lib/google/apis/compute_v1/classes.rb', line 23333

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23338
23339
23340
# File 'lib/google/apis/compute_v1/classes.rb', line 23338

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagerAggregatedList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



23343
23344
23345
# File 'lib/google/apis/compute_v1/classes.rb', line 23343

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23350
23351
23352
23353
23354
23355
23356
23357
23358
# File 'lib/google/apis/compute_v1/classes.rb', line 23350

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end