Class: Google::Apis::ComputeV1::InstanceGroupManagerAutoHealingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerAutoHealingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#health_check ⇒ String
The URL for the health check that signals autohealing.
-
#initial_delay_sec ⇒ Fixnum
The initial delay is the number of seconds that a new VM takes to initialize and run its startup script.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerAutoHealingPolicy
constructor
A new instance of InstanceGroupManagerAutoHealingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerAutoHealingPolicy
Returns a new instance of InstanceGroupManagerAutoHealingPolicy.
19627 19628 19629 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_check ⇒ String
The URL for the health check that signals autohealing.
Corresponds to the JSON property healthCheck
19613 19614 19615 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19613 def health_check @health_check end |
#initial_delay_sec ⇒ Fixnum
The initial delay is the number of seconds that a new VM takes to
initialize and run its startup script. During a VM's initial delay
period, the MIG ignores unsuccessful health checks because the VM might
be in the startup process. This prevents the MIG from prematurely
recreating a VM. If the health check receives a healthy response during
the initial delay, it indicates that the startup process is complete and
the VM is ready. The value of initial delay must be between 0 and 3600
seconds. The default value is 0.
Corresponds to the JSON property initialDelaySec
19625 19626 19627 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19625 def initial_delay_sec @initial_delay_sec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19632 19633 19634 19635 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19632 def update!(**args) @health_check = args[:health_check] if args.key?(:health_check) @initial_delay_sec = args[:initial_delay_sec] if args.key?(:initial_delay_sec) end |