Class: Google::Apis::ComputeV1::InstanceGroupManagerInstanceLifecyclePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerInstanceLifecyclePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#default_action_on_failure ⇒ String
The action that a MIG performs on a failed or an unhealthy VM.
-
#force_update_on_repair ⇒ String
A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM.
-
#on_failed_health_check ⇒ String
The action that a MIG performs on an unhealthy VM.
-
#on_repair ⇒ Google::Apis::ComputeV1::InstanceGroupManagerInstanceLifecyclePolicyOnRepair
Configuration for VM repairs in the MIG.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerInstanceLifecyclePolicy
constructor
A new instance of InstanceGroupManagerInstanceLifecyclePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerInstanceLifecyclePolicy
Returns a new instance of InstanceGroupManagerInstanceLifecyclePolicy.
23200 23201 23202 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_action_on_failure ⇒ String
The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are
- REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG.
- DO_NOTHING: MIG does not repair a failed or an unhealthy
VM.
Corresponds to the JSON property
defaultActionOnFailure
23164 23165 23166 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23164 def default_action_on_failure @default_action_on_failure end |
#force_update_on_repair ⇒ String
A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:
NO (default): If configuration updates are available, they are not forcefully applied during repair. Instead, configuration updates are applied according to the group's update policy.
YES: If configuration updates are available, they are applied during repair. Corresponds to the JSON property
forceUpdateOnRepair
23178 23179 23180 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23178 def force_update_on_repair @force_update_on_repair end |
#on_failed_health_check ⇒ String
The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:
- DEFAULT_ACTION (default): MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.
- REPAIR: MIG automatically repairs an unhealthy VM by recreating it.
- DO_NOTHING: MIG doesn't repair an unhealthy VM.
For more information, see
About repairing VMs in a MIG.
Corresponds to the JSON property
onFailedHealthCheck
23193 23194 23195 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23193 def on_failed_health_check @on_failed_health_check end |
#on_repair ⇒ Google::Apis::ComputeV1::InstanceGroupManagerInstanceLifecyclePolicyOnRepair
Configuration for VM repairs in the MIG.
Corresponds to the JSON property onRepair
23198 23199 23200 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23198 def on_repair @on_repair end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23205 23206 23207 23208 23209 23210 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23205 def update!(**args) @default_action_on_failure = args[:default_action_on_failure] if args.key?(:default_action_on_failure) @force_update_on_repair = args[:force_update_on_repair] if args.key?(:force_update_on_repair) @on_failed_health_check = args[:on_failed_health_check] if args.key?(:on_failed_health_check) @on_repair = args[:on_repair] if args.key?(:on_repair) end |