Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Output only. Fatal errors encountered during the queueing or provisioning phases of the ResizeRequest that caused the transition to the FAILED state. Contrary to the last_attempt errors, this field is final and errors are never removed from here, as the ResizeRequest is not going to retry.

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



23550
23551
23552
# File 'lib/google/apis/compute_v1/classes.rb', line 23550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus::Error::Error>

[Output Only] The array of errors encountered while processing this operation. Corresponds to the JSON property errors



23548
23549
23550
# File 'lib/google/apis/compute_v1/classes.rb', line 23548

def errors
  @errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23555
23556
23557
# File 'lib/google/apis/compute_v1/classes.rb', line 23555

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
end