Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus::Error::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#error_details ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
20753 20754 20755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
20731 20732 20733 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20731 def code @code end |
#error_details ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error
details. There is a set of defined message types to use for providing
details.The syntax depends on the error code. For example,
QuotaExceededInfo will have details when the error code is
QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
20740 20741 20742 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20740 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
This property is optional.
Corresponds to the JSON property location
20746 20747 20748 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20746 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
20751 20752 20753 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20751 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20758 20759 20760 20761 20762 20763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20758 def update!(**args) @code = args[:code] if args.key?(:code) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |