Class: Google::Apis::ComputeV1::InstanceGroupManagerResourcePolicies
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerResourcePolicies
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#workload_policy ⇒ String
The URL of the workload policy that is specified for this managed instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResourcePolicies
constructor
A new instance of InstanceGroupManagerResourcePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResourcePolicies
Returns a new instance of InstanceGroupManagerResourcePolicies.
20410 20411 20412 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#workload_policy ⇒ String
The URL of the workload policy that is specified for this managed instance group. It can be a full or partial URL. For example, the following are all valid URLs to a workload policy:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ resourcePolicies/resourcePolicy
- projects/project/regions/region/resourcePolicies/resourcePolicy
- regions/region/resourcePolicies/resourcePolicy
Corresponds to the JSON property
workloadPolicy
20408 20409 20410 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20408 def workload_policy @workload_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20415 20416 20417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20415 def update!(**args) @workload_policy = args[:workload_policy] if args.key?(:workload_policy) end |