Class: Google::Apis::ComputeV1::InstanceGroupManagerStandbyPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStandbyPolicy

Returns a new instance of InstanceGroupManagerStandbyPolicy.



24343
24344
24345
# File 'lib/google/apis/compute_v1/classes.rb', line 24343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#initial_delay_secFixnum

Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created. The initial delay gives the initialization script the time to prepare your VM for a quick scale out. The value of initial delay must be between 0 and 3600 seconds. The default value is 0. Corresponds to the JSON property initialDelaySec

Returns:

  • (Fixnum)


24335
24336
24337
# File 'lib/google/apis/compute_v1/classes.rb', line 24335

def initial_delay_sec
  @initial_delay_sec
end

#modeString

Defines how a MIG resumes or starts VMs from a standby pool when the group scales out. The default mode is MANUAL. Corresponds to the JSON property mode

Returns:

  • (String)


24341
24342
24343
# File 'lib/google/apis/compute_v1/classes.rb', line 24341

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24348
24349
24350
24351
# File 'lib/google/apis/compute_v1/classes.rb', line 24348

def update!(**args)
  @initial_delay_sec = args[:initial_delay_sec] if args.key?(:initial_delay_sec)
  @mode = args[:mode] if args.key?(:mode)
end