Class: Google::Apis::ComputeV1::InstanceGroupManagerStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusAcceleratorTopology

Returns a new instance of InstanceGroupManagerStatusAcceleratorTopology.



24438
24439
24440
# File 'lib/google/apis/compute_v1/classes.rb', line 24438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


24425
24426
24427
# File 'lib/google/apis/compute_v1/classes.rb', line 24425

def accelerator_topology
  @accelerator_topology
end

#stateString

Output only. The state of the accelerator topology. Corresponds to the JSON property state

Returns:

  • (String)


24430
24431
24432
# File 'lib/google/apis/compute_v1/classes.rb', line 24430

def state
  @state
end

#state_detailsGoogle::Apis::ComputeV1::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails

Output only. The result of the latest accelerator topology state check. Corresponds to the JSON property stateDetails



24436
24437
24438
# File 'lib/google/apis/compute_v1/classes.rb', line 24436

def state_details
  @state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24443
24444
24445
24446
24447
# File 'lib/google/apis/compute_v1/classes.rb', line 24443

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
end