Class: Google::Apis::ComputeV1::InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck::Error::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a single error encountered during the processing of an operation.

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



24378
24379
24380
# File 'lib/google/apis/compute_v1/classes.rb', line 24378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


24356
24357
24358
# File 'lib/google/apis/compute_v1/classes.rb', line 24356

def code
  @code
end

#error_detailsArray<Google::Apis::ComputeV1::InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck::Error::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



24365
24366
24367
# File 'lib/google/apis/compute_v1/classes.rb', line 24365

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


24371
24372
24373
# File 'lib/google/apis/compute_v1/classes.rb', line 24371

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


24376
24377
24378
# File 'lib/google/apis/compute_v1/classes.rb', line 24376

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24383
24384
24385
24386
24387
24388
# File 'lib/google/apis/compute_v1/classes.rb', line 24383

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end