Class: Google::Apis::ComputeV1::InstanceGroupManagerStatusStateful
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerStatusStateful
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#has_stateful_config ⇒ Boolean
(also: #has_stateful_config?)
Output only.
-
#per_instance_configs ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusStatefulPerInstanceConfigs
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatusStateful
constructor
A new instance of InstanceGroupManagerStatusStateful.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatusStateful
Returns a new instance of InstanceGroupManagerStatusStateful.
20553 20554 20555 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#has_stateful_config ⇒ Boolean Also known as: has_stateful_config?
Output only. [Output Only] A bit indicating whether the managed instance group
has stateful configuration, that is, if you have configured any items
in a stateful policy or in per-instance configs.
The group might report that it has no stateful configuration even when
there is still some preserved state on a managed instance, for example,
if you have deleted all PICs but not yet applied those deletions.
Corresponds to the JSON property hasStatefulConfig
20544 20545 20546 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20544 def has_stateful_config @has_stateful_config end |
#per_instance_configs ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusStatefulPerInstanceConfigs
Output only. [Output Only] Status of per-instance configurations on the
instances.
Corresponds to the JSON property perInstanceConfigs
20551 20552 20553 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20551 def per_instance_configs @per_instance_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20558 20559 20560 20561 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20558 def update!(**args) @has_stateful_config = args[:has_stateful_config] if args.key?(:has_stateful_config) @per_instance_configs = args[:per_instance_configs] if args.key?(:per_instance_configs) end |