Class: Google::Apis::ComputeV1::InstanceGroupManagerTargetSizePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerTargetSizePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#mode ⇒ String
The mode of target size policy based on which the MIG creates its VMs individually or all at once.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerTargetSizePolicy
constructor
A new instance of InstanceGroupManagerTargetSizePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerTargetSizePolicy
Returns a new instance of InstanceGroupManagerTargetSizePolicy.
23926 23927 23928 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mode ⇒ String
The mode of target size policy based on which the MIG creates its VMs
individually or all at once.
Corresponds to the JSON property mode
23924 23925 23926 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23924 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23931 23932 23933 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23931 def update!(**args) @mode = args[:mode] if args.key?(:mode) end |