Class: Google::Apis::ComputeV1::InstanceGroupManagerUpdatePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerUpdatePolicy

Returns a new instance of InstanceGroupManagerUpdatePolicy.



25097
25098
25099
# File 'lib/google/apis/compute_v1/classes.rb', line 25097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_redistribution_typeString

The instance redistribution policy for regional managed instance groups. Valid values are:

  • PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region.
  • NONE: For non-autoscaled groups, proactive redistribution is disabled. Corresponds to the JSON property instanceRedistributionType

Returns:

  • (String)


25041
25042
25043
# File 'lib/google/apis/compute_v1/classes.rb', line 25041

def instance_redistribution_type
  @instance_redistribution_type
end

#max_surgeGoogle::Apis::ComputeV1::FixedOrPercent

Encapsulates numeric value that can be either absolute or relative. Corresponds to the JSON property maxSurge



25046
25047
25048
# File 'lib/google/apis/compute_v1/classes.rb', line 25046

def max_surge
  @max_surge
end

#max_unavailableGoogle::Apis::ComputeV1::FixedOrPercent

Encapsulates numeric value that can be either absolute or relative. Corresponds to the JSON property maxUnavailable



25051
25052
25053
# File 'lib/google/apis/compute_v1/classes.rb', line 25051

def max_unavailable
  @max_unavailable
end

#minimal_actionString

Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary.

  • To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update.
  • To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. Corresponds to the JSON property minimalAction

Returns:

  • (String)


25068
25069
25070
# File 'lib/google/apis/compute_v1/classes.rb', line 25068

def minimal_action
  @minimal_action
end

#most_disruptive_allowed_actionString

Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. Corresponds to the JSON property mostDisruptiveAllowedAction

Returns:

  • (String)


25080
25081
25082
# File 'lib/google/apis/compute_v1/classes.rb', line 25080

def most_disruptive_allowed_action
  @most_disruptive_allowed_action
end

#replacement_methodString

What action should be used to replace instances. See minimal_action.REPLACE Corresponds to the JSON property replacementMethod

Returns:

  • (String)


25086
25087
25088
# File 'lib/google/apis/compute_v1/classes.rb', line 25086

def replacement_method
  @replacement_method
end

#typeString

The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want to update. Corresponds to the JSON property type

Returns:

  • (String)


25095
25096
25097
# File 'lib/google/apis/compute_v1/classes.rb', line 25095

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25102
25103
25104
25105
25106
25107
25108
25109
25110
# File 'lib/google/apis/compute_v1/classes.rb', line 25102

def update!(**args)
  @instance_redistribution_type = args[:instance_redistribution_type] if args.key?(:instance_redistribution_type)
  @max_surge = args[:max_surge] if args.key?(:max_surge)
  @max_unavailable = args[:max_unavailable] if args.key?(:max_unavailable)
  @minimal_action = args[:minimal_action] if args.key?(:minimal_action)
  @most_disruptive_allowed_action = args[:most_disruptive_allowed_action] if args.key?(:most_disruptive_allowed_action)
  @replacement_method = args[:replacement_method] if args.key?(:replacement_method)
  @type = args[:type] if args.key?(:type)
end