Class: Google::Apis::ComputeV1::InstanceGroupManagerVersion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerVersion

Returns a new instance of InstanceGroupManagerVersion.



25140
25141
25142
# File 'lib/google/apis/compute_v1/classes.rb', line 25140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create new instances in the managed instance group until the targetSize for this version is reached. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group' supdatePolicy.type to PROACTIVE; in those cases, existing instances are updated until the targetSize for this version is reached. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


25127
25128
25129
# File 'lib/google/apis/compute_v1/classes.rb', line 25127

def instance_template
  @instance_template
end

#nameString

Name of the version. Unique among all versions in the scope of this managed instance group. Corresponds to the JSON property name

Returns:

  • (String)


25133
25134
25135
# File 'lib/google/apis/compute_v1/classes.rb', line 25133

def name
  @name
end

#target_sizeGoogle::Apis::ComputeV1::FixedOrPercent

Encapsulates numeric value that can be either absolute or relative. Corresponds to the JSON property targetSize



25138
25139
25140
# File 'lib/google/apis/compute_v1/classes.rb', line 25138

def target_size
  @target_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25145
25146
25147
25148
25149
# File 'lib/google/apis/compute_v1/classes.rb', line 25145

def update!(**args)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @name = args[:name] if args.key?(:name)
  @target_size = args[:target_size] if args.key?(:target_size)
end