Class: Google::Apis::ComputeV1::InstanceGroupManagersListPerInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersListPerInstanceConfigsResp

Returns a new instance of InstanceGroupManagersListPerInstanceConfigsResp.



25037
25038
25039
# File 'lib/google/apis/compute_v1/classes.rb', line 25037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeV1::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



25019
25020
25021
# File 'lib/google/apis/compute_v1/classes.rb', line 25019

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25030
25031
25032
# File 'lib/google/apis/compute_v1/classes.rb', line 25030

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagersListPerInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



25035
25036
25037
# File 'lib/google/apis/compute_v1/classes.rb', line 25035

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25042
25043
25044
25045
25046
# File 'lib/google/apis/compute_v1/classes.rb', line 25042

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end