Class: Google::Apis::ComputeV1::InstanceGroupManagersScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagersScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#instance_group_managers ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceGroupManagersScopedList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersScopedList
constructor
A new instance of InstanceGroupManagersScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersScopedList
Returns a new instance of InstanceGroupManagersScopedList.
25162 25163 25164 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_group_managers ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
Output only. The list of managed instance groups that are contained in the
specified
project and zone.
Corresponds to the JSON property instanceGroupManagers
25153 25154 25155 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25153 def instance_group_managers @instance_group_managers end |
#warning ⇒ Google::Apis::ComputeV1::InstanceGroupManagersScopedList::Warning
Output only. The warning that replaces the list of managed instance groups
when the list
is empty.
Corresponds to the JSON property warning
25160 25161 25162 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25160 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25167 25168 25169 25170 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25167 def update!(**args) @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers) @warning = args[:warning] if args.key?(:warning) end |