Class: Google::Apis::ComputeV1::InstanceGroupManagersSetTargetPoolsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersSetTargetPoolsRequest

Returns a new instance of InstanceGroupManagersSetTargetPoolsRequest.



25319
25320
25321
# File 'lib/google/apis/compute_v1/classes.rb', line 25319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

The fingerprint of the target pools information. Use this optional property to prevent conflicts when multiple users change the target pools settings concurrently. Obtain the fingerprint with theinstanceGroupManagers. get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


25309
25310
25311
# File 'lib/google/apis/compute_v1/classes.rb', line 25309

def fingerprint
  @fingerprint
end

#target_poolsArray<String>

The list of target pool URLs that instances in this managed instance group belong to. The managed instance group applies these target pools to all of the instances in the group. Existing instances and new instances in the group all receive these target pool settings. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


25317
25318
25319
# File 'lib/google/apis/compute_v1/classes.rb', line 25317

def target_pools
  @target_pools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25324
25325
25326
25327
# File 'lib/google/apis/compute_v1/classes.rb', line 25324

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
end