Class: Google::Apis::ComputeV1::InstanceGroupManagersStopInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagersStopInstancesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#force_stop ⇒ Boolean
(also: #force_stop?)
If this flag is set to true, the Instance Group Manager will proceed to stop the instances, skipping initialization on them.
-
#instances ⇒ Array<String>
The URLs of one or more instances to stop.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersStopInstancesRequest
constructor
A new instance of InstanceGroupManagersStopInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersStopInstancesRequest
Returns a new instance of InstanceGroupManagersStopInstancesRequest.
21323 21324 21325 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force_stop ⇒ Boolean Also known as: force_stop?
If this flag is set to true, the Instance Group Manager will proceed to
stop the instances, skipping initialization on them.
Corresponds to the JSON property forceStop
21314 21315 21316 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21314 def force_stop @force_stop end |
#instances ⇒ Array<String>
The URLs of one or more instances to stop. This can be a full URL or
a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
Corresponds to the JSON property instances
21321 21322 21323 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21321 def instances @instances end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21328 21329 21330 21331 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21328 def update!(**args) @force_stop = args[:force_stop] if args.key?(:force_stop) @instances = args[:instances] if args.key?(:instances) end |