Class: Google::Apis::ComputeV1::InstanceGroupsSetNamedPortsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest

Returns a new instance of InstanceGroupsSetNamedPortsRequest.



26105
26106
26107
# File 'lib/google/apis/compute_v1/classes.rb', line 26105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with theinstanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. A request with an incorrect fingerprint will fail with error412 conditionNotMet. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


26098
26099
26100
# File 'lib/google/apis/compute_v1/classes.rb', line 26098

def fingerprint
  @fingerprint
end

#named_portsArray<Google::Apis::ComputeV1::NamedPort>

The list of named ports to set for this instance group. Corresponds to the JSON property namedPorts



26103
26104
26105
# File 'lib/google/apis/compute_v1/classes.rb', line 26103

def named_ports
  @named_ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26110
26111
26112
26113
# File 'lib/google/apis/compute_v1/classes.rb', line 26110

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
end