Class: Google::Apis::ComputeV1::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



26281
26282
26283
# File 'lib/google/apis/compute_v1/classes.rb', line 26281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26248
26249
26250
# File 'lib/google/apis/compute_v1/classes.rb', line 26248

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Reference>

A list of Reference resources. Corresponds to the JSON property items



26253
26254
26255
# File 'lib/google/apis/compute_v1/classes.rb', line 26253

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


26259
26260
26261
# File 'lib/google/apis/compute_v1/classes.rb', line 26259

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26269
26270
26271
# File 'lib/google/apis/compute_v1/classes.rb', line 26269

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26274
26275
26276
# File 'lib/google/apis/compute_v1/classes.rb', line 26274

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



26279
26280
26281
# File 'lib/google/apis/compute_v1/classes.rb', line 26279

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26286
26287
26288
26289
26290
26291
26292
26293
# File 'lib/google/apis/compute_v1/classes.rb', line 26286

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end