Class: Google::Apis::ComputeV1::InstancePropertiesPatch

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents the change that you want to make to the instance properties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancePropertiesPatch

Returns a new instance of InstancePropertiesPatch.



23020
23021
23022
# File 'lib/google/apis/compute_v1/classes.rb', line 23020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

The label key-value pairs that you want to patch onto the instance. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


23011
23012
23013
# File 'lib/google/apis/compute_v1/classes.rb', line 23011

def labels
  @labels
end

#metadataHash<String,String>

The metadata key-value pairs that you want to patch onto the instance. For more information, see Project and instance metadata. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


23018
23019
23020
# File 'lib/google/apis/compute_v1/classes.rb', line 23018

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23025
23026
23027
23028
# File 'lib/google/apis/compute_v1/classes.rb', line 23025

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
end