Class: Google::Apis::ComputeV1::InstanceTemplatesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplatesScopedList

Returns a new instance of InstanceTemplatesScopedList.



27225
27226
27227
# File 'lib/google/apis/compute_v1/classes.rb', line 27225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_templatesArray<Google::Apis::ComputeV1::InstanceTemplate>

[Output Only] A list of instance templates that are contained within the specified project and zone. Corresponds to the JSON property instanceTemplates



27217
27218
27219
# File 'lib/google/apis/compute_v1/classes.rb', line 27217

def instance_templates
  @instance_templates
end

#warningGoogle::Apis::ComputeV1::InstanceTemplatesScopedList::Warning

[Output Only] An informational warning that replaces the list of instance templates when the list is empty. Corresponds to the JSON property warning



27223
27224
27225
# File 'lib/google/apis/compute_v1/classes.rb', line 27223

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27230
27231
27232
27233
# File 'lib/google/apis/compute_v1/classes.rb', line 27230

def update!(**args)
  @instance_templates = args[:instance_templates] if args.key?(:instance_templates)
  @warning = args[:warning] if args.key?(:warning)
end