Class: Google::Apis::ComputeV1::InstancesSetServiceAccountRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstancesSetServiceAccountRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#email ⇒ String
Email address of the service account.
-
#scopes ⇒ Array<String>
The list of scopes to be made available for this service account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesSetServiceAccountRequest
constructor
A new instance of InstancesSetServiceAccountRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesSetServiceAccountRequest
Returns a new instance of InstancesSetServiceAccountRequest.
15700 15701 15702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
Email address of the service account.
Corresponds to the JSON property email
15693 15694 15695 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15693 def email @email end |
#scopes ⇒ Array<String>
The list of scopes to be made available for this service account.
Corresponds to the JSON property scopes
15698 15699 15700 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15698 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15705 15706 15707 15708 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15705 def update!(**args) @email = args[:email] if args.key?(:email) @scopes = args[:scopes] if args.key?(:scopes) end |