Class: Google::Apis::ComputeV1::InstancesStartWithEncryptionKeyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstancesStartWithEncryptionKeyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeV1::CustomerEncryptionKeyProtectedDisk>
Array of disks associated with this instance that are protected with acustomer- supplied encryption key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesStartWithEncryptionKeyRequest
constructor
A new instance of InstancesStartWithEncryptionKeyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesStartWithEncryptionKeyRequest
Returns a new instance of InstancesStartWithEncryptionKeyRequest.
24092 24093 24094 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeV1::CustomerEncryptionKeyProtectedDisk>
Array of disks associated with this instance that are protected with acustomer-
supplied
encryption key.
In order to start the instance, the disk url and its corresponding key must
be provided.
If the disk is not protected with a customer-supplied encryption key it
should not be specified.
Corresponds to the JSON property disks
24090 24091 24092 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24090 def disks @disks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24097 24098 24099 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24097 def update!(**args) @disks = args[:disks] if args.key?(:disks) end |