Class: Google::Apis::ComputeV1::InstantSnapshotGroupParameters

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotGroupParameters

Returns a new instance of InstantSnapshotGroupParameters.



27928
27929
27930
# File 'lib/google/apis/compute_v1/classes.rb', line 27928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_instant_snapshot_groupString

The source instant snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


27926
27927
27928
# File 'lib/google/apis/compute_v1/classes.rb', line 27926

def source_instant_snapshot_group
  @source_instant_snapshot_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27933
27934
27935
# File 'lib/google/apis/compute_v1/classes.rb', line 27933

def update!(**args)
  @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group)
end