Class: Google::Apis::ComputeV1::InstantSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstantSnapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotList

Returns a new instance of InstantSnapshotList.



28391
28392
28393
# File 'lib/google/apis/compute_v1/classes.rb', line 28391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28359
28360
28361
# File 'lib/google/apis/compute_v1/classes.rb', line 28359

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstantSnapshot>

A list of InstantSnapshot resources. Corresponds to the JSON property items



28364
28365
28366
# File 'lib/google/apis/compute_v1/classes.rb', line 28364

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


28369
28370
28371
# File 'lib/google/apis/compute_v1/classes.rb', line 28369

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28379
28380
28381
# File 'lib/google/apis/compute_v1/classes.rb', line 28379

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28384
28385
28386
# File 'lib/google/apis/compute_v1/classes.rb', line 28384

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstantSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



28389
28390
28391
# File 'lib/google/apis/compute_v1/classes.rb', line 28389

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28396
28397
28398
28399
28400
28401
28402
28403
# File 'lib/google/apis/compute_v1/classes.rb', line 28396

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end