Class: Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnect

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration information for application awareness on this Cloud Interconnect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect

Returns a new instance of InterconnectApplicationAwareInterconnect.



28426
28427
28428
# File 'lib/google/apis/compute_v1/classes.rb', line 28426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bandwidth_percentage_policyGoogle::Apis::ComputeV1::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy

Corresponds to the JSON property bandwidthPercentagePolicy



28406
28407
28408
# File 'lib/google/apis/compute_v1/classes.rb', line 28406

def bandwidth_percentage_policy
  @bandwidth_percentage_policy
end

#profile_descriptionString

Description for the application awareness profile on this Cloud Interconnect. Corresponds to the JSON property profileDescription

Returns:

  • (String)


28412
28413
28414
# File 'lib/google/apis/compute_v1/classes.rb', line 28412

def profile_description
  @profile_description
end

#shape_average_percentagesArray<Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnectBandwidthPercentage>

Optional field to specify a list of shape average percentages to be applied in conjunction with StrictPriorityPolicy or BandwidthPercentagePolicy. Corresponds to the JSON property shapeAveragePercentages



28419
28420
28421
# File 'lib/google/apis/compute_v1/classes.rb', line 28419

def shape_average_percentages
  @shape_average_percentages
end

#strict_priority_policyGoogle::Apis::ComputeV1::InterconnectApplicationAwareInterconnectStrictPriorityPolicy

Specify configuration for StrictPriorityPolicy. Corresponds to the JSON property strictPriorityPolicy



28424
28425
28426
# File 'lib/google/apis/compute_v1/classes.rb', line 28424

def strict_priority_policy
  @strict_priority_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28431
28432
28433
28434
28435
28436
# File 'lib/google/apis/compute_v1/classes.rb', line 28431

def update!(**args)
  @bandwidth_percentage_policy = args[:bandwidth_percentage_policy] if args.key?(:bandwidth_percentage_policy)
  @profile_description = args[:profile_description] if args.key?(:profile_description)
  @shape_average_percentages = args[:shape_average_percentages] if args.key?(:shape_average_percentages)
  @strict_priority_policy = args[:strict_priority_policy] if args.key?(:strict_priority_policy)
end