Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupConfigured

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfigured

Returns a new instance of InterconnectAttachmentGroupConfigured.



25259
25260
25261
# File 'lib/google/apis/compute_v1/classes.rb', line 25259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_slaGoogle::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySla

[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements. Corresponds to the JSON property availabilitySla



25257
25258
25259
# File 'lib/google/apis/compute_v1/classes.rb', line 25257

def availability_sla
  @availability_sla
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25264
25265
25266
# File 'lib/google/apis/compute_v1/classes.rb', line 25264

def update!(**args)
  @availability_sla = args[:availability_sla] if args.key?(:availability_sla)
end