Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySla

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySla

Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySla.



29588
29589
29590
# File 'lib/google/apis/compute_v1/classes.rb', line 29588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_slaString

Corresponds to the JSON property effectiveSla

Returns:

  • (String)


29581
29582
29583
# File 'lib/google/apis/compute_v1/classes.rb', line 29581

def effective_sla
  @effective_sla
end

#intended_sla_blockersArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers>

Corresponds to the JSON property intendedSlaBlockers



29586
29587
29588
# File 'lib/google/apis/compute_v1/classes.rb', line 29586

def intended_sla_blockers
  @intended_sla_blockers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29593
29594
29595
29596
# File 'lib/google/apis/compute_v1/classes.rb', line 29593

def update!(**args)
  @effective_sla = args[:effective_sla] if args.key?(:effective_sla)
  @intended_sla_blockers = args[:intended_sla_blockers] if args.key?(:intended_sla_blockers)
end