Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



30071
30072
30073
# File 'lib/google/apis/compute_v1/classes.rb', line 30071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



30069
30070
30071
# File 'lib/google/apis/compute_v1/classes.rb', line 30069

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30076
30077
30078
# File 'lib/google/apis/compute_v1/classes.rb', line 30076

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end