Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetro

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] The metros of Attachments in this group in this region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro

Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.



30122
30123
30124
# File 'lib/google/apis/compute_v1/classes.rb', line 30122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilitiesArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>

Corresponds to the JSON property facilities



30113
30114
30115
# File 'lib/google/apis/compute_v1/classes.rb', line 30113

def facilities
  @facilities
end

#metroString

Output only. [Output Only] The name of the metro, as a three-letter lowercase string like "iad". This is the first component of the location of an Interconnect. Corresponds to the JSON property metro

Returns:

  • (String)


30120
30121
30122
# File 'lib/google/apis/compute_v1/classes.rb', line 30120

def metro
  @metro
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30127
30128
30129
30130
# File 'lib/google/apis/compute_v1/classes.rb', line 30127

def update!(**args)
  @facilities = args[:facilities] if args.key?(:facilities)
  @metro = args[:metro] if args.key?(:metro)
end