Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



30264
30265
30266
# File 'lib/google/apis/compute_v1/classes.rb', line 30264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


30220
30221
30222
# File 'lib/google/apis/compute_v1/classes.rb', line 30220

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30225
30226
30227
# File 'lib/google/apis/compute_v1/classes.rb', line 30225

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



30230
30231
30232
# File 'lib/google/apis/compute_v1/classes.rb', line 30230

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


30235
30236
30237
# File 'lib/google/apis/compute_v1/classes.rb', line 30235

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30245
30246
30247
# File 'lib/google/apis/compute_v1/classes.rb', line 30245

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30250
30251
30252
# File 'lib/google/apis/compute_v1/classes.rb', line 30250

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


30257
30258
30259
# File 'lib/google/apis/compute_v1/classes.rb', line 30257

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30262
30263
30264
# File 'lib/google/apis/compute_v1/classes.rb', line 30262

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30269
30270
30271
30272
30273
30274
30275
30276
30277
30278
# File 'lib/google/apis/compute_v1/classes.rb', line 30269

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end