Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The status of one Attachment in the group. List order is arbitrary.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Output only.
-
#attachment ⇒ String
Output only.
-
#is_active ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
constructor
A new instance of InterconnectAttachmentGroupsOperationalStatusAttachmentStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
Returns a new instance of InterconnectAttachmentGroupsOperationalStatusAttachmentStatus.
30430 30431 30432 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Output only. Whether this Attachment is enabled. This becomes false when the
customer
drains their Attachment.
Corresponds to the JSON property adminEnabled
30408 30409 30410 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30408 def admin_enabled @admin_enabled end |
#attachment ⇒ String
Output only. The URL of the Attachment being described.
Corresponds to the JSON property attachment
30414 30415 30416 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30414 def @attachment end |
#is_active ⇒ String
Output only. Whether this Attachment is participating in the redundant
configuration.
This will be ACTIVE if and only if the status below is CONNECTION_UP.
Any INACTIVE Attachments are excluded from the analysis that generates
operational.availabilitySLA.
Corresponds to the JSON property isActive
30423 30424 30425 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30423 def is_active @is_active end |
#status ⇒ String
Output only. Whether this Attachment is active, and if so, whether BGP is up.
Corresponds to the JSON property status
30428 30429 30430 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30428 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30435 30436 30437 30438 30439 30440 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30435 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @attachment = args[:attachment] if args.key?(:attachment) @is_active = args[:is_active] if args.key?(:is_active) @status = args[:status] if args.key?(:status) end |