Class: Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The inner VLAN-to-Appliance mapping.
Instance Attribute Summary collapse
-
#inner_appliance_ip_address ⇒ String
Required in this object.
-
#inner_vlan_tags ⇒ Array<String>
Required in this object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
constructor
A new instance of InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
Returns a new instance of InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping.
29963 29964 29965 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29963 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inner_appliance_ip_address ⇒ String
Required in this object. A single IPv4 or IPv6 address used as the
destination IP address for ingress packets that match on both VLAN
tags.
Corresponds to the JSON property innerApplianceIpAddress
29951 29952 29953 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29951 def inner_appliance_ip_address @inner_appliance_ip_address end |
#inner_vlan_tags ⇒ Array<String>
Required in this object. Used to match the inner VLAN tag on the
packet. Each entry can be a single number or a range of numbers in
the range of 1 to 4094, e.g., ["1", "4001-4094"] is valid. Non-empty
and Non-overlapping VLAN tag ranges are enforced, and violating
operations will be rejected.
The inner VLAN tags must have an ethertype value of 0x8100.
Corresponds to the JSON property innerVlanTags
29961 29962 29963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29961 def @inner_vlan_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29968 29969 29970 29971 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29968 def update!(**args) @inner_appliance_ip_address = args[:inner_appliance_ip_address] if args.key?(:inner_appliance_ip_address) @inner_vlan_tags = args[:inner_vlan_tags] if args.key?(:inner_vlan_tags) end |