Class: Google::Apis::ComputeV1::InterconnectAttachmentPrivateInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentPrivateInfo

Returns a new instance of InterconnectAttachmentPrivateInfo.



26122
26123
26124
# File 'lib/google/apis/compute_v1/classes.rb', line 26122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tag8021qFixnum

[Output Only] 802.1q encapsulation tag to be used for traffic between Google and the customer, going to and from this network and region. Corresponds to the JSON property tag8021q

Returns:

  • (Fixnum)


26120
26121
26122
# File 'lib/google/apis/compute_v1/classes.rb', line 26120

def tag8021q
  @tag8021q
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26127
26128
26129
# File 'lib/google/apis/compute_v1/classes.rb', line 26127

def update!(**args)
  @tag8021q = args[:tag8021q] if args.key?(:tag8021q)
end