Class: Google::Apis::ComputeV1::InterconnectAttachmentsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentsScopedList

Returns a new instance of InterconnectAttachmentsScopedList.



30823
30824
30825
# File 'lib/google/apis/compute_v1/classes.rb', line 30823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interconnect_attachmentsArray<Google::Apis::ComputeV1::InterconnectAttachment>

A list of interconnect attachments contained in this scope. Corresponds to the JSON property interconnectAttachments



30815
30816
30817
# File 'lib/google/apis/compute_v1/classes.rb', line 30815

def interconnect_attachments
  @interconnect_attachments
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentsScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



30821
30822
30823
# File 'lib/google/apis/compute_v1/classes.rb', line 30821

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30828
30829
30830
30831
# File 'lib/google/apis/compute_v1/classes.rb', line 30828

def update!(**args)
  @interconnect_attachments = args[:interconnect_attachments] if args.key?(:interconnect_attachments)
  @warning = args[:warning] if args.key?(:warning)
end