Class: Google::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus

Returns a new instance of InterconnectDiagnosticsLinkLacpStatus.



31035
31036
31037
# File 'lib/google/apis/compute_v1/classes.rb', line 31035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_system_idString

System ID of the port on Google's side of the LACP exchange. Corresponds to the JSON property googleSystemId

Returns:

  • (String)


31019
31020
31021
# File 'lib/google/apis/compute_v1/classes.rb', line 31019

def google_system_id
  @google_system_id
end

#neighbor_system_idString

System ID of the port on the neighbor's side of the LACP exchange. Corresponds to the JSON property neighborSystemId

Returns:

  • (String)


31024
31025
31026
# File 'lib/google/apis/compute_v1/classes.rb', line 31024

def neighbor_system_id
  @neighbor_system_id
end

#stateString

The state of a LACP link, which can take one of the following values:

  • ACTIVE: The link is configured and active within the bundle.
  • DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty. Corresponds to the JSON property state

Returns:

  • (String)


31033
31034
31035
# File 'lib/google/apis/compute_v1/classes.rb', line 31033

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31040
31041
31042
31043
31044
# File 'lib/google/apis/compute_v1/classes.rb', line 31040

def update!(**args)
  @google_system_id = args[:google_system_id] if args.key?(:google_system_id)
  @neighbor_system_id = args[:neighbor_system_id] if args.key?(:neighbor_system_id)
  @state = args[:state] if args.key?(:state)
end