Class: Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.
Instance Attribute Summary collapse
-
#blocker_type ⇒ String
Corresponds to the JSON property
blockerType. -
#documentation_link ⇒ String
Output only.
-
#explanation ⇒ String
Output only.
-
#facilities ⇒ Array<String>
Output only.
-
#interconnects ⇒ Array<String>
Output only.
-
#metros ⇒ Array<String>
Output only.
-
#zones ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
constructor
A new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
Returns a new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.
31024 31025 31026 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocker_type ⇒ String
Corresponds to the JSON property blockerType
30980 30981 30982 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30980 def blocker_type @blocker_type end |
#documentation_link ⇒ String
Output only. [Output Only] The url of Google Cloud public documentation
explaining
this requirement. This is set for every type of requirement.
Corresponds to the JSON property documentationLink
30987 30988 30989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30987 def documentation_link @documentation_link end |
#explanation ⇒ String
Output only. [Output Only] A human-readable explanation of this requirement
and
why it's not met. This is set for every type of requirement.
Corresponds to the JSON property explanation
30994 30995 30996 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30994 def explanation @explanation end |
#facilities ⇒ Array<String>
Output only. [Output Only] Facilities used to explain this blocker in more
detail.
Like physicalStructure.metros.facilities.facility, this is a numeric
string like "5467".
Corresponds to the JSON property facilities
31002 31003 31004 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31002 def facilities @facilities end |
#interconnects ⇒ Array<String>
Output only. [Output Only] Interconnects used to explain this blocker in more
detail.
Corresponds to the JSON property interconnects
31008 31009 31010 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31008 def interconnects @interconnects end |
#metros ⇒ Array<String>
Output only. [Output Only] Metros used to explain this blocker in more detail.
These are three-letter lowercase strings like "iad". A blocker like
INCOMPATIBLE_METROS will specify the problematic metros in this
field.
Corresponds to the JSON property metros
31016 31017 31018 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31016 def metros @metros end |
#zones ⇒ Array<String>
Output only. [Output Only] Zones used to explain this blocker in more detail.
Zone names are "zone1" and/or "zone2".
Corresponds to the JSON property zones
31022 31023 31024 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31022 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31029 31030 31031 31032 31033 31034 31035 31036 31037 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31029 def update!(**args) @blocker_type = args[:blocker_type] if args.key?(:blocker_type) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @explanation = args[:explanation] if args.key?(:explanation) @facilities = args[:facilities] if args.key?(:facilities) @interconnects = args[:interconnects] if args.key?(:interconnects) @metros = args[:metros] if args.key?(:metros) @zones = args[:zones] if args.key?(:zones) end |