Class: Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilities

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] The facilities Interconnects in this metro are present in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities

Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilities.



31102
31103
31104
# File 'lib/google/apis/compute_v1/classes.rb', line 31102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilityString

Output only. [Output Only] The ID of this facility, as a numeric string like "5467". This is the third component of the location of Interconnects in this facility. Corresponds to the JSON property facility

Returns:

  • (String)


31095
31096
31097
# File 'lib/google/apis/compute_v1/classes.rb', line 31095

def facility
  @facility
end

#zonesArray<Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>

Corresponds to the JSON property zones



31100
31101
31102
# File 'lib/google/apis/compute_v1/classes.rb', line 31100

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31107
31108
31109
31110
# File 'lib/google/apis/compute_v1/classes.rb', line 31107

def update!(**args)
  @facility = args[:facility] if args.key?(:facility)
  @zones = args[:zones] if args.key?(:zones)
end