Class: Google::Apis::ComputeV1::InterconnectGroupsCreateMembersInterconnectInput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsCreateMembersInterconnectInput

Returns a new instance of InterconnectGroupsCreateMembersInterconnectInput.



31686
31687
31688
# File 'lib/google/apis/compute_v1/classes.rb', line 31686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Administrative status of the interconnect. When this is set to true, the Interconnect is functional and can carry traffic. When set to false, no packets can be carried over the interconnect and no BGP routes are exchanged over it. By default, the status is set to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


31593
31594
31595
# File 'lib/google/apis/compute_v1/classes.rb', line 31593

def admin_enabled
  @admin_enabled
end

#customer_nameString

Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect. Corresponds to the JSON property customerName

Returns:

  • (String)


31600
31601
31602
# File 'lib/google/apis/compute_v1/classes.rb', line 31600

def customer_name
  @customer_name
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


31606
31607
31608
# File 'lib/google/apis/compute_v1/classes.rb', line 31606

def description
  @description
end

#facilityString

A zone-free location to use for all Interconnects created in this call, like "iad-1234". Corresponds to the JSON property facility

Returns:

  • (String)


31612
31613
31614
# File 'lib/google/apis/compute_v1/classes.rb', line 31612

def facility
  @facility
end

#interconnect_typeString

Type of interconnect, which can take one of the following values:

  • PARTNER: A partner-managed interconnection shared between customers though a partner.
  • DEDICATED: A dedicated physical interconnection with the customer. Note that a value IT_PRIVATE has been deprecated in favor of DEDICATED. Corresponds to the JSON property interconnectType

Returns:

  • (String)


31624
31625
31626
# File 'lib/google/apis/compute_v1/classes.rb', line 31624

def interconnect_type
  @interconnect_type
end

Type of link requested, which can take one of the following values:

  • LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics
  • LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics.
  • LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics. Note that this field indicates the speed of each of the links in the bundle, not the speed of the entire bundle. Corresponds to the JSON property linkType

Returns:

  • (String)


31636
31637
31638
# File 'lib/google/apis/compute_v1/classes.rb', line 31636

def link_type
  @link_type
end

#nameString

Name of the Interconnects to be created. This must be specified on the template and/or on each individual interconnect. The name, if not empty, must be 1-63 characters long, and comply with RFC1035. Specifically, any nonempty name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


31648
31649
31650
# File 'lib/google/apis/compute_v1/classes.rb', line 31648

def name
  @name
end

#noc_contact_emailString

Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect. If specified, this will be used for notifications in addition to all other forms described, such as Cloud Monitoring logs alerting and Cloud Notifications. This field is required for users who sign up for Cloud Interconnect using workforce identity federation. Corresponds to the JSON property nocContactEmail

Returns:

  • (String)


31658
31659
31660
# File 'lib/google/apis/compute_v1/classes.rb', line 31658

def noc_contact_email
  @noc_contact_email
end

#remote_locationString

Indicates that this is a Cross-Cloud Interconnect. This field specifies the location outside of Google's network that the interconnect is connected to. Corresponds to the JSON property remoteLocation

Returns:

  • (String)


31665
31666
31667
# File 'lib/google/apis/compute_v1/classes.rb', line 31665

def remote_location
  @remote_location
end

#requested_featuresArray<String>

Optional. List of features requested for this Interconnect connection, which can take one of the following values:

  • IF_MACSEC: If specified, then the connection is created on MACsec capable hardware ports. If not specified, non-MACsec capable ports will also be considered.
  • IF_CROSS_SITE_NETWORK: If specified, then the connection is created exclusively for Cross-Site Networking. The connection can not be used for Cross-Site Networking unless this feature is specified. Corresponds to the JSON property requestedFeatures

Returns:

  • (Array<String>)


31678
31679
31680
# File 'lib/google/apis/compute_v1/classes.rb', line 31678

def requested_features
  @requested_features
end

Target number of physical links in the link bundle, as requested by the customer. Corresponds to the JSON property requestedLinkCount

Returns:

  • (Fixnum)


31684
31685
31686
# File 'lib/google/apis/compute_v1/classes.rb', line 31684

def requested_link_count
  @requested_link_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31691
31692
31693
31694
31695
31696
31697
31698
31699
31700
31701
31702
31703
# File 'lib/google/apis/compute_v1/classes.rb', line 31691

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @customer_name = args[:customer_name] if args.key?(:customer_name)
  @description = args[:description] if args.key?(:description)
  @facility = args[:facility] if args.key?(:facility)
  @interconnect_type = args[:interconnect_type] if args.key?(:interconnect_type)
  @link_type = args[:link_type] if args.key?(:link_type)
  @name = args[:name] if args.key?(:name)
  @noc_contact_email = args[:noc_contact_email] if args.key?(:noc_contact_email)
  @remote_location = args[:remote_location] if args.key?(:remote_location)
  @requested_features = args[:requested_features] if args.key?(:requested_features)
  @requested_link_count = args[:requested_link_count] if args.key?(:requested_link_count)
end