Class: Google::Apis::ComputeV1::InterconnectGroupsGetOperationalStatusResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupsGetOperationalStatusResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response for the InterconnectGroupsGetOperationalStatusResponse.
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#result ⇒ Google::Apis::ComputeV1::InterconnectGroupsOperationalStatus
Request to get the status of the interconnect group with extra detail.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsGetOperationalStatusResponse
constructor
A new instance of InterconnectGroupsGetOperationalStatusResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsGetOperationalStatusResponse
Returns a new instance of InterconnectGroupsGetOperationalStatusResponse.
31143 31144 31145 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
31136 31137 31138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31136 def etag @etag end |
#result ⇒ Google::Apis::ComputeV1::InterconnectGroupsOperationalStatus
Request to get the status of the interconnect group with extra detail.
Corresponds to the JSON property result
31141 31142 31143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31141 def result @result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31148 31149 31150 31151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31148 def update!(**args) @etag = args[:etag] if args.key?(:etag) @result = args[:result] if args.key?(:result) end |