Class: Google::Apis::ComputeV1::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



31800
31801
31802
# File 'lib/google/apis/compute_v1/classes.rb', line 31800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


31757
31758
31759
# File 'lib/google/apis/compute_v1/classes.rb', line 31757

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31762
31763
31764
# File 'lib/google/apis/compute_v1/classes.rb', line 31762

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



31767
31768
31769
# File 'lib/google/apis/compute_v1/classes.rb', line 31767

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


31772
31773
31774
# File 'lib/google/apis/compute_v1/classes.rb', line 31772

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31782
31783
31784
# File 'lib/google/apis/compute_v1/classes.rb', line 31782

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31787
31788
31789
# File 'lib/google/apis/compute_v1/classes.rb', line 31787

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


31793
31794
31795
# File 'lib/google/apis/compute_v1/classes.rb', line 31793

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31798
31799
31800
# File 'lib/google/apis/compute_v1/classes.rb', line 31798

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31805
31806
31807
31808
31809
31810
31811
31812
31813
31814
# File 'lib/google/apis/compute_v1/classes.rb', line 31805

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end