Class: Google::Apis::ComputeV1::InterconnectLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationList

Returns a new instance of InterconnectLocationList.



32350
32351
32352
# File 'lib/google/apis/compute_v1/classes.rb', line 32350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32316
32317
32318
# File 'lib/google/apis/compute_v1/classes.rb', line 32316

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectLocation>

A list of InterconnectLocation resources. Corresponds to the JSON property items



32321
32322
32323
# File 'lib/google/apis/compute_v1/classes.rb', line 32321

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectLocationList for lists of interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


32328
32329
32330
# File 'lib/google/apis/compute_v1/classes.rb', line 32328

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32338
32339
32340
# File 'lib/google/apis/compute_v1/classes.rb', line 32338

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32343
32344
32345
# File 'lib/google/apis/compute_v1/classes.rb', line 32343

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32348
32349
32350
# File 'lib/google/apis/compute_v1/classes.rb', line 32348

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32355
32356
32357
32358
32359
32360
32361
32362
# File 'lib/google/apis/compute_v1/classes.rb', line 32355

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end