Class: Google::Apis::ComputeV1::InterconnectMacsecConfigPreSharedKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectMacsecConfigPreSharedKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Describes a pre-shared key used to setup MACsec in static connectivity association key (CAK) mode.
Instance Attribute Summary collapse
-
#cak ⇒ String
An auto-generated Connectivity Association Key (CAK) for this key.
-
#ckn ⇒ String
An auto-generated Connectivity Association Key Name (CKN) for this key.
-
#name ⇒ String
User provided name for this pre-shared key.
-
#start_time ⇒ String
User provided timestamp on or after which this key is valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectMacsecConfigPreSharedKey
constructor
A new instance of InterconnectMacsecConfigPreSharedKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectMacsecConfigPreSharedKey
Returns a new instance of InterconnectMacsecConfigPreSharedKey.
31961 31962 31963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cak ⇒ String
An auto-generated Connectivity Association Key (CAK) for this key.
Corresponds to the JSON property cak
31944 31945 31946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31944 def cak @cak end |
#ckn ⇒ String
An auto-generated Connectivity Association Key Name (CKN) for this key.
Corresponds to the JSON property ckn
31949 31950 31951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31949 def ckn @ckn end |
#name ⇒ String
User provided name for this pre-shared key.
Corresponds to the JSON property name
31954 31955 31956 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31954 def name @name end |
#start_time ⇒ String
User provided timestamp on or after which this key is valid.
Corresponds to the JSON property startTime
31959 31960 31961 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31959 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31966 31967 31968 31969 31970 31971 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31966 def update!(**args) @cak = args[:cak] if args.key?(:cak) @ckn = args[:ckn] if args.key?(:ckn) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |