Class: Google::Apis::ComputeV1::InterconnectMacsecPreSharedKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Describes a pre-shared key used to setup MACsec in static connectivity association key (CAK) mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectMacsecPreSharedKey

Returns a new instance of InterconnectMacsecPreSharedKey.



32009
32010
32011
# File 'lib/google/apis/compute_v1/classes.rb', line 32009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. A name for this pre-shared key. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


31997
31998
31999
# File 'lib/google/apis/compute_v1/classes.rb', line 31997

def name
  @name
end

#start_timeString

A RFC3339 timestamp on or after which the key is valid. startTime can be in the future. If the keychain has a single key, startTime can be omitted. If the keychain has multiple keys, startTime is mandatory for each key. The start times of keys must be in increasing order. The start times of two consecutive keys must be at least 6 hours apart. Corresponds to the JSON property startTime

Returns:

  • (String)


32007
32008
32009
# File 'lib/google/apis/compute_v1/classes.rb', line 32007

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32014
32015
32016
32017
# File 'lib/google/apis/compute_v1/classes.rb', line 32014

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
end