Class: Google::Apis::ComputeV1::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



33043
33044
33045
# File 'lib/google/apis/compute_v1/classes.rb', line 33043

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33009
33010
33011
# File 'lib/google/apis/compute_v1/classes.rb', line 33009

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



33014
33015
33016
# File 'lib/google/apis/compute_v1/classes.rb', line 33014

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


33021
33022
33023
# File 'lib/google/apis/compute_v1/classes.rb', line 33021

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33031
33032
33033
# File 'lib/google/apis/compute_v1/classes.rb', line 33031

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33036
33037
33038
# File 'lib/google/apis/compute_v1/classes.rb', line 33036

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33041
33042
33043
# File 'lib/google/apis/compute_v1/classes.rb', line 33041

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33048
33049
33050
33051
33052
33053
33054
33055
# File 'lib/google/apis/compute_v1/classes.rb', line 33048

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end