Class: Google::Apis::ComputeV1::LicenseResourceRequirements

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicenseResourceRequirements

Returns a new instance of LicenseResourceRequirements.



32447
32448
32449
# File 'lib/google/apis/compute_v1/classes.rb', line 32447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#min_guest_cpu_countFixnum

[Input Only] Deprecated. This field no longer reflects the minimum number of guest cpus required to use the Instance. Corresponds to the JSON property minGuestCpuCount

Returns:

  • (Fixnum)


32439
32440
32441
# File 'lib/google/apis/compute_v1/classes.rb', line 32439

def min_guest_cpu_count
  @min_guest_cpu_count
end

#min_memory_mbFixnum

[Input Only] Deprecated. This field no longer reflects the minimum memory required to use the Instance. Corresponds to the JSON property minMemoryMb

Returns:

  • (Fixnum)


32445
32446
32447
# File 'lib/google/apis/compute_v1/classes.rb', line 32445

def min_memory_mb
  @min_memory_mb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32452
32453
32454
32455
# File 'lib/google/apis/compute_v1/classes.rb', line 32452

def update!(**args)
  @min_guest_cpu_count = args[:min_guest_cpu_count] if args.key?(:min_guest_cpu_count)
  @min_memory_mb = args[:min_memory_mb] if args.key?(:min_memory_mb)
end