Class: Google::Apis::ComputeV1::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



33811
33812
33813
# File 'lib/google/apis/compute_v1/classes.rb', line 33811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33768
33769
33770
# File 'lib/google/apis/compute_v1/classes.rb', line 33768

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33773
33774
33775
# File 'lib/google/apis/compute_v1/classes.rb', line 33773

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



33778
33779
33780
# File 'lib/google/apis/compute_v1/classes.rb', line 33778

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


33783
33784
33785
# File 'lib/google/apis/compute_v1/classes.rb', line 33783

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33793
33794
33795
# File 'lib/google/apis/compute_v1/classes.rb', line 33793

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33798
33799
33800
# File 'lib/google/apis/compute_v1/classes.rb', line 33798

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33804
33805
33806
# File 'lib/google/apis/compute_v1/classes.rb', line 33804

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33809
33810
33811
# File 'lib/google/apis/compute_v1/classes.rb', line 33809

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33816
33817
33818
33819
33820
33821
33822
33823
33824
33825
# File 'lib/google/apis/compute_v1/classes.rb', line 33816

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end