Class: Google::Apis::ComputeV1::LocalDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalDisk

Returns a new instance of LocalDisk.



33908
33909
33910
# File 'lib/google/apis/compute_v1/classes.rb', line 33908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_countFixnum

Specifies the number of such disks. Corresponds to the JSON property diskCount

Returns:

  • (Fixnum)


33893
33894
33895
# File 'lib/google/apis/compute_v1/classes.rb', line 33893

def disk_count
  @disk_count
end

#disk_size_gbFixnum

Specifies the size of the disk in base-2 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


33898
33899
33900
# File 'lib/google/apis/compute_v1/classes.rb', line 33898

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Specifies the desired disk type on the node. This disk type must be a local storage type (e.g.: local-ssd). Note that for nodeTemplates, this should be the name of the disk type and not its URL. Corresponds to the JSON property diskType

Returns:

  • (String)


33906
33907
33908
# File 'lib/google/apis/compute_v1/classes.rb', line 33906

def disk_type
  @disk_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33913
33914
33915
33916
33917
# File 'lib/google/apis/compute_v1/classes.rb', line 33913

def update!(**args)
  @disk_count = args[:disk_count] if args.key?(:disk_count)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
end