Class: Google::Apis::ComputeV1::LocalizedMessage
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::LocalizedMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
Instance Attribute Summary collapse
-
#locale ⇒ String
The locale used following the specification defined at https://www.rfc-editor.org/rfc/bcp/bcp47.txt.
-
#message ⇒ String
The localized error message in the above locale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocalizedMessage
constructor
A new instance of LocalizedMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocalizedMessage
Returns a new instance of LocalizedMessage.
33937 33938 33939 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locale ⇒ String
The locale used following the specification defined at
https://www.rfc-editor.org/rfc/bcp/bcp47.txt.
Examples are: "en-US", "fr-CH", "es-MX"
Corresponds to the JSON property locale
33930 33931 33932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33930 def locale @locale end |
#message ⇒ String
The localized error message in the above locale.
Corresponds to the JSON property message
33935 33936 33937 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33935 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33942 33943 33944 33945 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33942 def update!(**args) @locale = args[:locale] if args.key?(:locale) @message = args[:message] if args.key?(:message) end |