Class: Google::Apis::ComputeV1::MachineImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of machine images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageList

Returns a new instance of MachineImageList.



34303
34304
34305
# File 'lib/google/apis/compute_v1/classes.rb', line 34303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34270
34271
34272
# File 'lib/google/apis/compute_v1/classes.rb', line 34270

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::MachineImage>

A list of MachineImage resources. Corresponds to the JSON property items



34275
34276
34277
# File 'lib/google/apis/compute_v1/classes.rb', line 34275

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImagesListResponse for machine image lists. Corresponds to the JSON property kind

Returns:

  • (String)


34281
34282
34283
# File 'lib/google/apis/compute_v1/classes.rb', line 34281

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34291
34292
34293
# File 'lib/google/apis/compute_v1/classes.rb', line 34291

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34296
34297
34298
# File 'lib/google/apis/compute_v1/classes.rb', line 34296

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::MachineImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34301
34302
34303
# File 'lib/google/apis/compute_v1/classes.rb', line 34301

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34308
34309
34310
34311
34312
34313
34314
34315
# File 'lib/google/apis/compute_v1/classes.rb', line 34308

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end