Class: Google::Apis::ComputeV1::ManagedInstanceLastAttempt::Errors

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Output only. [Output Only] Encountered errors during the last attempt to create or delete the instance.

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Errors

Returns a new instance of Errors.



34494
34495
34496
# File 'lib/google/apis/compute_v1/classes.rb', line 34494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::ComputeV1::ManagedInstanceLastAttempt::Errors::Error>

[Output Only] The array of errors encountered while processing this operation. Corresponds to the JSON property errors



34492
34493
34494
# File 'lib/google/apis/compute_v1/classes.rb', line 34492

def errors
  @errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34499
34500
34501
# File 'lib/google/apis/compute_v1/classes.rb', line 34499

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
end