Class: Google::Apis::ComputeV1::ManagedInstanceLastAttempt::Errors::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ManagedInstanceLastAttempt::Errors::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#error_details ⇒ Array<Google::Apis::ComputeV1::ManagedInstanceLastAttempt::Errors::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
34778 34779 34780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
34756 34757 34758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34756 def code @code end |
#error_details ⇒ Array<Google::Apis::ComputeV1::ManagedInstanceLastAttempt::Errors::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error
details. There is a set of defined message types to use for providing
details.The syntax depends on the error code. For example,
QuotaExceededInfo will have details when the error code is
QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
34765 34766 34767 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34765 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
This property is optional.
Corresponds to the JSON property location
34771 34772 34773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34771 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
34776 34777 34778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34776 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34783 34784 34785 34786 34787 34788 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34783 def update!(**args) @code = args[:code] if args.key?(:code) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |