Class: Google::Apis::ComputeV1::MetadataFilterLabelMatch

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

MetadataFilter label name value pairs that are expected to match corresponding labels presented as metadata to the load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetadataFilterLabelMatch

Returns a new instance of MetadataFilterLabelMatch.



34793
34794
34795
# File 'lib/google/apis/compute_v1/classes.rb', line 34793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of metadata label. The name can have a maximum length of 1024 characters and must be at least 1 character long. Corresponds to the JSON property name

Returns:

  • (String)


34785
34786
34787
# File 'lib/google/apis/compute_v1/classes.rb', line 34785

def name
  @name
end

#valueString

The value of the label must match the specified value. value can have a maximum length of 1024 characters. Corresponds to the JSON property value

Returns:

  • (String)


34791
34792
34793
# File 'lib/google/apis/compute_v1/classes.rb', line 34791

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34798
34799
34800
34801
# File 'lib/google/apis/compute_v1/classes.rb', line 34798

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end