Class: Google::Apis::ComputeV1::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



36190
36191
36192
# File 'lib/google/apis/compute_v1/classes.rb', line 36190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36158
36159
36160
# File 'lib/google/apis/compute_v1/classes.rb', line 36158

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



36163
36164
36165
# File 'lib/google/apis/compute_v1/classes.rb', line 36163

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


36168
36169
36170
# File 'lib/google/apis/compute_v1/classes.rb', line 36168

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36178
36179
36180
# File 'lib/google/apis/compute_v1/classes.rb', line 36178

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36183
36184
36185
# File 'lib/google/apis/compute_v1/classes.rb', line 36183

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36188
36189
36190
# File 'lib/google/apis/compute_v1/classes.rb', line 36188

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36195
36196
36197
36198
36199
36200
36201
36202
# File 'lib/google/apis/compute_v1/classes.rb', line 36195

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end