Class: Google::Apis::ComputeV1::NetworkEndpointGroupCloudFunction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupCloudFunction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask. Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#function ⇒ String
A user-defined name of the Cloud Function.
-
#url_mask ⇒ String
An URL mask is one of the main components of the Cloud Function.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupCloudFunction
constructor
A new instance of NetworkEndpointGroupCloudFunction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupCloudFunction
Returns a new instance of NetworkEndpointGroupCloudFunction.
32061 32062 32063 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#function ⇒ String
A user-defined name of the Cloud Function.
The function name is case-sensitive and must be 1-63
characters long.
Example value: func1.
Corresponds to the JSON property function
32045 32046 32047 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32045 def function @function end |
#url_mask ⇒ String
An URL
mask is one of the main components of the Cloud Function.
A template to parse function field from a request URL. URL
mask allows for routing to multiple Cloud Functions without having to
create multiple Network Endpoint Groups and backend services.
For example, request URLs mydomain.com/function1 andmydomain.com/function2 can
be backed by the same
Serverless NEG with URL mask /function = "function1" andfunction = "function2"
respectively.
Corresponds to the JSON property urlMask
32059 32060 32061 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32059 def url_mask @url_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32066 32067 32068 32069 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32066 def update!(**args) @function = args[:function] if args.key?(:function) @url_mask = args[:url_mask] if args.key?(:url_mask) end |