Class: Google::Apis::ComputeV1::NetworkEndpointGroupsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsScopedList

Returns a new instance of NetworkEndpointGroupsScopedList.



37077
37078
37079
# File 'lib/google/apis/compute_v1/classes.rb', line 37077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_endpoint_groupsArray<Google::Apis::ComputeV1::NetworkEndpointGroup>

Output only. [Output Only] The list ofnetwork endpoint groups that are contained in this scope. Corresponds to the JSON property networkEndpointGroups



37068
37069
37070
# File 'lib/google/apis/compute_v1/classes.rb', line 37068

def network_endpoint_groups
  @network_endpoint_groups
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupsScopedList::Warning

Output only. [Output Only] An informational warning that replaces the list of network endpoint groups when the list is empty. Corresponds to the JSON property warning



37075
37076
37077
# File 'lib/google/apis/compute_v1/classes.rb', line 37075

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37082
37083
37084
37085
# File 'lib/google/apis/compute_v1/classes.rb', line 37082

def update!(**args)
  @network_endpoint_groups = args[:network_endpoint_groups] if args.key?(:network_endpoint_groups)
  @warning = args[:warning] if args.key?(:warning)
end