Class: Google::Apis::ComputeV1::NetworkParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Additional network parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkParams

Returns a new instance of NetworkParams.



38215
38216
38217
# File 'lib/google/apis/compute_v1/classes.rb', line 38215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_manager_tagsHash<String,String>

Tag keys/values directly bound to this resource. Tag keys and values have the same definition as resource manager tags. The field is allowed for INSERT only. The keys/values to set on the resource should be specified in either ID : or Namespaced format :. For example the following are valid inputs:

  • "tagKeys/333" : "tagValues/444", "tagKeys/123" : "tagValues/456"
  • "123/environment" : "production", "345/abc" : "xyz" Note:
  • Invalid combinations of ID & namespaced format is not supported. For instance: "123/environment" : "tagValues/444" is invalid. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


38213
38214
38215
# File 'lib/google/apis/compute_v1/classes.rb', line 38213

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38220
38221
38222
# File 'lib/google/apis/compute_v1/classes.rb', line 38220

def update!(**args)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end