Class: Google::Apis::ComputeV1::NetworkPeeringConnectionStatusTrafficConfiguration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeeringConnectionStatusTrafficConfiguration

Returns a new instance of NetworkPeeringConnectionStatusTrafficConfiguration.



37925
37926
37927
# File 'lib/google/apis/compute_v1/classes.rb', line 37925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_custom_routes_to_peerBoolean Also known as: export_custom_routes_to_peer?

Whether custom routes are being exported to the peer network. Corresponds to the JSON property exportCustomRoutesToPeer

Returns:

  • (Boolean)


37896
37897
37898
# File 'lib/google/apis/compute_v1/classes.rb', line 37896

def export_custom_routes_to_peer
  @export_custom_routes_to_peer
end

#export_subnet_routes_with_public_ip_to_peerBoolean Also known as: export_subnet_routes_with_public_ip_to_peer?

Whether subnet routes with public IP ranges are being exported to the peer network. Corresponds to the JSON property exportSubnetRoutesWithPublicIpToPeer

Returns:

  • (Boolean)


37903
37904
37905
# File 'lib/google/apis/compute_v1/classes.rb', line 37903

def export_subnet_routes_with_public_ip_to_peer
  @export_subnet_routes_with_public_ip_to_peer
end

#import_custom_routes_from_peerBoolean Also known as: import_custom_routes_from_peer?

Whether custom routes are being imported from the peer network. Corresponds to the JSON property importCustomRoutesFromPeer

Returns:

  • (Boolean)


37909
37910
37911
# File 'lib/google/apis/compute_v1/classes.rb', line 37909

def import_custom_routes_from_peer
  @import_custom_routes_from_peer
end

#import_subnet_routes_with_public_ip_from_peerBoolean Also known as: import_subnet_routes_with_public_ip_from_peer?

Whether subnet routes with public IP ranges are being imported from the peer network. Corresponds to the JSON property importSubnetRoutesWithPublicIpFromPeer

Returns:

  • (Boolean)


37916
37917
37918
# File 'lib/google/apis/compute_v1/classes.rb', line 37916

def import_subnet_routes_with_public_ip_from_peer
  @import_subnet_routes_with_public_ip_from_peer
end

#stack_typeString

Which IP version(s) of traffic and routes are being imported or exported between peer networks. Corresponds to the JSON property stackType

Returns:

  • (String)


37923
37924
37925
# File 'lib/google/apis/compute_v1/classes.rb', line 37923

def stack_type
  @stack_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37930
37931
37932
37933
37934
37935
37936
# File 'lib/google/apis/compute_v1/classes.rb', line 37930

def update!(**args)
  @export_custom_routes_to_peer = args[:export_custom_routes_to_peer] if args.key?(:export_custom_routes_to_peer)
  @export_subnet_routes_with_public_ip_to_peer = args[:export_subnet_routes_with_public_ip_to_peer] if args.key?(:export_subnet_routes_with_public_ip_to_peer)
  @import_custom_routes_from_peer = args[:import_custom_routes_from_peer] if args.key?(:import_custom_routes_from_peer)
  @import_subnet_routes_with_public_ip_from_peer = args[:import_subnet_routes_with_public_ip_from_peer] if args.key?(:import_subnet_routes_with_public_ip_from_peer)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
end