Class: Google::Apis::ComputeV1::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
38960 38961 38962 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
38914 38915 38916 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38914 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38919 38920 38921 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38919 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
38924 38925 38926 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38924 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
38930 38931 38932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38930 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38942 38943 38944 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38942 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38947 38948 38949 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38947 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
38953 38954 38955 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38953 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38958 38959 38960 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38958 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38965 38966 38967 38968 38969 38970 38971 38972 38973 38974 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38965 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |