Class: Google::Apis::ComputeV1::NodeGroupsSetNodeTemplateRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroupsSetNodeTemplateRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#node_template ⇒ String
Full or partial URL of the node template resource to be updated for this node group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupsSetNodeTemplateRequest
constructor
A new instance of NodeGroupsSetNodeTemplateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupsSetNodeTemplateRequest
Returns a new instance of NodeGroupsSetNodeTemplateRequest.
35025 35026 35027 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#node_template ⇒ String
Full or partial URL of the node template resource to be updated for this
node group.
Corresponds to the JSON property nodeTemplate
35023 35024 35025 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35023 def node_template @node_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35030 35031 35032 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35030 def update!(**args) @node_template = args[:node_template] if args.key?(:node_template) end |