Class: Google::Apis::ComputeV1::NodeTemplate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represent a sole-tenant Node Template resource. You can use a template to define properties for nodes in a node group. For more information, readCreating node groups and instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplate

Returns a new instance of NodeTemplate.



40317
40318
40319
# File 'lib/google/apis/compute_v1/classes.rb', line 40317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ComputeV1::AcceleratorConfig>

Corresponds to the JSON property accelerators



40216
40217
40218
# File 'lib/google/apis/compute_v1/classes.rb', line 40216

def accelerators
  @accelerators
end

#cpu_overcommit_typeString

CPU overcommit. Corresponds to the JSON property cpuOvercommitType

Returns:

  • (String)


40221
40222
40223
# File 'lib/google/apis/compute_v1/classes.rb', line 40221

def cpu_overcommit_type
  @cpu_overcommit_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


40227
40228
40229
# File 'lib/google/apis/compute_v1/classes.rb', line 40227

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


40233
40234
40235
# File 'lib/google/apis/compute_v1/classes.rb', line 40233

def description
  @description
end

#disksArray<Google::Apis::ComputeV1::LocalDisk>

Corresponds to the JSON property disks



40238
40239
40240
# File 'lib/google/apis/compute_v1/classes.rb', line 40238

def disks
  @disks
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


40245
40246
40247
# File 'lib/google/apis/compute_v1/classes.rb', line 40245

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute# nodeTemplate for node templates. Corresponds to the JSON property kind

Returns:

  • (String)


40251
40252
40253
# File 'lib/google/apis/compute_v1/classes.rb', line 40251

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


40263
40264
40265
# File 'lib/google/apis/compute_v1/classes.rb', line 40263

def name
  @name
end

#node_affinity_labelsHash<String,String>

Labels to use for node affinity, which will be used in instance scheduling. Corresponds to the JSON property nodeAffinityLabels

Returns:

  • (Hash<String,String>)


40268
40269
40270
# File 'lib/google/apis/compute_v1/classes.rb', line 40268

def node_affinity_labels
  @node_affinity_labels
end

#node_typeString

The node type to use for nodes group that are created from this template. Corresponds to the JSON property nodeType

Returns:

  • (String)


40273
40274
40275
# File 'lib/google/apis/compute_v1/classes.rb', line 40273

def node_type
  @node_type
end

#node_type_flexibilityGoogle::Apis::ComputeV1::NodeTemplateNodeTypeFlexibility

Do not use. Instead, use the node_type property. Corresponds to the JSON property nodeTypeFlexibility



40278
40279
40280
# File 'lib/google/apis/compute_v1/classes.rb', line 40278

def node_type_flexibility
  @node_type_flexibility
end

#regionString

Output only. [Output Only] The name of the region where the node template resides, such as us-central1. Corresponds to the JSON property region

Returns:

  • (String)


40285
40286
40287
# File 'lib/google/apis/compute_v1/classes.rb', line 40285

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40290
40291
40292
# File 'lib/google/apis/compute_v1/classes.rb', line 40290

def self_link
  @self_link
end

#server_bindingGoogle::Apis::ComputeV1::ServerBinding

Sets the binding properties for the physical server. Valid values include:

  • [Default] RESTART_NODE_ON_ANY_SERVER: Restarts VMs on any available physical server
  • RESTART_NODE_ON_MINIMAL_SERVER: Restarts VMs on the same physical server whenever possible See Sole-tenant node options for more information. Corresponds to the JSON property serverBinding


40303
40304
40305
# File 'lib/google/apis/compute_v1/classes.rb', line 40303

def server_binding
  @server_binding
end

#statusString

Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. Corresponds to the JSON property status

Returns:

  • (String)


40309
40310
40311
# File 'lib/google/apis/compute_v1/classes.rb', line 40309

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


40315
40316
40317
# File 'lib/google/apis/compute_v1/classes.rb', line 40315

def status_message
  @status_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40322
40323
40324
40325
40326
40327
40328
40329
40330
40331
40332
40333
40334
40335
40336
40337
40338
40339
# File 'lib/google/apis/compute_v1/classes.rb', line 40322

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @cpu_overcommit_type = args[:cpu_overcommit_type] if args.key?(:cpu_overcommit_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @node_affinity_labels = args[:node_affinity_labels] if args.key?(:node_affinity_labels)
  @node_type = args[:node_type] if args.key?(:node_type)
  @node_type_flexibility = args[:node_type_flexibility] if args.key?(:node_type_flexibility)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @server_binding = args[:server_binding] if args.key?(:server_binding)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
end