Class: Google::Apis::ComputeV1::NodeType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeType

Returns a new instance of NodeType.



40820
40821
40822
# File 'lib/google/apis/compute_v1/classes.rb', line 40820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpu_platformString

[Output Only] The CPU platform used by this node type. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


40751
40752
40753
# File 'lib/google/apis/compute_v1/classes.rb', line 40751

def cpu_platform
  @cpu_platform
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


40757
40758
40759
# File 'lib/google/apis/compute_v1/classes.rb', line 40757

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeV1::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



40762
40763
40764
# File 'lib/google/apis/compute_v1/classes.rb', line 40762

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


40767
40768
40769
# File 'lib/google/apis/compute_v1/classes.rb', line 40767

def description
  @description
end

#guest_cpusFixnum

[Output Only] The number of virtual CPUs that are available to the node type. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


40773
40774
40775
# File 'lib/google/apis/compute_v1/classes.rb', line 40773

def guest_cpus
  @guest_cpus
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


40779
40780
40781
# File 'lib/google/apis/compute_v1/classes.rb', line 40779

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#nodeType for node types. Corresponds to the JSON property kind

Returns:

  • (String)


40785
40786
40787
# File 'lib/google/apis/compute_v1/classes.rb', line 40785

def kind
  @kind
end

#local_ssd_gbFixnum

[Output Only] Local SSD available to the node type, defined in GB. Corresponds to the JSON property localSsdGb

Returns:

  • (Fixnum)


40790
40791
40792
# File 'lib/google/apis/compute_v1/classes.rb', line 40790

def local_ssd_gb
  @local_ssd_gb
end

#max_vmsFixnum

Output only. [Output Only] Maximum number of VMs that can be created for this node type. Corresponds to the JSON property maxVms

Returns:

  • (Fixnum)


40796
40797
40798
# File 'lib/google/apis/compute_v1/classes.rb', line 40796

def max_vms
  @max_vms
end

#memory_mbFixnum

[Output Only] The amount of physical memory available to the node type, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


40802
40803
40804
# File 'lib/google/apis/compute_v1/classes.rb', line 40802

def memory_mb
  @memory_mb
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


40807
40808
40809
# File 'lib/google/apis/compute_v1/classes.rb', line 40807

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40812
40813
40814
# File 'lib/google/apis/compute_v1/classes.rb', line 40812

def self_link
  @self_link
end

#zoneString

Output only. [Output Only] The name of the zone where the node type resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


40818
40819
40820
# File 'lib/google/apis/compute_v1/classes.rb', line 40818

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40825
40826
40827
40828
40829
40830
40831
40832
40833
40834
40835
40836
40837
40838
40839
# File 'lib/google/apis/compute_v1/classes.rb', line 40825

def update!(**args)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb)
  @max_vms = args[:max_vms] if args.key?(:max_vms)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @zone = args[:zone] if args.key?(:zone)
end