Class: Google::Apis::ComputeV1::Operation::Error::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



37401
37402
37403
# File 'lib/google/apis/compute_v1/classes.rb', line 37401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


37379
37380
37381
# File 'lib/google/apis/compute_v1/classes.rb', line 37379

def code
  @code
end

#error_detailsArray<Google::Apis::ComputeV1::Operation::Error::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



37388
37389
37390
# File 'lib/google/apis/compute_v1/classes.rb', line 37388

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


37394
37395
37396
# File 'lib/google/apis/compute_v1/classes.rb', line 37394

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


37399
37400
37401
# File 'lib/google/apis/compute_v1/classes.rb', line 37399

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37406
37407
37408
37409
37410
37411
# File 'lib/google/apis/compute_v1/classes.rb', line 37406

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end