Class: Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo

Returns a new instance of PacketMirroringMirroredResourceInfo.



43130
43131
43132
# File 'lib/google/apis/compute_v1/classes.rb', line 43130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfoInstanceInfo>

A set of virtual machine instances that are being mirrored. They must live in zones contained in the same region as this packetMirroring. Note that this config will apply only to those network interfaces of the Instances that belong to the network specified in this packetMirroring. You may specify a maximum of 50 Instances. Corresponds to the JSON property instances



43115
43116
43117
# File 'lib/google/apis/compute_v1/classes.rb', line 43115

def instances
  @instances
end

#subnetworksArray<Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfoSubnetInfo>

A set of subnetworks for which traffic from/to all VM instances will be mirrored. They must live in the same region as this packetMirroring. You may specify a maximum of 5 subnetworks. Corresponds to the JSON property subnetworks



43122
43123
43124
# File 'lib/google/apis/compute_v1/classes.rb', line 43122

def subnetworks
  @subnetworks
end

#tagsArray<String>

A set of mirrored tags. Traffic from/to all VM instances that have one or more of these tags will be mirrored. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


43128
43129
43130
# File 'lib/google/apis/compute_v1/classes.rb', line 43128

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43135
43136
43137
43138
43139
# File 'lib/google/apis/compute_v1/classes.rb', line 43135

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
  @tags = args[:tags] if args.key?(:tags)
end