Class: Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfoInstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfoInstanceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#canonical_url ⇒ String
Output only.
-
#url ⇒ String
Resource URL to the virtual machine instance which is being mirrored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfoInstanceInfo
constructor
A new instance of PacketMirroringMirroredResourceInfoInstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfoInstanceInfo
Returns a new instance of PacketMirroringMirroredResourceInfoInstanceInfo.
41806 41807 41808 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_url ⇒ String
Output only. [Output Only] Unique identifier for the instance; defined by the
server.
Corresponds to the JSON property canonicalUrl
41799 41800 41801 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41799 def canonical_url @canonical_url end |
#url ⇒ String
Resource URL to the virtual machine instance which is being mirrored.
Corresponds to the JSON property url
41804 41805 41806 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41804 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41811 41812 41813 41814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41811 def update!(**args) @canonical_url = args[:canonical_url] if args.key?(:canonical_url) @url = args[:url] if args.key?(:url) end |