Class: Google::Apis::ComputeV1::PerInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PerInstanceConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Fingerprint of this per-instance config.
-
#name ⇒ String
The name of a per-instance configuration and its corresponding instance.
-
#preserved_state ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
-
#status ⇒ String
The status of applying this per-instance configuration on the corresponding managed instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PerInstanceConfig
constructor
A new instance of PerInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PerInstanceConfig
Returns a new instance of PerInstanceConfig.
43518 43519 43520 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Fingerprint of this per-instance config. This field can be used in
optimistic locking. It is ignored when inserting a per-instance
config. An up-to-date fingerprint must be provided in order to update an
existing per-instance configuration or the field needs to be unset.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
43494 43495 43496 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43494 def fingerprint @fingerprint end |
#name ⇒ String
The name of a per-instance configuration and its corresponding instance.
Serves as a merge key during UpdatePerInstanceConfigs
operations, that is, if a per-instance configuration with the same name
exists then it will be updated, otherwise a new one will be created for the
VM instance with the same name. An attempt to create a per-instance
configuration for a VM instance that either doesn't exist or is not part
of the group will result in an error.
Corresponds to the JSON property name
43505 43506 43507 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43505 def name @name end |
#preserved_state ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedState
43510 43511 43512 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43510 def preserved_state @preserved_state end |
#status ⇒ String
The status of applying this per-instance configuration on the corresponding
managed instance.
Corresponds to the JSON property status
43516 43517 43518 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43516 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43523 43524 43525 43526 43527 43528 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43523 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @preserved_state = args[:preserved_state] if args.key?(:preserved_state) @status = args[:status] if args.key?(:status) end |