Class: Google::Apis::ComputeV1::PreservedStatePreservedNetworkIpIpAddress
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreservedStatePreservedNetworkIpIpAddress
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#address ⇒ String
The URL of the reservation for this IP address.
-
#literal ⇒ String
An IPv4 internal network address to assign to the instance for this network interface.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedStatePreservedNetworkIpIpAddress
constructor
A new instance of PreservedStatePreservedNetworkIpIpAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedStatePreservedNetworkIpIpAddress
Returns a new instance of PreservedStatePreservedNetworkIpIpAddress.
42472 42473 42474 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42472 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The URL of the reservation for this IP address.
Corresponds to the JSON property address
42464 42465 42466 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42464 def address @address end |
#literal ⇒ String
An IPv4 internal network address to assign to the instance for this
network interface.
Corresponds to the JSON property literal
42470 42471 42472 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42470 def literal @literal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42477 42478 42479 42480 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42477 def update!(**args) @address = args[:address] if args.key?(:address) @literal = args[:literal] if args.key?(:literal) end |