Class: Google::Apis::ComputeV1::PreviewFeatureStatusReleaseStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] The release status of the feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureStatusReleaseStatus

Returns a new instance of PreviewFeatureStatusReleaseStatus.



44224
44225
44226
# File 'lib/google/apis/compute_v1/classes.rb', line 44224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stageString

Output only. [Output Only] The stage of the feature. Corresponds to the JSON property stage

Returns:

  • (String)


44205
44206
44207
# File 'lib/google/apis/compute_v1/classes.rb', line 44205

def stage
  @stage
end

#update_dateGoogle::Apis::ComputeV1::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:

  • A full date, with non-zero year, month, and day values.
  • A month and day, with a zero year (for example, an anniversary).
  • A year on its own, with a zero month and a zero day.
  • A year and month, with a zero day (for example, a credit card expiration date). Related types:
  • google.type.TimeOfDay
  • google.type.DateTime
  • google.protobuf.Timestamp Corresponds to the JSON property updateDate


44222
44223
44224
# File 'lib/google/apis/compute_v1/classes.rb', line 44222

def update_date
  @update_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44229
44230
44231
44232
# File 'lib/google/apis/compute_v1/classes.rb', line 44229

def update!(**args)
  @stage = args[:stage] if args.key?(:stage)
  @update_date = args[:update_date] if args.key?(:update_date)
end