Class: Google::Apis::ComputeV1::Project

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Project

Returns a new instance of Project.



44320
44321
44322
# File 'lib/google/apis/compute_v1/classes.rb', line 44320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_armor_tierString

Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to beCA_STANDARD. Corresponds to the JSON property cloudArmorTier

Returns:

  • (String)


44236
44237
44238
# File 'lib/google/apis/compute_v1/classes.rb', line 44236

def cloud_armor_tier
  @cloud_armor_tier
end

#common_instance_metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property commonInstanceMetadata



44241
44242
44243
# File 'lib/google/apis/compute_v1/classes.rb', line 44241

def 
  @common_instance_metadata
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


44247
44248
44249
# File 'lib/google/apis/compute_v1/classes.rb', line 44247

def creation_timestamp
  @creation_timestamp
end

#default_network_tierString

This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Corresponds to the JSON property defaultNetworkTier

Returns:

  • (String)


44255
44256
44257
# File 'lib/google/apis/compute_v1/classes.rb', line 44255

def default_network_tier
  @default_network_tier
end

#default_service_accountString

[Output Only] Default service account used by VMs running in this project. Corresponds to the JSON property defaultServiceAccount

Returns:

  • (String)


44260
44261
44262
# File 'lib/google/apis/compute_v1/classes.rb', line 44260

def 
  @default_service_account
end

#descriptionString

An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


44265
44266
44267
# File 'lib/google/apis/compute_v1/classes.rb', line 44265

def description
  @description
end

#enabled_featuresArray<String>

An optional list of restricted features enabled for use on this project. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


44270
44271
44272
# File 'lib/google/apis/compute_v1/classes.rb', line 44270

def enabled_features
  @enabled_features
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources. Corresponds to the JSON property id

Returns:

  • (Fixnum)


44277
44278
44279
# File 'lib/google/apis/compute_v1/classes.rb', line 44277

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#project for projects. Corresponds to the JSON property kind

Returns:

  • (String)


44283
44284
44285
# File 'lib/google/apis/compute_v1/classes.rb', line 44283

def kind
  @kind
end

#nameString

The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine. Corresponds to the JSON property name

Returns:

  • (String)


44289
44290
44291
# File 'lib/google/apis/compute_v1/classes.rb', line 44289

def name
  @name
end

#quotasArray<Google::Apis::ComputeV1::Quota>

[Output Only] Quotas assigned to this project. Corresponds to the JSON property quotas

Returns:



44294
44295
44296
# File 'lib/google/apis/compute_v1/classes.rb', line 44294

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44299
44300
44301
# File 'lib/google/apis/compute_v1/classes.rb', line 44299

def self_link
  @self_link
end

#usage_export_locationGoogle::Apis::ComputeV1::UsageExportLocation

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix. Corresponds to the JSON property usageExportLocation



44305
44306
44307
# File 'lib/google/apis/compute_v1/classes.rb', line 44305

def usage_export_location
  @usage_export_location
end

#vm_dns_settingString

Output only. [Output Only] Default internal DNS setting used by VMs running in this project. Corresponds to the JSON property vmDnsSetting

Returns:

  • (String)


44311
44312
44313
# File 'lib/google/apis/compute_v1/classes.rb', line 44311

def vm_dns_setting
  @vm_dns_setting
end

#xpn_project_statusString

[Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Corresponds to the JSON property xpnProjectStatus

Returns:

  • (String)


44318
44319
44320
# File 'lib/google/apis/compute_v1/classes.rb', line 44318

def xpn_project_status
  @xpn_project_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44325
44326
44327
44328
44329
44330
44331
44332
44333
44334
44335
44336
44337
44338
44339
44340
44341
# File 'lib/google/apis/compute_v1/classes.rb', line 44325

def update!(**args)
  @cloud_armor_tier = args[:cloud_armor_tier] if args.key?(:cloud_armor_tier)
  @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier)
  @default_service_account = args[:default_service_account] if args.key?(:default_service_account)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location)
  @vm_dns_setting = args[:vm_dns_setting] if args.key?(:vm_dns_setting)
  @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status)
end