Class: Google::Apis::ComputeV1::PublicAdvertisedPrefixPublicDelegatedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a CIDR range which can be used to assign addresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix

Returns a new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.



44434
44435
44436
# File 'lib/google/apis/compute_v1/classes.rb', line 44434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_rangeString

The IP address range of the public delegated prefix Corresponds to the JSON property ipRange

Returns:

  • (String)


44408
44409
44410
# File 'lib/google/apis/compute_v1/classes.rb', line 44408

def ip_range
  @ip_range
end

#nameString

The name of the public delegated prefix Corresponds to the JSON property name

Returns:

  • (String)


44413
44414
44415
# File 'lib/google/apis/compute_v1/classes.rb', line 44413

def name
  @name
end

#projectString

The project number of the public delegated prefix Corresponds to the JSON property project

Returns:

  • (String)


44418
44419
44420
# File 'lib/google/apis/compute_v1/classes.rb', line 44418

def project
  @project
end

#regionString

The region of the public delegated prefix if it is regional. If absent, the prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


44424
44425
44426
# File 'lib/google/apis/compute_v1/classes.rb', line 44424

def region
  @region
end

#statusString

The status of the public delegated prefix. Possible values are: INITIALIZING: The public delegated prefix is being initialized and addresses cannot be created yet. ANNOUNCED: The public delegated prefix is active. Corresponds to the JSON property status

Returns:

  • (String)


44432
44433
44434
# File 'lib/google/apis/compute_v1/classes.rb', line 44432

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44439
44440
44441
44442
44443
44444
44445
# File 'lib/google/apis/compute_v1/classes.rb', line 44439

def update!(**args)
  @ip_range = args[:ip_range] if args.key?(:ip_range)
  @name = args[:name] if args.key?(:name)
  @project = args[:project] if args.key?(:project)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end