Class: Google::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



45027
45028
45029
# File 'lib/google/apis/compute_v1/classes.rb', line 45027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44988
44989
44990
# File 'lib/google/apis/compute_v1/classes.rb', line 44988

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



44993
44994
44995
# File 'lib/google/apis/compute_v1/classes.rb', line 44993

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


45000
45001
45002
# File 'lib/google/apis/compute_v1/classes.rb', line 45000

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45010
45011
45012
# File 'lib/google/apis/compute_v1/classes.rb', line 45010

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45015
45016
45017
# File 'lib/google/apis/compute_v1/classes.rb', line 45015

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


45020
45021
45022
# File 'lib/google/apis/compute_v1/classes.rb', line 45020

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45025
45026
45027
# File 'lib/google/apis/compute_v1/classes.rb', line 45025

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45032
45033
45034
45035
45036
45037
45038
45039
45040
# File 'lib/google/apis/compute_v1/classes.rb', line 45032

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end