Class: Google::Apis::ComputeV1::QuotaExceededInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Additional details for quota exceeded error for resource quota.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaExceededInfo

Returns a new instance of QuotaExceededInfo.



44958
44959
44960
# File 'lib/google/apis/compute_v1/classes.rb', line 44958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsHash<String,String>

The map holding related quota dimensions. Corresponds to the JSON property dimensions

Returns:

  • (Hash<String,String>)


44929
44930
44931
# File 'lib/google/apis/compute_v1/classes.rb', line 44929

def dimensions
  @dimensions
end

#future_limitFloat

Future quota limit being rolled out. The limit's unit depends on the quota type or metric. Corresponds to the JSON property futureLimit

Returns:

  • (Float)


44935
44936
44937
# File 'lib/google/apis/compute_v1/classes.rb', line 44935

def future_limit
  @future_limit
end

#limitFloat

Current effective quota limit. The limit's unit depends on the quota type or metric. Corresponds to the JSON property limit

Returns:

  • (Float)


44941
44942
44943
# File 'lib/google/apis/compute_v1/classes.rb', line 44941

def limit
  @limit
end

#limit_nameString

The name of the quota limit. Corresponds to the JSON property limitName

Returns:

  • (String)


44946
44947
44948
# File 'lib/google/apis/compute_v1/classes.rb', line 44946

def limit_name
  @limit_name
end

#metric_nameString

The Compute Engine quota metric name. Corresponds to the JSON property metricName

Returns:

  • (String)


44951
44952
44953
# File 'lib/google/apis/compute_v1/classes.rb', line 44951

def metric_name
  @metric_name
end

#rollout_statusString

Rollout status of the future quota limit. Corresponds to the JSON property rolloutStatus

Returns:

  • (String)


44956
44957
44958
# File 'lib/google/apis/compute_v1/classes.rb', line 44956

def rollout_status
  @rollout_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44963
44964
44965
44966
44967
44968
44969
44970
# File 'lib/google/apis/compute_v1/classes.rb', line 44963

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @future_limit = args[:future_limit] if args.key?(:future_limit)
  @limit = args[:limit] if args.key?(:limit)
  @limit_name = args[:limit_name] if args.key?(:limit_name)
  @metric_name = args[:metric_name] if args.key?(:metric_name)
  @rollout_status = args[:rollout_status] if args.key?(:rollout_status)
end