Class: Google::Apis::ComputeV1::Reference
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Reference
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reference to a resource.
Instance Attribute Summary collapse
-
#kind ⇒ String
Output only.
-
#reference_type ⇒ String
A description of the reference type with no implied semantics.
-
#referrer ⇒ String
URL of the resource which refers to the target.
-
#target ⇒ String
URL of the resource to which this reference points.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reference
constructor
A new instance of Reference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reference
Returns a new instance of Reference.
45179 45180 45181 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45179 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#reference
for references.
Corresponds to the JSON property kind
45158 45159 45160 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45158 def kind @kind end |
#reference_type ⇒ String
A description of the reference type with no implied semantics. Possible values include:
- MEMBER_OF
Corresponds to the JSON property
referenceType
45167 45168 45169 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45167 def reference_type @reference_type end |
#referrer ⇒ String
URL of the resource which refers to the target.
Corresponds to the JSON property referrer
45172 45173 45174 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45172 def referrer @referrer end |
#target ⇒ String
URL of the resource to which this reference points.
Corresponds to the JSON property target
45177 45178 45179 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45177 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45184 45185 45186 45187 45188 45189 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45184 def update!(**args) @kind = args[:kind] if args.key?(:kind) @reference_type = args[:reference_type] if args.key?(:reference_type) @referrer = args[:referrer] if args.key?(:referrer) @target = args[:target] if args.key?(:target) end |