Class: Google::Apis::ComputeV1::Region
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Region
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Region resource. A region is a geographical area where a resource is located. For more information, readRegions and Zones.
Defined Under Namespace
Classes: QuotaStatusWarning
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#quota_status_warning ⇒ Google::Apis::ComputeV1::Region::QuotaStatusWarning
Output only.
-
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this region.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
-
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of resource URLs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Region
constructor
A new instance of Region.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Region
Returns a new instance of Region.
45254 45255 45256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
45191 45192 45193 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45191 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
45196 45197 45198 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45196 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
45201 45202 45203 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45201 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
45207 45208 45209 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45207 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#region for
regions.
Corresponds to the JSON property kind
45213 45214 45215 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45213 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
45218 45219 45220 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45218 def name @name end |
#quota_status_warning ⇒ Google::Apis::ComputeV1::Region::QuotaStatusWarning
Output only. [Output Only] Warning of fetching the quotas field for this
region. This
field is populated only if fetching of the quotas field fails.
Corresponds to the JSON property quotaStatusWarning
45225 45226 45227 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45225 def quota_status_warning @quota_status_warning end |
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this region.
Corresponds to the JSON property quotas
45230 45231 45232 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45230 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
45235 45236 45237 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45235 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
Corresponds to the JSON property status
45240 45241 45242 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45240 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
45245 45246 45247 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45245 def supports_pzs @supports_pzs end |
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of
resource URLs.
Corresponds to the JSON property zones
45252 45253 45254 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45252 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45259 45260 45261 45262 45263 45264 45265 45266 45267 45268 45269 45270 45271 45272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45259 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @quota_status_warning = args[:quota_status_warning] if args.key?(:quota_status_warning) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) @zones = args[:zones] if args.key?(:zones) end |