Class: Google::Apis::ComputeV1::RegionAddressesMoveRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionAddressesMoveRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional destination address description if intended to be different from the source.
-
#destination_address ⇒ String
The URL of the destination address to move to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionAddressesMoveRequest
constructor
A new instance of RegionAddressesMoveRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionAddressesMoveRequest
Returns a new instance of RegionAddressesMoveRequest.
44314 44315 44316 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44314 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional destination address description if intended to be different
from the source.
Corresponds to the JSON property description
44300 44301 44302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44300 def description @description end |
#destination_address ⇒ String
The URL of the destination address to move to. This can be a full or partial URL. For example, the following are all valid URLs to a address:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ addresses/address
- projects/project/regions/region/addresses/address
Note that destination project must be different from the source project. So/
regions/region/addresses/address is not valid partial url.
Corresponds to the JSON property
destinationAddress
44312 44313 44314 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44312 def destination_address @destination_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44319 44320 44321 44322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44319 def update!(**args) @description = args[:description] if args.key?(:description) @destination_address = args[:destination_address] if args.key?(:destination_address) end |