Class: Google::Apis::ComputeV1::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



45795
45796
45797
# File 'lib/google/apis/compute_v1/classes.rb', line 45795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45763
45764
45765
# File 'lib/google/apis/compute_v1/classes.rb', line 45763

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



45768
45769
45770
# File 'lib/google/apis/compute_v1/classes.rb', line 45768

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


45773
45774
45775
# File 'lib/google/apis/compute_v1/classes.rb', line 45773

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45783
45784
45785
# File 'lib/google/apis/compute_v1/classes.rb', line 45783

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45788
45789
45790
# File 'lib/google/apis/compute_v1/classes.rb', line 45788

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45793
45794
45795
# File 'lib/google/apis/compute_v1/classes.rb', line 45793

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45800
45801
45802
45803
45804
45805
45806
45807
# File 'lib/google/apis/compute_v1/classes.rb', line 45800

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end