Class: Google::Apis::ComputeV1::RegionDiskUpdateKmsKeyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionDiskUpdateKmsKeyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionDiskUpdateKmsKeyRequest
constructor
A new instance of RegionDiskUpdateKmsKeyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionDiskUpdateKmsKeyRequest
Returns a new instance of RegionDiskUpdateKmsKeyRequest.
45659 45660 45661 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Optional. The new KMS key to replace the current one on the disk. If empty, the disk will be re-encrypted using the primary version of the disk's current KMS key. The KMS key can be provided in the following formats:
- projects/project_id/locations/location/keyRings/key_ring/cryptoKeys/key
Where project is the project ID or
project number.
Corresponds to the JSON property
kmsKeyName
45657 45658 45659 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45657 def kms_key_name @kms_key_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45664 45665 45666 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45664 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) end |