Class: Google::Apis::ComputeV1::RegionInstanceGroupManagersApplyUpdatesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupManagersApplyUpdatesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
RegionInstanceGroupManagers.applyUpdatesToInstances
Instance Attribute Summary collapse
-
#all_instances ⇒ Boolean
(also: #all_instances?)
Flag to update all instances instead of specified list of "instances".
-
#instances ⇒ Array<String>
The list of URLs of one or more instances for which you want to apply updates.
-
#minimal_action ⇒ String
The minimal action that you want to perform on each instance during the update:.
-
#most_disruptive_allowed_action ⇒ String
The most disruptive action that you want to perform on each instance during the update:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagersApplyUpdatesRequest
constructor
A new instance of RegionInstanceGroupManagersApplyUpdatesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagersApplyUpdatesRequest
Returns a new instance of RegionInstanceGroupManagersApplyUpdatesRequest.
46658 46659 46660 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46658 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances ⇒ Boolean Also known as: all_instances?
Flag to update all instances instead of specified list of "instances".
If the flag is set to true then the instances may not be specified
in the request.
Corresponds to the JSON property allInstances
46612 46613 46614 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46612 def all_instances @all_instances end |
#instances ⇒ Array<String>
The list of URLs of one or more instances for which you want to apply
updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/
instances/[INSTANCE_NAME].
Corresponds to the JSON property instances
46620 46621 46622 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46620 def instances @instances end |
#minimal_action ⇒ String
The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not
disrupt the instance at all.
By default, the minimum action is NONE. If your update
requires a more disruptive action than you set with this flag, the
necessary action is performed to execute the update.
Corresponds to the JSON property
minimalAction
46639 46640 46641 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46639 def minimal_action @minimal_action end |
#most_disruptive_allowed_action ⇒ String
The most disruptive action that you want to perform on each instance during the update:
- REPLACE: Delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not disrupt the
instance at all.
By default, the most disruptive allowed action is REPLACE. If
your update requires a more disruptive action than you set with this flag,
the update request will fail.
Corresponds to the JSON property
mostDisruptiveAllowedAction
46656 46657 46658 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46656 def most_disruptive_allowed_action @most_disruptive_allowed_action end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46663 46664 46665 46666 46667 46668 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46663 def update!(**args) @all_instances = args[:all_instances] if args.key?(:all_instances) @instances = args[:instances] if args.key?(:instances) @minimal_action = args[:minimal_action] if args.key?(:minimal_action) @most_disruptive_allowed_action = args[:most_disruptive_allowed_action] if args.key?(:most_disruptive_allowed_action) end |