Class: Google::Apis::ComputeV1::RegionInstanceGroupManagersListInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstanceConfigsResp

Returns a new instance of RegionInstanceGroupManagersListInstanceConfigsResp.



46779
46780
46781
# File 'lib/google/apis/compute_v1/classes.rb', line 46779

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeV1::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



46761
46762
46763
# File 'lib/google/apis/compute_v1/classes.rb', line 46761

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46772
46773
46774
# File 'lib/google/apis/compute_v1/classes.rb', line 46772

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupManagersListInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



46777
46778
46779
# File 'lib/google/apis/compute_v1/classes.rb', line 46777

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46784
46785
46786
46787
46788
# File 'lib/google/apis/compute_v1/classes.rb', line 46784

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end