Class: Google::Apis::ComputeV1::RegionSnapshotUpdateKmsKeyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionSnapshotUpdateKmsKeyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionSnapshotUpdateKmsKeyRequest
constructor
A new instance of RegionSnapshotUpdateKmsKeyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionSnapshotUpdateKmsKeyRequest
Returns a new instance of RegionSnapshotUpdateKmsKeyRequest.
46819 46820 46821 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Optional. The new KMS key to replace the current one on the snapshot. If empty, the snapshot will be re-encrypted using the primary version of the snapshot's current KMS key. The KMS key can be provided in the following formats:
- projects/project_id/locations/region/keyRings/region/cryptoKeys/key
Corresponds to the JSON property
kmsKeyName
46817 46818 46819 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46817 def kms_key_name @kms_key_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46824 46825 46826 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46824 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) end |