Class: Google::Apis::ComputeV1::RemoveTargetPoolsInstanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RemoveTargetPoolsInstanceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::ComputeV1::InstanceReference>
URLs of the instances to be removed from target pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveTargetPoolsInstanceRequest
constructor
A new instance of RemoveTargetPoolsInstanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveTargetPoolsInstanceRequest
Returns a new instance of RemoveTargetPoolsInstanceRequest.
57724 57725 57726 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::ComputeV1::InstanceReference>
URLs of the instances to be removed from target pool.
Corresponds to the JSON property instances
57722 57723 57724 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57722 def instances @instances end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57729 57730 57731 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57729 def update!(**args) @instances = args[:instances] if args.key?(:instances) end |