Class: Google::Apis::ComputeV1::RequestMirrorPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A policy that specifies how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer doesn't wait for responses from the shadow service. Before sending traffic to the shadow service, the host or authority header is suffixed with-shadow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RequestMirrorPolicy

Returns a new instance of RequestMirrorPolicy.



42062
42063
42064
# File 'lib/google/apis/compute_v1/classes.rb', line 42062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceString

The full or partial URL to the BackendService resource being mirrored to. The backend service configured for a mirroring policy must reference backends that are of the same type as the original backend service matched in the URL map. Serverless NEG backends are not currently supported as a mirrored backend service. Corresponds to the JSON property backendService

Returns:

  • (String)


42055
42056
42057
# File 'lib/google/apis/compute_v1/classes.rb', line 42055

def backend_service
  @backend_service
end

#mirror_percentFloat

The percentage of requests to be mirrored to backend_service. Corresponds to the JSON property mirrorPercent

Returns:

  • (Float)


42060
42061
42062
# File 'lib/google/apis/compute_v1/classes.rb', line 42060

def mirror_percent
  @mirror_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42067
42068
42069
42070
# File 'lib/google/apis/compute_v1/classes.rb', line 42067

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @mirror_percent = args[:mirror_percent] if args.key?(:mirror_percent)
end