Class: Google::Apis::ComputeV1::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



47966
47967
47968
# File 'lib/google/apis/compute_v1/classes.rb', line 47966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


47954
47955
47956
# File 'lib/google/apis/compute_v1/classes.rb', line 47954

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


47959
47960
47961
# File 'lib/google/apis/compute_v1/classes.rb', line 47959

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeV1::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



47964
47965
47966
# File 'lib/google/apis/compute_v1/classes.rb', line 47964

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47971
47972
47973
47974
47975
# File 'lib/google/apis/compute_v1/classes.rb', line 47971

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end