Class: Google::Apis::ComputeV1::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeV1::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
48229 48230 48231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48229 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
48172 48173 48174 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48172 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
48179 48180 48181 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48179 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
48185 48186 48187 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48185 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
48190 48191 48192 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48190 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
48195 48196 48197 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48195 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
48201 48202 48203 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48201 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
48207 48208 48209 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48207 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
48212 48213 48214 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48212 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
48217 48218 48219 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48217 def state @state end |
#status ⇒ Google::Apis::ComputeV1::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
48222 48223 48224 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48222 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
48227 48228 48229 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48227 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48234 48235 48236 48237 48238 48239 48240 48241 48242 48243 48244 48245 48246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48234 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |