Class: Google::Apis::ComputeV1::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation slots within a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotsListResponse

Returns a new instance of ReservationSlotsListResponse.



49146
49147
49148
# File 'lib/google/apis/compute_v1/classes.rb', line 49146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49113
49114
49115
# File 'lib/google/apis/compute_v1/classes.rb', line 49113

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationSlot>

A list of reservation slot resources. Corresponds to the JSON property items



49118
49119
49120
# File 'lib/google/apis/compute_v1/classes.rb', line 49118

def items
  @items
end

#kindString

The type of resource. Alwayscompute#reservationSlot for a list of reservation slots. Corresponds to the JSON property kind

Returns:

  • (String)


49124
49125
49126
# File 'lib/google/apis/compute_v1/classes.rb', line 49124

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49134
49135
49136
# File 'lib/google/apis/compute_v1/classes.rb', line 49134

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49139
49140
49141
# File 'lib/google/apis/compute_v1/classes.rb', line 49139

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationSlotsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



49144
49145
49146
# File 'lib/google/apis/compute_v1/classes.rb', line 49144

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49151
49152
49153
49154
49155
49156
49157
49158
# File 'lib/google/apis/compute_v1/classes.rb', line 49151

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end