Class: Google::Apis::ComputeV1::ReservationSubBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a reservation subBlock resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlock

Returns a new instance of ReservationSubBlock.



49323
49324
49325
# File 'lib/google/apis/compute_v1/classes.rb', line 49323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologies_infoGoogle::Apis::ComputeV1::AcceleratorTopologiesInfo

Info for accelerator topologies within a densely packed reservation. Corresponds to the JSON property acceleratorTopologiesInfo



49238
49239
49240
# File 'lib/google/apis/compute_v1/classes.rb', line 49238

def accelerator_topologies_info
  @accelerator_topologies_info
end

#countFixnum

Output only. [Output Only] The number of hosts that are allocated in this reservation subBlock. Corresponds to the JSON property count

Returns:

  • (Fixnum)


49244
49245
49246
# File 'lib/google/apis/compute_v1/classes.rb', line 49244

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


49249
49250
49251
# File 'lib/google/apis/compute_v1/classes.rb', line 49249

def creation_timestamp
  @creation_timestamp
end

#health_infoGoogle::Apis::ComputeV1::ReservationSubBlockHealthInfo

Health information for the reservation subBlock. Corresponds to the JSON property healthInfo



49254
49255
49256
# File 'lib/google/apis/compute_v1/classes.rb', line 49254

def health_info
  @health_info
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


49261
49262
49263
# File 'lib/google/apis/compute_v1/classes.rb', line 49261

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation subBlock. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


49268
49269
49270
# File 'lib/google/apis/compute_v1/classes.rb', line 49268

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


49275
49276
49277
# File 'lib/google/apis/compute_v1/classes.rb', line 49275

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationSubBlock for reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


49281
49282
49283
# File 'lib/google/apis/compute_v1/classes.rb', line 49281

def kind
  @kind
end

#nameString

Output only. [Output Only] The name of this reservation subBlock generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


49289
49290
49291
# File 'lib/google/apis/compute_v1/classes.rb', line 49289

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeV1::ReservationSubBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation subBlock. Corresponds to the JSON property physicalTopology



49294
49295
49296
# File 'lib/google/apis/compute_v1/classes.rb', line 49294

def physical_topology
  @physical_topology
end

#reservation_sub_block_maintenanceGoogle::Apis::ComputeV1::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationSubBlockMaintenance



49299
49300
49301
# File 'lib/google/apis/compute_v1/classes.rb', line 49299

def reservation_sub_block_maintenance
  @reservation_sub_block_maintenance
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49305
49306
49307
# File 'lib/google/apis/compute_v1/classes.rb', line 49305

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


49311
49312
49313
# File 'lib/google/apis/compute_v1/classes.rb', line 49311

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation subBlock. Corresponds to the JSON property status

Returns:

  • (String)


49316
49317
49318
# File 'lib/google/apis/compute_v1/classes.rb', line 49316

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation subBlock resides. Corresponds to the JSON property zone

Returns:

  • (String)


49321
49322
49323
# File 'lib/google/apis/compute_v1/classes.rb', line 49321

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49328
49329
49330
49331
49332
49333
49334
49335
49336
49337
49338
49339
49340
49341
49342
49343
49344
# File 'lib/google/apis/compute_v1/classes.rb', line 49328

def update!(**args)
  @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @health_info = args[:health_info] if args.key?(:health_info)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end