Class: Google::Apis::ComputeV1::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



48591
48592
48593
# File 'lib/google/apis/compute_v1/classes.rb', line 48591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


48584
48585
48586
# File 'lib/google/apis/compute_v1/classes.rb', line 48584

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


48589
48590
48591
# File 'lib/google/apis/compute_v1/classes.rb', line 48589

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48596
48597
48598
48599
# File 'lib/google/apis/compute_v1/classes.rb', line 48596

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end