Class: Google::Apis::ComputeV1::ReservationsResizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationsResizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#specific_sku_count ⇒ Fixnum
Number of allocated resources can be resized with minimum = 1 and maximum = 1000.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationsResizeRequest
constructor
A new instance of ReservationsResizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationsResizeRequest
Returns a new instance of ReservationsResizeRequest.
43431 43432 43433 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#specific_sku_count ⇒ Fixnum
Number of allocated resources can be resized with minimum = 1 and
maximum = 1000.
Corresponds to the JSON property specificSkuCount
43429 43430 43431 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43429 def specific_sku_count @specific_sku_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43436 43437 43438 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43436 def update!(**args) @specific_sku_count = args[:specific_sku_count] if args.key?(:specific_sku_count) end |