Class: Google::Apis::ComputeV1::ReservationsScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationsScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#reservations ⇒ Array<Google::Apis::ComputeV1::Reservation>
A list of reservations contained in this scope.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationsScopedList::Warning
Informational warning which replaces the list of reservations when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationsScopedList
constructor
A new instance of ReservationsScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationsScopedList
Returns a new instance of ReservationsScopedList.
49716 49717 49718 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reservations ⇒ Array<Google::Apis::ComputeV1::Reservation>
A list of reservations contained in this scope.
Corresponds to the JSON property reservations
49708 49709 49710 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49708 def reservations @reservations end |
#warning ⇒ Google::Apis::ComputeV1::ReservationsScopedList::Warning
Informational warning which replaces the list of reservations when
the list is empty.
Corresponds to the JSON property warning
49714 49715 49716 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49714 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49721 49722 49723 49724 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49721 def update!(**args) @reservations = args[:reservations] if args.key?(:reservations) @warning = args[:warning] if args.key?(:warning) end |