Class: Google::Apis::ComputeV1::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



50161
50162
50163
# File 'lib/google/apis/compute_v1/classes.rb', line 50161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50119
50120
50121
# File 'lib/google/apis/compute_v1/classes.rb', line 50119

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50124
50125
50126
# File 'lib/google/apis/compute_v1/classes.rb', line 50124

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



50129
50130
50131
# File 'lib/google/apis/compute_v1/classes.rb', line 50129

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


50134
50135
50136
# File 'lib/google/apis/compute_v1/classes.rb', line 50134

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50144
50145
50146
# File 'lib/google/apis/compute_v1/classes.rb', line 50144

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50149
50150
50151
# File 'lib/google/apis/compute_v1/classes.rb', line 50149

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50154
50155
50156
# File 'lib/google/apis/compute_v1/classes.rb', line 50154

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50159
50160
50161
# File 'lib/google/apis/compute_v1/classes.rb', line 50159

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50166
50167
50168
50169
50170
50171
50172
50173
50174
50175
# File 'lib/google/apis/compute_v1/classes.rb', line 50166

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end