Class: Google::Apis::ComputeV1::ResourcePolicyHourlyCycle

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Time window specified for hourly operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyHourlyCycle

Returns a new instance of ResourcePolicyHourlyCycle.



48705
48706
48707
# File 'lib/google/apis/compute_v1/classes.rb', line 48705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario. Corresponds to the JSON property duration

Returns:

  • (String)


48691
48692
48693
# File 'lib/google/apis/compute_v1/classes.rb', line 48691

def duration
  @duration
end

#hours_in_cycleFixnum

Defines a schedule with units measured in hours. The value determines how many hours pass between the start of each cycle. Corresponds to the JSON property hoursInCycle

Returns:

  • (Fixnum)


48697
48698
48699
# File 'lib/google/apis/compute_v1/classes.rb', line 48697

def hours_in_cycle
  @hours_in_cycle
end

#start_timeString

Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT. Corresponds to the JSON property startTime

Returns:

  • (String)


48703
48704
48705
# File 'lib/google/apis/compute_v1/classes.rb', line 48703

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48710
48711
48712
48713
48714
# File 'lib/google/apis/compute_v1/classes.rb', line 48710

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @hours_in_cycle = args[:hours_in_cycle] if args.key?(:hours_in_cycle)
  @start_time = args[:start_time] if args.key?(:start_time)
end