Class: Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy

Returns a new instance of ResourcePolicyInstanceSchedulePolicy.



50368
50369
50370
# File 'lib/google/apis/compute_v1/classes.rb', line 50368

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expiration_timeString

The expiration time of the schedule. The timestamp is an RFC3339 string. Corresponds to the JSON property expirationTime

Returns:

  • (String)


50344
50345
50346
# File 'lib/google/apis/compute_v1/classes.rb', line 50344

def expiration_time
  @expiration_time
end

#start_timeString

The start time of the schedule. The timestamp is an RFC3339 string. Corresponds to the JSON property startTime

Returns:

  • (String)


50349
50350
50351
# File 'lib/google/apis/compute_v1/classes.rb', line 50349

def start_time
  @start_time
end

#time_zoneString

Specifies the time zone to be used in interpreting Schedule.schedule. The value of this field must be a time zone name from the tz database: https://wikipedia.org/wiki/Tz_database. Corresponds to the JSON property timeZone

Returns:

  • (String)


50356
50357
50358
# File 'lib/google/apis/compute_v1/classes.rb', line 50356

def time_zone
  @time_zone
end

#vm_start_scheduleGoogle::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule

Schedule for an instance operation. Corresponds to the JSON property vmStartSchedule



50361
50362
50363
# File 'lib/google/apis/compute_v1/classes.rb', line 50361

def vm_start_schedule
  @vm_start_schedule
end

#vm_stop_scheduleGoogle::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule

Schedule for an instance operation. Corresponds to the JSON property vmStopSchedule



50366
50367
50368
# File 'lib/google/apis/compute_v1/classes.rb', line 50366

def vm_stop_schedule
  @vm_stop_schedule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50373
50374
50375
50376
50377
50378
50379
# File 'lib/google/apis/compute_v1/classes.rb', line 50373

def update!(**args)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @vm_start_schedule = args[:vm_start_schedule] if args.key?(:vm_start_schedule)
  @vm_stop_schedule = args[:vm_stop_schedule] if args.key?(:vm_stop_schedule)
end