Class: Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicySnapshotProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicySnapshotProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specified snapshot properties for scheduled snapshots created by this policy.
Instance Attribute Summary collapse
-
#chain_name ⇒ String
Chain name that the snapshot is created in.
-
#guest_flush ⇒ Boolean
(also: #guest_flush?)
Indication to perform a 'guest aware' snapshot.
-
#labels ⇒ Hash<String,String>
Labels to apply to scheduled snapshots.
-
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicySnapshotProperties
constructor
A new instance of ResourcePolicySnapshotSchedulePolicySnapshotProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicySnapshotProperties
Returns a new instance of ResourcePolicySnapshotSchedulePolicySnapshotProperties.
50704 50705 50706 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50704 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chain_name ⇒ String
Chain name that the snapshot is created in.
Corresponds to the JSON property chainName
50684 50685 50686 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50684 def chain_name @chain_name end |
#guest_flush ⇒ Boolean Also known as: guest_flush?
Indication to perform a 'guest aware' snapshot.
Corresponds to the JSON property guestFlush
50689 50690 50691 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50689 def guest_flush @guest_flush end |
#labels ⇒ Hash<String,String>
Labels to apply to scheduled snapshots. These can be later modified
by the setLabels method. Label values may be empty.
Corresponds to the JSON property labels
50696 50697 50698 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50696 def labels @labels end |
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the auto snapshot (regional or
multi-regional).
Corresponds to the JSON property storageLocations
50702 50703 50704 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50702 def storage_locations @storage_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50709 50710 50711 50712 50713 50714 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50709 def update!(**args) @chain_name = args[:chain_name] if args.key?(:chain_name) @guest_flush = args[:guest_flush] if args.key?(:guest_flush) @labels = args[:labels] if args.key?(:labels) @storage_locations = args[:storage_locations] if args.key?(:storage_locations) end |