Class: Google::Apis::ComputeV1::ResourcePolicyWeeklyCycleDayOfWeek
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyWeeklyCycleDayOfWeek
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#day ⇒ String
Defines a schedule that runs on specific days of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ String
Time within the window to start the operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyWeeklyCycleDayOfWeek
constructor
A new instance of ResourcePolicyWeeklyCycleDayOfWeek.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyWeeklyCycleDayOfWeek
Returns a new instance of ResourcePolicyWeeklyCycleDayOfWeek.
49141 49142 49143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Defines a schedule that runs on specific days of the week. Specify
one or more days. The following options are available:
MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
Corresponds to the JSON property day
49126 49127 49128 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49126 def day @day end |
#duration ⇒ String
Output only. [Output only] Duration of the time window, automatically chosen
to be
smallest possible in the given scenario.
Corresponds to the JSON property duration
49133 49134 49135 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49133 def duration @duration end |
#start_time ⇒ String
Time within the window to start the operations.
It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
Corresponds to the JSON property startTime
49139 49140 49141 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49139 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49146 49147 49148 49149 49150 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49146 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |