Class: Google::Apis::ComputeV1::ResourcePolicyWorkloadPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents the workload policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy

Returns a new instance of ResourcePolicyWorkloadPolicy.



50066
50067
50068
# File 'lib/google/apis/compute_v1/classes.rb', line 50066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Specifies the topology required to create a partition for VMs that have interconnected GPUs. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


50048
50049
50050
# File 'lib/google/apis/compute_v1/classes.rb', line 50048

def accelerator_topology
  @accelerator_topology
end

#accelerator_topology_modeString

Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Corresponds to the JSON property acceleratorTopologyMode

Returns:

  • (String)


50054
50055
50056
# File 'lib/google/apis/compute_v1/classes.rb', line 50054

def accelerator_topology_mode
  @accelerator_topology_mode
end

#max_topology_distanceString

Specifies the maximum distance between instances. Corresponds to the JSON property maxTopologyDistance

Returns:

  • (String)


50059
50060
50061
# File 'lib/google/apis/compute_v1/classes.rb', line 50059

def max_topology_distance
  @max_topology_distance
end

#typeString

Specifies the intent of the instance placement in the MIG. Corresponds to the JSON property type

Returns:

  • (String)


50064
50065
50066
# File 'lib/google/apis/compute_v1/classes.rb', line 50064

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50071
50072
50073
50074
50075
50076
# File 'lib/google/apis/compute_v1/classes.rb', line 50071

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode)
  @max_topology_distance = args[:max_topology_distance] if args.key?(:max_topology_distance)
  @type = args[:type] if args.key?(:type)
end