Class: Google::Apis::ComputeV1::ResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatus

Returns a new instance of ResourceStatus.



50903
50904
50905
# File 'lib/google/apis/compute_v1/classes.rb', line 50903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_instance_metadataGoogle::Apis::ComputeV1::ResourceStatusEffectiveInstanceMetadata

Effective values of predefined metadata keys for an instance. Corresponds to the JSON property effectiveInstanceMetadata



50866
50867
50868
# File 'lib/google/apis/compute_v1/classes.rb', line 50866

def 
  @effective_instance_metadata
end

#physical_hostString

Output only. [Output Only] The precise location of your instance within the zone's data center, including the block, sub-block, and host. The field is formatted as follows: blockId/subBlockId/hostId. Corresponds to the JSON property physicalHost

Returns:

  • (String)


50874
50875
50876
# File 'lib/google/apis/compute_v1/classes.rb', line 50874

def physical_host
  @physical_host
end

#physical_host_topologyGoogle::Apis::ComputeV1::ResourceStatusPhysicalHostTopology

Represents the physical host topology of the host on which the VM is running. Corresponds to the JSON property physicalHostTopology



50880
50881
50882
# File 'lib/google/apis/compute_v1/classes.rb', line 50880

def physical_host_topology
  @physical_host_topology
end

#reservation_consumption_infoGoogle::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo

Reservation consumption information that the instance is consuming from. Corresponds to the JSON property reservationConsumptionInfo



50885
50886
50887
# File 'lib/google/apis/compute_v1/classes.rb', line 50885

def reservation_consumption_info
  @reservation_consumption_info
end

#schedulingGoogle::Apis::ComputeV1::ResourceStatusScheduling

Corresponds to the JSON property scheduling



50890
50891
50892
# File 'lib/google/apis/compute_v1/classes.rb', line 50890

def scheduling
  @scheduling
end

#shutdown_detailsGoogle::Apis::ComputeV1::ResourceStatusShutdownDetails

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled. Corresponds to the JSON property shutdownDetails



50896
50897
50898
# File 'lib/google/apis/compute_v1/classes.rb', line 50896

def shutdown_details
  @shutdown_details
end

#upcoming_maintenanceGoogle::Apis::ComputeV1::UpcomingMaintenance

Upcoming Maintenance notification information. Corresponds to the JSON property upcomingMaintenance



50901
50902
50903
# File 'lib/google/apis/compute_v1/classes.rb', line 50901

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50908
50909
50910
50911
50912
50913
50914
50915
50916
# File 'lib/google/apis/compute_v1/classes.rb', line 50908

def update!(**args)
  @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata)
  @physical_host = args[:physical_host] if args.key?(:physical_host)
  @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology)
  @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end