Class: Google::Apis::ComputeV1::ResourceStatusShutdownDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusShutdownDetails

Returns a new instance of ResourceStatusShutdownDetails.



51167
51168
51169
# File 'lib/google/apis/compute_v1/classes.rb', line 51167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_durationGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxDuration



51149
51150
51151
# File 'lib/google/apis/compute_v1/classes.rb', line 51149

def max_duration
  @max_duration
end

#request_timestampString

Past timestamp indicating the beginning of current stopState in RFC3339 text format. Corresponds to the JSON property requestTimestamp

Returns:

  • (String)


51155
51156
51157
# File 'lib/google/apis/compute_v1/classes.rb', line 51155

def request_timestamp
  @request_timestamp
end

#stop_stateString

Current stopping state of the instance. Corresponds to the JSON property stopState

Returns:

  • (String)


51160
51161
51162
# File 'lib/google/apis/compute_v1/classes.rb', line 51160

def stop_state
  @stop_state
end

#target_stateString

Target instance state. Corresponds to the JSON property targetState

Returns:

  • (String)


51165
51166
51167
# File 'lib/google/apis/compute_v1/classes.rb', line 51165

def target_state
  @target_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51172
51173
51174
51175
51176
51177
# File 'lib/google/apis/compute_v1/classes.rb', line 51172

def update!(**args)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp)
  @stop_state = args[:stop_state] if args.key?(:stop_state)
  @target_state = args[:target_state] if args.key?(:target_state)
end