Class: Google::Apis::ComputeV1::RiskDetailsGlobalDnsInsight

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Detailed insights for a global DNS reliability risk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RiskDetailsGlobalDnsInsight

Returns a new instance of RiskDetailsGlobalDnsInsight.



51249
51250
51251
# File 'lib/google/apis/compute_v1/classes.rb', line 51249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#project_default_is_global_dnsBoolean Also known as: project_default_is_global_dns?

Indicates whether the project's default DNS setting is global DNS. Corresponds to the JSON property projectDefaultIsGlobalDns

Returns:

  • (Boolean)


51230
51231
51232
# File 'lib/google/apis/compute_v1/classes.rb', line 51230

def project_default_is_global_dns
  @project_default_is_global_dns
end

#query_observation_windowString

The observation window for the query counts. Corresponds to the JSON property queryObservationWindow

Returns:

  • (String)


51236
51237
51238
# File 'lib/google/apis/compute_v1/classes.rb', line 51236

def query_observation_window
  @query_observation_window
end

#risky_query_countFixnum

The number of queries that are risky. This is always less than or equal to total_query_count. Corresponds to the JSON property riskyQueryCount

Returns:

  • (Fixnum)


51242
51243
51244
# File 'lib/google/apis/compute_v1/classes.rb', line 51242

def risky_query_count
  @risky_query_count
end

#total_query_countFixnum

The total number of queries in the observation window. Corresponds to the JSON property totalQueryCount

Returns:

  • (Fixnum)


51247
51248
51249
# File 'lib/google/apis/compute_v1/classes.rb', line 51247

def total_query_count
  @total_query_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51254
51255
51256
51257
51258
51259
# File 'lib/google/apis/compute_v1/classes.rb', line 51254

def update!(**args)
  @project_default_is_global_dns = args[:project_default_is_global_dns] if args.key?(:project_default_is_global_dns)
  @query_observation_window = args[:query_observation_window] if args.key?(:query_observation_window)
  @risky_query_count = args[:risky_query_count] if args.key?(:risky_query_count)
  @total_query_count = args[:total_query_count] if args.key?(:total_query_count)
end