Class: Google::Apis::ComputeV1::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Rollout
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Rollout resource. A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.
Instance Attribute Summary collapse
-
#cancellation_time ⇒ String
Output only.
-
#completion_time ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#current_wave_number ⇒ Fixnum
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#etag ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#pause_time ⇒ String
Output only.
-
#resume_time ⇒ String
Output only.
-
#rollout_entity ⇒ Google::Apis::ComputeV1::RolloutRolloutEntity
Specifications of the resource to roll out.
-
#rollout_plan ⇒ String
Required.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#wave_details ⇒ Array<Google::Apis::ComputeV1::RolloutWaveDetails>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
51394 51395 51396 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancellation_time ⇒ String
Output only. The timestamp at which the Rollout was cancelled.
Corresponds to the JSON property cancellationTime
51297 51298 51299 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51297 def cancellation_time @cancellation_time end |
#completion_time ⇒ String
Output only. The timestamp at which the Rollout was completed.
Corresponds to the JSON property completionTime
51302 51303 51304 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51302 def completion_time @completion_time end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
51308 51309 51310 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51308 def @creation_timestamp end |
#current_wave_number ⇒ Fixnum
Output only. The number of the currently running wave.
Ex. 1
Corresponds to the JSON property currentWaveNumber
51314 51315 51316 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51314 def current_wave_number @current_wave_number end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
51320 51321 51322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51320 def description @description end |
#etag ⇒ String
Output only. etag of the Rollout
Ex. abc1234
Corresponds to the JSON property etag
51326 51327 51328 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51326 def etag @etag end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
51333 51334 51335 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51333 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#rollout
for rollouts.
Corresponds to the JSON property kind
51339 51340 51341 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51339 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
51350 51351 51352 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51350 def name @name end |
#pause_time ⇒ String
Output only. The timestamp at which the Rollout was paused.
Corresponds to the JSON property pauseTime
51355 51356 51357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51355 def pause_time @pause_time end |
#resume_time ⇒ String
Output only. The timestamp at which the Rollout was resumed.
Corresponds to the JSON property resumeTime
51360 51361 51362 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51360 def resume_time @resume_time end |
#rollout_entity ⇒ Google::Apis::ComputeV1::RolloutRolloutEntity
Specifications of the resource to roll out.
Corresponds to the JSON property rolloutEntity
51365 51366 51367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51365 def rollout_entity @rollout_entity end |
#rollout_plan ⇒ String
Required. Rollout Plan used to model the Rollout.
Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1
Corresponds to the JSON property rolloutPlan
51371 51372 51373 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51371 def rollout_plan @rollout_plan end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
51377 51378 51379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51377 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
51382 51383 51384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51382 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. The current state of the Rollout.
Corresponds to the JSON property state
51387 51388 51389 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51387 def state @state end |
#wave_details ⇒ Array<Google::Apis::ComputeV1::RolloutWaveDetails>
Output only. Details about each wave of the rollout.
Corresponds to the JSON property waveDetails
51392 51393 51394 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51392 def wave_details @wave_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51399 51400 51401 51402 51403 51404 51405 51406 51407 51408 51409 51410 51411 51412 51413 51414 51415 51416 51417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51399 def update!(**args) @cancellation_time = args[:cancellation_time] if args.key?(:cancellation_time) @completion_time = args[:completion_time] if args.key?(:completion_time) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @current_wave_number = args[:current_wave_number] if args.key?(:current_wave_number) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @pause_time = args[:pause_time] if args.key?(:pause_time) @resume_time = args[:resume_time] if args.key?(:resume_time) @rollout_entity = args[:rollout_entity] if args.key?(:rollout_entity) @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @wave_details = args[:wave_details] if args.key?(:wave_details) end |