Class: Google::Apis::ComputeV1::RolloutPlan

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

RolloutPlan resource. A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as "waves". Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlan

Returns a new instance of RolloutPlan.



50521
50522
50523
# File 'lib/google/apis/compute_v1/classes.rb', line 50521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


50467
50468
50469
# File 'lib/google/apis/compute_v1/classes.rb', line 50467

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


50473
50474
50475
# File 'lib/google/apis/compute_v1/classes.rb', line 50473

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


50480
50481
50482
# File 'lib/google/apis/compute_v1/classes.rb', line 50480

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#rolloutPlan for rolloutPlans. Corresponds to the JSON property kind

Returns:

  • (String)


50486
50487
50488
# File 'lib/google/apis/compute_v1/classes.rb', line 50486

def kind
  @kind
end

#location_scopeString

The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL. Corresponds to the JSON property locationScope

Returns:

  • (String)


50492
50493
50494
# File 'lib/google/apis/compute_v1/classes.rb', line 50492

def location_scope
  @location_scope
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


50503
50504
50505
# File 'lib/google/apis/compute_v1/classes.rb', line 50503

def name
  @name
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50509
50510
50511
# File 'lib/google/apis/compute_v1/classes.rb', line 50509

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


50514
50515
50516
# File 'lib/google/apis/compute_v1/classes.rb', line 50514

def self_link_with_id
  @self_link_with_id
end

#wavesArray<Google::Apis::ComputeV1::RolloutPlanWave>

Required. The waves included in this rollout plan. Corresponds to the JSON property waves



50519
50520
50521
# File 'lib/google/apis/compute_v1/classes.rb', line 50519

def waves
  @waves
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50526
50527
50528
50529
50530
50531
50532
50533
50534
50535
50536
# File 'lib/google/apis/compute_v1/classes.rb', line 50526

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @location_scope = args[:location_scope] if args.key?(:location_scope)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @waves = args[:waves] if args.key?(:waves)
end