Class: Google::Apis::ComputeV1::RolloutPlanWave

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A single wave in a rollout plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWave

Returns a new instance of RolloutPlanWave.



51492
51493
51494
# File 'lib/google/apis/compute_v1/classes.rb', line 51492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of this wave of the rollout plan. Corresponds to the JSON property displayName

Returns:

  • (String)


51465
51466
51467
# File 'lib/google/apis/compute_v1/classes.rb', line 51465

def display_name
  @display_name
end

#numberFixnum

Output only. The wave number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


51470
51471
51472
# File 'lib/google/apis/compute_v1/classes.rb', line 51470

def number
  @number
end

#orchestration_optionsGoogle::Apis::ComputeV1::RolloutPlanWaveOrchestrationOptions

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern. Corresponds to the JSON property orchestrationOptions



51477
51478
51479
# File 'lib/google/apis/compute_v1/classes.rb', line 51477

def orchestration_options
  @orchestration_options
end

#selectorsArray<Google::Apis::ComputeV1::RolloutPlanWaveSelector>

Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave. Corresponds to the JSON property selectors



51485
51486
51487
# File 'lib/google/apis/compute_v1/classes.rb', line 51485

def selectors
  @selectors
end

#validationGoogle::Apis::ComputeV1::RolloutPlanWaveValidation

The validation to be performed before progressing to the next wave. Corresponds to the JSON property validation



51490
51491
51492
# File 'lib/google/apis/compute_v1/classes.rb', line 51490

def validation
  @validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51497
51498
51499
51500
51501
51502
51503
# File 'lib/google/apis/compute_v1/classes.rb', line 51497

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @number = args[:number] if args.key?(:number)
  @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options)
  @selectors = args[:selectors] if args.key?(:selectors)
  @validation = args[:validation] if args.key?(:validation)
end