Class: Google::Apis::ComputeV1::RolloutPlanWaveOrchestrationOptionsDelay

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Options to control the delay, if any, between batches of projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptionsDelay

Returns a new instance of RolloutPlanWaveOrchestrationOptionsDelay.



51615
51616
51617
# File 'lib/google/apis/compute_v1/classes.rb', line 51615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location. Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. Corresponds to the JSON property delimiter

Returns:

  • (String)


51599
51600
51601
# File 'lib/google/apis/compute_v1/classes.rb', line 51599

def delimiter
  @delimiter
end

#durationString

Optional. The duration of the delay, if any, to be added between batches of projects. A zero duration corresponds to no delay. Corresponds to the JSON property duration

Returns:

  • (String)


51605
51606
51607
# File 'lib/google/apis/compute_v1/classes.rb', line 51605

def duration
  @duration
end

#typeString

Optional. Controls whether the specified duration is to be added at the end of each batch, or if the total processing time for each batch will be padded if needed to meet the specified duration. Must be set to TYPE_UNSPECIFIED if no delay is to be added. Corresponds to the JSON property type

Returns:

  • (String)


51613
51614
51615
# File 'lib/google/apis/compute_v1/classes.rb', line 51613

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51620
51621
51622
51623
51624
# File 'lib/google/apis/compute_v1/classes.rb', line 51620

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
  @duration = args[:duration] if args.key?(:duration)
  @type = args[:type] if args.key?(:type)
end