Class: Google::Apis::ComputeV1::RolloutPlansListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of RolloutPlan resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlansListResponse

Returns a new instance of RolloutPlansListResponse.



51803
51804
51805
# File 'lib/google/apis/compute_v1/classes.rb', line 51803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51765
51766
51767
# File 'lib/google/apis/compute_v1/classes.rb', line 51765

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51770
51771
51772
# File 'lib/google/apis/compute_v1/classes.rb', line 51770

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::RolloutPlan>

A list of RolloutPlan resources. Corresponds to the JSON property items



51775
51776
51777
# File 'lib/google/apis/compute_v1/classes.rb', line 51775

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51785
51786
51787
# File 'lib/google/apis/compute_v1/classes.rb', line 51785

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51790
51791
51792
# File 'lib/google/apis/compute_v1/classes.rb', line 51790

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51796
51797
51798
# File 'lib/google/apis/compute_v1/classes.rb', line 51796

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RolloutPlansListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51801
51802
51803
# File 'lib/google/apis/compute_v1/classes.rb', line 51801

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51808
51809
51810
51811
51812
51813
51814
51815
51816
# File 'lib/google/apis/compute_v1/classes.rb', line 51808

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end