Class: Google::Apis::ComputeV1::RolloutRolloutEntity
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutRolloutEntity
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specifications of the resource to roll out.
Instance Attribute Summary collapse
-
#orchestrated_entity ⇒ Google::Apis::ComputeV1::RolloutRolloutEntityOrchestratedEntity
This message is used if the resource type follows the Orchestrated integration model with ProgressiveRollout.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutRolloutEntity
constructor
A new instance of RolloutRolloutEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutRolloutEntity
Returns a new instance of RolloutRolloutEntity.
50617 50618 50619 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#orchestrated_entity ⇒ Google::Apis::ComputeV1::RolloutRolloutEntityOrchestratedEntity
This message is used if the resource type follows the Orchestrated
integration model with ProgressiveRollout.
Corresponds to the JSON property orchestratedEntity
50615 50616 50617 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50615 def orchestrated_entity @orchestrated_entity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50622 50623 50624 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50622 def update!(**args) @orchestrated_entity = args[:orchestrated_entity] if args.key?(:orchestrated_entity) end |