Class: Google::Apis::ComputeV1::RolloutWaveDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutWaveDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Additional metadata about the status of each wave provided by the server.
Instance Attribute Summary collapse
-
#orchestrated_wave_details ⇒ Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetails
Details of the wave for products using the Orchestrated integration model.
-
#wave_display_name ⇒ String
Output only.
-
#wave_number ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutWaveDetails
constructor
A new instance of RolloutWaveDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutWaveDetails
Returns a new instance of RolloutWaveDetails.
51016 51017 51018 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#orchestrated_wave_details ⇒ Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetails
Details of the wave for products using the Orchestrated integration
model.
Corresponds to the JSON property orchestratedWaveDetails
51003 51004 51005 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51003 def orchestrated_wave_details @orchestrated_wave_details end |
#wave_display_name ⇒ String
Output only. Wave name.
Ex. wave1
Corresponds to the JSON property waveDisplayName
51009 51010 51011 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51009 def wave_display_name @wave_display_name end |
#wave_number ⇒ Fixnum
Output only. System generated number for the wave.
Corresponds to the JSON property waveNumber
51014 51015 51016 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51014 def wave_number @wave_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51021 51022 51023 51024 51025 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51021 def update!(**args) @orchestrated_wave_details = args[:orchestrated_wave_details] if args.key?(:orchestrated_wave_details) @wave_display_name = args[:wave_display_name] if args.key?(:wave_display_name) @wave_number = args[:wave_number] if args.key?(:wave_number) end |