Class: Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Details of the wave for products using the Orchestrated integration model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails

Returns a new instance of RolloutWaveDetailsOrchestratedWaveDetails.



52033
52034
52035
# File 'lib/google/apis/compute_v1/classes.rb', line 52033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_resources_countFixnum

Output only. Resource completed so far. Corresponds to the JSON property completedResourcesCount

Returns:

  • (Fixnum)


52000
52001
52002
# File 'lib/google/apis/compute_v1/classes.rb', line 52000

def completed_resources_count
  @completed_resources_count
end

#estimated_completion_timeString

Output only. Estimated timestamp at which the wave will complete. Extrapolated from current progress. Corresponds to the JSON property estimatedCompletionTime

Returns:

  • (String)


52007
52008
52009
# File 'lib/google/apis/compute_v1/classes.rb', line 52007

def estimated_completion_time
  @estimated_completion_time
end

#estimated_total_resources_countFixnum

Output only. Estimated total count of resources. Corresponds to the JSON property estimatedTotalResourcesCount

Returns:

  • (Fixnum)


52012
52013
52014
# File 'lib/google/apis/compute_v1/classes.rb', line 52012

def estimated_total_resources_count
  @estimated_total_resources_count
end

#failed_locationsArray<String>

Output only. Locations that failed during orchestration, and ProgressiveRollout stopped retrying. There may be some successful resources rolled out in the wave as the location may have failed later in the Rollout. Corresponds to the JSON property failedLocations

Returns:

  • (Array<String>)


52020
52021
52022
# File 'lib/google/apis/compute_v1/classes.rb', line 52020

def failed_locations
  @failed_locations
end

#failed_resources_countFixnum

Output only. Resources failed. Corresponds to the JSON property failedResourcesCount

Returns:

  • (Fixnum)


52025
52026
52027
# File 'lib/google/apis/compute_v1/classes.rb', line 52025

def failed_resources_count
  @failed_resources_count
end

#location_statusHash<String,Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>

Output only. Status of each location in the wave. Map keys (locations) must be specified like "us-east1" or "asia-west1-a". Corresponds to the JSON property locationStatus



52031
52032
52033
# File 'lib/google/apis/compute_v1/classes.rb', line 52031

def location_status
  @location_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52038
52039
52040
52041
52042
52043
52044
52045
# File 'lib/google/apis/compute_v1/classes.rb', line 52038

def update!(**args)
  @completed_resources_count = args[:completed_resources_count] if args.key?(:completed_resources_count)
  @estimated_completion_time = args[:estimated_completion_time] if args.key?(:estimated_completion_time)
  @estimated_total_resources_count = args[:estimated_total_resources_count] if args.key?(:estimated_total_resources_count)
  @failed_locations = args[:failed_locations] if args.key?(:failed_locations)
  @failed_resources_count = args[:failed_resources_count] if args.key?(:failed_resources_count)
  @location_status = args[:location_status] if args.key?(:location_status)
end