Class: Google::Apis::ComputeV1::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



52112
52113
52114
# File 'lib/google/apis/compute_v1/classes.rb', line 52112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


52074
52075
52076
# File 'lib/google/apis/compute_v1/classes.rb', line 52074

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52079
52080
52081
# File 'lib/google/apis/compute_v1/classes.rb', line 52079

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



52084
52085
52086
# File 'lib/google/apis/compute_v1/classes.rb', line 52084

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52094
52095
52096
# File 'lib/google/apis/compute_v1/classes.rb', line 52094

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52099
52100
52101
# File 'lib/google/apis/compute_v1/classes.rb', line 52099

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52105
52106
52107
# File 'lib/google/apis/compute_v1/classes.rb', line 52105

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52110
52111
52112
# File 'lib/google/apis/compute_v1/classes.rb', line 52110

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52117
52118
52119
52120
52121
52122
52123
52124
52125
# File 'lib/google/apis/compute_v1/classes.rb', line 52117

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end