Class: Google::Apis::ComputeV1::RouteAsPath
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouteAsPath
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#as_lists ⇒ Array<Fixnum>
[Output Only] The AS numbers of the AS Path.
-
#path_segment_type ⇒ String
[Output Only] The type of the AS Path, which can be one of the following values: - 'AS_SET': unordered set of autonomous systems that the route in has traversed - 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed - 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed - 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Corresponds to the JSON property
pathSegmentType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteAsPath
constructor
A new instance of RouteAsPath.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteAsPath
Returns a new instance of RouteAsPath.
46298 46299 46300 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#as_lists ⇒ Array<Fixnum>
[Output Only] The AS numbers of the AS Path.
Corresponds to the JSON property asLists
46280 46281 46282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46280 def as_lists @as_lists end |
#path_segment_type ⇒ String
[Output Only] The type of the AS Path, which can be one of the following values:
- 'AS_SET': unordered set of autonomous systems that the route in has traversed
- 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed
- 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed
- 'AS_CONFED_SET': unordered set of
Member Autonomous Systems in the local confederation that the route has
traversed
Corresponds to the JSON property
pathSegmentType
46296 46297 46298 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46296 def path_segment_type @path_segment_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46303 46304 46305 46306 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46303 def update!(**args) @as_lists = args[:as_lists] if args.key?(:as_lists) @path_segment_type = args[:path_segment_type] if args.key?(:path_segment_type) end |