Class: Google::Apis::ComputeV1::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



53023
53024
53025
# File 'lib/google/apis/compute_v1/classes.rb', line 53023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52986
52987
52988
# File 'lib/google/apis/compute_v1/classes.rb', line 52986

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



52991
52992
52993
# File 'lib/google/apis/compute_v1/classes.rb', line 52991

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


52996
52997
52998
# File 'lib/google/apis/compute_v1/classes.rb', line 52996

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53006
53007
53008
# File 'lib/google/apis/compute_v1/classes.rb', line 53006

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53011
53012
53013
# File 'lib/google/apis/compute_v1/classes.rb', line 53011

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53016
53017
53018
# File 'lib/google/apis/compute_v1/classes.rb', line 53016

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53021
53022
53023
# File 'lib/google/apis/compute_v1/classes.rb', line 53021

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53028
53029
53030
53031
53032
53033
53034
53035
53036
# File 'lib/google/apis/compute_v1/classes.rb', line 53028

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end