Class: Google::Apis::ComputeV1::RouterNat

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Nat resource. It enables the VMs within the specified subnetworks to access Internet without external IP addresses. It specifies a list of subnetworks (and the ranges within) that want to use NAT. Customers can also provide the external IPs that would be used for NAT. GCP would auto-allocate ephemeral IPs if no external IPs are provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNat

Returns a new instance of RouterNat.



53937
53938
53939
# File 'lib/google/apis/compute_v1/classes.rb', line 53937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_network_tierString

The network tier to use when automatically reserving NAT IP addresses. Must be one of: PREMIUM, STANDARD. If not specified, then the current project-level default tier is used. Corresponds to the JSON property autoNetworkTier

Returns:

  • (String)


53754
53755
53756
# File 'lib/google/apis/compute_v1/classes.rb', line 53754

def auto_network_tier
  @auto_network_tier
end

#drain_nat_ipsArray<String>

A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT only. Corresponds to the JSON property drainNatIps

Returns:

  • (Array<String>)


53761
53762
53763
# File 'lib/google/apis/compute_v1/classes.rb', line 53761

def drain_nat_ips
  @drain_nat_ips
end

#effective_tcp_time_wait_timeout_secFixnum

Output only. Effective timeout (in seconds) for TCP connections that are in TIME_WAIT state. This value is equal to tcp_time_wait_timeout_sec. If tcp_time_wait_timeout_sec isn't set, the effective timeout is 30s or 120s. The field is output only. Corresponds to the JSON property effectiveTcpTimeWaitTimeoutSec

Returns:

  • (Fixnum)


53770
53771
53772
# File 'lib/google/apis/compute_v1/classes.rb', line 53770

def effective_tcp_time_wait_timeout_sec
  @effective_tcp_time_wait_timeout_sec
end

#enable_dynamic_port_allocationBoolean Also known as: enable_dynamic_port_allocation?

Enable Dynamic Port Allocation. If not specified, it is disabled by default. If set to true,

  • Dynamic Port Allocation will be enabled on this NAT config.
  • enableEndpointIndependentMapping cannot be set to true.
  • If minPorts is set, minPortsPerVm must be set to a power of two greater than or equal to 32. If minPortsPerVm is not set, a minimum of 32 ports will be allocated to a VM from this NAT config. Corresponds to the JSON property enableDynamicPortAllocation

Returns:

  • (Boolean)


53785
53786
53787
# File 'lib/google/apis/compute_v1/classes.rb', line 53785

def enable_dynamic_port_allocation
  @enable_dynamic_port_allocation
end

#enable_endpoint_independent_mappingBoolean Also known as: enable_endpoint_independent_mapping?

Corresponds to the JSON property enableEndpointIndependentMapping

Returns:

  • (Boolean)


53791
53792
53793
# File 'lib/google/apis/compute_v1/classes.rb', line 53791

def enable_endpoint_independent_mapping
  @enable_endpoint_independent_mapping
end

#endpoint_typesArray<String>

List of NAT-ted endpoint types supported by the Nat Gateway. If the list is empty, then it will be equivalent to include ENDPOINT_TYPE_VM Corresponds to the JSON property endpointTypes

Returns:

  • (Array<String>)


53798
53799
53800
# File 'lib/google/apis/compute_v1/classes.rb', line 53798

def endpoint_types
  @endpoint_types
end

#icmp_idle_timeout_secFixnum

Timeout (in seconds) for ICMP connections. Defaults to 30s if not set. Corresponds to the JSON property icmpIdleTimeoutSec

Returns:

  • (Fixnum)


53803
53804
53805
# File 'lib/google/apis/compute_v1/classes.rb', line 53803

def icmp_idle_timeout_sec
  @icmp_idle_timeout_sec
end

#log_configGoogle::Apis::ComputeV1::RouterNatLogConfig

Configuration of logging on a NAT. Corresponds to the JSON property logConfig



53808
53809
53810
# File 'lib/google/apis/compute_v1/classes.rb', line 53808

def log_config
  @log_config
end

#max_ports_per_vmFixnum

Maximum number of ports allocated to a VM from this NAT config when Dynamic Port Allocation is enabled. If Dynamic Port Allocation is not enabled, this field has no effect. If Dynamic Port Allocation is enabled, and this field is set, it must be set to a power of two greater than minPortsPerVm, or 64 if minPortsPerVm is not set. If Dynamic Port Allocation is enabled and this field is not set, a maximum of 65536 ports will be allocated to a VM from this NAT config. Corresponds to the JSON property maxPortsPerVm

Returns:

  • (Fixnum)


53821
53822
53823
# File 'lib/google/apis/compute_v1/classes.rb', line 53821

def max_ports_per_vm
  @max_ports_per_vm
end

#min_ports_per_vmFixnum

Minimum number of ports allocated to a VM from this NAT config. If not set, a default number of ports is allocated to a VM. This is rounded up to the nearest power of 2. For example, if the value of this field is 50, at least 64 ports are allocated to a VM. Corresponds to the JSON property minPortsPerVm

Returns:

  • (Fixnum)


53829
53830
53831
# File 'lib/google/apis/compute_v1/classes.rb', line 53829

def min_ports_per_vm
  @min_ports_per_vm
end

#nameString

Unique name of this Nat service. The name must be 1-63 characters long and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


53835
53836
53837
# File 'lib/google/apis/compute_v1/classes.rb', line 53835

def name
  @name
end

#nat64_subnetworksArray<Google::Apis::ComputeV1::RouterNatSubnetworkToNat64>

List of Subnetwork resources whose traffic should be translated by NAT64 Gateway. It is used only when LIST_OF_IPV6_SUBNETWORKS is selected for the SubnetworkIpRangeToNat64Option above. Corresponds to the JSON property nat64Subnetworks



53842
53843
53844
# File 'lib/google/apis/compute_v1/classes.rb', line 53842

def nat64_subnetworks
  @nat64_subnetworks
end

#nat_ip_allocate_optionString

Specify the NatIpAllocateOption, which can take one of the following values:

  • MANUAL_ONLY: Uses only Nat IP addresses provided by customers. When there are not enough specified Nat IPs, the Nat service fails for new VMs.
  • AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform; customers can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip should be empty. Corresponds to the JSON property natIpAllocateOption

Returns:

  • (String)


53855
53856
53857
# File 'lib/google/apis/compute_v1/classes.rb', line 53855

def nat_ip_allocate_option
  @nat_ip_allocate_option
end

#nat_ipsArray<String>

A list of URLs of the IP resources used for this Nat service. These IP addresses must be valid static external IP addresses assigned to the project. Corresponds to the JSON property natIps

Returns:

  • (Array<String>)


53862
53863
53864
# File 'lib/google/apis/compute_v1/classes.rb', line 53862

def nat_ips
  @nat_ips
end

#rulesArray<Google::Apis::ComputeV1::RouterNatRule>

A list of rules associated with this NAT. Corresponds to the JSON property rules



53867
53868
53869
# File 'lib/google/apis/compute_v1/classes.rb', line 53867

def rules
  @rules
end

#source_subnetwork_ip_ranges_to_natString

Specify the Nat option, which can take one of the following values:

  • ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are allowed to Nat.
  • ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP ranges in every Subnetwork are allowed to Nat.
  • LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field subnetwork below) The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES then there should not be any other Router.Nat section in any Router for this network in this region. Corresponds to the JSON property sourceSubnetworkIpRangesToNat

Returns:

  • (String)


53883
53884
53885
# File 'lib/google/apis/compute_v1/classes.rb', line 53883

def source_subnetwork_ip_ranges_to_nat
  @source_subnetwork_ip_ranges_to_nat
end

#source_subnetwork_ip_ranges_to_nat64String

Specify the Nat option for NAT64, which can take one of the following values:

  • ALL_IPV6_SUBNETWORKS: All of the IP ranges in every Subnetwork are allowed to Nat.
  • LIST_OF_IPV6_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field nat64_subnetwork below) The default is NAT64_OPTION_UNSPECIFIED. Note that if this field contains NAT64_ALL_V6_SUBNETWORKS no other Router.Nat section in this region can also enable NAT64 for any Subnetworks in this network. Other Router.Nat sections can still be present to enable NAT44 only. Corresponds to the JSON property sourceSubnetworkIpRangesToNat64

Returns:

  • (String)


53899
53900
53901
# File 'lib/google/apis/compute_v1/classes.rb', line 53899

def source_subnetwork_ip_ranges_to_nat64
  @source_subnetwork_ip_ranges_to_nat64
end

#subnetworksArray<Google::Apis::ComputeV1::RouterNatSubnetworkToNat>

A list of Subnetwork resources whose traffic should be translated by NAT Gateway. It is used only when LIST_OF_SUBNETWORKS is selected for the SubnetworkIpRangeToNatOption above. Corresponds to the JSON property subnetworks



53906
53907
53908
# File 'lib/google/apis/compute_v1/classes.rb', line 53906

def subnetworks
  @subnetworks
end

#tcp_established_idle_timeout_secFixnum

Timeout (in seconds) for TCP established connections. Defaults to 1200s if not set. Corresponds to the JSON property tcpEstablishedIdleTimeoutSec

Returns:

  • (Fixnum)


53912
53913
53914
# File 'lib/google/apis/compute_v1/classes.rb', line 53912

def tcp_established_idle_timeout_sec
  @tcp_established_idle_timeout_sec
end

#tcp_time_wait_timeout_secFixnum

Timeout (in seconds) for TCP connections that are in TIME_WAIT state. Defaults to 120s if not set. Corresponds to the JSON property tcpTimeWaitTimeoutSec

Returns:

  • (Fixnum)


53918
53919
53920
# File 'lib/google/apis/compute_v1/classes.rb', line 53918

def tcp_time_wait_timeout_sec
  @tcp_time_wait_timeout_sec
end

#tcp_transitory_idle_timeout_secFixnum

Timeout (in seconds) for TCP transitory connections. Defaults to 30s if not set. Corresponds to the JSON property tcpTransitoryIdleTimeoutSec

Returns:

  • (Fixnum)


53924
53925
53926
# File 'lib/google/apis/compute_v1/classes.rb', line 53924

def tcp_transitory_idle_timeout_sec
  @tcp_transitory_idle_timeout_sec
end

#typeString

Indicates whether this NAT is used for public or private IP translation. If unspecified, it defaults to PUBLIC. Corresponds to the JSON property type

Returns:

  • (String)


53930
53931
53932
# File 'lib/google/apis/compute_v1/classes.rb', line 53930

def type
  @type
end

#udp_idle_timeout_secFixnum

Timeout (in seconds) for UDP connections. Defaults to 30s if not set. Corresponds to the JSON property udpIdleTimeoutSec

Returns:

  • (Fixnum)


53935
53936
53937
# File 'lib/google/apis/compute_v1/classes.rb', line 53935

def udp_idle_timeout_sec
  @udp_idle_timeout_sec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53942
53943
53944
53945
53946
53947
53948
53949
53950
53951
53952
53953
53954
53955
53956
53957
53958
53959
53960
53961
53962
53963
53964
53965
53966
# File 'lib/google/apis/compute_v1/classes.rb', line 53942

def update!(**args)
  @auto_network_tier = args[:auto_network_tier] if args.key?(:auto_network_tier)
  @drain_nat_ips = args[:drain_nat_ips] if args.key?(:drain_nat_ips)
  @effective_tcp_time_wait_timeout_sec = args[:effective_tcp_time_wait_timeout_sec] if args.key?(:effective_tcp_time_wait_timeout_sec)
  @enable_dynamic_port_allocation = args[:enable_dynamic_port_allocation] if args.key?(:enable_dynamic_port_allocation)
  @enable_endpoint_independent_mapping = args[:enable_endpoint_independent_mapping] if args.key?(:enable_endpoint_independent_mapping)
  @endpoint_types = args[:endpoint_types] if args.key?(:endpoint_types)
  @icmp_idle_timeout_sec = args[:icmp_idle_timeout_sec] if args.key?(:icmp_idle_timeout_sec)
  @log_config = args[:log_config] if args.key?(:log_config)
  @max_ports_per_vm = args[:max_ports_per_vm] if args.key?(:max_ports_per_vm)
  @min_ports_per_vm = args[:min_ports_per_vm] if args.key?(:min_ports_per_vm)
  @name = args[:name] if args.key?(:name)
  @nat64_subnetworks = args[:nat64_subnetworks] if args.key?(:nat64_subnetworks)
  @nat_ip_allocate_option = args[:nat_ip_allocate_option] if args.key?(:nat_ip_allocate_option)
  @nat_ips = args[:nat_ips] if args.key?(:nat_ips)
  @rules = args[:rules] if args.key?(:rules)
  @source_subnetwork_ip_ranges_to_nat = args[:source_subnetwork_ip_ranges_to_nat] if args.key?(:source_subnetwork_ip_ranges_to_nat)
  @source_subnetwork_ip_ranges_to_nat64 = args[:source_subnetwork_ip_ranges_to_nat64] if args.key?(:source_subnetwork_ip_ranges_to_nat64)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
  @tcp_established_idle_timeout_sec = args[:tcp_established_idle_timeout_sec] if args.key?(:tcp_established_idle_timeout_sec)
  @tcp_time_wait_timeout_sec = args[:tcp_time_wait_timeout_sec] if args.key?(:tcp_time_wait_timeout_sec)
  @tcp_transitory_idle_timeout_sec = args[:tcp_transitory_idle_timeout_sec] if args.key?(:tcp_transitory_idle_timeout_sec)
  @type = args[:type] if args.key?(:type)
  @udp_idle_timeout_sec = args[:udp_idle_timeout_sec] if args.key?(:udp_idle_timeout_sec)
end