Class: Google::Apis::ComputeV1::RouterNatSubnetworkToNat
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterNatSubnetworkToNat
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Defines the IP ranges that want to use NAT for a subnetwork.
Instance Attribute Summary collapse
-
#name ⇒ String
URL for the subnetwork resource that will use NAT.
-
#secondary_ip_range_names ⇒ Array<String>
A list of the secondary ranges of the Subnetwork that are allowed to use NAT.
-
#source_ip_ranges_to_nat ⇒ Array<String>
Specify the options for NAT ranges in the Subnetwork.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNatSubnetworkToNat
constructor
A new instance of RouterNatSubnetworkToNat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNatSubnetworkToNat
Returns a new instance of RouterNatSubnetworkToNat.
29778 29779 29780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
URL for the subnetwork resource that will use NAT.
Corresponds to the JSON property name
29761 29762 29763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29761 def name @name end |
#secondary_ip_range_names ⇒ Array<String>
A list of the secondary ranges of the Subnetwork that are allowed to use NAT.
This can be populated only if "LIST_OF_SECONDARY_IP_RANGES" is one of the
values in source_ip_ranges_to_nat.
Corresponds to the JSON property secondaryIpRangeNames
29768 29769 29770 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29768 def secondary_ip_range_names @secondary_ip_range_names end |
#source_ip_ranges_to_nat ⇒ Array<String>
Specify the options for NAT ranges in the Subnetwork. All options of a single
value are valid except NAT_IP_RANGE_OPTION_UNSPECIFIED. The only valid option
with multiple values is: ["PRIMARY_IP_RANGE", "LIST_OF_SECONDARY_IP_RANGES"]
Default: [ALL_IP_RANGES]
Corresponds to the JSON property sourceIpRangesToNat
29776 29777 29778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29776 def source_ip_ranges_to_nat @source_ip_ranges_to_nat end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29783 29784 29785 29786 29787 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29783 def update!(**args) @name = args[:name] if args.key?(:name) @secondary_ip_range_names = args[:secondary_ip_range_names] if args.key?(:secondary_ip_range_names) @source_ip_ranges_to_nat = args[:source_ip_ranges_to_nat] if args.key?(:source_ip_ranges_to_nat) end |