Class: Google::Apis::ComputeV1::RouterStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatus

Returns a new instance of RouterStatus.



54232
54233
54234
# File 'lib/google/apis/compute_v1/classes.rb', line 54232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#best_routesArray<Google::Apis::ComputeV1::Route>

A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router. Lists all of the best routes per prefix that are programmed into this region's VPC data plane. When global dynamic routing mode is turned on in the VPC network, this list can include cross-region dynamic routes from Cloud Routers in other regions. Corresponds to the JSON property bestRoutes

Returns:



54202
54203
54204
# File 'lib/google/apis/compute_v1/classes.rb', line 54202

def best_routes
  @best_routes
end

#best_routes_for_routerArray<Google::Apis::ComputeV1::Route>

A list of the best BGP routes learned by this Cloud Router. It is possible that routes listed might not be programmed into the data plane, if the Google Cloud control plane finds a more optimal route for a prefix than a route learned by this Cloud Router. Corresponds to the JSON property bestRoutesForRouter

Returns:



54210
54211
54212
# File 'lib/google/apis/compute_v1/classes.rb', line 54210

def best_routes_for_router
  @best_routes_for_router
end

#bgp_peer_statusArray<Google::Apis::ComputeV1::RouterStatusBgpPeerStatus>

Corresponds to the JSON property bgpPeerStatus



54215
54216
54217
# File 'lib/google/apis/compute_v1/classes.rb', line 54215

def bgp_peer_status
  @bgp_peer_status
end

#nat_statusArray<Google::Apis::ComputeV1::RouterStatusNatStatus>

Corresponds to the JSON property natStatus



54220
54221
54222
# File 'lib/google/apis/compute_v1/classes.rb', line 54220

def nat_status
  @nat_status
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


54225
54226
54227
# File 'lib/google/apis/compute_v1/classes.rb', line 54225

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


54230
54231
54232
# File 'lib/google/apis/compute_v1/classes.rb', line 54230

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54237
54238
54239
54240
54241
54242
54243
54244
# File 'lib/google/apis/compute_v1/classes.rb', line 54237

def update!(**args)
  @best_routes = args[:best_routes] if args.key?(:best_routes)
  @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router)
  @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status)
  @nat_status = args[:nat_status] if args.key?(:nat_status)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
end