Class: Google::Apis::ComputeV1::SavedAttachedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SavedAttachedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.
Instance Attribute Summary collapse
-
#auto_delete ⇒ Boolean
(also: #auto_delete?)
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
-
#boot ⇒ Boolean
(also: #boot?)
Indicates that this is a boot disk.
-
#device_name ⇒ String
Specifies the name of the disk attached to the source instance.
-
#disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The encryption key for the disk.
-
#disk_size_gb ⇒ Fixnum
The size of the disk in base-2 GB.
-
#disk_type ⇒ String
Output only.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeV1::GuestOsFeature>
A list of features to enable on the guest operating system.
-
#index ⇒ Fixnum
Output only.
-
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
-
#kind ⇒ String
Output only.
-
#licenses ⇒ Array<String>
Output only.
-
#mode ⇒ String
The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
-
#source ⇒ String
Specifies a URL of the disk attached to the source instance.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
-
#type ⇒ String
Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedAttachedDisk
constructor
A new instance of SavedAttachedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedAttachedDisk
Returns a new instance of SavedAttachedDisk.
55307 55308 55309 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ Boolean Also known as: auto_delete?
Specifies whether the disk will be auto-deleted when the instance is
deleted (but not when the disk is detached from the instance).
Corresponds to the JSON property autoDelete
55211 55212 55213 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55211 def auto_delete @auto_delete end |
#boot ⇒ Boolean Also known as: boot?
Indicates that this is a boot disk. The virtual machine will use the first
partition of the disk for its root filesystem.
Corresponds to the JSON property boot
55218 55219 55220 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55218 def boot @boot end |
#device_name ⇒ String
Specifies the name of the disk attached to the source instance.
Corresponds to the JSON property deviceName
55224 55225 55226 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55224 def device_name @device_name end |
#disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The encryption key for the disk.
Corresponds to the JSON property diskEncryptionKey
55229 55230 55231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55229 def disk_encryption_key @disk_encryption_key end |
#disk_size_gb ⇒ Fixnum
The size of the disk in base-2 GB.
Corresponds to the JSON property diskSizeGb
55234 55235 55236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55234 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Output only. [Output Only] URL of the disk type resource. For example:projects/
project/zones/zone/diskTypes/pd-standard or
pd-ssd
Corresponds to the JSON property diskType
55241 55242 55243 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55241 def disk_type @disk_type end |
#guest_os_features ⇒ Array<Google::Apis::ComputeV1::GuestOsFeature>
A list of features to enable on the guest operating system. Applicable only
for bootable images. Read
Enabling guest operating system features to see a list of available
options.
Corresponds to the JSON property guestOsFeatures
55249 55250 55251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55249 def guest_os_features @guest_os_features end |
#index ⇒ Fixnum
Output only. Specifies zero-based index of the disk that is attached to the
source
instance.
Corresponds to the JSON property index
55256 55257 55258 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55256 def index @index end |
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is
either SCSI or NVME.
Corresponds to the JSON property interface
55262 55263 55264 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55262 def interface @interface end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk
for attached disks.
Corresponds to the JSON property kind
55268 55269 55270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55268 def kind @kind end |
#licenses ⇒ Array<String>
Output only. [Output Only] Any valid publicly visible licenses.
Corresponds to the JSON property licenses
55273 55274 55275 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55273 def licenses @licenses end |
#mode ⇒ String
The mode in which this disk is attached to the source instance,
eitherREAD_WRITE or READ_ONLY.
Corresponds to the JSON property mode
55279 55280 55281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55279 def mode @mode end |
#source ⇒ String
Specifies a URL of the disk attached to the source instance.
Corresponds to the JSON property source
55284 55285 55286 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55284 def source @source end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] A size of the storage used by the disk's snapshot
by this
machine image.
Corresponds to the JSON property storageBytes
55291 55292 55293 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55291 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
55300 55301 55302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55300 def storage_bytes_status @storage_bytes_status end |
#type ⇒ String
Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
Corresponds to the JSON property type
55305 55306 55307 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55305 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55312 55313 55314 55315 55316 55317 55318 55319 55320 55321 55322 55323 55324 55325 55326 55327 55328 55329 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55312 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @boot = args[:boot] if args.key?(:boot) @device_name = args[:device_name] if args.key?(:device_name) @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @index = args[:index] if args.key?(:index) @interface = args[:interface] if args.key?(:interface) @kind = args[:kind] if args.key?(:kind) @licenses = args[:licenses] if args.key?(:licenses) @mode = args[:mode] if args.key?(:mode) @source = args[:source] if args.key?(:source) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) @type = args[:type] if args.key?(:type) end |