Class: Google::Apis::ComputeV1::SavedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedDisk

Returns a new instance of SavedDisk.



55322
55323
55324
# File 'lib/google/apis/compute_v1/classes.rb', line 55322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. [Output Only] The architecture of the attached disk. Corresponds to the JSON property architecture

Returns:

  • (String)


55293
55294
55295
# File 'lib/google/apis/compute_v1/classes.rb', line 55293

def architecture
  @architecture
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#savedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


55299
55300
55301
# File 'lib/google/apis/compute_v1/classes.rb', line 55299

def kind
  @kind
end

#source_diskString

Output only. Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property sourceDisk

Returns:

  • (String)


55304
55305
55306
# File 'lib/google/apis/compute_v1/classes.rb', line 55304

def source_disk
  @source_disk
end

#storage_bytesFixnum

Output only. [Output Only] Size of the individual disk snapshot used by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


55311
55312
55313
# File 'lib/google/apis/compute_v1/classes.rb', line 55311

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


55320
55321
55322
# File 'lib/google/apis/compute_v1/classes.rb', line 55320

def storage_bytes_status
  @storage_bytes_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55327
55328
55329
55330
55331
55332
55333
# File 'lib/google/apis/compute_v1/classes.rb', line 55327

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @kind = args[:kind] if args.key?(:kind)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
end