Class: Google::Apis::ComputeV1::SecurityPoliciesScopedList::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Informational warning which replaces the list of security policies when the list is empty.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



55849
55850
55851
# File 'lib/google/apis/compute_v1/classes.rb', line 55849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


55831
55832
55833
# File 'lib/google/apis/compute_v1/classes.rb', line 55831

def code
  @code
end

#dataArray<Google::Apis::ComputeV1::SecurityPoliciesScopedList::Warning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" Corresponds to the JSON property data



55842
55843
55844
# File 'lib/google/apis/compute_v1/classes.rb', line 55842

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


55847
55848
55849
# File 'lib/google/apis/compute_v1/classes.rb', line 55847

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55854
55855
55856
55857
55858
# File 'lib/google/apis/compute_v1/classes.rb', line 55854

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end