Class: Google::Apis::ComputeV1::SecurityPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Google Cloud Armor security policy resource. Only external backend services that use load balancers can reference a security policy. For more information, see Google Cloud Armor security policy overview.
Instance Attribute Summary collapse
-
#adaptive_protection_config ⇒ Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfig
Configuration options for Cloud Armor Adaptive Protection (CAAP).
-
#advanced_options_config ⇒ Google::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfig
Corresponds to the JSON property
advancedOptionsConfig. -
#associations ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyAssociation>
A list of associations that belong to this policy.
-
#creation_timestamp ⇒ String
Output only.
-
#ddos_protection_config ⇒ Google::Apis::ComputeV1::SecurityPolicyDdosProtectionConfig
Corresponds to the JSON property
ddosProtectionConfig. -
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this security policy, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#name ⇒ String
Name of the resource.
-
#parent ⇒ String
Output only.
-
#recaptcha_options_config ⇒ Google::Apis::ComputeV1::SecurityPolicyRecaptchaOptionsConfig
Corresponds to the JSON property
recaptchaOptionsConfig. -
#region ⇒ String
Output only.
-
#rules ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRule>
A list of rules that belong to this policy.
-
#self_link ⇒ String
Output only.
-
#short_name ⇒ String
User-provided name of the organization security policy.
-
#type ⇒ String
The type indicates the intended use of the security policy.
-
#user_defined_fields ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyUserDefinedField>
Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicy
constructor
A new instance of SecurityPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicy
Returns a new instance of SecurityPolicy.
56138 56139 56140 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptive_protection_config ⇒ Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfig
Configuration options for Cloud Armor Adaptive Protection (CAAP).
Corresponds to the JSON property adaptiveProtectionConfig
55968 55969 55970 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55968 def adaptive_protection_config @adaptive_protection_config end |
#advanced_options_config ⇒ Google::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfig
Corresponds to the JSON property advancedOptionsConfig
55973 55974 55975 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55973 def @advanced_options_config end |
#associations ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyAssociation>
A list of associations that belong to this policy.
Corresponds to the JSON property associations
55978 55979 55980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55978 def associations @associations end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
55984 55985 55986 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55984 def @creation_timestamp end |
#ddos_protection_config ⇒ Google::Apis::ComputeV1::SecurityPolicyDdosProtectionConfig
Corresponds to the JSON property ddosProtectionConfig
55989 55990 55991 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55989 def ddos_protection_config @ddos_protection_config end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
55995 55996 55997 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55995 def description @description end |
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of
the metadata's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update metadata. You must always provide an
up-to-date fingerprint hash in order to update or change metadata,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make get() request to the
security policy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
56008 56009 56010 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56008 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
56015 56016 56017 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56015 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#
securityPolicyfor security policies
Corresponds to the JSON property kind
56021 56022 56023 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56021 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this security policy, which
is essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels.
To see the latest fingerprint, make get() request to the
security policy.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
56033 56034 56035 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56033 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
56040 56041 56042 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56040 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
56051 56052 56053 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56051 def name @name end |
#parent ⇒ String
Output only. [Output Only] The parent of the security policy.
Corresponds to the JSON property parent
56056 56057 56058 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56056 def parent @parent end |
#recaptcha_options_config ⇒ Google::Apis::ComputeV1::SecurityPolicyRecaptchaOptionsConfig
Corresponds to the JSON property recaptchaOptionsConfig
56061 56062 56063 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56061 def @recaptcha_options_config end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional security
policy
resides. This field is not applicable to global security policies.
Corresponds to the JSON property region
56068 56069 56070 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56068 def region @region end |
#rules ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRule>
A list of rules that belong to this policy.
There must always be a default rule which is a rule with priority
2147483647 and match all condition (for the match condition this means
match "" for srcIpRanges and for the networkMatch condition every field
must be either match "" or not set). If no rules are provided when
creating a security policy, a default rule with action "allow" will be
added.
Corresponds to the JSON property rules
56079 56080 56081 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56079 def rules @rules end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
56084 56085 56086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56084 def self_link @self_link end |
#short_name ⇒ String
User-provided name of the organization security policy. The name should be
unique in the organization in which the security policy is created. This
should only be used when SecurityPolicyType is CLOUD_ARMOR.
The name must be 1-63 characters long, and comply with
https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be 1-63
characters long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a
lowercase letter, and all following characters must be a dash, lowercase
letter, or digit, except the last character, which cannot be a dash.
Corresponds to the JSON property shortName
56097 56098 56099 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56097 def short_name @short_name end |
#type ⇒ String
The type indicates the intended use of the security policy.
- CLOUD_ARMOR: Cloud Armor backend security policies can be configured to filter incoming HTTP requests targeting backend services. They filter requests before they hit the origin servers.
- CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can be configured to filter incoming HTTP requests targeting backend services (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). They filter requests before the request is served from Google's cache.
- CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor internal service policies can be configured to filter HTTP requests targeting services managed by Traffic Director in a service mesh. They filter requests before the request is served from the application.
- CLOUD_ARMOR_NETWORK: Cloud Armor network policies
can be configured to filter packets targeting network load balancing
resources such as backend services, target pools, target instances, and
instances with external IPs. They filter requests before the request is
served from the application.
This field can be set only at resource creation time.
Corresponds to the JSON property
type
56120 56121 56122 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56120 def type @type end |
#user_defined_fields ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyUserDefinedField>
Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies. A user-defined field consists of up to 4 bytes extracted from a fixed offset in the packet, relative to the IPv4, IPv6, TCP, or UDP header, with an optional mask to select certain bits. Rules may then specify matching values for these fields. Example: userDefinedFields:
- name: "ipv4_fragment_offset"
base: IPV4
offset: 6
size: 2
mask: "0x1fff"
Corresponds to the JSON property
userDefinedFields
56136 56137 56138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56136 def user_defined_fields @user_defined_fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56143 56144 56145 56146 56147 56148 56149 56150 56151 56152 56153 56154 56155 56156 56157 56158 56159 56160 56161 56162 56163 56164 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56143 def update!(**args) @adaptive_protection_config = args[:adaptive_protection_config] if args.key?(:adaptive_protection_config) @advanced_options_config = args[:advanced_options_config] if args.key?(:advanced_options_config) @associations = args[:associations] if args.key?(:associations) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @ddos_protection_config = args[:ddos_protection_config] if args.key?(:ddos_protection_config) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @recaptcha_options_config = args[:recaptcha_options_config] if args.key?(:recaptcha_options_config) @region = args[:region] if args.key?(:region) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @short_name = args[:short_name] if args.key?(:short_name) @type = args[:type] if args.key?(:type) @user_defined_fields = args[:user_defined_fields] if args.key?(:user_defined_fields) end |