Class: Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration options for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig

Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.



55036
55037
55038
# File 'lib/google/apis/compute_v1/classes.rb', line 55036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

If set to true, enables CAAP for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR. Corresponds to the JSON property enable

Returns:

  • (Boolean)


55018
55019
55020
# File 'lib/google/apis/compute_v1/classes.rb', line 55018

def enable
  @enable
end

#rule_visibilityString

Rule visibility can be one of the following: STANDARD - opaque rules. (default) PREMIUM - transparent rules. This field is only supported in Global Security Policies of type CLOUD_ARMOR. Corresponds to the JSON property ruleVisibility

Returns:

  • (String)


55028
55029
55030
# File 'lib/google/apis/compute_v1/classes.rb', line 55028

def rule_visibility
  @rule_visibility
end

#threshold_configsArray<Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig>

Configuration options for layer7 adaptive protection for various customizable thresholds. Corresponds to the JSON property thresholdConfigs



55034
55035
55036
# File 'lib/google/apis/compute_v1/classes.rb', line 55034

def threshold_configs
  @threshold_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55041
55042
55043
55044
55045
# File 'lib/google/apis/compute_v1/classes.rb', line 55041

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @rule_visibility = args[:rule_visibility] if args.key?(:rule_visibility)
  @threshold_configs = args[:threshold_configs] if args.key?(:threshold_configs)
end