Class: Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Configurations to specifc granular traffic units processed by Adaptive Protection.
Instance Attribute Summary collapse
-
#enable_each_unique_value ⇒ Boolean
(also: #enable_each_unique_value?)
If enabled, traffic matching each unique value for the specified type constitutes a separate traffic unit.
-
#type ⇒ String
Type of this configuration.
-
#value ⇒ String
Requests that match this value constitute a granular traffic unit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
constructor
A new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.
54796 54797 54798 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_each_unique_value ⇒ Boolean Also known as: enable_each_unique_value?
If enabled, traffic matching each unique value for the specified
type constitutes a separate traffic unit.
It can only be set to true if value is empty.
Corresponds to the JSON property enableEachUniqueValue
54783 54784 54785 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54783 def enable_each_unique_value @enable_each_unique_value end |
#type ⇒ String
Type of this configuration.
Corresponds to the JSON property type
54789 54790 54791 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54789 def type @type end |
#value ⇒ String
Requests that match this value constitute a granular traffic unit.
Corresponds to the JSON property value
54794 54795 54796 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54794 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54801 54802 54803 54804 54805 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54801 def update!(**args) @enable_each_unique_value = args[:enable_each_unique_value] if args.key?(:enable_each_unique_value) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |