Class: Google::Apis::ComputeV1::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions

Returns a new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.



56126
56127
56128
# File 'lib/google/apis/compute_v1/classes.rb', line 56126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_token_site_keysArray<String>

A list of site keys to be used during the validation of reCAPTCHA action-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created. Corresponds to the JSON property actionTokenSiteKeys

Returns:

  • (Array<String>)


56116
56117
56118
# File 'lib/google/apis/compute_v1/classes.rb', line 56116

def action_token_site_keys
  @action_token_site_keys
end

#session_token_site_keysArray<String>

A list of site keys to be used during the validation of reCAPTCHA session-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created. Corresponds to the JSON property sessionTokenSiteKeys

Returns:

  • (Array<String>)


56124
56125
56126
# File 'lib/google/apis/compute_v1/classes.rb', line 56124

def session_token_site_keys
  @session_token_site_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56131
56132
56133
56134
# File 'lib/google/apis/compute_v1/classes.rb', line 56131

def update!(**args)
  @action_token_site_keys = args[:action_token_site_keys] if args.key?(:action_token_site_keys)
  @session_token_site_keys = args[:session_token_site_keys] if args.key?(:session_token_site_keys)
end