Class: Google::Apis::ComputeV1::SecurityPolicyRuleNetworkMatcher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a match condition that incoming network traffic is evaluated against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleNetworkMatcher

Returns a new instance of SecurityPolicyRuleNetworkMatcher.



56976
56977
56978
# File 'lib/google/apis/compute_v1/classes.rb', line 56976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_ip_rangesArray<String>

Destination IPv4/IPv6 addresses or CIDR prefixes, in standard text format. Corresponds to the JSON property destIpRanges

Returns:

  • (Array<String>)


56932
56933
56934
# File 'lib/google/apis/compute_v1/classes.rb', line 56932

def dest_ip_ranges
  @dest_ip_ranges
end

#dest_portsArray<String>

Destination port numbers for TCP/UDP/SCTP. Each element can be a 16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023"). Corresponds to the JSON property destPorts

Returns:

  • (Array<String>)


56938
56939
56940
# File 'lib/google/apis/compute_v1/classes.rb', line 56938

def dest_ports
  @dest_ports
end

#ip_protocolsArray<String>

IPv4 protocol / IPv6 next header (after extension headers). Each element can be an 8-bit unsigned decimal number (e.g. "6"), range (e.g. "253-254"), or one of the following protocol names: "tcp", "udp", "icmp", "esp", "ah", "ipip", or "sctp". Corresponds to the JSON property ipProtocols

Returns:

  • (Array<String>)


56946
56947
56948
# File 'lib/google/apis/compute_v1/classes.rb', line 56946

def ip_protocols
  @ip_protocols
end

#src_asnsArray<Fixnum>

BGP Autonomous System Number associated with the source IP address. Corresponds to the JSON property srcAsns

Returns:

  • (Array<Fixnum>)


56951
56952
56953
# File 'lib/google/apis/compute_v1/classes.rb', line 56951

def src_asns
  @src_asns
end

#src_ip_rangesArray<String>

Source IPv4/IPv6 addresses or CIDR prefixes, in standard text format. Corresponds to the JSON property srcIpRanges

Returns:

  • (Array<String>)


56956
56957
56958
# File 'lib/google/apis/compute_v1/classes.rb', line 56956

def src_ip_ranges
  @src_ip_ranges
end

#src_portsArray<String>

Source port numbers for TCP/UDP/SCTP. Each element can be a 16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023"). Corresponds to the JSON property srcPorts

Returns:

  • (Array<String>)


56962
56963
56964
# File 'lib/google/apis/compute_v1/classes.rb', line 56962

def src_ports
  @src_ports
end

#src_region_codesArray<String>

Two-letter ISO 3166-1 alpha-2 country code associated with the source IP address. Corresponds to the JSON property srcRegionCodes

Returns:

  • (Array<String>)


56968
56969
56970
# File 'lib/google/apis/compute_v1/classes.rb', line 56968

def src_region_codes
  @src_region_codes
end

#user_defined_fieldsArray<Google::Apis::ComputeV1::SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>

User-defined fields. Each element names a defined field and lists the matching values for that field. Corresponds to the JSON property userDefinedFields



56974
56975
56976
# File 'lib/google/apis/compute_v1/classes.rb', line 56974

def user_defined_fields
  @user_defined_fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56981
56982
56983
56984
56985
56986
56987
56988
56989
56990
# File 'lib/google/apis/compute_v1/classes.rb', line 56981

def update!(**args)
  @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges)
  @dest_ports = args[:dest_ports] if args.key?(:dest_ports)
  @ip_protocols = args[:ip_protocols] if args.key?(:ip_protocols)
  @src_asns = args[:src_asns] if args.key?(:src_asns)
  @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges)
  @src_ports = args[:src_ports] if args.key?(:src_ports)
  @src_region_codes = args[:src_region_codes] if args.key?(:src_region_codes)
  @user_defined_fields = args[:user_defined_fields] if args.key?(:user_defined_fields)
end