Class: Google::Apis::ComputeV1::ServiceAttachmentConsumerProjectLimit

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConsumerProjectLimit

Returns a new instance of ServiceAttachmentConsumerProjectLimit.



56504
56505
56506
# File 'lib/google/apis/compute_v1/classes.rb', line 56504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_limitFixnum

The value of the limit to set. For endpoint_url, the limit should be no more than 1. Corresponds to the JSON property connectionLimit

Returns:

  • (Fixnum)


56487
56488
56489
# File 'lib/google/apis/compute_v1/classes.rb', line 56487

def connection_limit
  @connection_limit
end

#endpoint_urlString

The URL for the PSC endpoint to accept Corresponds to the JSON property endpointUrl

Returns:

  • (String)


56492
56493
56494
# File 'lib/google/apis/compute_v1/classes.rb', line 56492

def endpoint_url
  @endpoint_url
end

#network_urlString

The network URL for the network to set the limit for. Corresponds to the JSON property networkUrl

Returns:

  • (String)


56497
56498
56499
# File 'lib/google/apis/compute_v1/classes.rb', line 56497

def network_url
  @network_url
end

#project_id_or_numString

The project id or number for the project to set the limit for. Corresponds to the JSON property projectIdOrNum

Returns:

  • (String)


56502
56503
56504
# File 'lib/google/apis/compute_v1/classes.rb', line 56502

def project_id_or_num
  @project_id_or_num
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56509
56510
56511
56512
56513
56514
# File 'lib/google/apis/compute_v1/classes.rb', line 56509

def update!(**args)
  @connection_limit = args[:connection_limit] if args.key?(:connection_limit)
  @endpoint_url = args[:endpoint_url] if args.key?(:endpoint_url)
  @network_url = args[:network_url] if args.key?(:network_url)
  @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num)
end