Class: Google::Apis::ComputeV1::ShieldedInstanceIntegrityPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The policy describes the baseline against which Instance boot integrity is measured.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShieldedInstanceIntegrityPolicy

Returns a new instance of ShieldedInstanceIntegrityPolicy.



57674
57675
57676
# File 'lib/google/apis/compute_v1/classes.rb', line 57674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#update_auto_learn_policyBoolean Also known as: update_auto_learn_policy?

Updates the integrity policy baseline using the measurements from the VM instance's most recent boot. Corresponds to the JSON property updateAutoLearnPolicy

Returns:

  • (Boolean)


57671
57672
57673
# File 'lib/google/apis/compute_v1/classes.rb', line 57671

def update_auto_learn_policy
  @update_auto_learn_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57679
57680
57681
# File 'lib/google/apis/compute_v1/classes.rb', line 57679

def update!(**args)
  @update_auto_learn_policy = args[:update_auto_learn_policy] if args.key?(:update_auto_learn_policy)
end