Class: Google::Apis::ComputeV1::SnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Snapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotList

Returns a new instance of SnapshotList.



59006
59007
59008
# File 'lib/google/apis/compute_v1/classes.rb', line 59006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58974
58975
58976
# File 'lib/google/apis/compute_v1/classes.rb', line 58974

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Snapshot>

A list of Snapshot resources. Corresponds to the JSON property items



58979
58980
58981
# File 'lib/google/apis/compute_v1/classes.rb', line 58979

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


58984
58985
58986
# File 'lib/google/apis/compute_v1/classes.rb', line 58984

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58994
58995
58996
# File 'lib/google/apis/compute_v1/classes.rb', line 58994

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58999
59000
59001
# File 'lib/google/apis/compute_v1/classes.rb', line 58999

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59004
59005
59006
# File 'lib/google/apis/compute_v1/classes.rb', line 59004

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59011
59012
59013
59014
59015
59016
59017
59018
# File 'lib/google/apis/compute_v1/classes.rb', line 59011

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end