Class: Google::Apis::ComputeV1::SnapshotSettingsAccessLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettingsAccessLocation

Returns a new instance of SnapshotSettingsAccessLocation.



59109
59110
59111
# File 'lib/google/apis/compute_v1/classes.rb', line 59109

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationsHash<String,Google::Apis::ComputeV1::SnapshotSettingsAccessLocationAccessLocationPreference>

List of regions that can restore a regional snapshot from the current region Corresponds to the JSON property locations



59102
59103
59104
# File 'lib/google/apis/compute_v1/classes.rb', line 59102

def locations
  @locations
end

#policyString

Policy of which location is allowed to access snapshot. Corresponds to the JSON property policy

Returns:

  • (String)


59107
59108
59109
# File 'lib/google/apis/compute_v1/classes.rb', line 59107

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59114
59115
59116
59117
# File 'lib/google/apis/compute_v1/classes.rb', line 59114

def update!(**args)
  @locations = args[:locations] if args.key?(:locations)
  @policy = args[:policy] if args.key?(:policy)
end