Class: Google::Apis::ComputeV1::SnapshotUpdateKmsKeyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotUpdateKmsKeyRequest

Returns a new instance of SnapshotUpdateKmsKeyRequest.



58035
58036
58037
# File 'lib/google/apis/compute_v1/classes.rb', line 58035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Optional. The new KMS key to replace the current one on the snapshot. If empty, the snapshot will be re-encrypted using the primary version of the snapshot's current KMS key. The KMS key can be provided in the following formats:

  • projects/project_id/locations/region/keyRings/key_ring/cryptoKeys/key Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


58033
58034
58035
# File 'lib/google/apis/compute_v1/classes.rb', line 58033

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58040
58041
58042
# File 'lib/google/apis/compute_v1/classes.rb', line 58040

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end