Class: Google::Apis::ComputeV1::SourceDiskEncryptionKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceDiskEncryptionKey

Returns a new instance of SourceDiskEncryptionKey.



56227
56228
56229
# File 'lib/google/apis/compute_v1/classes.rb', line 56227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property diskEncryptionKey



56213
56214
56215
# File 'lib/google/apis/compute_v1/classes.rb', line 56213

def disk_encryption_key
  @disk_encryption_key
end

#source_diskString

URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values:

Returns:

  • (String)


56225
56226
56227
# File 'lib/google/apis/compute_v1/classes.rb', line 56225

def source_disk
  @source_disk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56232
56233
56234
56235
# File 'lib/google/apis/compute_v1/classes.rb', line 56232

def update!(**args)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
end