Class: Google::Apis::ComputeV1::SslCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an SSL certificate resource. Google Compute Engine has two SSL certificate resources:

  • Global
  • Regional The global SSL certificates (sslCertificates) are used by:

  • Global external Application Load Balancers

  • Classic Application Load Balancers

  • Proxy Network Load Balancers (with target SSL proxies) The regional SSL certificates (regionSslCertificates) are used by:

  • Regional external Application Load Balancers

  • Regional internal Application Load Balancers Optionally, certificate file contents that you upload can contain a set of up to five PEM-encoded certificates. The API call creates an object (sslCertificate) that holds this data. You can use SSL keys and certificates to secure connections to a load balancer. For more information, read Creating and using SSL certificates,SSL certificates quotas and limits, and Troubleshooting SSL certificates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificate

Returns a new instance of SslCertificate.



58344
58345
58346
# File 'lib/google/apis/compute_v1/classes.rb', line 58344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificateString

A value read into memory from a certificate file. The certificate file must be in PEM format. The certificate chain must be no greater than 5 certs long. The chain must include at least one intermediate cert. Corresponds to the JSON property certificate

Returns:

  • (String)


58260
58261
58262
# File 'lib/google/apis/compute_v1/classes.rb', line 58260

def certificate
  @certificate
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


58266
58267
58268
# File 'lib/google/apis/compute_v1/classes.rb', line 58266

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


58272
58273
58274
# File 'lib/google/apis/compute_v1/classes.rb', line 58272

def description
  @description
end

#expire_timeString

Output only. [Output Only] Expire time of the certificate. RFC3339 Corresponds to the JSON property expireTime

Returns:

  • (String)


58277
58278
58279
# File 'lib/google/apis/compute_v1/classes.rb', line 58277

def expire_time
  @expire_time
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


58283
58284
58285
# File 'lib/google/apis/compute_v1/classes.rb', line 58283

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#sslCertificate for SSL certificates. Corresponds to the JSON property kind

Returns:

  • (String)


58289
58290
58291
# File 'lib/google/apis/compute_v1/classes.rb', line 58289

def kind
  @kind
end

#managedGoogle::Apis::ComputeV1::SslCertificateManagedSslCertificate

Configuration and status of a managed SSL certificate. Corresponds to the JSON property managed



58294
58295
58296
# File 'lib/google/apis/compute_v1/classes.rb', line 58294

def managed
  @managed
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


58305
58306
58307
# File 'lib/google/apis/compute_v1/classes.rb', line 58305

def name
  @name
end

#private_keyString

A value read into memory from a write-only private key file. The private key file must be in PEM format. For security, only insert requests include this field. Corresponds to the JSON property privateKey

Returns:

  • (String)


58312
58313
58314
# File 'lib/google/apis/compute_v1/classes.rb', line 58312

def private_key
  @private_key
end

#regionString

Output only. [Output Only] URL of the region where the regional SSL Certificate resides. This field is not applicable to global SSL Certificate. Corresponds to the JSON property region

Returns:

  • (String)


58319
58320
58321
# File 'lib/google/apis/compute_v1/classes.rb', line 58319

def region
  @region
end

[Output only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58324
58325
58326
# File 'lib/google/apis/compute_v1/classes.rb', line 58324

def self_link
  @self_link
end

#self_managedGoogle::Apis::ComputeV1::SslCertificateSelfManagedSslCertificate

Configuration and status of a self-managed SSL certificate. Corresponds to the JSON property selfManaged



58329
58330
58331
# File 'lib/google/apis/compute_v1/classes.rb', line 58329

def self_managed
  @self_managed
end

#subject_alternative_namesArray<String>

Output only. [Output Only] Domains associated with the certificate via Subject Alternative Name. Corresponds to the JSON property subjectAlternativeNames

Returns:

  • (Array<String>)


58335
58336
58337
# File 'lib/google/apis/compute_v1/classes.rb', line 58335

def subject_alternative_names
  @subject_alternative_names
end

#typeString

(Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. Corresponds to the JSON property type

Returns:

  • (String)


58342
58343
58344
# File 'lib/google/apis/compute_v1/classes.rb', line 58342

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58349
58350
58351
58352
58353
58354
58355
58356
58357
58358
58359
58360
58361
58362
58363
58364
# File 'lib/google/apis/compute_v1/classes.rb', line 58349

def update!(**args)
  @certificate = args[:certificate] if args.key?(:certificate)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @managed = args[:managed] if args.key?(:managed)
  @name = args[:name] if args.key?(:name)
  @private_key = args[:private_key] if args.key?(:private_key)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_managed = args[:self_managed] if args.key?(:self_managed)
  @subject_alternative_names = args[:subject_alternative_names] if args.key?(:subject_alternative_names)
  @type = args[:type] if args.key?(:type)
end