Class: Google::Apis::ComputeV1::SslCertificateManagedSslCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration and status of a managed SSL certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateManagedSslCertificate

Returns a new instance of SslCertificateManagedSslCertificate.



52004
52005
52006
# File 'lib/google/apis/compute_v1/classes.rb', line 52004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domain_statusHash<String,String>

Output only. [Output only] Detailed statuses of the domains specified for managed certificate resource. Corresponds to the JSON property domainStatus

Returns:

  • (Hash<String,String>)


51989
51990
51991
# File 'lib/google/apis/compute_v1/classes.rb', line 51989

def domain_status
  @domain_status
end

#domainsArray<String>

The domains for which a managed SSL certificate will be generated. Each Google-managed SSL certificate supports up to the maximum number of domains per Google-managed SSL certificate. Corresponds to the JSON property domains

Returns:

  • (Array<String>)


51997
51998
51999
# File 'lib/google/apis/compute_v1/classes.rb', line 51997

def domains
  @domains
end

#statusString

Output only. [Output only] Status of the managed certificate resource. Corresponds to the JSON property status

Returns:

  • (String)


52002
52003
52004
# File 'lib/google/apis/compute_v1/classes.rb', line 52002

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52009
52010
52011
52012
52013
# File 'lib/google/apis/compute_v1/classes.rb', line 52009

def update!(**args)
  @domain_status = args[:domain_status] if args.key?(:domain_status)
  @domains = args[:domains] if args.key?(:domains)
  @status = args[:status] if args.key?(:status)
end