Class: Google::Apis::ComputeV1::SslCertificateSelfManagedSslCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration and status of a self-managed SSL certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateSelfManagedSslCertificate

Returns a new instance of SslCertificateSelfManagedSslCertificate.



52033
52034
52035
# File 'lib/google/apis/compute_v1/classes.rb', line 52033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificateString

A local certificate file. The certificate must be in PEM format. The certificate chain must be no greater than 5 certs long. The chain must include at least one intermediate cert. Corresponds to the JSON property certificate

Returns:

  • (String)


52025
52026
52027
# File 'lib/google/apis/compute_v1/classes.rb', line 52025

def certificate
  @certificate
end

#private_keyString

A write-only private key in PEM format. Only insert requests will include this field. Corresponds to the JSON property privateKey

Returns:

  • (String)


52031
52032
52033
# File 'lib/google/apis/compute_v1/classes.rb', line 52031

def private_key
  @private_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52038
52039
52040
52041
# File 'lib/google/apis/compute_v1/classes.rb', line 52038

def update!(**args)
  @certificate = args[:certificate] if args.key?(:certificate)
  @private_key = args[:private_key] if args.key?(:private_key)
end