Class: Google::Apis::ComputeV1::StatefulPolicyPreservedState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration of preserved resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedState

Returns a new instance of StatefulPolicyPreservedState.



60654
60655
60656
# File 'lib/google/apis/compute_v1/classes.rb', line 60654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateDiskDevice>

Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks. Corresponds to the JSON property disks



60638
60639
60640
# File 'lib/google/apis/compute_v1/classes.rb', line 60638

def disks
  @disks
end

#external_i_psHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>

External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property externalIPs



60645
60646
60647
# File 'lib/google/apis/compute_v1/classes.rb', line 60645

def external_i_ps
  @external_i_ps
end

#internal_i_psHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>

Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property internalIPs



60652
60653
60654
# File 'lib/google/apis/compute_v1/classes.rb', line 60652

def internal_i_ps
  @internal_i_ps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60659
60660
60661
60662
60663
# File 'lib/google/apis/compute_v1/classes.rb', line 60659

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps)
  @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps)
end