Class: Google::Apis::ComputeV1::StatefulPolicyPreservedStateDiskDevice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedStateDiskDevice

Returns a new instance of StatefulPolicyPreservedStateDiskDevice.



60680
60681
60682
# File 'lib/google/apis/compute_v1/classes.rb', line 60680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteString

These stateful disks will never be deleted during autohealing, update or VM instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Note: disks attached inREAD_ONLY mode cannot be auto-deleted. Corresponds to the JSON property autoDelete

Returns:

  • (String)


60678
60679
60680
# File 'lib/google/apis/compute_v1/classes.rb', line 60678

def auto_delete
  @auto_delete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60685
60686
60687
# File 'lib/google/apis/compute_v1/classes.rb', line 60685

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
end