Class: Google::Apis::ComputeV1::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



61233
61234
61235
# File 'lib/google/apis/compute_v1/classes.rb', line 61233

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


61189
61190
61191
# File 'lib/google/apis/compute_v1/classes.rb', line 61189

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61194
61195
61196
# File 'lib/google/apis/compute_v1/classes.rb', line 61194

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



61199
61200
61201
# File 'lib/google/apis/compute_v1/classes.rb', line 61199

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


61205
61206
61207
# File 'lib/google/apis/compute_v1/classes.rb', line 61205

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61215
61216
61217
# File 'lib/google/apis/compute_v1/classes.rb', line 61215

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61220
61221
61222
# File 'lib/google/apis/compute_v1/classes.rb', line 61220

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


61226
61227
61228
# File 'lib/google/apis/compute_v1/classes.rb', line 61226

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61231
61232
61233
# File 'lib/google/apis/compute_v1/classes.rb', line 61231

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61238
61239
61240
61241
61242
61243
61244
61245
61246
61247
# File 'lib/google/apis/compute_v1/classes.rb', line 61238

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end