Class: Google::Apis::ComputeV1::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



61374
61375
61376
# File 'lib/google/apis/compute_v1/classes.rb', line 61374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


61327
61328
61329
# File 'lib/google/apis/compute_v1/classes.rb', line 61327

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61333
61334
61335
# File 'lib/google/apis/compute_v1/classes.rb', line 61333

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



61338
61339
61340
# File 'lib/google/apis/compute_v1/classes.rb', line 61338

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


61345
61346
61347
# File 'lib/google/apis/compute_v1/classes.rb', line 61345

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61356
61357
61358
# File 'lib/google/apis/compute_v1/classes.rb', line 61356

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61361
61362
61363
# File 'lib/google/apis/compute_v1/classes.rb', line 61361

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


61367
61368
61369
# File 'lib/google/apis/compute_v1/classes.rb', line 61367

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



61372
61373
61374
# File 'lib/google/apis/compute_v1/classes.rb', line 61372

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61379
61380
61381
61382
61383
61384
61385
61386
61387
61388
# File 'lib/google/apis/compute_v1/classes.rb', line 61379

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end