Class: Google::Apis::ComputeV1::StoragePoolsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolsScopedList

Returns a new instance of StoragePoolsScopedList.



62120
62121
62122
# File 'lib/google/apis/compute_v1/classes.rb', line 62120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#storage_poolsArray<Google::Apis::ComputeV1::StoragePool>

[Output Only] A list of storage pool contained in this scope. Corresponds to the JSON property storagePools



62112
62113
62114
# File 'lib/google/apis/compute_v1/classes.rb', line 62112

def storage_pools
  @storage_pools
end

#warningGoogle::Apis::ComputeV1::StoragePoolsScopedList::Warning

[Output Only] Informational warning which replaces the list of storage pool when the list is empty. Corresponds to the JSON property warning



62118
62119
62120
# File 'lib/google/apis/compute_v1/classes.rb', line 62118

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62125
62126
62127
62128
# File 'lib/google/apis/compute_v1/classes.rb', line 62125

def update!(**args)
  @storage_pools = args[:storage_pools] if args.key?(:storage_pools)
  @warning = args[:warning] if args.key?(:warning)
end