Class: Google::Apis::ComputeV1::SubnetworksScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworksScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#subnetworks ⇒ Array<Google::Apis::ComputeV1::Subnetwork>
A list of subnetworks contained in this scope.
-
#warning ⇒ Google::Apis::ComputeV1::SubnetworksScopedList::Warning
An informational warning that appears when the list of addresses is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworksScopedList
constructor
A new instance of SubnetworksScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworksScopedList
Returns a new instance of SubnetworksScopedList.
61843 61844 61845 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#subnetworks ⇒ Array<Google::Apis::ComputeV1::Subnetwork>
A list of subnetworks contained in this scope.
Corresponds to the JSON property subnetworks
61835 61836 61837 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61835 def subnetworks @subnetworks end |
#warning ⇒ Google::Apis::ComputeV1::SubnetworksScopedList::Warning
An informational warning that appears when the list of addresses
is empty.
Corresponds to the JSON property warning
61841 61842 61843 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61841 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61848 61849 61850 61851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61848 def update!(**args) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) @warning = args[:warning] if args.key?(:warning) end |