Class: Google::Apis::ComputeV1::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyAggregatedList

Returns a new instance of TargetHttpProxyAggregatedList.



63909
63910
63911
# File 'lib/google/apis/compute_v1/classes.rb', line 63909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63875
63876
63877
# File 'lib/google/apis/compute_v1/classes.rb', line 63875

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetHttpProxiesScopedList>

A list of TargetHttpProxiesScopedList resources. Corresponds to the JSON property items



63880
63881
63882
# File 'lib/google/apis/compute_v1/classes.rb', line 63880

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


63887
63888
63889
# File 'lib/google/apis/compute_v1/classes.rb', line 63887

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63897
63898
63899
# File 'lib/google/apis/compute_v1/classes.rb', line 63897

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63902
63903
63904
# File 'lib/google/apis/compute_v1/classes.rb', line 63902

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63907
63908
63909
# File 'lib/google/apis/compute_v1/classes.rb', line 63907

def unreachables
  @unreachables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63914
63915
63916
63917
63918
63919
63920
63921
# File 'lib/google/apis/compute_v1/classes.rb', line 63914

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
end