Class: Google::Apis::ComputeV1::TargetHttpsProxiesScopedList::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Informational warning which replaces the list of backend services when the list is empty.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



56149
56150
56151
# File 'lib/google/apis/compute_v1/classes.rb', line 56149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


56131
56132
56133
# File 'lib/google/apis/compute_v1/classes.rb', line 56131

def code
  @code
end

#dataArray<Google::Apis::ComputeV1::TargetHttpsProxiesScopedList::Warning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" Corresponds to the JSON property data



56142
56143
56144
# File 'lib/google/apis/compute_v1/classes.rb', line 56142

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


56147
56148
56149
# File 'lib/google/apis/compute_v1/classes.rb', line 56147

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56154
56155
56156
56157
56158
# File 'lib/google/apis/compute_v1/classes.rb', line 56154

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end