Class: Google::Apis::ComputeV1::TargetHttpsProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Target HTTPS Proxy resource. Google Compute Engine has two Target HTTPS Proxy resources:

  • Global
  • Regional A target HTTPS proxy is a component of Google Cloud HTTPS load balancers.
  • targetHttpsProxies are used by global external Application Load Balancers, classic Application Load Balancers, cross-region internal Application Load Balancers, and Traffic Director.
  • regionTargetHttpsProxies are used by regional internal Application Load Balancers and regional external Application Load Balancers. Forwarding rules reference a target HTTPS proxy, and the target proxy then references a URL map. For more information, readUsing Target Proxies and Forwarding rule concepts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxy

Returns a new instance of TargetHttpsProxy.



63191
63192
63193
# File 'lib/google/apis/compute_v1/classes.rb', line 63191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorization_policyString

Optional. A URL referring to a networksecurity.AuthorizationPolicy resource that describes how the proxy should authorize inbound traffic. If left blank, access will not be restricted by an authorization policy. Refer to the AuthorizationPolicy resource for additional details. authorizationPolicy only applies to a globalTargetHttpsProxy attached toglobalForwardingRules with theloadBalancingScheme set to INTERNAL_SELF_MANAGED. Note: This field currently has no impact. Corresponds to the JSON property authorizationPolicy

Returns:

  • (String)


62998
62999
63000
# File 'lib/google/apis/compute_v1/classes.rb', line 62998

def authorization_policy
  @authorization_policy
end

#certificate_mapString

URL of a certificate map that identifies a certificate map associated with the given target proxy. This field can only be set for Global external Application Load Balancer or Classic Application Load Balancer. For other products use Certificate Manager Certificates instead. If set, sslCertificates will be ignored. Accepted format is//certificatemanager.googleapis.com/projects/project/ locations/location/certificateMaps/resourceName. Corresponds to the JSON property certificateMap

Returns:

  • (String)


63010
63011
63012
# File 'lib/google/apis/compute_v1/classes.rb', line 63010

def certificate_map
  @certificate_map
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


63016
63017
63018
# File 'lib/google/apis/compute_v1/classes.rb', line 63016

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


63022
63023
63024
# File 'lib/google/apis/compute_v1/classes.rb', line 63022

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetHttpsProxy. An up-to-date fingerprint must be provided in order to patch the TargetHttpsProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetHttpsProxy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


63034
63035
63036
# File 'lib/google/apis/compute_v1/classes.rb', line 63034

def fingerprint
  @fingerprint
end

#http_keep_alive_timeout_secFixnum

Specifies how long to keep a connection open, after completing a response, while there is no matching traffic (in seconds). If an HTTP keep-alive is not specified, a default value (610 seconds) will be used. For global external Application Load Balancers, the minimum allowed value is 5 seconds and the maximum allowed value is 1200 seconds. For classic Application Load Balancers, this option is not supported. Corresponds to the JSON property httpKeepAliveTimeoutSec

Returns:

  • (Fixnum)


63044
63045
63046
# File 'lib/google/apis/compute_v1/classes.rb', line 63044

def http_keep_alive_timeout_sec
  @http_keep_alive_timeout_sec
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


63050
63051
63052
# File 'lib/google/apis/compute_v1/classes.rb', line 63050

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetHttpsProxy for target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


63056
63057
63058
# File 'lib/google/apis/compute_v1/classes.rb', line 63056

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


63067
63068
63069
# File 'lib/google/apis/compute_v1/classes.rb', line 63067

def name
  @name
end

#proxy_bindBoolean Also known as: proxy_bind?

This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false. Corresponds to the JSON property proxyBind

Returns:

  • (Boolean)


63080
63081
63082
# File 'lib/google/apis/compute_v1/classes.rb', line 63080

def proxy_bind
  @proxy_bind
end

#quic_overrideString

Specifies the QUIC override policy for this TargetHttpsProxy resource. This setting determines whether the load balancer attempts to negotiate QUIC with clients. You can specify NONE, ENABLE, orDISABLE.

  • When quic-override is set to NONE, Google manages whether QUIC is used.
  • When quic-override is set to ENABLE, the load balancer uses QUIC when possible.
  • When quic-override is set to DISABLE, the load balancer doesn't use QUIC.
  • If the quic-override flag is not specified,NONE is implied. Corresponds to the JSON property quicOverride

Returns:

  • (String)


63097
63098
63099
# File 'lib/google/apis/compute_v1/classes.rb', line 63097

def quic_override
  @quic_override
end

#regionString

Output only. [Output Only] URL of the region where the regional TargetHttpsProxy resides. This field is not applicable to global TargetHttpsProxies. Corresponds to the JSON property region

Returns:

  • (String)


63104
63105
63106
# File 'lib/google/apis/compute_v1/classes.rb', line 63104

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63109
63110
63111
# File 'lib/google/apis/compute_v1/classes.rb', line 63109

def self_link
  @self_link
end

#server_tls_policyString

Optional. A URL referring to a networksecurity.ServerTlsPolicy resource that describes how the proxy should authenticate inbound traffic. serverTlsPolicy only applies to a globalTargetHttpsProxy attached toglobalForwardingRules with theloadBalancingScheme set to INTERNAL_SELF_MANAGED or EXTERNAL orEXTERNAL_MANAGED or INTERNAL_MANAGED. It also applies to a regional TargetHttpsProxy attached to regional forwardingRules with theloadBalancingScheme set to EXTERNAL_MANAGED orINTERNAL_MANAGED. For details whichServerTlsPolicy resources are accepted withINTERNAL_SELF_MANAGED and which with EXTERNAL,INTERNAL_MANAGED, EXTERNAL_MANAGEDloadBalancingScheme consult ServerTlsPolicy documentation. If left blank, communications are not encrypted. Corresponds to the JSON property serverTlsPolicy

Returns:

  • (String)


63126
63127
63128
# File 'lib/google/apis/compute_v1/classes.rb', line 63126

def server_tls_policy
  @server_tls_policy
end

#ssl_certificatesArray<String>

URLs to SslCertificate resources that are used to authenticate connections between users and the load balancer. At least one SSL certificate must be specified. SslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED. The URLs should refer to a SSL Certificate resource or Certificate Manager Certificate resource. Mixing Classic Certificates and Certificate Manager Certificates is not allowed. Certificate Manager Certificates must include the certificatemanager API namespace. Using Certificate Manager Certificates in this field is not supported by Global external Application Load Balancer or Classic Application Load Balancer, use certificate_map instead. Currently, you may specify up to 15 Classic SSL Certificates or up to 100 Certificate Manager Certificates. Certificate Manager Certificates accepted formats are:

Returns:

  • (Array<String>)


63149
63150
63151
# File 'lib/google/apis/compute_v1/classes.rb', line 63149

def ssl_certificates
  @ssl_certificates
end

#ssl_policyString

URL of SslPolicy resource that will be associated with the TargetHttpsProxy resource. If not set, the TargetHttpsProxy resource has no SSL policy configured. Corresponds to the JSON property sslPolicy

Returns:

  • (String)


63156
63157
63158
# File 'lib/google/apis/compute_v1/classes.rb', line 63156

def ssl_policy
  @ssl_policy
end

#tls_early_dataString

Specifies whether TLS 1.3 0-RTT Data ("Early Data") should be accepted for this service. Early Data allows a TLS resumption handshake to include the initial application payload (a HTTP request) alongside the handshake, reducing the effective round trips to "zero". This applies to TLS 1.3 connections over TCP (HTTP/2) as well as over UDP (QUIC/h3). This can improve application performance, especially on networks where interruptions may be common, such as on mobile. Requests with Early Data will have the "Early-Data" HTTP header set on the request, with a value of "1", to allow the backend to determine whether Early Data was included. Note: TLS Early Data may allow requests to be replayed, as the data is sent to the backend before the handshake has fully completed. Applications that allow idempotent HTTP methods to make non-idempotent changes, such as a GET request updating a database, should not accept Early Data on those requests, and reject requests with the "Early-Data: 1" HTTP header by returning a HTTP 425 (Too Early) status code, in order to remain RFC compliant. The default value is DISABLED. Corresponds to the JSON property tlsEarlyData

Returns:

  • (String)


63178
63179
63180
# File 'lib/google/apis/compute_v1/classes.rb', line 63178

def tls_early_data
  @tls_early_data
end

#url_mapString

A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService. For example, the following are all valid URLs for specifying a URL map:

Returns:

  • (String)


63189
63190
63191
# File 'lib/google/apis/compute_v1/classes.rb', line 63189

def url_map
  @url_map
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63196
63197
63198
63199
63200
63201
63202
63203
63204
63205
63206
63207
63208
63209
63210
63211
63212
63213
63214
63215
# File 'lib/google/apis/compute_v1/classes.rb', line 63196

def update!(**args)
  @authorization_policy = args[:authorization_policy] if args.key?(:authorization_policy)
  @certificate_map = args[:certificate_map] if args.key?(:certificate_map)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @http_keep_alive_timeout_sec = args[:http_keep_alive_timeout_sec] if args.key?(:http_keep_alive_timeout_sec)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind)
  @quic_override = args[:quic_override] if args.key?(:quic_override)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @server_tls_policy = args[:server_tls_policy] if args.key?(:server_tls_policy)
  @ssl_certificates = args[:ssl_certificates] if args.key?(:ssl_certificates)
  @ssl_policy = args[:ssl_policy] if args.key?(:ssl_policy)
  @tls_early_data = args[:tls_early_data] if args.key?(:tls_early_data)
  @url_map = args[:url_map] if args.key?(:url_map)
end