Class: Google::Apis::ComputeV1::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



64502
64503
64504
# File 'lib/google/apis/compute_v1/classes.rb', line 64502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64463
64464
64465
# File 'lib/google/apis/compute_v1/classes.rb', line 64463

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



64468
64469
64470
# File 'lib/google/apis/compute_v1/classes.rb', line 64468

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


64475
64476
64477
# File 'lib/google/apis/compute_v1/classes.rb', line 64475

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64485
64486
64487
# File 'lib/google/apis/compute_v1/classes.rb', line 64485

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64490
64491
64492
# File 'lib/google/apis/compute_v1/classes.rb', line 64490

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64495
64496
64497
# File 'lib/google/apis/compute_v1/classes.rb', line 64495

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64500
64501
64502
# File 'lib/google/apis/compute_v1/classes.rb', line 64500

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64507
64508
64509
64510
64511
64512
64513
64514
64515
# File 'lib/google/apis/compute_v1/classes.rb', line 64507

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end