Class: Google::Apis::ComputeV1::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



64628
64629
64630
# File 'lib/google/apis/compute_v1/classes.rb', line 64628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64595
64596
64597
# File 'lib/google/apis/compute_v1/classes.rb', line 64595

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



64600
64601
64602
# File 'lib/google/apis/compute_v1/classes.rb', line 64600

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


64606
64607
64608
# File 'lib/google/apis/compute_v1/classes.rb', line 64606

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64616
64617
64618
# File 'lib/google/apis/compute_v1/classes.rb', line 64616

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64621
64622
64623
# File 'lib/google/apis/compute_v1/classes.rb', line 64621

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64626
64627
64628
# File 'lib/google/apis/compute_v1/classes.rb', line 64626

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64633
64634
64635
64636
64637
64638
64639
64640
# File 'lib/google/apis/compute_v1/classes.rb', line 64633

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end