Class: Google::Apis::ComputeV1::TargetInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Target Instance resource. You can use a target instance to handle traffic for one or more forwarding rules, which is ideal for forwarding protocol traffic that is managed by a single source. For example, ESP, AH, TCP, or UDP. For more information, readTarget instances.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#instance ⇒ String
A URL to the virtual machine instance that handles traffic for this target instance.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#nat_policy ⇒ String
Must have a value of NO_NAT.
-
#network ⇒ String
The URL of the network this target instance uses to forward traffic.
-
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this target instance.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstance
constructor
A new instance of TargetInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstance
Returns a new instance of TargetInstance.
64802 64803 64804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64802 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
64726 64727 64728 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64726 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
64732 64733 64734 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64732 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
64738 64739 64740 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64738 def id @id end |
#instance ⇒ String
A URL to the virtual machine instance that handles traffic for this target instance. When creating a target instance, you can provide the fully-qualified URL or a valid partial URL to the desired virtual machine. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ instances/instance
- projects/project/zones/zone/instances/instance
- zones/zone/instances/instance
Corresponds to the JSON property
instance
64751 64752 64753 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64751 def instance @instance end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#
targetInstance for target instances.
Corresponds to the JSON property kind
64757 64758 64759 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64757 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
64768 64769 64770 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64768 def name @name end |
#nat_policy ⇒ String
Must have a value of NO_NAT.
Protocol forwarding delivers packets while preserving the destination IP
address of the forwarding rule referencing the target instance.
Corresponds to the JSON property natPolicy
64775 64776 64777 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64775 def nat_policy @nat_policy end |
#network ⇒ String
The URL of the network this target instance uses to forward traffic.
If not specified, the traffic will be forwarded to the network that
the default network interface belongs to.
Corresponds to the JSON property network
64782 64783 64784 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64782 def network @network end |
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this
target instance.
Corresponds to the JSON property securityPolicy
64788 64789 64790 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64788 def security_policy @security_policy end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
64793 64794 64795 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64793 def self_link @self_link end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the target instance resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
64800 64801 64802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64800 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64807 64808 64809 64810 64811 64812 64813 64814 64815 64816 64817 64818 64819 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64807 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @nat_policy = args[:nat_policy] if args.key?(:nat_policy) @network = args[:network] if args.key?(:network) @security_policy = args[:security_policy] if args.key?(:security_policy) @self_link = args[:self_link] if args.key?(:self_link) @zone = args[:zone] if args.key?(:zone) end |