Class: Google::Apis::ComputeV1::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



64866
64867
64868
# File 'lib/google/apis/compute_v1/classes.rb', line 64866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64829
64830
64831
# File 'lib/google/apis/compute_v1/classes.rb', line 64829

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



64834
64835
64836
# File 'lib/google/apis/compute_v1/classes.rb', line 64834

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


64839
64840
64841
# File 'lib/google/apis/compute_v1/classes.rb', line 64839

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64849
64850
64851
# File 'lib/google/apis/compute_v1/classes.rb', line 64849

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64854
64855
64856
# File 'lib/google/apis/compute_v1/classes.rb', line 64854

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64859
64860
64861
# File 'lib/google/apis/compute_v1/classes.rb', line 64859

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64864
64865
64866
# File 'lib/google/apis/compute_v1/classes.rb', line 64864

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64871
64872
64873
64874
64875
64876
64877
64878
64879
# File 'lib/google/apis/compute_v1/classes.rb', line 64871

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end