Class: Google::Apis::ComputeV1::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



64991
64992
64993
# File 'lib/google/apis/compute_v1/classes.rb', line 64991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64959
64960
64961
# File 'lib/google/apis/compute_v1/classes.rb', line 64959

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



64964
64965
64966
# File 'lib/google/apis/compute_v1/classes.rb', line 64964

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


64969
64970
64971
# File 'lib/google/apis/compute_v1/classes.rb', line 64969

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64979
64980
64981
# File 'lib/google/apis/compute_v1/classes.rb', line 64979

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64984
64985
64986
# File 'lib/google/apis/compute_v1/classes.rb', line 64984

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64989
64990
64991
# File 'lib/google/apis/compute_v1/classes.rb', line 64989

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64996
64997
64998
64999
65000
65001
65002
65003
# File 'lib/google/apis/compute_v1/classes.rb', line 64996

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end