Class: Google::Apis::ComputeV1::TargetInstancesScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstancesScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#target_instances ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of target instances contained in this scope.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstancesScopedList::Warning
Informational warning which replaces the list of addresses when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstancesScopedList
constructor
A new instance of TargetInstancesScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstancesScopedList
Returns a new instance of TargetInstancesScopedList.
57138 57139 57140 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_instances ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of target instances contained in this scope.
Corresponds to the JSON property targetInstances
57130 57131 57132 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57130 def target_instances @target_instances end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstancesScopedList::Warning
Informational warning which replaces the list of addresses when
the list is empty.
Corresponds to the JSON property warning
57136 57137 57138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57136 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57143 57144 57145 57146 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57143 def update!(**args) @target_instances = args[:target_instances] if args.key?(:target_instances) @warning = args[:warning] if args.key?(:warning) end |