Class: Google::Apis::ComputeV1::TargetSslProxiesSetCertificateMapRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetSslProxiesSetCertificateMapRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#certificate_map ⇒ String
URL of the Certificate Map to associate with this TargetSslProxy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetSslProxiesSetCertificateMapRequest
constructor
A new instance of TargetSslProxiesSetCertificateMapRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetSslProxiesSetCertificateMapRequest
Returns a new instance of TargetSslProxiesSetCertificateMapRequest.
59083 59084 59085 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_map ⇒ String
URL of the Certificate Map to associate with this TargetSslProxy.
Accepted format is//certificatemanager.googleapis.com/projects/project/
locations/location/certificateMaps/resourceName.
Corresponds to the JSON property certificateMap
59081 59082 59083 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59081 def certificate_map @certificate_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59088 59089 59090 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59088 def update!(**args) @certificate_map = args[:certificate_map] if args.key?(:certificate_map) end |