Class: Google::Apis::ComputeV1::TargetTcpProxiesScopedList::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Informational warning which replaces the list of backend services when the list is empty.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



64542
64543
64544
# File 'lib/google/apis/compute_v1/classes.rb', line 64542

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


64524
64525
64526
# File 'lib/google/apis/compute_v1/classes.rb', line 64524

def code
  @code
end

#dataArray<Google::Apis::ComputeV1::TargetTcpProxiesScopedList::Warning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" Corresponds to the JSON property data



64535
64536
64537
# File 'lib/google/apis/compute_v1/classes.rb', line 64535

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


64540
64541
64542
# File 'lib/google/apis/compute_v1/classes.rb', line 64540

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64547
64548
64549
64550
64551
# File 'lib/google/apis/compute_v1/classes.rb', line 64547

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end