Class: Google::Apis::ComputeV1::TargetTcpProxiesSetProxyHeaderRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetTcpProxiesSetProxyHeaderRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#proxy_header ⇒ String
The new type of proxy header to append before sending data to the backend.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxiesSetProxyHeaderRequest
constructor
A new instance of TargetTcpProxiesSetProxyHeaderRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxiesSetProxyHeaderRequest
Returns a new instance of TargetTcpProxiesSetProxyHeaderRequest.
64629 64630 64631 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#proxy_header ⇒ String
The new type of proxy header to append before sending data to the
backend. NONE or PROXY_V1 are allowed.
Corresponds to the JSON property proxyHeader
64627 64628 64629 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64627 def proxy_header @proxy_header end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64634 64635 64636 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64634 def update!(**args) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) end |