Class: Google::Apis::ComputeV1::TargetTcpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyAggregatedList

Returns a new instance of TargetTcpProxyAggregatedList.



66402
66403
66404
# File 'lib/google/apis/compute_v1/classes.rb', line 66402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66363
66364
66365
# File 'lib/google/apis/compute_v1/classes.rb', line 66363

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetTcpProxiesScopedList>

A list of TargetTcpProxiesScopedList resources. Corresponds to the JSON property items



66368
66369
66370
# File 'lib/google/apis/compute_v1/classes.rb', line 66368

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetTcpProxyAggregatedList for lists of Target TCP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


66375
66376
66377
# File 'lib/google/apis/compute_v1/classes.rb', line 66375

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66385
66386
66387
# File 'lib/google/apis/compute_v1/classes.rb', line 66385

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66390
66391
66392
# File 'lib/google/apis/compute_v1/classes.rb', line 66390

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66395
66396
66397
# File 'lib/google/apis/compute_v1/classes.rb', line 66395

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetTcpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66400
66401
66402
# File 'lib/google/apis/compute_v1/classes.rb', line 66400

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66407
66408
66409
66410
66411
66412
66413
66414
66415
# File 'lib/google/apis/compute_v1/classes.rb', line 66407

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end