Class: Google::Apis::ComputeV1::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



67183
67184
67185
# File 'lib/google/apis/compute_v1/classes.rb', line 67183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


67136
67137
67138
# File 'lib/google/apis/compute_v1/classes.rb', line 67136

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


67142
67143
67144
# File 'lib/google/apis/compute_v1/classes.rb', line 67142

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


67148
67149
67150
# File 'lib/google/apis/compute_v1/classes.rb', line 67148

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


67154
67155
67156
# File 'lib/google/apis/compute_v1/classes.rb', line 67154

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


67160
67161
67162
# File 'lib/google/apis/compute_v1/classes.rb', line 67160

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


67166
67167
67168
# File 'lib/google/apis/compute_v1/classes.rb', line 67166

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeV1::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



67171
67172
67173
# File 'lib/google/apis/compute_v1/classes.rb', line 67171

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


67176
67177
67178
# File 'lib/google/apis/compute_v1/classes.rb', line 67176

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


67181
67182
67183
# File 'lib/google/apis/compute_v1/classes.rb', line 67181

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67188
67189
67190
67191
67192
67193
67194
67195
67196
67197
67198
# File 'lib/google/apis/compute_v1/classes.rb', line 67188

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end