Class: Google::Apis::ComputeV1::VmExtensionPoliciesScopedList::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Informational warning which replaces the list of backend services when the list is empty.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



67162
67163
67164
# File 'lib/google/apis/compute_v1/classes.rb', line 67162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


67144
67145
67146
# File 'lib/google/apis/compute_v1/classes.rb', line 67144

def code
  @code
end

#dataArray<Google::Apis::ComputeV1::VmExtensionPoliciesScopedList::Warning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" Corresponds to the JSON property data



67155
67156
67157
# File 'lib/google/apis/compute_v1/classes.rb', line 67155

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


67160
67161
67162
# File 'lib/google/apis/compute_v1/classes.rb', line 67160

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67167
67168
67169
67170
67171
# File 'lib/google/apis/compute_v1/classes.rb', line 67167

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end