Class: Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response for the aggregated list of VM extension policies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse

Returns a new instance of VmExtensionPolicyAggregatedListResponse.



69039
69040
69041
# File 'lib/google/apis/compute_v1/classes.rb', line 69039

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


68995
68996
68997
# File 'lib/google/apis/compute_v1/classes.rb', line 68995

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69000
69001
69002
# File 'lib/google/apis/compute_v1/classes.rb', line 69000

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



69005
69006
69007
# File 'lib/google/apis/compute_v1/classes.rb', line 69005

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


69012
69013
69014
# File 'lib/google/apis/compute_v1/classes.rb', line 69012

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69022
69023
69024
# File 'lib/google/apis/compute_v1/classes.rb', line 69022

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69027
69028
69029
# File 'lib/google/apis/compute_v1/classes.rb', line 69027

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69032
69033
69034
# File 'lib/google/apis/compute_v1/classes.rb', line 69032

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69037
69038
69039
# File 'lib/google/apis/compute_v1/classes.rb', line 69037

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69044
69045
69046
69047
69048
69049
69050
69051
69052
69053
# File 'lib/google/apis/compute_v1/classes.rb', line 69044

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end