Class: Google::Apis::ComputeV1::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



69519
69520
69521
# File 'lib/google/apis/compute_v1/classes.rb', line 69519

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69481
69482
69483
# File 'lib/google/apis/compute_v1/classes.rb', line 69481

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



69486
69487
69488
# File 'lib/google/apis/compute_v1/classes.rb', line 69486

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


69492
69493
69494
# File 'lib/google/apis/compute_v1/classes.rb', line 69492

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69502
69503
69504
# File 'lib/google/apis/compute_v1/classes.rb', line 69502

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69507
69508
69509
# File 'lib/google/apis/compute_v1/classes.rb', line 69507

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69512
69513
69514
# File 'lib/google/apis/compute_v1/classes.rb', line 69512

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69517
69518
69519
# File 'lib/google/apis/compute_v1/classes.rb', line 69517

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69524
69525
69526
69527
69528
69529
69530
69531
69532
# File 'lib/google/apis/compute_v1/classes.rb', line 69524

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end