Class: Google::Apis::ComputeV1::VpnGatewayStatusHighAvailabilityRequirementState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayStatusHighAvailabilityRequirementState

Returns a new instance of VpnGatewayStatusHighAvailabilityRequirementState.



68156
68157
68158
# File 'lib/google/apis/compute_v1/classes.rb', line 68156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Corresponds to the JSON property state

Returns:

  • (String)


68147
68148
68149
# File 'lib/google/apis/compute_v1/classes.rb', line 68147

def state
  @state
end

#unsatisfied_reasonString

Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE. Corresponds to the JSON property unsatisfiedReason

Returns:

  • (String)


68154
68155
68156
# File 'lib/google/apis/compute_v1/classes.rb', line 68154

def unsatisfied_reason
  @unsatisfied_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68161
68162
68163
68164
# File 'lib/google/apis/compute_v1/classes.rb', line 68161

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @unsatisfied_reason = args[:unsatisfied_reason] if args.key?(:unsatisfied_reason)
end