Class: Google::Apis::ComputeV1::VpnGatewayStatusVpnConnection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A VPN connection contains all VPN tunnels connected from this VpnGateway to the same peer gateway. The peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayStatusVpnConnection

Returns a new instance of VpnGatewayStatusVpnConnection.



66476
66477
66478
# File 'lib/google/apis/compute_v1/classes.rb', line 66476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#peer_external_gatewayString

Output only. URL reference to the peer external VPN gateways to which the VPN tunnels in this VPN connection are connected. This field is mutually exclusive with peer_gcp_gateway. Corresponds to the JSON property peerExternalGateway

Returns:

  • (String)


66455
66456
66457
# File 'lib/google/apis/compute_v1/classes.rb', line 66455

def peer_external_gateway
  @peer_external_gateway
end

#peer_gcp_gatewayString

Output only. URL reference to the peer side VPN gateways to which the VPN tunnels in this VPN connection are connected. This field is mutually exclusive with peer_gcp_gateway. Corresponds to the JSON property peerGcpGateway

Returns:

  • (String)


66463
66464
66465
# File 'lib/google/apis/compute_v1/classes.rb', line 66463

def peer_gcp_gateway
  @peer_gcp_gateway
end

#stateGoogle::Apis::ComputeV1::VpnGatewayStatusHighAvailabilityRequirementState

Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway. Corresponds to the JSON property state



66469
66470
66471
# File 'lib/google/apis/compute_v1/classes.rb', line 66469

def state
  @state
end

#tunnelsArray<Google::Apis::ComputeV1::VpnGatewayStatusTunnel>

List of VPN tunnels that are in this VPN connection. Corresponds to the JSON property tunnels



66474
66475
66476
# File 'lib/google/apis/compute_v1/classes.rb', line 66474

def tunnels
  @tunnels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66481
66482
66483
66484
66485
66486
# File 'lib/google/apis/compute_v1/classes.rb', line 66481

def update!(**args)
  @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway)
  @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway)
  @state = args[:state] if args.key?(:state)
  @tunnels = args[:tunnels] if args.key?(:tunnels)
end