Class: Google::Apis::ComputeV1::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



70366
70367
70368
# File 'lib/google/apis/compute_v1/classes.rb', line 70366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70328
70329
70330
# File 'lib/google/apis/compute_v1/classes.rb', line 70328

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



70333
70334
70335
# File 'lib/google/apis/compute_v1/classes.rb', line 70333

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


70339
70340
70341
# File 'lib/google/apis/compute_v1/classes.rb', line 70339

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70349
70350
70351
# File 'lib/google/apis/compute_v1/classes.rb', line 70349

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70354
70355
70356
# File 'lib/google/apis/compute_v1/classes.rb', line 70354

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70359
70360
70361
# File 'lib/google/apis/compute_v1/classes.rb', line 70359

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70364
70365
70366
# File 'lib/google/apis/compute_v1/classes.rb', line 70364

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70371
70372
70373
70374
70375
70376
70377
70378
70379
# File 'lib/google/apis/compute_v1/classes.rb', line 70371

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end