Class: Google::Apis::ComputeV1::VpnTunnelList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of VpnTunnel resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelList

Returns a new instance of VpnTunnelList.



70517
70518
70519
# File 'lib/google/apis/compute_v1/classes.rb', line 70517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70484
70485
70486
# File 'lib/google/apis/compute_v1/classes.rb', line 70484

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::VpnTunnel>

A list of VpnTunnel resources. Corresponds to the JSON property items



70489
70490
70491
# File 'lib/google/apis/compute_v1/classes.rb', line 70489

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


70495
70496
70497
# File 'lib/google/apis/compute_v1/classes.rb', line 70495

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70505
70506
70507
# File 'lib/google/apis/compute_v1/classes.rb', line 70505

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70510
70511
70512
# File 'lib/google/apis/compute_v1/classes.rb', line 70510

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::VpnTunnelList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70515
70516
70517
# File 'lib/google/apis/compute_v1/classes.rb', line 70515

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70522
70523
70524
70525
70526
70527
70528
70529
# File 'lib/google/apis/compute_v1/classes.rb', line 70522

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end