Class: Google::Apis::ComputeV1::WafExpressionSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WafExpressionSet

Returns a new instance of WafExpressionSet.



69587
69588
69589
# File 'lib/google/apis/compute_v1/classes.rb', line 69587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aliasesArray<String>

A list of alternate IDs. The format should be:

  • E.g. XSS-stable Generic suffix like "stable" is particularly useful if a policy likes to avail newer set of expressions without having to change the policy. A given alias name can't be used for more than one entity set. Corresponds to the JSON property aliases

Returns:

  • (Array<String>)


69573
69574
69575
# File 'lib/google/apis/compute_v1/classes.rb', line 69573

def aliases
  @aliases
end

#expressionsArray<Google::Apis::ComputeV1::WafExpressionSetExpression>

List of available expressions. Corresponds to the JSON property expressions



69578
69579
69580
# File 'lib/google/apis/compute_v1/classes.rb', line 69578

def expressions
  @expressions
end

#idString

Google specified expression set ID. The format should be:

  • E.g. XSS-20170329 required Corresponds to the JSON property id

Returns:

  • (String)


69585
69586
69587
# File 'lib/google/apis/compute_v1/classes.rb', line 69585

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69592
69593
69594
69595
69596
# File 'lib/google/apis/compute_v1/classes.rb', line 69592

def update!(**args)
  @aliases = args[:aliases] if args.key?(:aliases)
  @expressions = args[:expressions] if args.key?(:expressions)
  @id = args[:id] if args.key?(:id)
end