Class: Google::Apis::ComputeV1::WireGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A resource that represents a group of redundant wires.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroup

Returns a new instance of WireGroup.



70187
70188
70189
# File 'lib/google/apis/compute_v1/classes.rb', line 70187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Indicates whether the wires in the wire group are enabled. When false, the wires in the wire group are disabled. When true and when there is simultaneously no wire-specific override of adminEnabled to false, a given wire is enabled. Defaults to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


70113
70114
70115
# File 'lib/google/apis/compute_v1/classes.rb', line 70113

def admin_enabled
  @admin_enabled
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


70120
70121
70122
# File 'lib/google/apis/compute_v1/classes.rb', line 70120

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of the wire group. Corresponds to the JSON property description

Returns:

  • (String)


70125
70126
70127
# File 'lib/google/apis/compute_v1/classes.rb', line 70125

def description
  @description
end

#endpointsHash<String,Google::Apis::ComputeV1::WireGroupEndpoint>

A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:

  • Key: an RFC1035 user-specified label.
  • Value: an Endpoint object. Corresponds to the JSON property endpoints


70134
70135
70136
# File 'lib/google/apis/compute_v1/classes.rb', line 70134

def endpoints
  @endpoints
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


70141
70142
70143
# File 'lib/google/apis/compute_v1/classes.rb', line 70141

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


70147
70148
70149
# File 'lib/google/apis/compute_v1/classes.rb', line 70147

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


70158
70159
70160
# File 'lib/google/apis/compute_v1/classes.rb', line 70158

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. [Output Only] Indicates whether there are wire changes yet to be processed. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


70164
70165
70166
# File 'lib/google/apis/compute_v1/classes.rb', line 70164

def reconciling
  @reconciling
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70170
70171
70172
# File 'lib/google/apis/compute_v1/classes.rb', line 70170

def self_link
  @self_link
end

#topologyGoogle::Apis::ComputeV1::WireGroupTopology

Topology details for the wire group. Corresponds to the JSON property topology



70175
70176
70177
# File 'lib/google/apis/compute_v1/classes.rb', line 70175

def topology
  @topology
end

#wire_propertiesGoogle::Apis::ComputeV1::WireProperties

The properties of a wire. Corresponds to the JSON property wireProperties



70180
70181
70182
# File 'lib/google/apis/compute_v1/classes.rb', line 70180

def wire_properties
  @wire_properties
end

#wiresArray<Google::Apis::ComputeV1::Wire>

Output only. The single/redundant wire(s) managed by the wire group. Corresponds to the JSON property wires

Returns:



70185
70186
70187
# File 'lib/google/apis/compute_v1/classes.rb', line 70185

def wires
  @wires
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70192
70193
70194
70195
70196
70197
70198
70199
70200
70201
70202
70203
70204
70205
# File 'lib/google/apis/compute_v1/classes.rb', line 70192

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @topology = args[:topology] if args.key?(:topology)
  @wire_properties = args[:wire_properties] if args.key?(:wire_properties)
  @wires = args[:wires] if args.key?(:wires)
end