Class: Google::Apis::ComputeV1::XpnHostList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpnHostList

Returns a new instance of XpnHostList.



71474
71475
71476
# File 'lib/google/apis/compute_v1/classes.rb', line 71474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71441
71442
71443
# File 'lib/google/apis/compute_v1/classes.rb', line 71441

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Project>

[Output Only] A list of shared VPC host project URLs. Corresponds to the JSON property items



71446
71447
71448
# File 'lib/google/apis/compute_v1/classes.rb', line 71446

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#xpnHostList for lists of shared VPC hosts. Corresponds to the JSON property kind

Returns:

  • (String)


71452
71453
71454
# File 'lib/google/apis/compute_v1/classes.rb', line 71452

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71462
71463
71464
# File 'lib/google/apis/compute_v1/classes.rb', line 71462

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71467
71468
71469
# File 'lib/google/apis/compute_v1/classes.rb', line 71467

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::XpnHostList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71472
71473
71474
# File 'lib/google/apis/compute_v1/classes.rb', line 71472

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71479
71480
71481
71482
71483
71484
71485
71486
# File 'lib/google/apis/compute_v1/classes.rb', line 71479

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end