Class: Google::Apis::ComputeV1::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



71718
71719
71720
# File 'lib/google/apis/compute_v1/classes.rb', line 71718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71686
71687
71688
# File 'lib/google/apis/compute_v1/classes.rb', line 71686

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Zone>

A list of Zone resources. Corresponds to the JSON property items

Returns:



71691
71692
71693
# File 'lib/google/apis/compute_v1/classes.rb', line 71691

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


71696
71697
71698
# File 'lib/google/apis/compute_v1/classes.rb', line 71696

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71706
71707
71708
# File 'lib/google/apis/compute_v1/classes.rb', line 71706

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71711
71712
71713
# File 'lib/google/apis/compute_v1/classes.rb', line 71711

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71716
71717
71718
# File 'lib/google/apis/compute_v1/classes.rb', line 71716

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71723
71724
71725
71726
71727
71728
71729
71730
# File 'lib/google/apis/compute_v1/classes.rb', line 71723

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end