Class: Google::Apis::ComputeV1::Address

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an IP Address resource. Google Compute Engine has two IP Address resources:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Address

Returns a new instance of Address.



917
918
919
# File 'lib/google/apis/compute_v1/classes.rb', line 917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

The static IP address represented by this resource. Corresponds to the JSON property address

Returns:

  • (String)


726
727
728
# File 'lib/google/apis/compute_v1/classes.rb', line 726

def address
  @address
end

#address_typeString

The type of address to reserve, either INTERNAL orEXTERNAL. If unspecified, defaults to EXTERNAL. Corresponds to the JSON property addressType

Returns:

  • (String)


732
733
734
# File 'lib/google/apis/compute_v1/classes.rb', line 732

def address_type
  @address_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


738
739
740
# File 'lib/google/apis/compute_v1/classes.rb', line 738

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


744
745
746
# File 'lib/google/apis/compute_v1/classes.rb', line 744

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


751
752
753
# File 'lib/google/apis/compute_v1/classes.rb', line 751

def id
  @id
end

#ip_collectionString

Reference to the source of IP addresses. It supports the following cases:

- Case 1: PublicDelegatedPrefix (PDP) for BYOIP external IPv4

addresses. The PDP must support enhanced IPv4 allocations.

Case 2: Internal Range for global internal addresses. Use one of the following formats to specify the resource: For a Public Delegated Prefix:

- Full resource URL:https://www.googleapis.com/compute/v1/projects/projectId/ regions/region/publicDelegatedPrefixes/pdp

  • Partial URL:
  • projects/projectId/regions/region/publicDelegatedPrefixes/pdp-name
  • regions/region/publicDelegatedPrefixes/pdp-name

For an Internal Range:

Returns:

  • (String)


779
780
781
# File 'lib/google/apis/compute_v1/classes.rb', line 779

def ip_collection
  @ip_collection
end

#ip_versionString

The IP version that will be used by this address. Valid options areIPV4 or IPV6. Corresponds to the JSON property ipVersion

Returns:

  • (String)


785
786
787
# File 'lib/google/apis/compute_v1/classes.rb', line 785

def ip_version
  @ip_version
end

#ipv6_endpoint_typeString

The endpoint type of this address, which should be VM or NETLB. This is used for deciding which type of endpoint this address can be used after the external IPv6 address reservation. Corresponds to the JSON property ipv6EndpointType

Returns:

  • (String)


792
793
794
# File 'lib/google/apis/compute_v1/classes.rb', line 792

def ipv6_endpoint_type
  @ipv6_endpoint_type
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#address for addresses. Corresponds to the JSON property kind

Returns:

  • (String)


798
799
800
# File 'lib/google/apis/compute_v1/classes.rb', line 798

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this Address, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an Address. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


811
812
813
# File 'lib/google/apis/compute_v1/classes.rb', line 811

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


818
819
820
# File 'lib/google/apis/compute_v1/classes.rb', line 818

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit. Corresponds to the JSON property name

Returns:

  • (String)


829
830
831
# File 'lib/google/apis/compute_v1/classes.rb', line 829

def name
  @name
end

#networkString

The URL of the network in which to reserve the address. This field can only be used with INTERNAL type with theVPC_PEERING purpose. Corresponds to the JSON property network

Returns:

  • (String)


835
836
837
# File 'lib/google/apis/compute_v1/classes.rb', line 835

def network
  @network
end

#network_tierString

This signifies the networking tier used for configuring this address and can only take the following values: PREMIUM orSTANDARD. Internal IP addresses are always Premium Tier; global external IP addresses are always Premium Tier; regional external IP addresses can be either Standard or Premium Tier. If this field is not specified, it is assumed to be PREMIUM. Corresponds to the JSON property networkTier

Returns:

  • (String)


845
846
847
# File 'lib/google/apis/compute_v1/classes.rb', line 845

def network_tier
  @network_tier
end

#prefix_lengthFixnum

The prefix length if the resource represents an IP range. Corresponds to the JSON property prefixLength

Returns:

  • (Fixnum)


850
851
852
# File 'lib/google/apis/compute_v1/classes.rb', line 850

def prefix_length
  @prefix_length
end

#purposeString

The purpose of this resource, which can be one of the following values:

  • GCE_ENDPOINT for addresses that are used by VM instances, alias IP ranges, load balancers, and similar resources.
  • DNS_RESOLVER for a DNS resolver address in a subnetwork for a Cloud DNS inbound forwarder IP addresses (regional internal IP address in a subnet of a VPC network)
  • VPC_PEERING for global internal IP addresses used for

private services access allocated ranges.

  • NAT_AUTO for the regional external IP addresses used by Cloud NAT when allocating addresses using

automatic NAT IP address allocation.

  • IPSEC_INTERCONNECT for addresses created from a private IP range that are reserved for a VLAN attachment in an HA VPN over Cloud Interconnect configuration. These addresses are regional resources.
  • SHARED_LOADBALANCER_VIP for an internal IP address that is assigned to multiple internal forwarding rules.
  • PRIVATE_SERVICE_CONNECT for a private network address that is used to configure Private Service Connect. Only global internal addresses can use this purpose. Corresponds to the JSON property purpose

Returns:

  • (String)


879
880
881
# File 'lib/google/apis/compute_v1/classes.rb', line 879

def purpose
  @purpose
end

#regionString

Output only. [Output Only] The URL of the region where a regional address resides. For regional addresses, you must specify the region as a path parameter in the HTTP request URL. This field is not applicable to global addresses. Corresponds to the JSON property region

Returns:

  • (String)


888
889
890
# File 'lib/google/apis/compute_v1/classes.rb', line 888

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


893
894
895
# File 'lib/google/apis/compute_v1/classes.rb', line 893

def self_link
  @self_link
end

#statusString

Output only. [Output Only] The status of the address, which can be one ofRESERVING, RESERVED, or IN_USE. An address that is RESERVING is currently in the process of being reserved. A RESERVED address is currently reserved and available to use. An IN_USE address is currently being used by another resource and is not available. Corresponds to the JSON property status

Returns:

  • (String)


903
904
905
# File 'lib/google/apis/compute_v1/classes.rb', line 903

def status
  @status
end

#subnetworkString

The URL of the subnetwork in which to reserve the address. If an IP address is specified, it must be within the subnetwork's IP range. This field can only be used with INTERNAL type with aGCE_ENDPOINT or DNS_RESOLVER purpose. Corresponds to the JSON property subnetwork

Returns:

  • (String)


910
911
912
# File 'lib/google/apis/compute_v1/classes.rb', line 910

def subnetwork
  @subnetwork
end

#usersArray<String>

[Output Only] The URLs of the resources that are using this address. Corresponds to the JSON property users

Returns:

  • (Array<String>)


915
916
917
# File 'lib/google/apis/compute_v1/classes.rb', line 915

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
# File 'lib/google/apis/compute_v1/classes.rb', line 922

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @address_type = args[:address_type] if args.key?(:address_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @ip_collection = args[:ip_collection] if args.key?(:ip_collection)
  @ip_version = args[:ip_version] if args.key?(:ip_version)
  @ipv6_endpoint_type = args[:ipv6_endpoint_type] if args.key?(:ipv6_endpoint_type)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_tier = args[:network_tier] if args.key?(:network_tier)
  @prefix_length = args[:prefix_length] if args.key?(:prefix_length)
  @purpose = args[:purpose] if args.key?(:purpose)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @users = args[:users] if args.key?(:users)
end