Class: Google::Apis::ComputeV1::AddressAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AddressAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::AddressesScopedList>
A list of AddressesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::AddressAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddressAggregatedList
constructor
A new instance of AddressAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddressAggregatedList
Returns a new instance of AddressAggregatedList.
1007 1008 1009 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
968 969 970 |
# File 'lib/google/apis/compute_v1/classes.rb', line 968 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::AddressesScopedList>
A list of AddressesScopedList resources.
Corresponds to the JSON property items
973 974 975 |
# File 'lib/google/apis/compute_v1/classes.rb', line 973 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
addressAggregatedList for aggregated lists of
addresses.
Corresponds to the JSON property kind
980 981 982 |
# File 'lib/google/apis/compute_v1/classes.rb', line 980 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
990 991 992 |
# File 'lib/google/apis/compute_v1/classes.rb', line 990 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
995 996 997 |
# File 'lib/google/apis/compute_v1/classes.rb', line 995 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
1000 1001 1002 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1000 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::AddressAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
1005 1006 1007 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1005 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1012 1013 1014 1015 1016 1017 1018 1019 1020 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1012 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |