Class: Google::Apis::ComputeV1::AddressAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressAggregatedList

Returns a new instance of AddressAggregatedList.



1001
1002
1003
# File 'lib/google/apis/compute_v1/classes.rb', line 1001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


962
963
964
# File 'lib/google/apis/compute_v1/classes.rb', line 962

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::AddressesScopedList>

A list of AddressesScopedList resources. Corresponds to the JSON property items



967
968
969
# File 'lib/google/apis/compute_v1/classes.rb', line 967

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# addressAggregatedList for aggregated lists of addresses. Corresponds to the JSON property kind

Returns:

  • (String)


974
975
976
# File 'lib/google/apis/compute_v1/classes.rb', line 974

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


984
985
986
# File 'lib/google/apis/compute_v1/classes.rb', line 984

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


989
990
991
# File 'lib/google/apis/compute_v1/classes.rb', line 989

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


994
995
996
# File 'lib/google/apis/compute_v1/classes.rb', line 994

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::AddressAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



999
1000
1001
# File 'lib/google/apis/compute_v1/classes.rb', line 999

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1006
1007
1008
1009
1010
1011
1012
1013
1014
# File 'lib/google/apis/compute_v1/classes.rb', line 1006

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end