Class: Google::Apis::ComputeV1::AddressAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressAggregatedList

Returns a new instance of AddressAggregatedList.



993
994
995
# File 'lib/google/apis/compute_v1/classes.rb', line 993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


954
955
956
# File 'lib/google/apis/compute_v1/classes.rb', line 954

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::AddressesScopedList>

A list of AddressesScopedList resources. Corresponds to the JSON property items



959
960
961
# File 'lib/google/apis/compute_v1/classes.rb', line 959

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# addressAggregatedList for aggregated lists of addresses. Corresponds to the JSON property kind

Returns:

  • (String)


966
967
968
# File 'lib/google/apis/compute_v1/classes.rb', line 966

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


976
977
978
# File 'lib/google/apis/compute_v1/classes.rb', line 976

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


981
982
983
# File 'lib/google/apis/compute_v1/classes.rb', line 981

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


986
987
988
# File 'lib/google/apis/compute_v1/classes.rb', line 986

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::AddressAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



991
992
993
# File 'lib/google/apis/compute_v1/classes.rb', line 991

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



998
999
1000
1001
1002
1003
1004
1005
1006
# File 'lib/google/apis/compute_v1/classes.rb', line 998

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end