Class: Google::Apis::ComputeV1::AddressList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of addresses.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddressList

Returns a new instance of AddressList.



1119
1120
1121
# File 'lib/google/apis/compute_v1/classes.rb', line 1119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


1086
1087
1088
# File 'lib/google/apis/compute_v1/classes.rb', line 1086

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Address>

A list of Address resources. Corresponds to the JSON property items



1091
1092
1093
# File 'lib/google/apis/compute_v1/classes.rb', line 1091

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#addressList for lists of addresses. Corresponds to the JSON property kind

Returns:

  • (String)


1097
1098
1099
# File 'lib/google/apis/compute_v1/classes.rb', line 1097

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1107
1108
1109
# File 'lib/google/apis/compute_v1/classes.rb', line 1107

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1112
1113
1114
# File 'lib/google/apis/compute_v1/classes.rb', line 1112

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::AddressList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



1117
1118
1119
# File 'lib/google/apis/compute_v1/classes.rb', line 1117

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1124
1125
1126
1127
1128
1129
1130
1131
# File 'lib/google/apis/compute_v1/classes.rb', line 1124

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end