Class: Google::Apis::ComputeV1::AllocationAggregateReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationAggregateReservation

Returns a new instance of AllocationAggregateReservation.



1433
1434
1435
# File 'lib/google/apis/compute_v1/classes.rb', line 1433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#in_use_resourcesArray<Google::Apis::ComputeV1::AllocationAggregateReservationReservedResourceInfo>

Output only. [Output only] List of resources currently in use. Corresponds to the JSON property inUseResources



1415
1416
1417
# File 'lib/google/apis/compute_v1/classes.rb', line 1415

def in_use_resources
  @in_use_resources
end

#reserved_resourcesArray<Google::Apis::ComputeV1::AllocationAggregateReservationReservedResourceInfo>

List of reserved resources (CPUs, memory, accelerators). Corresponds to the JSON property reservedResources



1420
1421
1422
# File 'lib/google/apis/compute_v1/classes.rb', line 1420

def reserved_resources
  @reserved_resources
end

#vm_familyString

The VM family that all instances scheduled against this reservation must belong to. Corresponds to the JSON property vmFamily

Returns:

  • (String)


1426
1427
1428
# File 'lib/google/apis/compute_v1/classes.rb', line 1426

def vm_family
  @vm_family
end

#workload_typeString

The workload type of the instances that will target this reservation. Corresponds to the JSON property workloadType

Returns:

  • (String)


1431
1432
1433
# File 'lib/google/apis/compute_v1/classes.rb', line 1431

def workload_type
  @workload_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1438
1439
1440
1441
1442
1443
# File 'lib/google/apis/compute_v1/classes.rb', line 1438

def update!(**args)
  @in_use_resources = args[:in_use_resources] if args.key?(:in_use_resources)
  @reserved_resources = args[:reserved_resources] if args.key?(:reserved_resources)
  @vm_family = args[:vm_family] if args.key?(:vm_family)
  @workload_type = args[:workload_type] if args.key?(:workload_type)
end