Class: Google::Apis::ComputeV1::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB.
-
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
constructor
A new instance of AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
Returns a new instance of AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk.
1603 1604 1605 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1603 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB.
Corresponds to the JSON property diskSizeGb
1594 1595 1596 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1594 def disk_size_gb @disk_size_gb end |
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is
either SCSI or NVME. The default isSCSI.
For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
Corresponds to the JSON property interface
1601 1602 1603 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1601 def interface @interface end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1608 1609 1610 1611 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1608 def update!(**args) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @interface = args[:interface] if args.key?(:interface) end |