Class: Google::Apis::ComputeV1::AllocationSpecificSkuAllocationReservedInstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Properties of the SKU instances being reserved. Next ID: 10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationSpecificSkuAllocationReservedInstanceProperties

Returns a new instance of AllocationSpecificSkuAllocationReservedInstanceProperties.



1658
1659
1660
# File 'lib/google/apis/compute_v1/classes.rb', line 1658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#guest_acceleratorsArray<Google::Apis::ComputeV1::AcceleratorConfig>

Specifies accelerator type and count. Corresponds to the JSON property guestAccelerators



1631
1632
1633
# File 'lib/google/apis/compute_v1/classes.rb', line 1631

def guest_accelerators
  @guest_accelerators
end

#local_ssdsArray<Google::Apis::ComputeV1::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk>

Specifies amount of local ssd to reserve with each instance. The type of disk is local-ssd. Corresponds to the JSON property localSsds



1637
1638
1639
# File 'lib/google/apis/compute_v1/classes.rb', line 1637

def local_ssds
  @local_ssds
end

#location_hintString

An opaque location hint used to place the allocation close to other resources. This field is for use by internal tools that use the public API. Corresponds to the JSON property locationHint

Returns:

  • (String)


1644
1645
1646
# File 'lib/google/apis/compute_v1/classes.rb', line 1644

def location_hint
  @location_hint
end

#machine_typeString

Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory. This also includes specifying custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern. Corresponds to the JSON property machineType

Returns:

  • (String)


1651
1652
1653
# File 'lib/google/apis/compute_v1/classes.rb', line 1651

def machine_type
  @machine_type
end

#min_cpu_platformString

Minimum cpu platform the reservation. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


1656
1657
1658
# File 'lib/google/apis/compute_v1/classes.rb', line 1656

def min_cpu_platform
  @min_cpu_platform
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1663
1664
1665
1666
1667
1668
1669
# File 'lib/google/apis/compute_v1/classes.rb', line 1663

def update!(**args)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @local_ssds = args[:local_ssds] if args.key?(:local_ssds)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
end