Class: Google::Apis::ComputeV1::AllocationSpecificSkuAllocationReservedInstanceProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AllocationSpecificSkuAllocationReservedInstanceProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Properties of the SKU instances being reserved. Next ID: 9
Instance Attribute Summary collapse
-
#guest_accelerators ⇒ Array<Google::Apis::ComputeV1::AcceleratorConfig>
Specifies accelerator type and count.
-
#local_ssds ⇒ Array<Google::Apis::ComputeV1::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk>
Specifies amount of local ssd to reserve with each instance.
-
#location_hint ⇒ String
An opaque location hint used to place the allocation close to other resources.
-
#machine_type ⇒ String
Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory.
-
#min_cpu_platform ⇒ String
Minimum cpu platform the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationSpecificSkuAllocationReservedInstanceProperties
constructor
A new instance of AllocationSpecificSkuAllocationReservedInstanceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationSpecificSkuAllocationReservedInstanceProperties
Returns a new instance of AllocationSpecificSkuAllocationReservedInstanceProperties.
1649 1650 1651 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#guest_accelerators ⇒ Array<Google::Apis::ComputeV1::AcceleratorConfig>
Specifies accelerator type and count.
Corresponds to the JSON property guestAccelerators
1622 1623 1624 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1622 def guest_accelerators @guest_accelerators end |
#local_ssds ⇒ Array<Google::Apis::ComputeV1::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk>
Specifies amount of local ssd to reserve with each instance. The type
of disk is local-ssd.
Corresponds to the JSON property localSsds
1628 1629 1630 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1628 def local_ssds @local_ssds end |
#location_hint ⇒ String
An opaque location hint used to place the allocation close to other
resources.
This field is for use by internal tools that use the public API.
Corresponds to the JSON property locationHint
1635 1636 1637 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1635 def location_hint @location_hint end |
#machine_type ⇒ String
Specifies type of machine (name only) which has fixed number of vCPUs
and fixed amount of memory. This also includes specifying custom
machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern.
Corresponds to the JSON property machineType
1642 1643 1644 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1642 def machine_type @machine_type end |
#min_cpu_platform ⇒ String
Minimum cpu platform the reservation.
Corresponds to the JSON property minCpuPlatform
1647 1648 1649 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1647 def min_cpu_platform @min_cpu_platform end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1654 1655 1656 1657 1658 1659 1660 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1654 def update!(**args) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) @local_ssds = args[:local_ssds] if args.key?(:local_ssds) @location_hint = args[:location_hint] if args.key?(:location_hint) @machine_type = args[:machine_type] if args.key?(:machine_type) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) end |