Class: Google::Apis::ComputeV1::AllocationSpecificSkuReservation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AllocationSpecificSkuReservation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
This reservation type allows to pre allocate specific instance configuration.
Instance Attribute Summary collapse
-
#assured_count ⇒ Fixnum
Output only.
-
#count ⇒ Fixnum
Specifies the number of resources that are allocated.
-
#in_use_count ⇒ Fixnum
Output only.
-
#instance_properties ⇒ Google::Apis::ComputeV1::AllocationSpecificSkuAllocationReservedInstanceProperties
Properties of the SKU instances being reserved.
-
#source_instance_template ⇒ String
Specifies the instance template to create the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationSpecificSkuReservation
constructor
A new instance of AllocationSpecificSkuReservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationSpecificSkuReservation
Returns a new instance of AllocationSpecificSkuReservation.
1713 1714 1715 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1713 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assured_count ⇒ Fixnum
Output only. [Output Only] Indicates how many instances are actually usable
currently.
Corresponds to the JSON property assuredCount
1681 1682 1683 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1681 def assured_count @assured_count end |
#count ⇒ Fixnum
Specifies the number of resources that are allocated.
Corresponds to the JSON property count
1686 1687 1688 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1686 def count @count end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] Indicates how many instances are in use.
Corresponds to the JSON property inUseCount
1691 1692 1693 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1691 def in_use_count @in_use_count end |
#instance_properties ⇒ Google::Apis::ComputeV1::AllocationSpecificSkuAllocationReservedInstanceProperties
Properties of the SKU instances being reserved.
Next ID: 10
Corresponds to the JSON property instanceProperties
1697 1698 1699 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1697 def instance_properties @instance_properties end |
#source_instance_template ⇒ String
Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field. This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template:
- https://www.googleapis.com/compute/v1/projects/project/global/ instanceTemplates/instanceTemplate
- projects/project/global/instanceTemplates/instanceTemplate
- global/instanceTemplates/instanceTemplate
Corresponds to the JSON property
sourceInstanceTemplate
1711 1712 1713 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1711 def source_instance_template @source_instance_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1718 1719 1720 1721 1722 1723 1724 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1718 def update!(**args) @assured_count = args[:assured_count] if args.key?(:assured_count) @count = args[:count] if args.key?(:count) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @source_instance_template = args[:source_instance_template] if args.key?(:source_instance_template) end |