Class: Google::Apis::ComputeV1::AttachedDiskInitializeParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AttachedDiskInitializeParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This field is persisted and returned for instanceTemplate and not returned in the context of instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the attached disk.
-
#description ⇒ String
An optional description.
-
#disk_name ⇒ String
Specifies the disk name.
-
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB.
-
#disk_type ⇒ String
Specifies the disk type to use to create the instance.
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Whether this disk is using confidential compute mode.
-
#labels ⇒ Hash<String,String>
Labels to apply to this disk.
-
#licenses ⇒ Array<String>
A list of publicly visible licenses.
-
#on_update_action ⇒ String
Specifies which action to take on instance update with this disk.
-
#provisioned_iops ⇒ Fixnum
Indicates how many IOPS to provision for the disk.
-
#provisioned_throughput ⇒ Fixnum
Indicates how much throughput to provision for the disk.
-
#replica_zones ⇒ Array<String>
Required for each regional disk associated with the instance.
-
#resource_manager_tags ⇒ Hash<String,String>
Resource manager tags to be bound to the disk.
-
#resource_policies ⇒ Array<String>
Resource policies applied to this disk for automatic snapshot creations.
-
#source_image ⇒ String
The source image to create this disk.
-
#source_image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source image.
-
#source_snapshot ⇒ String
The source snapshot to create this disk.
-
#source_snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source snapshot.
-
#storage_pool ⇒ String
The storage pool in which the new disk is created.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AttachedDiskInitializeParams
constructor
A new instance of AttachedDiskInitializeParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AttachedDiskInitializeParams
Returns a new instance of AttachedDiskInitializeParams.
2101 2102 2103 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The architecture of the attached disk. Valid values are
arm64 or x86_64.
Corresponds to the JSON property architecture
1922 1923 1924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1922 def architecture @architecture end |
#description ⇒ String
An optional description. Provide this property when creating the disk.
Corresponds to the JSON property description
1927 1928 1929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1927 def description @description end |
#disk_name ⇒ String
Specifies the disk name. If not specified, the default is to use the name
of the instance. If a disk with the same name already exists in the given
region, the existing disk is attached to the new instance and the
new disk is not created.
Corresponds to the JSON property diskName
1935 1936 1937 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1935 def disk_name @disk_name end |
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB. The size must be at least
10 GB. If you specify a sourceImage, which is required for
boot disks, the default size is the size of the sourceImage.
If you do not specify a sourceImage, the default disk size
is 500 GB.
Corresponds to the JSON property diskSizeGb
1944 1945 1946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1944 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Specifies the disk type to use to create the instance. If not specified, the default is pd-standard, specified using the full URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/diskTypes/pd- standard For a full list of acceptable values, seePersistent disk types. If you specify this field when creating a VM, you can provide either the full or partial URL. For example, the following values are valid:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ diskTypes/diskType
- projects/project/zones/zone/diskTypes/diskType
- zones/zone/diskTypes/diskType
If you specify this field when creating or updating an instance template
or all-instances configuration, specify the type of the disk, not the
URL. For example: pd-standard.
Corresponds to the JSON property
diskType
1966 1967 1968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1966 def disk_type @disk_type end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Whether this disk is using confidential compute mode.
Corresponds to the JSON property enableConfidentialCompute
1971 1972 1973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1971 def enable_confidential_compute @enable_confidential_compute end |
#labels ⇒ Hash<String,String>
Labels to apply to this disk. These can be later modified by thedisks.
setLabels method. This field is only applicable for
persistent disks.
Corresponds to the JSON property labels
1979 1980 1981 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1979 def labels @labels end |
#licenses ⇒ Array<String>
A list of publicly visible licenses. Reserved for Google's use.
Corresponds to the JSON property licenses
1984 1985 1986 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1984 def licenses @licenses end |
#on_update_action ⇒ String
Specifies which action to take on instance update with this disk. Default
is to use the existing disk.
Corresponds to the JSON property onUpdateAction
1990 1991 1992 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1990 def on_update_action @on_update_action end |
#provisioned_iops ⇒ Fixnum
Indicates how many IOPS to provision for the disk. This sets the number
of I/O operations per second that the disk can handle. Values must be
between 10,000 and 120,000. For more details, see theExtreme persistent
disk documentation.
Corresponds to the JSON property provisionedIops
1998 1999 2000 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1998 def provisioned_iops @provisioned_iops end |
#provisioned_throughput ⇒ Fixnum
Indicates how much throughput to provision for the disk. This sets the
number of throughput mb per second that the disk can handle. Values must
greater than or equal to 1.
Corresponds to the JSON property provisionedThroughput
2005 2006 2007 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2005 def provisioned_throughput @provisioned_throughput end |
#replica_zones ⇒ Array<String>
Required for each regional disk associated with the instance. Specify
the URLs of the zones where the disk should be replicated to.
You must provide exactly two replica zones, and one zone must be the same
as the instance zone.
Corresponds to the JSON property replicaZones
2013 2014 2015 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2013 def replica_zones @replica_zones end |
#resource_manager_tags ⇒ Hash<String,String>
Resource manager tags to be bound to the disk. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/456` or in namespaced
format such asorg_id|project_id/tag_key_short_nameand
tag_value_short_name`. The field is ignored (both PUT & PATCH) when
empty.
Corresponds to the JSON propertyresourceManagerTags`
2024 2025 2026 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2024 def @resource_manager_tags end |
#resource_policies ⇒ Array<String>
Resource policies applied to this disk for automatic snapshot creations.
Specified using the full or partial URL. For instance template, specify
only the resource policy name.
Corresponds to the JSON property resourcePolicies
2031 2032 2033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2031 def resource_policies @resource_policies end |
#source_image ⇒ String
The source image to create this disk. When creating a new instance boot
disk, one of initializeParams.sourceImage orinitializeParams.sourceSnapshot or
disks.source
is required.
To create a disk with one of the public operating system
images, specify the image by its family name. For example, specifyfamily/
debian-9 to use the latest Debian 9 image:
projects/debian-cloud/global/images/family/debian-9
Alternatively, use a specific version of a public operating system image:
projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD
To create a disk with a custom image that you created, specify the
image name in the following format:
global/images/my-custom-image
You can also specify a custom image by its image family, which returns
the latest version of the image in that family. Replace the image name
with family/family-name:
global/images/family/my-image-family
If the source image is deleted later, this field will not be set.
Corresponds to the JSON property sourceImage
2053 2054 2055 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2053 def source_image @source_image end |
#source_image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Thecustomer-supplied
encryption key of the source image. Required if the source image is
protected by a customer-supplied encryption key.
InstanceTemplate and InstancePropertiesPatch do not storecustomer-supplied
encryption keys, so you cannot create disks for instances in a managed
instance group if the
source images are encrypted with your own keys.
Corresponds to the JSON property sourceImageEncryptionKey
2064 2065 2066 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2064 def source_image_encryption_key @source_image_encryption_key end |
#source_snapshot ⇒ String
The source snapshot to create this disk. When creating a new instance
boot disk, one of initializeParams.sourceSnapshot orinitializeParams.
sourceImage or disks.source
is required.
To create a disk with a snapshot that you created, specify the
snapshot name in the following format:
global/snapshots/my-backup
If the source snapshot is deleted later, this field will not be set.
Note: You cannot create VMs in bulk using a snapshot as the source. Use
an image instead when you create VMs using
the bulk
insert method.
Corresponds to the JSON property sourceSnapshot
2080 2081 2082 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2080 def source_snapshot @source_snapshot end |
#source_snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Thecustomer-supplied
encryption key of the source snapshot.
Corresponds to the JSON property sourceSnapshotEncryptionKey
2086 2087 2088 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2086 def source_snapshot_encryption_key @source_snapshot_encryption_key end |
#storage_pool ⇒ String
The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ storagePools/storagePool
- projects/project/zones/zone/storagePools/storagePool
- zones/zone/storagePools/storagePool
Corresponds to the JSON property
storagePool
2099 2100 2101 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2099 def storage_pool @storage_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2106 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @description = args[:description] if args.key?(:description) @disk_name = args[:disk_name] if args.key?(:disk_name) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) @labels = args[:labels] if args.key?(:labels) @licenses = args[:licenses] if args.key?(:licenses) @on_update_action = args[:on_update_action] if args.key?(:on_update_action) @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops) @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput) @replica_zones = args[:replica_zones] if args.key?(:replica_zones) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @source_image = args[:source_image] if args.key?(:source_image) @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key) @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot) @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key) @storage_pool = args[:storage_pool] if args.key?(:storage_pool) end |