Class: Google::Apis::ComputeV1::AttachedDiskInitializeParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AttachedDiskInitializeParams

Returns a new instance of AttachedDiskInitializeParams.



1481
1482
1483
# File 'lib/google/apis/compute_v1/classes.rb', line 1481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description. Provide this property when creating the disk. Corresponds to the JSON property description

Returns:

  • (String)


1378
1379
1380
# File 'lib/google/apis/compute_v1/classes.rb', line 1378

def description
  @description
end

#disk_nameString

Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created. Corresponds to the JSON property diskName

Returns:

  • (String)


1386
1387
1388
# File 'lib/google/apis/compute_v1/classes.rb', line 1386

def disk_name
  @disk_name
end

#disk_size_gbFixnum

Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


1394
1395
1396
# File 'lib/google/apis/compute_v1/classes.rb', line 1394

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Specifies the disk type to use to create the instance. If not specified, the default is pd-standard, specified using the full URL. For example: https://www. googleapis.com/compute/v1/projects/project/zones/zone /diskTypes/pd-standard For a full list of acceptable values, see Persistent disk types. If you define this field, you can provide either the full or partial URL. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/ project/zones/zone /diskTypes/diskType - projects/project/zones/zone/diskTypes/ diskType - zones/zone/diskTypes/diskType Note that for InstanceTemplate, this is the name of the disk type, not URL. Corresponds to the JSON property diskType

Returns:

  • (String)


1407
1408
1409
# File 'lib/google/apis/compute_v1/classes.rb', line 1407

def disk_type
  @disk_type
end

#labelsHash<String,String>

Labels to apply to this disk. These can be later modified by the disks. setLabels method. This field is only applicable for persistent disks. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1413
1414
1415
# File 'lib/google/apis/compute_v1/classes.rb', line 1413

def labels
  @labels
end

#licensesArray<String>

A list of publicly visible licenses. Reserved for Google's use. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


1418
1419
1420
# File 'lib/google/apis/compute_v1/classes.rb', line 1418

def licenses
  @licenses
end

#on_update_actionString

Specifies which action to take on instance update with this disk. Default is to use the existing disk. Corresponds to the JSON property onUpdateAction

Returns:

  • (String)


1424
1425
1426
# File 'lib/google/apis/compute_v1/classes.rb', line 1424

def on_update_action
  @on_update_action
end

#provisioned_iopsFixnum

Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see the Extreme persistent disk documentation. Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


1431
1432
1433
# File 'lib/google/apis/compute_v1/classes.rb', line 1431

def provisioned_iops
  @provisioned_iops
end

#resource_policiesArray<String>

Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


1438
1439
1440
# File 'lib/google/apis/compute_v1/classes.rb', line 1438

def resource_policies
  @resource_policies
end

#source_imageString

The source image to create this disk. When creating a new instance, one of initializeParams.sourceImage or initializeParams.sourceSnapshot or disks. source is required except for local SSD. To create a disk with one of the public operating system images, specify the image by its family name. For example, specify family/debian-9 to use the latest Debian 9 image: projects/ debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/ images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my- custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family If the source image is deleted later, this field will not be set. Corresponds to the JSON property sourceImage

Returns:

  • (String)


1455
1456
1457
# File 'lib/google/apis/compute_v1/classes.rb', line 1455

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. Instance templates do not store customer-supplied encryption keys, so you cannot create disks for instances in a managed instance group if the source images are encrypted with your own keys. Corresponds to the JSON property sourceImageEncryptionKey



1464
1465
1466
# File 'lib/google/apis/compute_v1/classes.rb', line 1464

def source_image_encryption_key
  @source_image_encryption_key
end

#source_snapshotString

The source snapshot to create this disk. When creating a new instance, one of initializeParams.sourceSnapshot or initializeParams.sourceImage or disks. source is required except for local SSD. To create a disk with a snapshot that you created, specify the snapshot name in the following format: global/ snapshots/my-backup If the source snapshot is deleted later, this field will not be set. Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


1474
1475
1476
# File 'lib/google/apis/compute_v1/classes.rb', line 1474

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The customer-supplied encryption key of the source snapshot. Corresponds to the JSON property sourceSnapshotEncryptionKey



1479
1480
1481
# File 'lib/google/apis/compute_v1/classes.rb', line 1479

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
# File 'lib/google/apis/compute_v1/classes.rb', line 1486

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @disk_name = args[:disk_name] if args.key?(:disk_name)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @labels = args[:labels] if args.key?(:labels)
  @licenses = args[:licenses] if args.key?(:licenses)
  @on_update_action = args[:on_update_action] if args.key?(:on_update_action)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
end