Class: Google::Apis::ComputeV1::AuditLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AuditLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Provides the configuration for logging a type of permissions.
Example:
"audit_log_configs": [
"log_type": "DATA_READ",
"exempted_members": [
"user:jose@example.com"
]
,
"log_type": "DATA_WRITE"
]
This enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting
jose@example.com from DATA_READ logging.
Instance Attribute Summary collapse
-
#exempted_members ⇒ Array<String>
Specifies the identities that do not cause logging for this type of permission.
-
#log_type ⇒ String
The log type that this config enables.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuditLogConfig
constructor
A new instance of AuditLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuditLogConfig
Returns a new instance of AuditLogConfig.
2217 2218 2219 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exempted_members ⇒ Array<String>
Specifies the identities that do not cause logging for this type of
permission.
Follows the same format of Binding.members.
Corresponds to the JSON property exemptedMembers
2210 2211 2212 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2210 def exempted_members @exempted_members end |
#log_type ⇒ String
The log type that this config enables.
Corresponds to the JSON property logType
2215 2216 2217 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2215 def log_type @log_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2222 2223 2224 2225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2222 def update!(**args) @exempted_members = args[:exempted_members] if args.key?(:exempted_members) @log_type = args[:log_type] if args.key?(:log_type) end |