Class: Google::Apis::ComputeV1::Autoscaler
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Autoscaler
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents an Autoscaler resource. Google Compute Engine has two Autoscaler resources: * Zonal * Regional Use autoscalers to automatically add or delete instances from a managed instance group according to your defined autoscaling policy. For more information, read Autoscaling Groups of Instances. For zonal managed instance groups resource, use the autoscaler resource. For regional managed instance groups, use the regionAutoscalers resource.
Instance Attribute Summary collapse
-
#autoscaling_policy ⇒ Google::Apis::ComputeV1::AutoscalingPolicy
Cloud Autoscaler policy.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#name ⇒ String
Name of the resource.
-
#recommended_size ⇒ Fixnum
[Output Only] Target recommended MIG size (number of instances) computed by autoscaler.
-
#region ⇒ String
[Output Only] URL of the region where the instance group resides (for autoscalers living in regional scope).
-
#scaling_schedule_status ⇒ Hash<String,Google::Apis::ComputeV1::ScalingScheduleStatus>
[Output Only] Status information of existing scaling schedules.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] The status of the autoscaler configuration.
-
#status_details ⇒ Array<Google::Apis::ComputeV1::AutoscalerStatusDetails>
[Output Only] Human-readable details about the current state of the autoscaler.
-
#target ⇒ String
URL of the managed instance group that this autoscaler will scale.
-
#zone ⇒ String
[Output Only] URL of the zone where the instance group resides (for autoscalers living in zonal scope).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Autoscaler
constructor
A new instance of Autoscaler.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Autoscaler
Returns a new instance of Autoscaler.
1709 1710 1711 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1709 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_policy ⇒ Google::Apis::ComputeV1::AutoscalingPolicy
Cloud Autoscaler policy.
Corresponds to the JSON property autoscalingPolicy
1620 1621 1622 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1620 def autoscaling_policy @autoscaling_policy end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
1625 1626 1627 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1625 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
1631 1632 1633 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1631 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
1637 1638 1639 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1637 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#autoscaler for autoscalers.
Corresponds to the JSON property kind
1642 1643 1644 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1642 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
1652 1653 1654 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1652 def name @name end |
#recommended_size ⇒ Fixnum
[Output Only] Target recommended MIG size (number of instances) computed by
autoscaler. Autoscaler calculates the recommended MIG size even when the
autoscaling policy mode is different from ON. This field is empty when
autoscaler is not connected to an existing managed instance group or
autoscaler did not generate its prediction.
Corresponds to the JSON property recommendedSize
1661 1662 1663 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1661 def recommended_size @recommended_size end |
#region ⇒ String
[Output Only] URL of the region where the instance group resides (for
autoscalers living in regional scope).
Corresponds to the JSON property region
1667 1668 1669 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1667 def region @region end |
#scaling_schedule_status ⇒ Hash<String,Google::Apis::ComputeV1::ScalingScheduleStatus>
[Output Only] Status information of existing scaling schedules.
Corresponds to the JSON property scalingScheduleStatus
1672 1673 1674 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1672 def scaling_schedule_status @scaling_schedule_status end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
1677 1678 1679 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1677 def self_link @self_link end |
#status ⇒ String
[Output Only] The status of the autoscaler configuration. Current set of
possible values: - PENDING: Autoscaler backend hasn't read new/updated
configuration. - DELETING: Configuration is being deleted. - ACTIVE:
Configuration is acknowledged to be effective. Some warnings might be present
in the statusDetails field. - ERROR: Configuration has errors. Actionable for
users. Details are present in the statusDetails field. New values might be
added in the future.
Corresponds to the JSON property status
1688 1689 1690 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1688 def status @status end |
#status_details ⇒ Array<Google::Apis::ComputeV1::AutoscalerStatusDetails>
[Output Only] Human-readable details about the current state of the autoscaler.
Read the documentation for Commonly returned status messages for examples of
status messages you might encounter.
Corresponds to the JSON property statusDetails
1695 1696 1697 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1695 def status_details @status_details end |
#target ⇒ String
URL of the managed instance group that this autoscaler will scale. This field
is required when creating an autoscaler.
Corresponds to the JSON property target
1701 1702 1703 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1701 def target @target end |
#zone ⇒ String
[Output Only] URL of the zone where the instance group resides (for
autoscalers living in zonal scope).
Corresponds to the JSON property zone
1707 1708 1709 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1707 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1714 def update!(**args) @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @recommended_size = args[:recommended_size] if args.key?(:recommended_size) @region = args[:region] if args.key?(:region) @scaling_schedule_status = args[:scaling_schedule_status] if args.key?(:scaling_schedule_status) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @status_details = args[:status_details] if args.key?(:status_details) @target = args[:target] if args.key?(:target) @zone = args[:zone] if args.key?(:zone) end |