Class: Google::Apis::ComputeV1::AutoscalerAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AutoscalerAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerAggregatedList
constructor
A new instance of AutoscalerAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerAggregatedList
Returns a new instance of AutoscalerAggregatedList.
2469 2470 2471 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
2429 2430 2431 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2429 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
Corresponds to the JSON property items
2434 2435 2436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2434 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
autoscalerAggregatedList for aggregated lists of
autoscalers.
Corresponds to the JSON property kind
2441 2442 2443 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2441 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2451 2452 2453 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2451 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2456 2457 2458 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2456 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
2462 2463 2464 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2462 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
2467 2468 2469 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2467 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2474 2475 2476 2477 2478 2479 2480 2481 2482 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2474 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |