Class: Google::Apis::ComputeV1::AutoscalerAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AutoscalerAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerAggregatedList
constructor
A new instance of AutoscalerAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerAggregatedList
Returns a new instance of AutoscalerAggregatedList.
2426 2427 2428 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
2386 2387 2388 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2386 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
Corresponds to the JSON property items
2391 2392 2393 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2391 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
autoscalerAggregatedList for aggregated lists of
autoscalers.
Corresponds to the JSON property kind
2398 2399 2400 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2398 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2408 2409 2410 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2408 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2413 2414 2415 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2413 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
2419 2420 2421 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2419 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
2424 2425 2426 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2424 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2431 2432 2433 2434 2435 2436 2437 2438 2439 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2431 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |