Class: Google::Apis::ComputeV1::AutoscalerAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AutoscalerAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerAggregatedList
constructor
A new instance of AutoscalerAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerAggregatedList
Returns a new instance of AutoscalerAggregatedList.
2417 2418 2419 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
2377 2378 2379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2377 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::AutoscalersScopedList>
A list of AutoscalersScopedList resources.
Corresponds to the JSON property items
2382 2383 2384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2382 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
autoscalerAggregatedList for aggregated lists of
autoscalers.
Corresponds to the JSON property kind
2389 2390 2391 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2389 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2399 2400 2401 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2399 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2404 2405 2406 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2404 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
2410 2411 2412 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2410 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::AutoscalerAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
2415 2416 2417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2415 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2422 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |