Class: Google::Apis::ComputeV1::AutoscalerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerAggregatedList

Returns a new instance of AutoscalerAggregatedList.



2434
2435
2436
# File 'lib/google/apis/compute_v1/classes.rb', line 2434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2394
2395
2396
# File 'lib/google/apis/compute_v1/classes.rb', line 2394

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::AutoscalersScopedList>

A list of AutoscalersScopedList resources. Corresponds to the JSON property items



2399
2400
2401
# File 'lib/google/apis/compute_v1/classes.rb', line 2399

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# autoscalerAggregatedList for aggregated lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2406
2407
2408
# File 'lib/google/apis/compute_v1/classes.rb', line 2406

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2416
2417
2418
# File 'lib/google/apis/compute_v1/classes.rb', line 2416

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2421
2422
2423
# File 'lib/google/apis/compute_v1/classes.rb', line 2421

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


2427
2428
2429
# File 'lib/google/apis/compute_v1/classes.rb', line 2427

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::AutoscalerAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



2432
2433
2434
# File 'lib/google/apis/compute_v1/classes.rb', line 2432

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/google/apis/compute_v1/classes.rb', line 2439

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end