Class: Google::Apis::ComputeV1::AutoscalerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerAggregatedList

Returns a new instance of AutoscalerAggregatedList.



1777
1778
1779
# File 'lib/google/apis/compute_v1/classes.rb', line 1777

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


1739
1740
1741
# File 'lib/google/apis/compute_v1/classes.rb', line 1739

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::AutoscalersScopedList>

A list of AutoscalersScopedList resources. Corresponds to the JSON property items



1744
1745
1746
# File 'lib/google/apis/compute_v1/classes.rb', line 1744

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#autoscalerAggregatedList for aggregated lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


1750
1751
1752
# File 'lib/google/apis/compute_v1/classes.rb', line 1750

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1759
1760
1761
# File 'lib/google/apis/compute_v1/classes.rb', line 1759

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1764
1765
1766
# File 'lib/google/apis/compute_v1/classes.rb', line 1764

def self_link
  @self_link
end

#unreachablesArray<String>

[Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


1770
1771
1772
# File 'lib/google/apis/compute_v1/classes.rb', line 1770

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::AutoscalerAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



1775
1776
1777
# File 'lib/google/apis/compute_v1/classes.rb', line 1775

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1782
1783
1784
1785
1786
1787
1788
1789
1790
# File 'lib/google/apis/compute_v1/classes.rb', line 1782

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end