Class: Google::Apis::ComputeV1::AutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Autoscaler resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::AutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerList
constructor
A new instance of AutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerList
Returns a new instance of AutoscalerList.
2601 2602 2603 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2601 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
2568 2569 2570 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2568 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
2573 2574 2575 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2573 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#autoscalerList
for lists of autoscalers.
Corresponds to the JSON property kind
2579 2580 2581 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2579 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2589 2590 2591 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2589 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2594 2595 2596 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2594 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::AutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
2599 2600 2601 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2599 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2606 2607 2608 2609 2610 2611 2612 2613 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2606 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |