Class: Google::Apis::ComputeV1::AutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Autoscaler resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerList

Returns a new instance of AutoscalerList.



2595
2596
2597
# File 'lib/google/apis/compute_v1/classes.rb', line 2595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2562
2563
2564
# File 'lib/google/apis/compute_v1/classes.rb', line 2562

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



2567
2568
2569
# File 'lib/google/apis/compute_v1/classes.rb', line 2567

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#autoscalerList for lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2573
2574
2575
# File 'lib/google/apis/compute_v1/classes.rb', line 2573

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2583
2584
2585
# File 'lib/google/apis/compute_v1/classes.rb', line 2583

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2588
2589
2590
# File 'lib/google/apis/compute_v1/classes.rb', line 2588

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::AutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



2593
2594
2595
# File 'lib/google/apis/compute_v1/classes.rb', line 2593

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2600
2601
2602
2603
2604
2605
2606
2607
# File 'lib/google/apis/compute_v1/classes.rb', line 2600

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end