Class: Google::Apis::ComputeV1::AutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Autoscaler resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::AutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerList
constructor
A new instance of AutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerList
Returns a new instance of AutoscalerList.
2552 2553 2554 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
2519 2520 2521 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2519 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
2524 2525 2526 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2524 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#autoscalerList
for lists of autoscalers.
Corresponds to the JSON property kind
2530 2531 2532 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2530 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2540 2541 2542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2540 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2545 2546 2547 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2545 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::AutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
2550 2551 2552 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2550 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2557 2558 2559 2560 2561 2562 2563 2564 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2557 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |