Class: Google::Apis::ComputeV1::AutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Autoscaler resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerList

Returns a new instance of AutoscalerList.



1896
1897
1898
# File 'lib/google/apis/compute_v1/classes.rb', line 1896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


1864
1865
1866
# File 'lib/google/apis/compute_v1/classes.rb', line 1864

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



1869
1870
1871
# File 'lib/google/apis/compute_v1/classes.rb', line 1869

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#autoscalerList for lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


1875
1876
1877
# File 'lib/google/apis/compute_v1/classes.rb', line 1875

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1884
1885
1886
# File 'lib/google/apis/compute_v1/classes.rb', line 1884

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1889
1890
1891
# File 'lib/google/apis/compute_v1/classes.rb', line 1889

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::AutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



1894
1895
1896
# File 'lib/google/apis/compute_v1/classes.rb', line 1894

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1901
1902
1903
1904
1905
1906
1907
1908
# File 'lib/google/apis/compute_v1/classes.rb', line 1901

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end