Class: Google::Apis::ComputeV1::AutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Autoscaler resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::AutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerList
constructor
A new instance of AutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerList
Returns a new instance of AutoscalerList.
1896 1897 1898 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
1864 1865 1866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1864 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
1869 1870 1871 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1869 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#autoscalerList for lists of
autoscalers.
Corresponds to the JSON property kind
1875 1876 1877 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1875 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
1884 1885 1886 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1884 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
1889 1890 1891 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1889 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::AutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
1894 1895 1896 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1894 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1901 1902 1903 1904 1905 1906 1907 1908 |
# File 'lib/google/apis/compute_v1/classes.rb', line 1901 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |