Class: Google::Apis::ComputeV1::AutoscalingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::AutoscalingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Cloud Autoscaler policy.
Instance Attribute Summary collapse
-
#cool_down_period_sec ⇒ Fixnum
The number of seconds that your application takes to initialize on a VM instance.
-
#cpu_utilization ⇒ Google::Apis::ComputeV1::AutoscalingPolicyCpuUtilization
CPU utilization policy.
-
#custom_metric_utilizations ⇒ Array<Google::Apis::ComputeV1::AutoscalingPolicyCustomMetricUtilization>
Configuration parameters of autoscaling based on a custom metric.
-
#load_balancing_utilization ⇒ Google::Apis::ComputeV1::AutoscalingPolicyLoadBalancingUtilization
Configuration parameters of autoscaling based on load balancing.
-
#max_num_replicas ⇒ Fixnum
The maximum number of instances that the autoscaler can scale out to.
-
#min_num_replicas ⇒ Fixnum
The minimum number of replicas that the autoscaler can scale in to.
-
#mode ⇒ String
Defines the operating mode for this policy.
-
#scale_in_control ⇒ Google::Apis::ComputeV1::AutoscalingPolicyScaleInControl
Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below.
-
#scaling_schedules ⇒ Hash<String,Google::Apis::ComputeV1::AutoscalingPolicyScalingSchedule>
Scaling schedules defined for an autoscaler.
-
#stabilization_period_sec ⇒ Fixnum
The number of seconds that autoscaler waits for load stabilization before making scale-in decisions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalingPolicy
constructor
A new instance of AutoscalingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalingPolicy
Returns a new instance of AutoscalingPolicy.
2943 2944 2945 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cool_down_period_sec ⇒ Fixnum
The number of seconds that your application takes to initialize on a VM
instance. This is referred to as the
initialization period.
Specifying an accurate initialization period improves
autoscaler decisions. For example, when scaling out, the autoscaler ignores
data from VMs that are still initializing because those VMs might not yet
represent normal usage of your application. The default initialization
period is 60 seconds.
Initialization periods might vary because of numerous
factors. We recommend that you test how long your application takes to
initialize. To do this, create a VM and time your application's startup
process.
Corresponds to the JSON property coolDownPeriodSec
2871 2872 2873 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2871 def cool_down_period_sec @cool_down_period_sec end |
#cpu_utilization ⇒ Google::Apis::ComputeV1::AutoscalingPolicyCpuUtilization
CPU utilization policy.
Corresponds to the JSON property cpuUtilization
2876 2877 2878 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2876 def cpu_utilization @cpu_utilization end |
#custom_metric_utilizations ⇒ Array<Google::Apis::ComputeV1::AutoscalingPolicyCustomMetricUtilization>
Configuration parameters of autoscaling based on a custom metric.
Corresponds to the JSON property customMetricUtilizations
2881 2882 2883 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2881 def custom_metric_utilizations @custom_metric_utilizations end |
#load_balancing_utilization ⇒ Google::Apis::ComputeV1::AutoscalingPolicyLoadBalancingUtilization
Configuration parameters of autoscaling based on load balancing.
Corresponds to the JSON property loadBalancingUtilization
2886 2887 2888 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2886 def load_balancing_utilization @load_balancing_utilization end |
#max_num_replicas ⇒ Fixnum
The maximum number of instances that the autoscaler can scale out to. This
is required when creating or updating an autoscaler. The maximum number
of replicas must not be lower than minimal number of replicas.
Corresponds to the JSON property maxNumReplicas
2893 2894 2895 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2893 def max_num_replicas @max_num_replicas end |
#min_num_replicas ⇒ Fixnum
The minimum number of replicas that the autoscaler can scale in to.
This cannot be less than 0. If not provided, autoscaler chooses a
default value depending on maximum number of instances allowed.
Corresponds to the JSON property minNumReplicas
2900 2901 2902 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2900 def min_num_replicas @min_num_replicas end |
#mode ⇒ String
Defines the operating mode for this policy. The following modes are available:
- OFF: Disables the autoscaler but maintains its configuration.
- ONLY_SCALE_OUT: Restricts the autoscaler to add VM instances only.
- ON: Enables all autoscaler activities according to its
policy.
For more information, see
"Turning off or restricting an autoscaler"
Corresponds to the JSON property
mode
2915 2916 2917 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2915 def mode @mode end |
#scale_in_control ⇒ Google::Apis::ComputeV1::AutoscalingPolicyScaleInControl
Configuration that allows for slower scale in so that even if Autoscaler
recommends an abrupt scale in of a MIG, it will be throttled as specified
by the parameters below.
Corresponds to the JSON property scaleInControl
2922 2923 2924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2922 def scale_in_control @scale_in_control end |
#scaling_schedules ⇒ Hash<String,Google::Apis::ComputeV1::AutoscalingPolicyScalingSchedule>
Scaling schedules defined for an autoscaler. Multiple schedules
can be set on an autoscaler, and they can overlap. During overlapping
periods the greatest min_required_replicas of all scaling schedules is
applied. Up to 128 scaling schedules are allowed.
Corresponds to the JSON property scalingSchedules
2930 2931 2932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2930 def scaling_schedules @scaling_schedules end |
#stabilization_period_sec ⇒ Fixnum
The number of seconds that autoscaler waits for load stabilization before
making scale-in decisions. This is referred to as the
stabilization period.
This might appear as a delay in scaling in but it is an important mechanism
for your application to not have fluctuating size due to short term load
fluctuations.
The default stabilization period is 600 seconds.
Corresponds to the JSON property stabilizationPeriodSec
2941 2942 2943 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2941 def stabilization_period_sec @stabilization_period_sec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 |
# File 'lib/google/apis/compute_v1/classes.rb', line 2948 def update!(**args) @cool_down_period_sec = args[:cool_down_period_sec] if args.key?(:cool_down_period_sec) @cpu_utilization = args[:cpu_utilization] if args.key?(:cpu_utilization) @custom_metric_utilizations = args[:custom_metric_utilizations] if args.key?(:custom_metric_utilizations) @load_balancing_utilization = args[:load_balancing_utilization] if args.key?(:load_balancing_utilization) @max_num_replicas = args[:max_num_replicas] if args.key?(:max_num_replicas) @min_num_replicas = args[:min_num_replicas] if args.key?(:min_num_replicas) @mode = args[:mode] if args.key?(:mode) @scale_in_control = args[:scale_in_control] if args.key?(:scale_in_control) @scaling_schedules = args[:scaling_schedules] if args.key?(:scaling_schedules) @stabilization_period_sec = args[:stabilization_period_sec] if args.key?(:stabilization_period_sec) end |