Class: Google::Apis::ComputeV1::AutoscalingPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Cloud Autoscaler policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalingPolicy

Returns a new instance of AutoscalingPolicy.



2908
2909
2910
# File 'lib/google/apis/compute_v1/classes.rb', line 2908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cool_down_period_secFixnum

The number of seconds that your application takes to initialize on a VM instance. This is referred to as the initialization period. Specifying an accurate initialization period improves autoscaler decisions. For example, when scaling out, the autoscaler ignores data from VMs that are still initializing because those VMs might not yet represent normal usage of your application. The default initialization period is 60 seconds. Initialization periods might vary because of numerous factors. We recommend that you test how long your application takes to initialize. To do this, create a VM and time your application's startup process. Corresponds to the JSON property coolDownPeriodSec

Returns:

  • (Fixnum)


2836
2837
2838
# File 'lib/google/apis/compute_v1/classes.rb', line 2836

def cool_down_period_sec
  @cool_down_period_sec
end

#cpu_utilizationGoogle::Apis::ComputeV1::AutoscalingPolicyCpuUtilization

CPU utilization policy. Corresponds to the JSON property cpuUtilization



2841
2842
2843
# File 'lib/google/apis/compute_v1/classes.rb', line 2841

def cpu_utilization
  @cpu_utilization
end

#custom_metric_utilizationsArray<Google::Apis::ComputeV1::AutoscalingPolicyCustomMetricUtilization>

Configuration parameters of autoscaling based on a custom metric. Corresponds to the JSON property customMetricUtilizations



2846
2847
2848
# File 'lib/google/apis/compute_v1/classes.rb', line 2846

def custom_metric_utilizations
  @custom_metric_utilizations
end

#load_balancing_utilizationGoogle::Apis::ComputeV1::AutoscalingPolicyLoadBalancingUtilization

Configuration parameters of autoscaling based on load balancing. Corresponds to the JSON property loadBalancingUtilization



2851
2852
2853
# File 'lib/google/apis/compute_v1/classes.rb', line 2851

def load_balancing_utilization
  @load_balancing_utilization
end

#max_num_replicasFixnum

The maximum number of instances that the autoscaler can scale out to. This is required when creating or updating an autoscaler. The maximum number of replicas must not be lower than minimal number of replicas. Corresponds to the JSON property maxNumReplicas

Returns:

  • (Fixnum)


2858
2859
2860
# File 'lib/google/apis/compute_v1/classes.rb', line 2858

def max_num_replicas
  @max_num_replicas
end

#min_num_replicasFixnum

The minimum number of replicas that the autoscaler can scale in to. This cannot be less than 0. If not provided, autoscaler chooses a default value depending on maximum number of instances allowed. Corresponds to the JSON property minNumReplicas

Returns:

  • (Fixnum)


2865
2866
2867
# File 'lib/google/apis/compute_v1/classes.rb', line 2865

def min_num_replicas
  @min_num_replicas
end

#modeString

Defines the operating mode for this policy. The following modes are available:

  • OFF: Disables the autoscaler but maintains its configuration.
  • ONLY_SCALE_OUT: Restricts the autoscaler to add VM instances only.
  • ON: Enables all autoscaler activities according to its policy. For more information, see "Turning off or restricting an autoscaler" Corresponds to the JSON property mode

Returns:

  • (String)


2880
2881
2882
# File 'lib/google/apis/compute_v1/classes.rb', line 2880

def mode
  @mode
end

#scale_in_controlGoogle::Apis::ComputeV1::AutoscalingPolicyScaleInControl

Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below. Corresponds to the JSON property scaleInControl



2887
2888
2889
# File 'lib/google/apis/compute_v1/classes.rb', line 2887

def scale_in_control
  @scale_in_control
end

#scaling_schedulesHash<String,Google::Apis::ComputeV1::AutoscalingPolicyScalingSchedule>

Scaling schedules defined for an autoscaler. Multiple schedules can be set on an autoscaler, and they can overlap. During overlapping periods the greatest min_required_replicas of all scaling schedules is applied. Up to 128 scaling schedules are allowed. Corresponds to the JSON property scalingSchedules



2895
2896
2897
# File 'lib/google/apis/compute_v1/classes.rb', line 2895

def scaling_schedules
  @scaling_schedules
end

#stabilization_period_secFixnum

The number of seconds that autoscaler waits for load stabilization before making scale-in decisions. This is referred to as the stabilization period. This might appear as a delay in scaling in but it is an important mechanism for your application to not have fluctuating size due to short term load fluctuations. The default stabilization period is 600 seconds. Corresponds to the JSON property stabilizationPeriodSec

Returns:

  • (Fixnum)


2906
2907
2908
# File 'lib/google/apis/compute_v1/classes.rb', line 2906

def stabilization_period_sec
  @stabilization_period_sec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
# File 'lib/google/apis/compute_v1/classes.rb', line 2913

def update!(**args)
  @cool_down_period_sec = args[:cool_down_period_sec] if args.key?(:cool_down_period_sec)
  @cpu_utilization = args[:cpu_utilization] if args.key?(:cpu_utilization)
  @custom_metric_utilizations = args[:custom_metric_utilizations] if args.key?(:custom_metric_utilizations)
  @load_balancing_utilization = args[:load_balancing_utilization] if args.key?(:load_balancing_utilization)
  @max_num_replicas = args[:max_num_replicas] if args.key?(:max_num_replicas)
  @min_num_replicas = args[:min_num_replicas] if args.key?(:min_num_replicas)
  @mode = args[:mode] if args.key?(:mode)
  @scale_in_control = args[:scale_in_control] if args.key?(:scale_in_control)
  @scaling_schedules = args[:scaling_schedules] if args.key?(:scaling_schedules)
  @stabilization_period_sec = args[:stabilization_period_sec] if args.key?(:stabilization_period_sec)
end