Class: Google::Apis::ComputeV1::Backend

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Message containing information of one individual backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Backend

Returns a new instance of Backend.



3352
3353
3354
# File 'lib/google/apis/compute_v1/classes.rb', line 3352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#balancing_modeString

Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. Corresponds to the JSON property balancingMode

Returns:

  • (String)


3193
3194
3195
# File 'lib/google/apis/compute_v1/classes.rb', line 3193

def balancing_mode
  @balancing_mode
end

#capacity_scalerFloat

A multiplier applied to the backend's target capacity of its balancing mode. The default value is 1, which means the group serves up to 100% of its configured capacity (depending onbalancingMode). A setting of 0 means the group is completely drained, offering 0% of its available capacity. The valid ranges are 0.0 and [0.1,1.0]. You cannot configure a setting larger than 0 and smaller than0.1. You cannot configure a setting of 0 when there is only one backend attached to the backend service. Not available with backends that don't support using abalancingMode. This includes backends such as global internet NEGs, regional serverless NEGs, and PSC NEGs. Corresponds to the JSON property capacityScaler

Returns:

  • (Float)


3210
3211
3212
# File 'lib/google/apis/compute_v1/classes.rb', line 3210

def capacity_scaler
  @capacity_scaler
end

#custom_metricsArray<Google::Apis::ComputeV1::BackendCustomMetric>

List of custom metrics that are used for CUSTOM_METRICS BalancingMode. Corresponds to the JSON property customMetrics



3216
3217
3218
# File 'lib/google/apis/compute_v1/classes.rb', line 3216

def custom_metrics
  @custom_metrics
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


3222
3223
3224
# File 'lib/google/apis/compute_v1/classes.rb', line 3222

def description
  @description
end

#failoverBoolean Also known as: failover?

This field designates whether this is a failover backend. More than one failover backend can be configured for a given BackendService. Corresponds to the JSON property failover

Returns:

  • (Boolean)


3228
3229
3230
# File 'lib/google/apis/compute_v1/classes.rb', line 3228

def failover
  @failover
end

#groupString

The fully-qualified URL of aninstance group or network endpoint group (NEG) resource. To determine what types of backends a load balancer supports, see the Backend services overview. You must use the fully-qualified URL (starting withhttps://www.googleapis. com/) to specify the instance group or NEG. Partial URLs are not supported. If haPolicy is specified, backends must refer to NEG resources of type GCE_VM_IP. Corresponds to the JSON property group

Returns:

  • (String)


3244
3245
3246
# File 'lib/google/apis/compute_v1/classes.rb', line 3244

def group
  @group
end

#max_connectionsFixnum

Defines a target maximum number of simultaneous connections. For usage guidelines, seeConnection balancing mode and Utilization balancing mode. Not available if the backend'sbalancingMode is RATE. Corresponds to the JSON property maxConnections

Returns:

  • (Fixnum)


3252
3253
3254
# File 'lib/google/apis/compute_v1/classes.rb', line 3252

def max_connections
  @max_connections
end

#max_connections_per_endpointFixnum

Defines a target maximum number of simultaneous connections. For usage guidelines, seeConnection balancing mode and Utilization balancing mode. Not available if the backend's balancingMode isRATE. Corresponds to the JSON property maxConnectionsPerEndpoint

Returns:

  • (Fixnum)


3261
3262
3263
# File 'lib/google/apis/compute_v1/classes.rb', line 3261

def max_connections_per_endpoint
  @max_connections_per_endpoint
end

#max_connections_per_instanceFixnum

Defines a target maximum number of simultaneous connections. For usage guidelines, seeConnection balancing mode and Utilization balancing mode. Not available if the backend's balancingMode isRATE. Corresponds to the JSON property maxConnectionsPerInstance

Returns:

  • (Fixnum)


3270
3271
3272
# File 'lib/google/apis/compute_v1/classes.rb', line 3270

def max_connections_per_instance
  @max_connections_per_instance
end

#max_in_flight_requestsFixnum

Defines a maximum number of in-flight requests for the whole NEG or instance group. Not available if backend's balancingMode isRATE or CONNECTION. Corresponds to the JSON property maxInFlightRequests

Returns:

  • (Fixnum)


3276
3277
3278
# File 'lib/google/apis/compute_v1/classes.rb', line 3276

def max_in_flight_requests
  @max_in_flight_requests
end

#max_in_flight_requests_per_endpointFixnum

Defines a maximum number of in-flight requests for a single endpoint. Not available if backend's balancingMode is RATE or CONNECTION. Corresponds to the JSON property maxInFlightRequestsPerEndpoint

Returns:

  • (Fixnum)


3283
3284
3285
# File 'lib/google/apis/compute_v1/classes.rb', line 3283

def max_in_flight_requests_per_endpoint
  @max_in_flight_requests_per_endpoint
end

#max_in_flight_requests_per_instanceFixnum

Defines a maximum number of in-flight requests for a single VM. Not available if backend's balancingMode is RATE or CONNECTION. Corresponds to the JSON property maxInFlightRequestsPerInstance

Returns:

  • (Fixnum)


3290
3291
3292
# File 'lib/google/apis/compute_v1/classes.rb', line 3290

def max_in_flight_requests_per_instance
  @max_in_flight_requests_per_instance
end

#max_rateFixnum

Defines a maximum number of HTTP requests per second (RPS). For usage guidelines, seeRate balancing mode and Utilization balancing mode. Not available if the backend's balancingMode isCONNECTION. Corresponds to the JSON property maxRate

Returns:

  • (Fixnum)


3299
3300
3301
# File 'lib/google/apis/compute_v1/classes.rb', line 3299

def max_rate
  @max_rate
end

#max_rate_per_endpointFloat

Defines a maximum target for requests per second (RPS). For usage guidelines, seeRate balancing mode and Utilization balancing mode. Not available if the backend's balancingMode isCONNECTION. Corresponds to the JSON property maxRatePerEndpoint

Returns:

  • (Float)


3308
3309
3310
# File 'lib/google/apis/compute_v1/classes.rb', line 3308

def max_rate_per_endpoint
  @max_rate_per_endpoint
end

#max_rate_per_instanceFloat

Defines a maximum target for requests per second (RPS). For usage guidelines, seeRate balancing mode and Utilization balancing mode. Not available if the backend's balancingMode isCONNECTION. Corresponds to the JSON property maxRatePerInstance

Returns:

  • (Float)


3317
3318
3319
# File 'lib/google/apis/compute_v1/classes.rb', line 3317

def max_rate_per_instance
  @max_rate_per_instance
end

#max_utilizationFloat

Optional parameter to define a target capacity for theUTILIZATION balancing mode. The valid range is[0.0, 1.0]. For usage guidelines, seeUtilization balancing mode. Corresponds to the JSON property maxUtilization

Returns:

  • (Float)


3325
3326
3327
# File 'lib/google/apis/compute_v1/classes.rb', line 3325

def max_utilization
  @max_utilization
end

#orchestration_infoGoogle::Apis::ComputeV1::BackendBackendOrchestrationInfo

A message containing information about the resource or system that manages the backend. Corresponds to the JSON property orchestrationInfo



3331
3332
3333
# File 'lib/google/apis/compute_v1/classes.rb', line 3331

def orchestration_info
  @orchestration_info
end

#preferenceString

This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are:

  • PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT.
  • DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default Corresponds to the JSON property preference

Returns:

  • (String)


3345
3346
3347
# File 'lib/google/apis/compute_v1/classes.rb', line 3345

def preference
  @preference
end

#traffic_durationString

Corresponds to the JSON property trafficDuration

Returns:

  • (String)


3350
3351
3352
# File 'lib/google/apis/compute_v1/classes.rb', line 3350

def traffic_duration
  @traffic_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
3374
3375
3376
3377
# File 'lib/google/apis/compute_v1/classes.rb', line 3357

def update!(**args)
  @balancing_mode = args[:balancing_mode] if args.key?(:balancing_mode)
  @capacity_scaler = args[:capacity_scaler] if args.key?(:capacity_scaler)
  @custom_metrics = args[:custom_metrics] if args.key?(:custom_metrics)
  @description = args[:description] if args.key?(:description)
  @failover = args[:failover] if args.key?(:failover)
  @group = args[:group] if args.key?(:group)
  @max_connections = args[:max_connections] if args.key?(:max_connections)
  @max_connections_per_endpoint = args[:max_connections_per_endpoint] if args.key?(:max_connections_per_endpoint)
  @max_connections_per_instance = args[:max_connections_per_instance] if args.key?(:max_connections_per_instance)
  @max_in_flight_requests = args[:max_in_flight_requests] if args.key?(:max_in_flight_requests)
  @max_in_flight_requests_per_endpoint = args[:max_in_flight_requests_per_endpoint] if args.key?(:max_in_flight_requests_per_endpoint)
  @max_in_flight_requests_per_instance = args[:max_in_flight_requests_per_instance] if args.key?(:max_in_flight_requests_per_instance)
  @max_rate = args[:max_rate] if args.key?(:max_rate)
  @max_rate_per_endpoint = args[:max_rate_per_endpoint] if args.key?(:max_rate_per_endpoint)
  @max_rate_per_instance = args[:max_rate_per_instance] if args.key?(:max_rate_per_instance)
  @max_utilization = args[:max_utilization] if args.key?(:max_utilization)
  @orchestration_info = args[:orchestration_info] if args.key?(:orchestration_info)
  @preference = args[:preference] if args.key?(:preference)
  @traffic_duration = args[:traffic_duration] if args.key?(:traffic_duration)
end