Class: Google::Apis::ComputeV1::BackendBucket
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendBucket
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Cloud Storage Bucket resource. This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, readBackend Buckets.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
Cloud Storage bucket name.
-
#cdn_policy ⇒ Google::Apis::ComputeV1::BackendBucketCdnPolicy
Message containing Cloud CDN configuration for a backend bucket.
-
#compression_mode ⇒ String
Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#custom_response_headers ⇒ Array<String>
Headers that the Application Load Balancer should add to proxied responses.
-
#description ⇒ String
An optional textual description of the resource; provided by the client when the resource is created.
-
#edge_security_policy ⇒ String
[Output Only] The resource URL for the edge security policy associated with this backend bucket.
-
#enable_cdn ⇒ Boolean
(also: #enable_cdn?)
If true, enable Cloud CDN for this BackendBucket.
-
#id ⇒ Fixnum
[Output Only] Unique identifier for the resource; defined by the server.
-
#kind ⇒ String
Output only.
-
#load_balancing_scheme ⇒ String
The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer.
-
#name ⇒ String
Name of the resource.
-
#params ⇒ Google::Apis::ComputeV1::BackendBucketParams
Additional Backend Bucket parameters.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#used_by ⇒ Array<Google::Apis::ComputeV1::BackendBucketUsedBy>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucket
constructor
A new instance of BackendBucket.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucket
Returns a new instance of BackendBucket.
3495 3496 3497 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_name ⇒ String
Cloud Storage bucket name.
Corresponds to the JSON property bucketName
3400 3401 3402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3400 def bucket_name @bucket_name end |
#cdn_policy ⇒ Google::Apis::ComputeV1::BackendBucketCdnPolicy
Message containing Cloud CDN configuration for a backend bucket.
Corresponds to the JSON property cdnPolicy
3405 3406 3407 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3405 def cdn_policy @cdn_policy end |
#compression_mode ⇒ String
Compress text responses using Brotli or gzip compression, based on
the client's Accept-Encoding header.
Corresponds to the JSON property compressionMode
3411 3412 3413 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3411 def compression_mode @compression_mode end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
3417 3418 3419 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3417 def @creation_timestamp end |
#custom_response_headers ⇒ Array<String>
Headers that the Application Load Balancer should add to proxied responses.
Corresponds to the JSON property customResponseHeaders
3422 3423 3424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3422 def custom_response_headers @custom_response_headers end |
#description ⇒ String
An optional textual description of the resource; provided by the client
when the resource is created.
Corresponds to the JSON property description
3428 3429 3430 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3428 def description @description end |
#edge_security_policy ⇒ String
[Output Only] The resource URL for the edge security policy associated with
this backend bucket.
Corresponds to the JSON property edgeSecurityPolicy
3434 3435 3436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3434 def edge_security_policy @edge_security_policy end |
#enable_cdn ⇒ Boolean Also known as: enable_cdn?
If true, enable Cloud CDN for this BackendBucket.
Corresponds to the JSON property enableCdn
3439 3440 3441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3439 def enable_cdn @enable_cdn end |
#id ⇒ Fixnum
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
3445 3446 3447 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3445 def id @id end |
#kind ⇒ String
Output only. Type of the resource.
Corresponds to the JSON property kind
3450 3451 3452 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3450 def kind @kind end |
#load_balancing_scheme ⇒ String
The value can only be INTERNAL_MANAGED for cross-region internal layer 7
load balancer.
If loadBalancingScheme is not specified, the backend bucket can be used by
classic global external load balancers, or global application external load
balancers, or both.
Corresponds to the JSON property loadBalancingScheme
3459 3460 3461 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3459 def load_balancing_scheme @load_balancing_scheme end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
3470 3471 3472 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3470 def name @name end |
#params ⇒ Google::Apis::ComputeV1::BackendBucketParams
Additional Backend Bucket parameters.
Corresponds to the JSON property params
3475 3476 3477 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3475 def params @params end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional backend bucket
resides. This field is not applicable to global backend buckets.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
3483 3484 3485 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3483 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
3488 3489 3490 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3488 def self_link @self_link end |
#used_by ⇒ Array<Google::Apis::ComputeV1::BackendBucketUsedBy>
Output only. [Output Only] List of resources referencing that backend bucket.
Corresponds to the JSON property usedBy
3493 3494 3495 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3493 def used_by @used_by end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3500 def update!(**args) @bucket_name = args[:bucket_name] if args.key?(:bucket_name) @cdn_policy = args[:cdn_policy] if args.key?(:cdn_policy) @compression_mode = args[:compression_mode] if args.key?(:compression_mode) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @custom_response_headers = args[:custom_response_headers] if args.key?(:custom_response_headers) @description = args[:description] if args.key?(:description) @edge_security_policy = args[:edge_security_policy] if args.key?(:edge_security_policy) @enable_cdn = args[:enable_cdn] if args.key?(:enable_cdn) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @used_by = args[:used_by] if args.key?(:used_by) end |