Class: Google::Apis::ComputeV1::BackendBucketCdnPolicyNegativeCachingPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specify CDN TTLs for response error codes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketCdnPolicyNegativeCachingPolicy

Returns a new instance of BackendBucketCdnPolicyNegativeCachingPolicy.



3732
3733
3734
# File 'lib/google/apis/compute_v1/classes.rb', line 3732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeFixnum

The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 can be specified as values, and you cannot specify a status code more than once. Corresponds to the JSON property code

Returns:

  • (Fixnum)


3721
3722
3723
# File 'lib/google/apis/compute_v1/classes.rb', line 3721

def code
  @code
end

#ttlFixnum

The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes), noting that infrequently accessed objects may be evicted from the cache before the defined TTL. Corresponds to the JSON property ttl

Returns:

  • (Fixnum)


3730
3731
3732
# File 'lib/google/apis/compute_v1/classes.rb', line 3730

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3737
3738
3739
3740
# File 'lib/google/apis/compute_v1/classes.rb', line 3737

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @ttl = args[:ttl] if args.key?(:ttl)
end