Class: Google::Apis::ComputeV1::BackendBucketList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of BackendBucket resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketList

Returns a new instance of BackendBucketList.



3939
3940
3941
# File 'lib/google/apis/compute_v1/classes.rb', line 3939

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


3907
3908
3909
# File 'lib/google/apis/compute_v1/classes.rb', line 3907

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



3912
3913
3914
# File 'lib/google/apis/compute_v1/classes.rb', line 3912

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


3917
3918
3919
# File 'lib/google/apis/compute_v1/classes.rb', line 3917

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3927
3928
3929
# File 'lib/google/apis/compute_v1/classes.rb', line 3927

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3932
3933
3934
# File 'lib/google/apis/compute_v1/classes.rb', line 3932

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendBucketList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



3937
3938
3939
# File 'lib/google/apis/compute_v1/classes.rb', line 3937

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3944
3945
3946
3947
3948
3949
3950
3951
# File 'lib/google/apis/compute_v1/classes.rb', line 3944

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end