Class: Google::Apis::ComputeV1::BackendBucketList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendBucketList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of BackendBucket resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::BackendBucketList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketList
constructor
A new instance of BackendBucketList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketList
Returns a new instance of BackendBucketList.
3939 3940 3941 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3939 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
3907 3908 3909 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3907 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
3912 3913 3914 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3912 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
3917 3918 3919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3917 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
3927 3928 3929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3927 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
3932 3933 3934 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3932 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::BackendBucketList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
3937 3938 3939 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3937 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3944 3945 3946 3947 3948 3949 3950 3951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3944 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |