Class: Google::Apis::ComputeV1::BackendBucketList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendBucketList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of BackendBucket resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::BackendBucketList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketList
constructor
A new instance of BackendBucketList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketList
Returns a new instance of BackendBucketList.
3956 3957 3958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
3924 3925 3926 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3924 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
3929 3930 3931 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3929 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
3934 3935 3936 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3934 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
3944 3945 3946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3944 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
3949 3950 3951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3949 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::BackendBucketList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
3954 3955 3956 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3954 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3961 3962 3963 3964 3965 3966 3967 3968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 3961 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |