Class: Google::Apis::ComputeV1::BackendBucketList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of BackendBucket resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketList

Returns a new instance of BackendBucketList.



3755
3756
3757
# File 'lib/google/apis/compute_v1/classes.rb', line 3755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


3723
3724
3725
# File 'lib/google/apis/compute_v1/classes.rb', line 3723

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



3728
3729
3730
# File 'lib/google/apis/compute_v1/classes.rb', line 3728

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


3733
3734
3735
# File 'lib/google/apis/compute_v1/classes.rb', line 3733

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3743
3744
3745
# File 'lib/google/apis/compute_v1/classes.rb', line 3743

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3748
3749
3750
# File 'lib/google/apis/compute_v1/classes.rb', line 3748

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendBucketList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



3753
3754
3755
# File 'lib/google/apis/compute_v1/classes.rb', line 3753

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/google/apis/compute_v1/classes.rb', line 3760

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end