Class: Google::Apis::ComputeV1::BackendBucketList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of BackendBucket resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketList

Returns a new instance of BackendBucketList.



2917
2918
2919
# File 'lib/google/apis/compute_v1/classes.rb', line 2917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2886
2887
2888
# File 'lib/google/apis/compute_v1/classes.rb', line 2886

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



2891
2892
2893
# File 'lib/google/apis/compute_v1/classes.rb', line 2891

def items
  @items
end

#kindString

Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


2896
2897
2898
# File 'lib/google/apis/compute_v1/classes.rb', line 2896

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2905
2906
2907
# File 'lib/google/apis/compute_v1/classes.rb', line 2905

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2910
2911
2912
# File 'lib/google/apis/compute_v1/classes.rb', line 2910

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendBucketList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



2915
2916
2917
# File 'lib/google/apis/compute_v1/classes.rb', line 2915

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2922
2923
2924
2925
2926
2927
2928
2929
# File 'lib/google/apis/compute_v1/classes.rb', line 2922

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end