Class: Google::Apis::ComputeV1::BackendBucketListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketListUsable

Returns a new instance of BackendBucketListUsable.



4117
4118
4119
# File 'lib/google/apis/compute_v1/classes.rb', line 4117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4083
4084
4085
# File 'lib/google/apis/compute_v1/classes.rb', line 4083

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4088
4089
4090
# File 'lib/google/apis/compute_v1/classes.rb', line 4088

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendBucketList for lists of usable backend buckets. Corresponds to the JSON property kind

Returns:

  • (String)


4095
4096
4097
# File 'lib/google/apis/compute_v1/classes.rb', line 4095

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4105
4106
4107
# File 'lib/google/apis/compute_v1/classes.rb', line 4105

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4110
4111
4112
# File 'lib/google/apis/compute_v1/classes.rb', line 4110

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendBucketListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4115
4116
4117
# File 'lib/google/apis/compute_v1/classes.rb', line 4115

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4122
4123
4124
4125
4126
4127
4128
4129
# File 'lib/google/apis/compute_v1/classes.rb', line 4122

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end