Class: Google::Apis::ComputeV1::BackendBucketListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketListUsable

Returns a new instance of BackendBucketListUsable.



4074
4075
4076
# File 'lib/google/apis/compute_v1/classes.rb', line 4074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4040
4041
4042
# File 'lib/google/apis/compute_v1/classes.rb', line 4040

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4045
4046
4047
# File 'lib/google/apis/compute_v1/classes.rb', line 4045

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendBucketList for lists of usable backend buckets. Corresponds to the JSON property kind

Returns:

  • (String)


4052
4053
4054
# File 'lib/google/apis/compute_v1/classes.rb', line 4052

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4062
4063
4064
# File 'lib/google/apis/compute_v1/classes.rb', line 4062

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4067
4068
4069
# File 'lib/google/apis/compute_v1/classes.rb', line 4067

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendBucketListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4072
4073
4074
# File 'lib/google/apis/compute_v1/classes.rb', line 4072

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4079
4080
4081
4082
4083
4084
4085
4086
# File 'lib/google/apis/compute_v1/classes.rb', line 4079

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end