Class: Google::Apis::ComputeV1::BackendBucketListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendBucketListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketListUsable
constructor
A new instance of BackendBucketListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketListUsable
Returns a new instance of BackendBucketListUsable.
4070 4071 4072 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
4036 4037 4038 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4036 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
4041 4042 4043 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4041 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendBucketList for lists of usable backend
buckets.
Corresponds to the JSON property kind
4048 4049 4050 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4048 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4058 4059 4060 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4058 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4063 4064 4065 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4063 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
4068 4069 4070 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4068 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4075 4076 4077 4078 4079 4080 4081 4082 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4075 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |