Class: Google::Apis::ComputeV1::BackendService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Backend Service resource. A backend service defines how Google Cloud load balancers distribute traffic. The backend service configuration contains a set of values, such as the protocol used to connect to backends, various distribution and session settings, health checks, and timeouts. These settings provide fine-grained control over how your load balancer behaves. Most of the settings have default values that allow for easy configuration if you need to get started quickly. Backend services in Google Compute Engine can be either regionally or globally scoped. * Global * Regional For more information, see Backend Services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendService

Returns a new instance of BackendService.



3289
3290
3291
# File 'lib/google/apis/compute_v1/classes.rb', line 3289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Lifetime of cookies in seconds. This setting is applicable to external and internal HTTP(S) load balancers and Traffic Director and requires GENERATED_COOKIE or HTTP_COOKIE session affinity. If set to 0, the cookie is non-persistent and lasts only until the end of the browser session (or equivalent). The maximum allowed value is one day (86,400). Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property affinityCookieTtlSec

Returns:

  • (Fixnum)


3019
3020
3021
# File 'lib/google/apis/compute_v1/classes.rb', line 3019

def affinity_cookie_ttl_sec
  @affinity_cookie_ttl_sec
end

#backendsArray<Google::Apis::ComputeV1::Backend>

The list of backends that serve this BackendService. Corresponds to the JSON property backends



3024
3025
3026
# File 'lib/google/apis/compute_v1/classes.rb', line 3024

def backends
  @backends
end

#cdn_policyGoogle::Apis::ComputeV1::BackendServiceCdnPolicy

Message containing Cloud CDN configuration for a backend service. Corresponds to the JSON property cdnPolicy



3029
3030
3031
# File 'lib/google/apis/compute_v1/classes.rb', line 3029

def cdn_policy
  @cdn_policy
end

#circuit_breakersGoogle::Apis::ComputeV1::CircuitBreakers

Settings controlling the volume of requests, connections and retries to this backend service. Corresponds to the JSON property circuitBreakers



3035
3036
3037
# File 'lib/google/apis/compute_v1/classes.rb', line 3035

def circuit_breakers
  @circuit_breakers
end

#connection_drainingGoogle::Apis::ComputeV1::ConnectionDraining

Message containing connection draining configuration. Corresponds to the JSON property connectionDraining



3040
3041
3042
# File 'lib/google/apis/compute_v1/classes.rb', line 3040

def connection_draining
  @connection_draining
end

#connection_tracking_policyGoogle::Apis::ComputeV1::BackendServiceConnectionTrackingPolicy

Connection Tracking configuration for this BackendService. Corresponds to the JSON property connectionTrackingPolicy



3045
3046
3047
# File 'lib/google/apis/compute_v1/classes.rb', line 3045

def connection_tracking_policy
  @connection_tracking_policy
end

#consistent_hashGoogle::Apis::ComputeV1::ConsistentHashLoadBalancerSettings

This message defines settings for a consistent hash style load balancer. Corresponds to the JSON property consistentHash



3050
3051
3052
# File 'lib/google/apis/compute_v1/classes.rb', line 3050

def consistent_hash
  @consistent_hash
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


3055
3056
3057
# File 'lib/google/apis/compute_v1/classes.rb', line 3055

def creation_timestamp
  @creation_timestamp
end

#custom_request_headersArray<String>

Headers that the load balancer adds to proxied requests. See Creating custom headers. Corresponds to the JSON property customRequestHeaders

Returns:

  • (Array<String>)


3061
3062
3063
# File 'lib/google/apis/compute_v1/classes.rb', line 3061

def custom_request_headers
  @custom_request_headers
end

#custom_response_headersArray<String>

Headers that the load balancer adds to proxied responses. See Creating custom headers. Corresponds to the JSON property customResponseHeaders

Returns:

  • (Array<String>)


3067
3068
3069
# File 'lib/google/apis/compute_v1/classes.rb', line 3067

def custom_response_headers
  @custom_response_headers
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


3073
3074
3075
# File 'lib/google/apis/compute_v1/classes.rb', line 3073

def description
  @description
end

#edge_security_policyString

[Output Only] The resource URL for the edge security policy associated with this backend service. Corresponds to the JSON property edgeSecurityPolicy

Returns:

  • (String)


3079
3080
3081
# File 'lib/google/apis/compute_v1/classes.rb', line 3079

def edge_security_policy
  @edge_security_policy
end

#enable_cdnBoolean Also known as: enable_cdn?

If true, enables Cloud CDN for the backend service of an external HTTP(S) load balancer. Corresponds to the JSON property enableCDN

Returns:

  • (Boolean)


3085
3086
3087
# File 'lib/google/apis/compute_v1/classes.rb', line 3085

def enable_cdn
  @enable_cdn
end

#failover_policyGoogle::Apis::ComputeV1::BackendServiceFailoverPolicy

For load balancers that have configurable failover: Internal TCP/UDP Load Balancing and external TCP/UDP Load Balancing. On failover or failback, this field indicates whether connection draining will be honored. Google Cloud has a fixed connection draining timeout of 10 minutes. A setting of true terminates existing TCP connections to the active pool during failover and failback, immediately draining traffic. A setting of false allows existing TCP connections to persist, even on VMs no longer in the active pool, for up to the duration of the connection draining timeout (10 minutes). Corresponds to the JSON property failoverPolicy



3100
3101
3102
# File 'lib/google/apis/compute_v1/classes.rb', line 3100

def failover_policy
  @failover_policy
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a BackendService. An up-to-date fingerprint must be provided in order to update the BackendService, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a BackendService. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3111
3112
3113
# File 'lib/google/apis/compute_v1/classes.rb', line 3111

def fingerprint
  @fingerprint
end

#health_checksArray<String>

The list of URLs to the healthChecks, httpHealthChecks (legacy), or httpsHealthChecks (legacy) resource for health checking this backend service. Not all backend services support legacy health checks. See Load balancer guide. Currently, at most one health check can be specified for each backend service. Backend services with instance group or zonal NEG backends must have a health check. Backend services with internet or serverless NEG backends must not have a health check. Corresponds to the JSON property healthChecks

Returns:

  • (Array<String>)


3122
3123
3124
# File 'lib/google/apis/compute_v1/classes.rb', line 3122

def health_checks
  @health_checks
end

#iapGoogle::Apis::ComputeV1::BackendServiceIap

Identity-Aware Proxy Corresponds to the JSON property iap



3127
3128
3129
# File 'lib/google/apis/compute_v1/classes.rb', line 3127

def iap
  @iap
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


3133
3134
3135
# File 'lib/google/apis/compute_v1/classes.rb', line 3133

def id
  @id
end

#kindString

[Output Only] Type of resource. Always compute#backendService for backend services. Corresponds to the JSON property kind

Returns:

  • (String)


3139
3140
3141
# File 'lib/google/apis/compute_v1/classes.rb', line 3139

def kind
  @kind
end

#load_balancing_schemeString

Specifies the load balancer type. A backend service created for one type of load balancer cannot be used with another. For more information, refer to Choosing a load balancer. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


3146
3147
3148
# File 'lib/google/apis/compute_v1/classes.rb', line 3146

def load_balancing_scheme
  @load_balancing_scheme
end

#locality_lb_policyString

The load balancing algorithm used within the scope of the locality. The possible values are: - ROUND_ROBIN: This is a simple policy in which each healthy backend is selected in round robin order. This is the default. - LEAST_REQUEST: An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests. - RING_HASH: The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests. - RANDOM: The load balancer selects a random healthy host. - ORIGINAL_DESTINATION: Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer. - MAGLEV: used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, see https://ai.google/research/pubs/pub44824 This field is applicable to either: - A regional backend service with the service_protocol set to HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to INTERNAL_MANAGED. - A global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED. If sessionAffinity is not NONE, and this field is not set to MAGLEV or RING_HASH, session affinity settings will not take effect. Only ROUND_ROBIN and RING_HASH are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property localityLbPolicy

Returns:

  • (String)


3173
3174
3175
# File 'lib/google/apis/compute_v1/classes.rb', line 3173

def locality_lb_policy
  @locality_lb_policy
end

#log_configGoogle::Apis::ComputeV1::BackendServiceLogConfig

The available logging options for the load balancer traffic served by this backend service. Corresponds to the JSON property logConfig



3179
3180
3181
# File 'lib/google/apis/compute_v1/classes.rb', line 3179

def log_config
  @log_config
end

#max_stream_durationGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10, 000 years. Corresponds to the JSON property maxStreamDuration



3187
3188
3189
# File 'lib/google/apis/compute_v1/classes.rb', line 3187

def max_stream_duration
  @max_stream_duration
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


3197
3198
3199
# File 'lib/google/apis/compute_v1/classes.rb', line 3197

def name
  @name
end

#networkString

The URL of the network to which this backend service belongs. This field can only be specified when the load balancing scheme is set to INTERNAL. Corresponds to the JSON property network

Returns:

  • (String)


3203
3204
3205
# File 'lib/google/apis/compute_v1/classes.rb', line 3203

def network
  @network
end

#outlier_detectionGoogle::Apis::ComputeV1::OutlierDetection

Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service. Corresponds to the JSON property outlierDetection



3209
3210
3211
# File 'lib/google/apis/compute_v1/classes.rb', line 3209

def outlier_detection
  @outlier_detection
end

#portFixnum

Deprecated in favor of portName. The TCP port to connect on the backend. The default value is 80. For Internal TCP/UDP Load Balancing and Network Load Balancing, omit port. Corresponds to the JSON property port

Returns:

  • (Fixnum)


3216
3217
3218
# File 'lib/google/apis/compute_v1/classes.rb', line 3216

def port
  @port
end

#port_nameString

A named port on a backend instance group representing the port for communication to the backend VMs in that group. The named port must be defined on each backend instance group. This parameter has no meaning if the backends are NEGs. For Internal TCP/UDP Load Balancing and Network Load Balancing, omit port_name. Corresponds to the JSON property portName

Returns:

  • (String)


3226
3227
3228
# File 'lib/google/apis/compute_v1/classes.rb', line 3226

def port_name
  @port_name
end

#protocolString

The protocol this BackendService uses to communicate with backends. Possible values are HTTP, HTTPS, HTTP2, TCP, SSL, UDP or GRPC. depending on the chosen load balancer or Traffic Director configuration. Refer to the documentation for the load balancers or for Traffic Director for more information. Must be set to GRPC when the backend service is referenced by a URL map that is bound to target gRPC proxy. Corresponds to the JSON property protocol

Returns:

  • (String)


3236
3237
3238
# File 'lib/google/apis/compute_v1/classes.rb', line 3236

def protocol
  @protocol
end

#regionString

[Output Only] URL of the region where the regional backend service resides. This field is not applicable to global backend services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


3244
3245
3246
# File 'lib/google/apis/compute_v1/classes.rb', line 3244

def region
  @region
end

#security_policyString

[Output Only] The resource URL for the security policy associated with this backend service. Corresponds to the JSON property securityPolicy

Returns:

  • (String)


3250
3251
3252
# File 'lib/google/apis/compute_v1/classes.rb', line 3250

def security_policy
  @security_policy
end

#security_settingsGoogle::Apis::ComputeV1::SecuritySettings

The authentication and authorization settings for a BackendService. Corresponds to the JSON property securitySettings



3255
3256
3257
# File 'lib/google/apis/compute_v1/classes.rb', line 3255

def security_settings
  @security_settings
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3260
3261
3262
# File 'lib/google/apis/compute_v1/classes.rb', line 3260

def self_link
  @self_link
end

#session_affinityString

Type of session affinity to use. The default is NONE. Only NONE and HEADER_FIELD are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. For more details, see: Session Affinity. Corresponds to the JSON property sessionAffinity

Returns:

  • (String)


3269
3270
3271
# File 'lib/google/apis/compute_v1/classes.rb', line 3269

def session_affinity
  @session_affinity
end

#subsettingGoogle::Apis::ComputeV1::Subsetting

Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director. Corresponds to the JSON property subsetting



3276
3277
3278
# File 'lib/google/apis/compute_v1/classes.rb', line 3276

def subsetting
  @subsetting
end

#timeout_secFixnum

The backend service timeout has a different meaning depending on the type of load balancer. For more information see, Backend service settings The default is 30 seconds. The full range of timeout values allowed is 1 - 2,147,483,647 seconds. This value can be overridden in the PathMatcher configuration of the UrlMap that references this backend service. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Instead, use maxStreamDuration. Corresponds to the JSON property timeoutSec

Returns:

  • (Fixnum)


3287
3288
3289
# File 'lib/google/apis/compute_v1/classes.rb', line 3287

def timeout_sec
  @timeout_sec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
# File 'lib/google/apis/compute_v1/classes.rb', line 3294

def update!(**args)
  @affinity_cookie_ttl_sec = args[:affinity_cookie_ttl_sec] if args.key?(:affinity_cookie_ttl_sec)
  @backends = args[:backends] if args.key?(:backends)
  @cdn_policy = args[:cdn_policy] if args.key?(:cdn_policy)
  @circuit_breakers = args[:circuit_breakers] if args.key?(:circuit_breakers)
  @connection_draining = args[:connection_draining] if args.key?(:connection_draining)
  @connection_tracking_policy = args[:connection_tracking_policy] if args.key?(:connection_tracking_policy)
  @consistent_hash = args[:consistent_hash] if args.key?(:consistent_hash)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @custom_request_headers = args[:custom_request_headers] if args.key?(:custom_request_headers)
  @custom_response_headers = args[:custom_response_headers] if args.key?(:custom_response_headers)
  @description = args[:description] if args.key?(:description)
  @edge_security_policy = args[:edge_security_policy] if args.key?(:edge_security_policy)
  @enable_cdn = args[:enable_cdn] if args.key?(:enable_cdn)
  @failover_policy = args[:failover_policy] if args.key?(:failover_policy)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @health_checks = args[:health_checks] if args.key?(:health_checks)
  @iap = args[:iap] if args.key?(:iap)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @locality_lb_policy = args[:locality_lb_policy] if args.key?(:locality_lb_policy)
  @log_config = args[:log_config] if args.key?(:log_config)
  @max_stream_duration = args[:max_stream_duration] if args.key?(:max_stream_duration)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @outlier_detection = args[:outlier_detection] if args.key?(:outlier_detection)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @protocol = args[:protocol] if args.key?(:protocol)
  @region = args[:region] if args.key?(:region)
  @security_policy = args[:security_policy] if args.key?(:security_policy)
  @security_settings = args[:security_settings] if args.key?(:security_settings)
  @self_link = args[:self_link] if args.key?(:self_link)
  @session_affinity = args[:session_affinity] if args.key?(:session_affinity)
  @subsetting = args[:subsetting] if args.key?(:subsetting)
  @timeout_sec = args[:timeout_sec] if args.key?(:timeout_sec)
end