Class: Google::Apis::ComputeV1::BackendServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of BackendServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceAggregatedList

Returns a new instance of BackendServiceAggregatedList.



4978
4979
4980
# File 'lib/google/apis/compute_v1/classes.rb', line 4978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4941
4942
4943
# File 'lib/google/apis/compute_v1/classes.rb', line 4941

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::BackendServicesScopedList>

A list of BackendServicesScopedList resources. Corresponds to the JSON property items



4946
4947
4948
# File 'lib/google/apis/compute_v1/classes.rb', line 4946

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


4951
4952
4953
# File 'lib/google/apis/compute_v1/classes.rb', line 4951

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4961
4962
4963
# File 'lib/google/apis/compute_v1/classes.rb', line 4961

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4966
4967
4968
# File 'lib/google/apis/compute_v1/classes.rb', line 4966

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


4971
4972
4973
# File 'lib/google/apis/compute_v1/classes.rb', line 4971

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::BackendServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4976
4977
4978
# File 'lib/google/apis/compute_v1/classes.rb', line 4976

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4983
4984
4985
4986
4987
4988
4989
4990
4991
# File 'lib/google/apis/compute_v1/classes.rb', line 4983

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end