Class: Google::Apis::ComputeV1::BackendServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of BackendServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceAggregatedList

Returns a new instance of BackendServiceAggregatedList.



4593
4594
4595
# File 'lib/google/apis/compute_v1/classes.rb', line 4593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4556
4557
4558
# File 'lib/google/apis/compute_v1/classes.rb', line 4556

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::BackendServicesScopedList>

A list of BackendServicesScopedList resources. Corresponds to the JSON property items



4561
4562
4563
# File 'lib/google/apis/compute_v1/classes.rb', line 4561

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


4566
4567
4568
# File 'lib/google/apis/compute_v1/classes.rb', line 4566

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4576
4577
4578
# File 'lib/google/apis/compute_v1/classes.rb', line 4576

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4581
4582
4583
# File 'lib/google/apis/compute_v1/classes.rb', line 4581

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


4586
4587
4588
# File 'lib/google/apis/compute_v1/classes.rb', line 4586

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::BackendServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4591
4592
4593
# File 'lib/google/apis/compute_v1/classes.rb', line 4591

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4598
4599
4600
4601
4602
4603
4604
4605
4606
# File 'lib/google/apis/compute_v1/classes.rb', line 4598

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end