Class: Google::Apis::ComputeV1::BackendServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of BackendServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceAggregatedList

Returns a new instance of BackendServiceAggregatedList.



3377
3378
3379
# File 'lib/google/apis/compute_v1/classes.rb', line 3377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


3341
3342
3343
# File 'lib/google/apis/compute_v1/classes.rb', line 3341

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::BackendServicesScopedList>

A list of BackendServicesScopedList resources. Corresponds to the JSON property items



3346
3347
3348
# File 'lib/google/apis/compute_v1/classes.rb', line 3346

def items
  @items
end

#kindString

Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


3351
3352
3353
# File 'lib/google/apis/compute_v1/classes.rb', line 3351

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3360
3361
3362
# File 'lib/google/apis/compute_v1/classes.rb', line 3360

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3365
3366
3367
# File 'lib/google/apis/compute_v1/classes.rb', line 3365

def self_link
  @self_link
end

#unreachablesArray<String>

[Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


3370
3371
3372
# File 'lib/google/apis/compute_v1/classes.rb', line 3370

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::BackendServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



3375
3376
3377
# File 'lib/google/apis/compute_v1/classes.rb', line 3375

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3382
3383
3384
3385
3386
3387
3388
3389
3390
# File 'lib/google/apis/compute_v1/classes.rb', line 3382

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end