Class: Google::Apis::ComputeV1::BackendServiceHaPolicyLeader
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceHaPolicyLeader
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#backend_group ⇒ String
A fully-qualified URL (starting with https://www.googleapis.com/) of the zonal Network Endpoint Group (NEG) with
GCE_VM_IPendpoints that the leader is attached to. -
#network_endpoint ⇒ Google::Apis::ComputeV1::BackendServiceHaPolicyLeaderNetworkEndpoint
The network endpoint within the leader.backendGroup that is designated as the leader.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceHaPolicyLeader
constructor
A new instance of BackendServiceHaPolicyLeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceHaPolicyLeader
Returns a new instance of BackendServiceHaPolicyLeader.
5636 5637 5638 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_group ⇒ String
A fully-qualified URL (starting with https://www.googleapis.com/)
of the zonal Network Endpoint Group (NEG) with GCE_VM_IP endpoints
that the leader is attached to.
The leader's backendGroup must already be specified as a backend of
this backend service. Removing a backend that is designated as the
leader's backendGroup is not permitted.
Corresponds to the JSON property backendGroup
5625 5626 5627 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5625 def backend_group @backend_group end |
#network_endpoint ⇒ Google::Apis::ComputeV1::BackendServiceHaPolicyLeaderNetworkEndpoint
The network endpoint within the leader.backendGroup that is
designated as the leader.
This network endpoint cannot be detached from the NEG specified in
the haPolicy.leader.backendGroup until the leader is updated with
another network endpoint, or the leader is removed from the haPolicy.
Corresponds to the JSON property networkEndpoint
5634 5635 5636 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5634 def network_endpoint @network_endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5641 5642 5643 5644 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5641 def update!(**args) @backend_group = args[:backend_group] if args.key?(:backend_group) @network_endpoint = args[:network_endpoint] if args.key?(:network_endpoint) end |