Class: Google::Apis::ComputeV1::BackendServiceHttpCookie
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceHttpCookie
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The HTTP cookie used for stateful session affinity.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the cookie.
-
#path ⇒ String
Path to set for the cookie.
-
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceHttpCookie
constructor
A new instance of BackendServiceHttpCookie.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceHttpCookie
Returns a new instance of BackendServiceHttpCookie.
5749 5750 5751 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the cookie.
Corresponds to the JSON property name
5734 5735 5736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5734 def name @name end |
#path ⇒ String
Path to set for the cookie.
Corresponds to the JSON property path
5739 5740 5741 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5739 def path @path end |
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property ttl
5747 5748 5749 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5747 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5754 5755 5756 5757 5758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5754 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @ttl = args[:ttl] if args.key?(:ttl) end |