Class: Google::Apis::ComputeV1::BackendServiceHttpCookie
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceHttpCookie
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The HTTP cookie used for stateful session affinity.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the cookie.
-
#path ⇒ String
Path to set for the cookie.
-
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceHttpCookie
constructor
A new instance of BackendServiceHttpCookie.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceHttpCookie
Returns a new instance of BackendServiceHttpCookie.
5693 5694 5695 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the cookie.
Corresponds to the JSON property name
5678 5679 5680 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5678 def name @name end |
#path ⇒ String
Path to set for the cookie.
Corresponds to the JSON property path
5683 5684 5685 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5683 def path @path end |
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property ttl
5691 5692 5693 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5691 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5698 5699 5700 5701 5702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5698 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @ttl = args[:ttl] if args.key?(:ttl) end |