Class: Google::Apis::ComputeV1::BackendServiceHttpCookie

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The HTTP cookie used for stateful session affinity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceHttpCookie

Returns a new instance of BackendServiceHttpCookie.



5710
5711
5712
# File 'lib/google/apis/compute_v1/classes.rb', line 5710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the cookie. Corresponds to the JSON property name

Returns:

  • (String)


5695
5696
5697
# File 'lib/google/apis/compute_v1/classes.rb', line 5695

def name
  @name
end

#pathString

Path to set for the cookie. Corresponds to the JSON property path

Returns:

  • (String)


5700
5701
5702
# File 'lib/google/apis/compute_v1/classes.rb', line 5700

def path
  @path
end

#ttlGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property ttl



5708
5709
5710
# File 'lib/google/apis/compute_v1/classes.rb', line 5708

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5715
5716
5717
5718
5719
# File 'lib/google/apis/compute_v1/classes.rb', line 5715

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
  @ttl = args[:ttl] if args.key?(:ttl)
end