Class: Google::Apis::ComputeV1::BackendServiceHttpCookie
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceHttpCookie
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The HTTP cookie used for stateful session affinity.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the cookie.
-
#path ⇒ String
Path to set for the cookie.
-
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceHttpCookie
constructor
A new instance of BackendServiceHttpCookie.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceHttpCookie
Returns a new instance of BackendServiceHttpCookie.
5279 5280 5281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the cookie.
Corresponds to the JSON property name
5264 5265 5266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5264 def name @name end |
#path ⇒ String
Path to set for the cookie.
Corresponds to the JSON property path
5269 5270 5271 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5269 def path @path end |
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property ttl
5277 5278 5279 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5277 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5284 5285 5286 5287 5288 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5284 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @ttl = args[:ttl] if args.key?(:ttl) end |