Class: Google::Apis::ComputeV1::BackendServiceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceList

Returns a new instance of BackendServiceList.



5806
5807
5808
# File 'lib/google/apis/compute_v1/classes.rb', line 5806

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


5773
5774
5775
# File 'lib/google/apis/compute_v1/classes.rb', line 5773

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



5778
5779
5780
# File 'lib/google/apis/compute_v1/classes.rb', line 5778

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList for lists of backend services. Corresponds to the JSON property kind

Returns:

  • (String)


5784
5785
5786
# File 'lib/google/apis/compute_v1/classes.rb', line 5784

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5794
5795
5796
# File 'lib/google/apis/compute_v1/classes.rb', line 5794

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5799
5800
5801
# File 'lib/google/apis/compute_v1/classes.rb', line 5799

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendServiceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



5804
5805
5806
# File 'lib/google/apis/compute_v1/classes.rb', line 5804

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5811
5812
5813
5814
5815
5816
5817
5818
# File 'lib/google/apis/compute_v1/classes.rb', line 5811

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end