Class: Google::Apis::ComputeV1::BackendServiceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::BackendServiceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceList
constructor
A new instance of BackendServiceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceList
Returns a new instance of BackendServiceList.
5375 5376 5377 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5375 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
5342 5343 5344 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5342 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
5347 5348 5349 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5347 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList
for lists of backend services.
Corresponds to the JSON property kind
5353 5354 5355 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5353 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5363 5364 5365 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5363 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
5368 5369 5370 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5368 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::BackendServiceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
5373 5374 5375 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5373 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5380 5381 5382 5383 5384 5385 5386 5387 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5380 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |