Class: Google::Apis::ComputeV1::BackendServiceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceList

Returns a new instance of BackendServiceList.



3901
3902
3903
# File 'lib/google/apis/compute_v1/classes.rb', line 3901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


3869
3870
3871
# File 'lib/google/apis/compute_v1/classes.rb', line 3869

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



3874
3875
3876
# File 'lib/google/apis/compute_v1/classes.rb', line 3874

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#backendServiceList for lists of backend services. Corresponds to the JSON property kind

Returns:

  • (String)


3880
3881
3882
# File 'lib/google/apis/compute_v1/classes.rb', line 3880

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3889
3890
3891
# File 'lib/google/apis/compute_v1/classes.rb', line 3889

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3894
3895
3896
# File 'lib/google/apis/compute_v1/classes.rb', line 3894

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendServiceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



3899
3900
3901
# File 'lib/google/apis/compute_v1/classes.rb', line 3899

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3906
3907
3908
3909
3910
3911
3912
3913
# File 'lib/google/apis/compute_v1/classes.rb', line 3906

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end