Class: Google::Apis::ComputeV1::BackendServiceListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of usable BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceListUsable

Returns a new instance of BackendServiceListUsable.



5971
5972
5973
# File 'lib/google/apis/compute_v1/classes.rb', line 5971

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


5937
5938
5939
# File 'lib/google/apis/compute_v1/classes.rb', line 5937

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



5942
5943
5944
# File 'lib/google/apis/compute_v1/classes.rb', line 5942

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendServiceList for lists of usable backend services. Corresponds to the JSON property kind

Returns:

  • (String)


5949
5950
5951
# File 'lib/google/apis/compute_v1/classes.rb', line 5949

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5959
5960
5961
# File 'lib/google/apis/compute_v1/classes.rb', line 5959

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5964
5965
5966
# File 'lib/google/apis/compute_v1/classes.rb', line 5964

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendServiceListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



5969
5970
5971
# File 'lib/google/apis/compute_v1/classes.rb', line 5969

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5976
5977
5978
5979
5980
5981
5982
5983
# File 'lib/google/apis/compute_v1/classes.rb', line 5976

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end