Class: Google::Apis::ComputeV1::BackendServiceListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of usable BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceListUsable
constructor
A new instance of BackendServiceListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceListUsable
Returns a new instance of BackendServiceListUsable.
5924 5925 5926 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
5890 5891 5892 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5890 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
5895 5896 5897 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5895 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendServiceList for lists of usable backend
services.
Corresponds to the JSON property kind
5902 5903 5904 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5902 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5912 5913 5914 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5912 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
5917 5918 5919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5917 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
5922 5923 5924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5922 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5929 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |