Class: Google::Apis::ComputeV1::BackendServiceListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of usable BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceListUsable

Returns a new instance of BackendServiceListUsable.



5920
5921
5922
# File 'lib/google/apis/compute_v1/classes.rb', line 5920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


5886
5887
5888
# File 'lib/google/apis/compute_v1/classes.rb', line 5886

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



5891
5892
5893
# File 'lib/google/apis/compute_v1/classes.rb', line 5891

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendServiceList for lists of usable backend services. Corresponds to the JSON property kind

Returns:

  • (String)


5898
5899
5900
# File 'lib/google/apis/compute_v1/classes.rb', line 5898

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5908
5909
5910
# File 'lib/google/apis/compute_v1/classes.rb', line 5908

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5913
5914
5915
# File 'lib/google/apis/compute_v1/classes.rb', line 5913

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::BackendServiceListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



5918
5919
5920
# File 'lib/google/apis/compute_v1/classes.rb', line 5918

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5925
5926
5927
5928
5929
5930
5931
5932
# File 'lib/google/apis/compute_v1/classes.rb', line 5925

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end