Class: Google::Apis::ComputeV1::BackendServiceListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of usable BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceListUsable
constructor
A new instance of BackendServiceListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceListUsable
Returns a new instance of BackendServiceListUsable.
5501 5502 5503 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
5467 5468 5469 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5467 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
5472 5473 5474 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5472 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendServiceList for lists of usable backend
services.
Corresponds to the JSON property kind
5479 5480 5481 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5479 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5489 5490 5491 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5489 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
5494 5495 5496 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5494 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
5499 5500 5501 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5499 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5506 5507 5508 5509 5510 5511 5512 5513 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5506 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |