Class: Google::Apis::ComputeV1::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The configuration for a custom policy implemented by the user and deployed with the client.
Instance Attribute Summary collapse
-
#data ⇒ String
An optional, arbitrary JSON object with configuration data, understood by a locally installed custom policy implementation.
-
#name ⇒ String
Identifies the custom policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
constructor
A new instance of BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
Returns a new instance of BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.
5671 5672 5673 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
An optional, arbitrary JSON object with configuration data, understood
by a locally installed custom policy implementation.
Corresponds to the JSON property data
5656 5657 5658 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5656 def data @data end |
#name ⇒ String
Identifies the custom policy.
The value should match the name of a custom implementation registered
on the gRPC clients. It should follow protocol buffer message naming
conventions and include the full path (for example,
myorg.CustomLbPolicy). The maximum length is 256 characters.
Do not specify the same custom policy more than once for a
backend. If you do, the configuration is rejected.
For an example of how to use this field, seeUse
a custom policy.
Corresponds to the JSON property name
5669 5670 5671 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5669 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5676 5677 5678 5679 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5676 def update!(**args) @data = args[:data] if args.key?(:data) @name = args[:name] if args.key?(:name) end |