Class: Google::Apis::ComputeV1::BackendServiceLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The available logging options for the load balancer traffic served by this backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLogConfig

Returns a new instance of BackendServiceLogConfig.



6142
6143
6144
# File 'lib/google/apis/compute_v1/classes.rb', line 6142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false. Corresponds to the JSON property enable

Returns:

  • (Boolean)


6103
6104
6105
# File 'lib/google/apis/compute_v1/classes.rb', line 6103

def enable
  @enable
end

#logging_http_request_headersArray<Google::Apis::ComputeV1::BackendServiceLogConfigLoggingHttpHeader>

The list of request headers that will be logged to Stackdriver. Corresponds to the JSON property loggingHttpRequestHeaders



6109
6110
6111
# File 'lib/google/apis/compute_v1/classes.rb', line 6109

def logging_http_request_headers
  @logging_http_request_headers
end

#logging_http_response_headersArray<Google::Apis::ComputeV1::BackendServiceLogConfigLoggingHttpHeader>

The list of response headers that will be logged to Stackdriver. Corresponds to the JSON property loggingHttpResponseHeaders



6114
6115
6116
# File 'lib/google/apis/compute_v1/classes.rb', line 6114

def logging_http_response_headers
  @logging_http_response_headers
end

#optional_fieldsArray<String>

This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM. Contains a list of optional fields you want to include in the logs. For example: serverInstance, serverGkeDetails.cluster, serverGkeDetails.pod.podNamespace Corresponds to the JSON property optionalFields

Returns:

  • (Array<String>)


6123
6124
6125
# File 'lib/google/apis/compute_v1/classes.rb', line 6123

def optional_fields
  @optional_fields
end

#optional_modeString

This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. Corresponds to the JSON property optionalMode

Returns:

  • (String)


6131
6132
6133
# File 'lib/google/apis/compute_v1/classes.rb', line 6131

def optional_mode
  @optional_mode
end

#sample_rateFloat

This field can only be specified if logging is enabled for this backend service. The value of the field must be in [0, 1]. This configures the sampling rate of requests to the load balancer where 1.0 means all logged requests are reported and 0.0 means no logged requests are reported. The default value is 1.0. Corresponds to the JSON property sampleRate

Returns:

  • (Float)


6140
6141
6142
# File 'lib/google/apis/compute_v1/classes.rb', line 6140

def sample_rate
  @sample_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6147
6148
6149
6150
6151
6152
6153
6154
# File 'lib/google/apis/compute_v1/classes.rb', line 6147

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @logging_http_request_headers = args[:logging_http_request_headers] if args.key?(:logging_http_request_headers)
  @logging_http_response_headers = args[:logging_http_response_headers] if args.key?(:logging_http_response_headers)
  @optional_fields = args[:optional_fields] if args.key?(:optional_fields)
  @optional_mode = args[:optional_mode] if args.key?(:optional_mode)
  @sample_rate = args[:sample_rate] if args.key?(:sample_rate)
end