Class: Google::Apis::ComputeV1::BackendServiceLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The available logging options for the load balancer traffic served by this backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLogConfig

Returns a new instance of BackendServiceLogConfig.



6133
6134
6135
# File 'lib/google/apis/compute_v1/classes.rb', line 6133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false. Corresponds to the JSON property enable

Returns:

  • (Boolean)


6094
6095
6096
# File 'lib/google/apis/compute_v1/classes.rb', line 6094

def enable
  @enable
end

#logging_http_request_headersArray<Google::Apis::ComputeV1::BackendServiceLogConfigLoggingHttpHeader>

The list of request headers that will be logged to Stackdriver. Corresponds to the JSON property loggingHttpRequestHeaders



6100
6101
6102
# File 'lib/google/apis/compute_v1/classes.rb', line 6100

def logging_http_request_headers
  @logging_http_request_headers
end

#logging_http_response_headersArray<Google::Apis::ComputeV1::BackendServiceLogConfigLoggingHttpHeader>

The list of response headers that will be logged to Stackdriver. Corresponds to the JSON property loggingHttpResponseHeaders



6105
6106
6107
# File 'lib/google/apis/compute_v1/classes.rb', line 6105

def logging_http_response_headers
  @logging_http_response_headers
end

#optional_fieldsArray<String>

This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM. Contains a list of optional fields you want to include in the logs. For example: serverInstance, serverGkeDetails.cluster, serverGkeDetails.pod.podNamespace Corresponds to the JSON property optionalFields

Returns:

  • (Array<String>)


6114
6115
6116
# File 'lib/google/apis/compute_v1/classes.rb', line 6114

def optional_fields
  @optional_fields
end

#optional_modeString

This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. Corresponds to the JSON property optionalMode

Returns:

  • (String)


6122
6123
6124
# File 'lib/google/apis/compute_v1/classes.rb', line 6122

def optional_mode
  @optional_mode
end

#sample_rateFloat

This field can only be specified if logging is enabled for this backend service. The value of the field must be in [0, 1]. This configures the sampling rate of requests to the load balancer where 1.0 means all logged requests are reported and 0.0 means no logged requests are reported. The default value is 1.0. Corresponds to the JSON property sampleRate

Returns:

  • (Float)


6131
6132
6133
# File 'lib/google/apis/compute_v1/classes.rb', line 6131

def sample_rate
  @sample_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6138
6139
6140
6141
6142
6143
6144
6145
# File 'lib/google/apis/compute_v1/classes.rb', line 6138

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @logging_http_request_headers = args[:logging_http_request_headers] if args.key?(:logging_http_request_headers)
  @logging_http_response_headers = args[:logging_http_response_headers] if args.key?(:logging_http_response_headers)
  @optional_fields = args[:optional_fields] if args.key?(:optional_fields)
  @optional_mode = args[:optional_mode] if args.key?(:optional_mode)
  @sample_rate = args[:sample_rate] if args.key?(:sample_rate)
end