Class: Google::Apis::ComputeV1::BackendServiceLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The available logging options for the load balancer traffic served by this backend service.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
Denotes whether to enable logging for the load balancer traffic served by this backend service.
-
#optional_fields ⇒ Array<String>
This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM.
-
#optional_mode ⇒ String
This field can only be specified if logging is enabled for this backend service.
-
#sample_rate ⇒ Float
This field can only be specified if logging is enabled for this backend service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceLogConfig
constructor
A new instance of BackendServiceLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceLogConfig
Returns a new instance of BackendServiceLogConfig.
5743 5744 5745 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
Denotes whether to enable logging for the load balancer
traffic served by this backend service. The default value is false.
Corresponds to the JSON property enable
5714 5715 5716 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5714 def enable @enable end |
#optional_fields ⇒ Array<String>
This field can only be specified if logging is enabled for this backend
service and "logConfig.optionalMode" was set to CUSTOM. Contains a list
of optional fields you want to include in the logs. For example:
serverInstance, serverGkeDetails.cluster,
serverGkeDetails.pod.podNamespace
Corresponds to the JSON property optionalFields
5724 5725 5726 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5724 def optional_fields @optional_fields end |
#optional_mode ⇒ String
This field can only be specified if logging is enabled for this backend
service. Configures whether all, none or a subset of optional fields
should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL,
EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL.
Corresponds to the JSON property optionalMode
5732 5733 5734 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5732 def optional_mode @optional_mode end |
#sample_rate ⇒ Float
This field can only be specified if logging is enabled for this backend
service. The value of the field must be in [0, 1]. This configures the
sampling rate of requests to the load balancer where 1.0 means all logged
requests are reported and 0.0 means no logged requests are reported. The
default value is 1.0.
Corresponds to the JSON property sampleRate
5741 5742 5743 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5741 def sample_rate @sample_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5748 5749 5750 5751 5752 5753 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5748 def update!(**args) @enable = args[:enable] if args.key?(:enable) @optional_fields = args[:optional_fields] if args.key?(:optional_fields) @optional_mode = args[:optional_mode] if args.key?(:optional_mode) @sample_rate = args[:sample_rate] if args.key?(:sample_rate) end |