Class: Google::Apis::ComputeV1::BackendServiceNetworkPassThroughLbTrafficPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceNetworkPassThroughLbTrafficPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#zonal_affinity ⇒ Google::Apis::ComputeV1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
When configured, new connections are load balanced across healthy backend endpoints in the local zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceNetworkPassThroughLbTrafficPolicy
constructor
A new instance of BackendServiceNetworkPassThroughLbTrafficPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceNetworkPassThroughLbTrafficPolicy
Returns a new instance of BackendServiceNetworkPassThroughLbTrafficPolicy.
5732 5733 5734 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#zonal_affinity ⇒ Google::Apis::ComputeV1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
When configured, new connections are load balanced across healthy backend
endpoints in the local zone.
Corresponds to the JSON property zonalAffinity
5730 5731 5732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5730 def zonal_affinity @zonal_affinity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5737 5738 5739 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5737 def update!(**args) @zonal_affinity = args[:zonal_affinity] if args.key?(:zonal_affinity) end |