Class: Google::Apis::ComputeV1::BackendServiceOrchestrationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A message containing information about the resource or system that manages the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceOrchestrationInfo

Returns a new instance of BackendServiceOrchestrationInfo.



6232
6233
6234
# File 'lib/google/apis/compute_v1/classes.rb', line 6232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_uriString

The resource URI of the resource or system that manages the backend service. Corresponds to the JSON property resourceUri

Returns:

  • (String)


6230
6231
6232
# File 'lib/google/apis/compute_v1/classes.rb', line 6230

def resource_uri
  @resource_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6237
6238
6239
# File 'lib/google/apis/compute_v1/classes.rb', line 6237

def update!(**args)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
end