Class: Google::Apis::ComputeV1::BackendServiceTlsSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceTlsSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#authentication_config ⇒ String
Reference to the BackendAuthenticationConfig resource from the networksecurity.googleapis.com namespace.
-
#sni ⇒ String
Server Name Indication - see RFC3546 section 3.1.
-
#subject_alt_names ⇒ Array<Google::Apis::ComputeV1::BackendServiceTlsSettingsSubjectAltName>
A list of Subject Alternative Names (SANs) that the Load Balancer verifies during a TLS handshake with the backend.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceTlsSettings
constructor
A new instance of BackendServiceTlsSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceTlsSettings
Returns a new instance of BackendServiceTlsSettings.
6341 6342 6343 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_config ⇒ String
Reference to the BackendAuthenticationConfig resource from the
networksecurity.googleapis.com namespace. Can be used in authenticating
TLS connections to the backend, as specified by the authenticationMode
field. Can only be specified if authenticationMode is not NONE.
Corresponds to the JSON property authenticationConfig
6315 6316 6317 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6315 def authentication_config @authentication_config end |
#sni ⇒ String
Server Name Indication - see RFC3546 section 3.1. If set, the load
balancer sends this string as the SNI hostname in the TLS connection to
the backend, and requires that this string match a Subject Alternative
Name (SAN) in the backend's server certificate. With a Regional Internet
NEG backend, if the SNI is specified here, the load balancer uses it
regardless of whether the Regional Internet NEG is specified with FQDN or
IP address and port. When both sni and subjectAltNames[] are specified,
the load balancer matches the backend certificate's SAN only to
subjectAltNames[].
Corresponds to the JSON property sni
6328 6329 6330 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6328 def sni @sni end |
#subject_alt_names ⇒ Array<Google::Apis::ComputeV1::BackendServiceTlsSettingsSubjectAltName>
A list of Subject Alternative Names (SANs) that the Load Balancer
verifies during a TLS handshake with the backend. When the server
presents its X.509 certificate to the Load Balancer, the Load Balancer
inspects the certificate's SAN field, and requires that at least one SAN
match one of the subjectAltNames in the list. This field is limited to 5
entries. When both sni and subjectAltNames[] are specified, the load
balancer matches the backend certificate's SAN only to subjectAltNames[].
Corresponds to the JSON property subjectAltNames
6339 6340 6341 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6339 def subject_alt_names @subject_alt_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6346 6347 6348 6349 6350 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6346 def update!(**args) @authentication_config = args[:authentication_config] if args.key?(:authentication_config) @sni = args[:sni] if args.key?(:sni) @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names) end |