Class: Google::Apis::ComputeV1::BackendServiceTlsSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BackendServiceTlsSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#authentication_config ⇒ String
Reference to the BackendAuthenticationConfig resource from the networksecurity.googleapis.com namespace.
-
#sni ⇒ String
Server Name Indication - see RFC3546 section 3.1.
-
#subject_alt_names ⇒ Array<Google::Apis::ComputeV1::BackendServiceTlsSettingsSubjectAltName>
A list of Subject Alternative Names (SANs) that the Load Balancer verifies during a TLS handshake with the backend.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceTlsSettings
constructor
A new instance of BackendServiceTlsSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceTlsSettings
Returns a new instance of BackendServiceTlsSettings.
5875 5876 5877 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_config ⇒ String
Reference to the BackendAuthenticationConfig resource from the
networksecurity.googleapis.com namespace. Can be used in authenticating
TLS connections to the backend, as specified by the authenticationMode
field. Can only be specified if authenticationMode is not NONE.
Corresponds to the JSON property authenticationConfig
5849 5850 5851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5849 def authentication_config @authentication_config end |
#sni ⇒ String
Server Name Indication - see RFC3546 section 3.1. If set, the load
balancer sends this string as the SNI hostname in the TLS connection to
the backend, and requires that this string match a Subject Alternative
Name (SAN) in the backend's server certificate. With a Regional Internet
NEG backend, if the SNI is specified here, the load balancer uses it
regardless of whether the Regional Internet NEG is specified with FQDN or
IP address and port. When both sni and subjectAltNames[] are specified,
the load balancer matches the backend certificate's SAN only to
subjectAltNames[].
Corresponds to the JSON property sni
5862 5863 5864 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5862 def sni @sni end |
#subject_alt_names ⇒ Array<Google::Apis::ComputeV1::BackendServiceTlsSettingsSubjectAltName>
A list of Subject Alternative Names (SANs) that the Load Balancer
verifies during a TLS handshake with the backend. When the server
presents its X.509 certificate to the Load Balancer, the Load Balancer
inspects the certificate's SAN field, and requires that at least one SAN
match one of the subjectAltNames in the list. This field is limited to 5
entries. When both sni and subjectAltNames[] are specified, the load
balancer matches the backend certificate's SAN only to subjectAltNames[].
Corresponds to the JSON property subjectAltNames
5873 5874 5875 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5873 def subject_alt_names @subject_alt_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5880 5881 5882 5883 5884 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5880 def update!(**args) @authentication_config = args[:authentication_config] if args.key?(:authentication_config) @sni = args[:sni] if args.key?(:sni) @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names) end |