Class: Google::Apis::ComputeV1::BackendServiceTlsSettingsSubjectAltName

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A Subject Alternative Name that the load balancer matches against the SAN field in the TLS certificate provided by the backend, specified as either a DNS name or a URI, in accordance with RFC 5280 4.2.1.6

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceTlsSettingsSubjectAltName

Returns a new instance of BackendServiceTlsSettingsSubjectAltName.



5903
5904
5905
# File 'lib/google/apis/compute_v1/classes.rb', line 5903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_nameString

The SAN specified as a DNS Name. Corresponds to the JSON property dnsName

Returns:

  • (String)


5896
5897
5898
# File 'lib/google/apis/compute_v1/classes.rb', line 5896

def dns_name
  @dns_name
end

#uniform_resource_identifierString

The SAN specified as a URI. Corresponds to the JSON property uniformResourceIdentifier

Returns:

  • (String)


5901
5902
5903
# File 'lib/google/apis/compute_v1/classes.rb', line 5901

def uniform_resource_identifier
  @uniform_resource_identifier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5908
5909
5910
5911
# File 'lib/google/apis/compute_v1/classes.rb', line 5908

def update!(**args)
  @dns_name = args[:dns_name] if args.key?(:dns_name)
  @uniform_resource_identifier = args[:uniform_resource_identifier] if args.key?(:uniform_resource_identifier)
end