Class: Google::Apis::ComputeV1::BfdPacket

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdPacket

Returns a new instance of BfdPacket.



6658
6659
6660
# File 'lib/google/apis/compute_v1/classes.rb', line 6658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_presentBoolean Also known as: authentication_present?

The Authentication Present bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property authenticationPresent

Returns:

  • (Boolean)


6562
6563
6564
# File 'lib/google/apis/compute_v1/classes.rb', line 6562

def authentication_present
  @authentication_present
end

#control_plane_independentBoolean Also known as: control_plane_independent?

The Control Plane Independent bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property controlPlaneIndependent

Returns:

  • (Boolean)


6569
6570
6571
# File 'lib/google/apis/compute_v1/classes.rb', line 6569

def control_plane_independent
  @control_plane_independent
end

#demandBoolean Also known as: demand?

The demand bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property demand

Returns:

  • (Boolean)


6575
6576
6577
# File 'lib/google/apis/compute_v1/classes.rb', line 6575

def demand
  @demand
end

#diagnosticString

The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Corresponds to the JSON property diagnostic

Returns:

  • (String)


6584
6585
6586
# File 'lib/google/apis/compute_v1/classes.rb', line 6584

def diagnostic
  @diagnostic
end

#finalBoolean Also known as: final?

The Final bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property final

Returns:

  • (Boolean)


6589
6590
6591
# File 'lib/google/apis/compute_v1/classes.rb', line 6589

def final
  @final
end

#lengthFixnum

The length of the BFD Control packet in bytes. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property length

Returns:

  • (Fixnum)


6596
6597
6598
# File 'lib/google/apis/compute_v1/classes.rb', line 6596

def length
  @length
end

#min_echo_rx_interval_msFixnum

The Required Min Echo RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property minEchoRxIntervalMs

Returns:

  • (Fixnum)


6602
6603
6604
# File 'lib/google/apis/compute_v1/classes.rb', line 6602

def min_echo_rx_interval_ms
  @min_echo_rx_interval_ms
end

#min_rx_interval_msFixnum

The Required Min RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property minRxIntervalMs

Returns:

  • (Fixnum)


6608
6609
6610
# File 'lib/google/apis/compute_v1/classes.rb', line 6608

def min_rx_interval_ms
  @min_rx_interval_ms
end

#min_tx_interval_msFixnum

The Desired Min TX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property minTxIntervalMs

Returns:

  • (Fixnum)


6614
6615
6616
# File 'lib/google/apis/compute_v1/classes.rb', line 6614

def min_tx_interval_ms
  @min_tx_interval_ms
end

#multiplierFixnum

The detection time multiplier of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property multiplier

Returns:

  • (Fixnum)


6620
6621
6622
# File 'lib/google/apis/compute_v1/classes.rb', line 6620

def multiplier
  @multiplier
end

#multipointBoolean Also known as: multipoint?

The multipoint bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property multipoint

Returns:

  • (Boolean)


6626
6627
6628
# File 'lib/google/apis/compute_v1/classes.rb', line 6626

def multipoint
  @multipoint
end

#my_discriminatorFixnum

The My Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property myDiscriminator

Returns:

  • (Fixnum)


6633
6634
6635
# File 'lib/google/apis/compute_v1/classes.rb', line 6633

def my_discriminator
  @my_discriminator
end

#pollBoolean Also known as: poll?

The Poll bit of the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property poll

Returns:

  • (Boolean)


6638
6639
6640
# File 'lib/google/apis/compute_v1/classes.rb', line 6638

def poll
  @poll
end

#stateString

The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Corresponds to the JSON property state

Returns:

  • (String)


6645
6646
6647
# File 'lib/google/apis/compute_v1/classes.rb', line 6645

def state
  @state
end

#versionFixnum

The version number of the BFD protocol, as specified in section 4.1 ofRFC5880. Corresponds to the JSON property version

Returns:

  • (Fixnum)


6650
6651
6652
# File 'lib/google/apis/compute_v1/classes.rb', line 6650

def version
  @version
end

#your_discriminatorFixnum

The Your Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880 Corresponds to the JSON property yourDiscriminator

Returns:

  • (Fixnum)


6656
6657
6658
# File 'lib/google/apis/compute_v1/classes.rb', line 6656

def your_discriminator
  @your_discriminator
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
6673
6674
6675
6676
6677
6678
6679
6680
# File 'lib/google/apis/compute_v1/classes.rb', line 6663

def update!(**args)
  @authentication_present = args[:authentication_present] if args.key?(:authentication_present)
  @control_plane_independent = args[:control_plane_independent] if args.key?(:control_plane_independent)
  @demand = args[:demand] if args.key?(:demand)
  @diagnostic = args[:diagnostic] if args.key?(:diagnostic)
  @final = args[:final] if args.key?(:final)
  @length = args[:length] if args.key?(:length)
  @min_echo_rx_interval_ms = args[:min_echo_rx_interval_ms] if args.key?(:min_echo_rx_interval_ms)
  @min_rx_interval_ms = args[:min_rx_interval_ms] if args.key?(:min_rx_interval_ms)
  @min_tx_interval_ms = args[:min_tx_interval_ms] if args.key?(:min_tx_interval_ms)
  @multiplier = args[:multiplier] if args.key?(:multiplier)
  @multipoint = args[:multipoint] if args.key?(:multipoint)
  @my_discriminator = args[:my_discriminator] if args.key?(:my_discriminator)
  @poll = args[:poll] if args.key?(:poll)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
  @your_discriminator = args[:your_discriminator] if args.key?(:your_discriminator)
end