Class: Google::Apis::ComputeV1::BfdPacket
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BfdPacket
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#authentication_present ⇒ Boolean
(also: #authentication_present?)
The Authentication Present bit of the BFD packet.
-
#control_plane_independent ⇒ Boolean
(also: #control_plane_independent?)
The Control Plane Independent bit of the BFD packet.
-
#demand ⇒ Boolean
(also: #demand?)
The demand bit of the BFD packet.
-
#diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#final ⇒ Boolean
(also: #final?)
The Final bit of the BFD packet.
-
#length ⇒ Fixnum
The length of the BFD Control packet in bytes.
-
#min_echo_rx_interval_ms ⇒ Fixnum
The Required Min Echo RX Interval value in the BFD packet.
-
#min_rx_interval_ms ⇒ Fixnum
The Required Min RX Interval value in the BFD packet.
-
#min_tx_interval_ms ⇒ Fixnum
The Desired Min TX Interval value in the BFD packet.
-
#multiplier ⇒ Fixnum
The detection time multiplier of the BFD packet.
-
#multipoint ⇒ Boolean
(also: #multipoint?)
The multipoint bit of the BFD packet.
-
#my_discriminator ⇒ Fixnum
The My Discriminator value in the BFD packet.
-
#poll ⇒ Boolean
(also: #poll?)
The Poll bit of the BFD packet.
-
#state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#version ⇒ Fixnum
The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
-
#your_discriminator ⇒ Fixnum
The Your Discriminator value in the BFD packet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdPacket
constructor
A new instance of BfdPacket.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdPacket
Returns a new instance of BfdPacket.
6611 6612 6613 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_present ⇒ Boolean Also known as: authentication_present?
The Authentication Present bit of the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property authenticationPresent
6515 6516 6517 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6515 def authentication_present @authentication_present end |
#control_plane_independent ⇒ Boolean Also known as: control_plane_independent?
The Control Plane Independent bit of the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property controlPlaneIndependent
6522 6523 6524 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6522 def control_plane_independent @control_plane_independent end |
#demand ⇒ Boolean Also known as: demand?
The demand bit of the BFD packet. This is specified in section 4.1 ofRFC5880
Corresponds to the JSON property demand
6528 6529 6530 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6528 def demand @demand end |
#diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property diagnostic
6537 6538 6539 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6537 def diagnostic @diagnostic end |
#final ⇒ Boolean Also known as: final?
The Final bit of the BFD packet. This is specified in section 4.1 ofRFC5880
Corresponds to the JSON property final
6542 6543 6544 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6542 def final @final end |
#length ⇒ Fixnum
The length of the BFD Control packet in bytes. This is specified in section
4.1 ofRFC5880
Corresponds to the JSON property length
6549 6550 6551 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6549 def length @length end |
#min_echo_rx_interval_ms ⇒ Fixnum
The Required Min Echo RX Interval value in the BFD packet. This is
specified in section 4.1 ofRFC5880
Corresponds to the JSON property minEchoRxIntervalMs
6555 6556 6557 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6555 def min_echo_rx_interval_ms @min_echo_rx_interval_ms end |
#min_rx_interval_ms ⇒ Fixnum
The Required Min RX Interval value in the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property minRxIntervalMs
6561 6562 6563 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6561 def min_rx_interval_ms @min_rx_interval_ms end |
#min_tx_interval_ms ⇒ Fixnum
The Desired Min TX Interval value in the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property minTxIntervalMs
6567 6568 6569 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6567 def min_tx_interval_ms @min_tx_interval_ms end |
#multiplier ⇒ Fixnum
The detection time multiplier of the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property multiplier
6573 6574 6575 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6573 def multiplier @multiplier end |
#multipoint ⇒ Boolean Also known as: multipoint?
The multipoint bit of the BFD packet. This is specified in section 4.1
ofRFC5880
Corresponds to the JSON property multipoint
6579 6580 6581 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6579 def multipoint @multipoint end |
#my_discriminator ⇒ Fixnum
The My Discriminator value in the BFD packet. This is specified in section
4.1 ofRFC5880
Corresponds to the JSON property myDiscriminator
6586 6587 6588 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6586 def my_discriminator @my_discriminator end |
#poll ⇒ Boolean Also known as: poll?
The Poll bit of the BFD packet. This is specified in section 4.1 ofRFC5880
Corresponds to the JSON property poll
6591 6592 6593 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6591 def poll @poll end |
#state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property state
6598 6599 6600 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6598 def state @state end |
#version ⇒ Fixnum
The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
Corresponds to the JSON property version
6603 6604 6605 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6603 def version @version end |
#your_discriminator ⇒ Fixnum
The Your Discriminator value in the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property yourDiscriminator
6609 6610 6611 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6609 def your_discriminator @your_discriminator end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6616 def update!(**args) @authentication_present = args[:authentication_present] if args.key?(:authentication_present) @control_plane_independent = args[:control_plane_independent] if args.key?(:control_plane_independent) @demand = args[:demand] if args.key?(:demand) @diagnostic = args[:diagnostic] if args.key?(:diagnostic) @final = args[:final] if args.key?(:final) @length = args[:length] if args.key?(:length) @min_echo_rx_interval_ms = args[:min_echo_rx_interval_ms] if args.key?(:min_echo_rx_interval_ms) @min_rx_interval_ms = args[:min_rx_interval_ms] if args.key?(:min_rx_interval_ms) @min_tx_interval_ms = args[:min_tx_interval_ms] if args.key?(:min_tx_interval_ms) @multiplier = args[:multiplier] if args.key?(:multiplier) @multipoint = args[:multipoint] if args.key?(:multipoint) @my_discriminator = args[:my_discriminator] if args.key?(:my_discriminator) @poll = args[:poll] if args.key?(:poll) @state = args[:state] if args.key?(:state) @version = args[:version] if args.key?(:version) @your_discriminator = args[:your_discriminator] if args.key?(:your_discriminator) end |