Class: Google::Apis::ComputeV1::BfdPacket

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdPacket

Returns a new instance of BfdPacket.



4226
4227
4228
# File 'lib/google/apis/compute_v1/classes.rb', line 4226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_presentBoolean Also known as: authentication_present?

The Authentication Present bit of the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property authenticationPresent

Returns:

  • (Boolean)


4130
4131
4132
# File 'lib/google/apis/compute_v1/classes.rb', line 4130

def authentication_present
  @authentication_present
end

#control_plane_independentBoolean Also known as: control_plane_independent?

The Control Plane Independent bit of the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property controlPlaneIndependent

Returns:

  • (Boolean)


4137
4138
4139
# File 'lib/google/apis/compute_v1/classes.rb', line 4137

def control_plane_independent
  @control_plane_independent
end

#demandBoolean Also known as: demand?

The demand bit of the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property demand

Returns:

  • (Boolean)


4143
4144
4145
# File 'lib/google/apis/compute_v1/classes.rb', line 4143

def demand
  @demand
end

#diagnosticString

The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 of RFC5880 Corresponds to the JSON property diagnostic

Returns:

  • (String)


4152
4153
4154
# File 'lib/google/apis/compute_v1/classes.rb', line 4152

def diagnostic
  @diagnostic
end

#finalBoolean Also known as: final?

The Final bit of the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property final

Returns:

  • (Boolean)


4157
4158
4159
# File 'lib/google/apis/compute_v1/classes.rb', line 4157

def final
  @final
end

#lengthFixnum

The length of the BFD Control packet in bytes. This is specified in section 4. 1 of RFC5880 Corresponds to the JSON property length

Returns:

  • (Fixnum)


4164
4165
4166
# File 'lib/google/apis/compute_v1/classes.rb', line 4164

def length
  @length
end

#min_echo_rx_interval_msFixnum

The Required Min Echo RX Interval value in the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property minEchoRxIntervalMs

Returns:

  • (Fixnum)


4170
4171
4172
# File 'lib/google/apis/compute_v1/classes.rb', line 4170

def min_echo_rx_interval_ms
  @min_echo_rx_interval_ms
end

#min_rx_interval_msFixnum

The Required Min RX Interval value in the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property minRxIntervalMs

Returns:

  • (Fixnum)


4176
4177
4178
# File 'lib/google/apis/compute_v1/classes.rb', line 4176

def min_rx_interval_ms
  @min_rx_interval_ms
end

#min_tx_interval_msFixnum

The Desired Min TX Interval value in the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property minTxIntervalMs

Returns:

  • (Fixnum)


4182
4183
4184
# File 'lib/google/apis/compute_v1/classes.rb', line 4182

def min_tx_interval_ms
  @min_tx_interval_ms
end

#multiplierFixnum

The detection time multiplier of the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property multiplier

Returns:

  • (Fixnum)


4188
4189
4190
# File 'lib/google/apis/compute_v1/classes.rb', line 4188

def multiplier
  @multiplier
end

#multipointBoolean Also known as: multipoint?

The multipoint bit of the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property multipoint

Returns:

  • (Boolean)


4194
4195
4196
# File 'lib/google/apis/compute_v1/classes.rb', line 4194

def multipoint
  @multipoint
end

#my_discriminatorFixnum

The My Discriminator value in the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property myDiscriminator

Returns:

  • (Fixnum)


4201
4202
4203
# File 'lib/google/apis/compute_v1/classes.rb', line 4201

def my_discriminator
  @my_discriminator
end

#pollBoolean Also known as: poll?

The Poll bit of the BFD packet. This is specified in section 4.1 of RFC5880 Corresponds to the JSON property poll

Returns:

  • (Boolean)


4206
4207
4208
# File 'lib/google/apis/compute_v1/classes.rb', line 4206

def poll
  @poll
end

#stateString

The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 of RFC5880 Corresponds to the JSON property state

Returns:

  • (String)


4213
4214
4215
# File 'lib/google/apis/compute_v1/classes.rb', line 4213

def state
  @state
end

#versionFixnum

The version number of the BFD protocol, as specified in section 4.1 of RFC5880. Corresponds to the JSON property version

Returns:

  • (Fixnum)


4218
4219
4220
# File 'lib/google/apis/compute_v1/classes.rb', line 4218

def version
  @version
end

#your_discriminatorFixnum

The Your Discriminator value in the BFD packet. This is specified in section 4. 1 of RFC5880 Corresponds to the JSON property yourDiscriminator

Returns:

  • (Fixnum)


4224
4225
4226
# File 'lib/google/apis/compute_v1/classes.rb', line 4224

def your_discriminator
  @your_discriminator
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4231
4232
4233
4234
4235
4236
4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
# File 'lib/google/apis/compute_v1/classes.rb', line 4231

def update!(**args)
  @authentication_present = args[:authentication_present] if args.key?(:authentication_present)
  @control_plane_independent = args[:control_plane_independent] if args.key?(:control_plane_independent)
  @demand = args[:demand] if args.key?(:demand)
  @diagnostic = args[:diagnostic] if args.key?(:diagnostic)
  @final = args[:final] if args.key?(:final)
  @length = args[:length] if args.key?(:length)
  @min_echo_rx_interval_ms = args[:min_echo_rx_interval_ms] if args.key?(:min_echo_rx_interval_ms)
  @min_rx_interval_ms = args[:min_rx_interval_ms] if args.key?(:min_rx_interval_ms)
  @min_tx_interval_ms = args[:min_tx_interval_ms] if args.key?(:min_tx_interval_ms)
  @multiplier = args[:multiplier] if args.key?(:multiplier)
  @multipoint = args[:multipoint] if args.key?(:multipoint)
  @my_discriminator = args[:my_discriminator] if args.key?(:my_discriminator)
  @poll = args[:poll] if args.key?(:poll)
  @state = args[:state] if args.key?(:state)
  @version = args[:version] if args.key?(:version)
  @your_discriminator = args[:your_discriminator] if args.key?(:your_discriminator)
end