Class: Google::Apis::ComputeV1::BfdPacket
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BfdPacket
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#authentication_present ⇒ Boolean
(also: #authentication_present?)
The Authentication Present bit of the BFD packet.
-
#control_plane_independent ⇒ Boolean
(also: #control_plane_independent?)
The Control Plane Independent bit of the BFD packet.
-
#demand ⇒ Boolean
(also: #demand?)
The demand bit of the BFD packet.
-
#diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#final ⇒ Boolean
(also: #final?)
The Final bit of the BFD packet.
-
#length ⇒ Fixnum
The length of the BFD Control packet in bytes.
-
#min_echo_rx_interval_ms ⇒ Fixnum
The Required Min Echo RX Interval value in the BFD packet.
-
#min_rx_interval_ms ⇒ Fixnum
The Required Min RX Interval value in the BFD packet.
-
#min_tx_interval_ms ⇒ Fixnum
The Desired Min TX Interval value in the BFD packet.
-
#multiplier ⇒ Fixnum
The detection time multiplier of the BFD packet.
-
#multipoint ⇒ Boolean
(also: #multipoint?)
The multipoint bit of the BFD packet.
-
#my_discriminator ⇒ Fixnum
The My Discriminator value in the BFD packet.
-
#poll ⇒ Boolean
(also: #poll?)
The Poll bit of the BFD packet.
-
#state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#version ⇒ Fixnum
The version number of the BFD protocol, as specified in section 4.1 of RFC5880.
-
#your_discriminator ⇒ Fixnum
The Your Discriminator value in the BFD packet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdPacket
constructor
A new instance of BfdPacket.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdPacket
Returns a new instance of BfdPacket.
4226 4227 4228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_present ⇒ Boolean Also known as: authentication_present?
The Authentication Present bit of the BFD packet. This is specified in section
4.1 of RFC5880
Corresponds to the JSON property authenticationPresent
4130 4131 4132 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4130 def authentication_present @authentication_present end |
#control_plane_independent ⇒ Boolean Also known as: control_plane_independent?
The Control Plane Independent bit of the BFD packet. This is specified in
section 4.1 of RFC5880
Corresponds to the JSON property controlPlaneIndependent
4137 4138 4139 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4137 def control_plane_independent @control_plane_independent end |
#demand ⇒ Boolean Also known as: demand?
The demand bit of the BFD packet. This is specified in section 4.1 of RFC5880
Corresponds to the JSON property demand
4143 4144 4145 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4143 def demand @demand end |
#diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in
session state. This allows remote systems to determine the reason that the
previous session failed, for example. These diagnostic codes are specified in
section 4.1 of RFC5880
Corresponds to the JSON property diagnostic
4152 4153 4154 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4152 def diagnostic @diagnostic end |
#final ⇒ Boolean Also known as: final?
The Final bit of the BFD packet. This is specified in section 4.1 of RFC5880
Corresponds to the JSON property final
4157 4158 4159 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4157 def final @final end |
#length ⇒ Fixnum
The length of the BFD Control packet in bytes. This is specified in section 4.
1 of RFC5880
Corresponds to the JSON property length
4164 4165 4166 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4164 def length @length end |
#min_echo_rx_interval_ms ⇒ Fixnum
The Required Min Echo RX Interval value in the BFD packet. This is specified
in section 4.1 of RFC5880
Corresponds to the JSON property minEchoRxIntervalMs
4170 4171 4172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4170 def min_echo_rx_interval_ms @min_echo_rx_interval_ms end |
#min_rx_interval_ms ⇒ Fixnum
The Required Min RX Interval value in the BFD packet. This is specified in
section 4.1 of RFC5880
Corresponds to the JSON property minRxIntervalMs
4176 4177 4178 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4176 def min_rx_interval_ms @min_rx_interval_ms end |
#min_tx_interval_ms ⇒ Fixnum
The Desired Min TX Interval value in the BFD packet. This is specified in
section 4.1 of RFC5880
Corresponds to the JSON property minTxIntervalMs
4182 4183 4184 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4182 def min_tx_interval_ms @min_tx_interval_ms end |
#multiplier ⇒ Fixnum
The detection time multiplier of the BFD packet. This is specified in section
4.1 of RFC5880
Corresponds to the JSON property multiplier
4188 4189 4190 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4188 def multiplier @multiplier end |
#multipoint ⇒ Boolean Also known as: multipoint?
The multipoint bit of the BFD packet. This is specified in section 4.1 of
RFC5880
Corresponds to the JSON property multipoint
4194 4195 4196 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4194 def multipoint @multipoint end |
#my_discriminator ⇒ Fixnum
The My Discriminator value in the BFD packet. This is specified in section 4.1
of RFC5880
Corresponds to the JSON property myDiscriminator
4201 4202 4203 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4201 def my_discriminator @my_discriminator end |
#poll ⇒ Boolean Also known as: poll?
The Poll bit of the BFD packet. This is specified in section 4.1 of RFC5880
Corresponds to the JSON property poll
4206 4207 4208 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4206 def poll @poll end |
#state ⇒ String
The current BFD session state as seen by the transmitting system. These states
are specified in section 4.1 of RFC5880
Corresponds to the JSON property state
4213 4214 4215 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4213 def state @state end |
#version ⇒ Fixnum
The version number of the BFD protocol, as specified in section 4.1 of RFC5880.
Corresponds to the JSON property version
4218 4219 4220 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4218 def version @version end |
#your_discriminator ⇒ Fixnum
The Your Discriminator value in the BFD packet. This is specified in section 4.
1 of RFC5880
Corresponds to the JSON property yourDiscriminator
4224 4225 4226 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4224 def your_discriminator @your_discriminator end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 |
# File 'lib/google/apis/compute_v1/classes.rb', line 4231 def update!(**args) @authentication_present = args[:authentication_present] if args.key?(:authentication_present) @control_plane_independent = args[:control_plane_independent] if args.key?(:control_plane_independent) @demand = args[:demand] if args.key?(:demand) @diagnostic = args[:diagnostic] if args.key?(:diagnostic) @final = args[:final] if args.key?(:final) @length = args[:length] if args.key?(:length) @min_echo_rx_interval_ms = args[:min_echo_rx_interval_ms] if args.key?(:min_echo_rx_interval_ms) @min_rx_interval_ms = args[:min_rx_interval_ms] if args.key?(:min_rx_interval_ms) @min_tx_interval_ms = args[:min_tx_interval_ms] if args.key?(:min_tx_interval_ms) @multiplier = args[:multiplier] if args.key?(:multiplier) @multipoint = args[:multipoint] if args.key?(:multipoint) @my_discriminator = args[:my_discriminator] if args.key?(:my_discriminator) @poll = args[:poll] if args.key?(:poll) @state = args[:state] if args.key?(:state) @version = args[:version] if args.key?(:version) @your_discriminator = args[:your_discriminator] if args.key?(:your_discriminator) end |