Class: Google::Apis::ComputeV1::BfdStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Next free: 15

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdStatus

Returns a new instance of BfdStatus.



6745
6746
6747
# File 'lib/google/apis/compute_v1/classes.rb', line 6745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bfd_session_initialization_modeString

The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. Corresponds to the JSON property bfdSessionInitializationMode

Returns:

  • (String)


6694
6695
6696
# File 'lib/google/apis/compute_v1/classes.rb', line 6694

def bfd_session_initialization_mode
  @bfd_session_initialization_mode
end

#config_update_timestamp_microsFixnum

Unix timestamp of the most recent config update. Corresponds to the JSON property configUpdateTimestampMicros

Returns:

  • (Fixnum)


6699
6700
6701
# File 'lib/google/apis/compute_v1/classes.rb', line 6699

def config_update_timestamp_micros
  @config_update_timestamp_micros
end

#control_packet_countsGoogle::Apis::ComputeV1::BfdStatusPacketCounts

Control packet counts for the current BFD session. Corresponds to the JSON property controlPacketCounts



6704
6705
6706
# File 'lib/google/apis/compute_v1/classes.rb', line 6704

def control_packet_counts
  @control_packet_counts
end

#control_packet_intervalsArray<Google::Apis::ComputeV1::PacketIntervals>

Inter-packet time interval statistics for control packets. Corresponds to the JSON property controlPacketIntervals



6709
6710
6711
# File 'lib/google/apis/compute_v1/classes.rb', line 6709

def control_packet_intervals
  @control_packet_intervals
end

#local_diagnosticString

The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Corresponds to the JSON property localDiagnostic

Returns:

  • (String)


6717
6718
6719
# File 'lib/google/apis/compute_v1/classes.rb', line 6717

def local_diagnostic
  @local_diagnostic
end

#local_stateString

The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Corresponds to the JSON property localState

Returns:

  • (String)


6723
6724
6725
# File 'lib/google/apis/compute_v1/classes.rb', line 6723

def local_state
  @local_state
end

#negotiated_local_control_tx_interval_msFixnum

Negotiated transmit interval for control packets. Corresponds to the JSON property negotiatedLocalControlTxIntervalMs

Returns:

  • (Fixnum)


6728
6729
6730
# File 'lib/google/apis/compute_v1/classes.rb', line 6728

def negotiated_local_control_tx_interval_ms
  @negotiated_local_control_tx_interval_ms
end

#rx_packetGoogle::Apis::ComputeV1::BfdPacket

The most recent Rx control packet for this BFD session. Corresponds to the JSON property rxPacket



6733
6734
6735
# File 'lib/google/apis/compute_v1/classes.rb', line 6733

def rx_packet
  @rx_packet
end

#tx_packetGoogle::Apis::ComputeV1::BfdPacket

The most recent Tx control packet for this BFD session. Corresponds to the JSON property txPacket



6738
6739
6740
# File 'lib/google/apis/compute_v1/classes.rb', line 6738

def tx_packet
  @tx_packet
end

#uptime_msFixnum

Session uptime in milliseconds. Value will be 0 if session is not up. Corresponds to the JSON property uptimeMs

Returns:

  • (Fixnum)


6743
6744
6745
# File 'lib/google/apis/compute_v1/classes.rb', line 6743

def uptime_ms
  @uptime_ms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6750
6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
# File 'lib/google/apis/compute_v1/classes.rb', line 6750

def update!(**args)
  @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode)
  @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros)
  @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts)
  @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals)
  @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic)
  @local_state = args[:local_state] if args.key?(:local_state)
  @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms)
  @rx_packet = args[:rx_packet] if args.key?(:rx_packet)
  @tx_packet = args[:tx_packet] if args.key?(:tx_packet)
  @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms)
end