Class: Google::Apis::ComputeV1::BfdStatusPacketCounts
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BfdStatusPacketCounts
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#num_rx ⇒ Fixnum
Number of packets received since the beginning of the current BFD session.
-
#num_rx_rejected ⇒ Fixnum
Number of packets received that were rejected because of errors since the beginning of the current BFD session.
-
#num_rx_successful ⇒ Fixnum
Number of packets received that were successfully processed since the beginning of the current BFD session.
-
#num_tx ⇒ Fixnum
Number of packets transmitted since the beginning of the current BFD session.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatusPacketCounts
constructor
A new instance of BfdStatusPacketCounts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatusPacketCounts
Returns a new instance of BfdStatusPacketCounts.
6745 6746 6747 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6745 def initialize(**args) update!(**args) end |
Instance Attribute Details
#num_rx ⇒ Fixnum
Number of packets received since the beginning of the current BFD
session.
Corresponds to the JSON property numRx
6725 6726 6727 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6725 def num_rx @num_rx end |
#num_rx_rejected ⇒ Fixnum
Number of packets received that were rejected because of errors since the
beginning of the current BFD session.
Corresponds to the JSON property numRxRejected
6731 6732 6733 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6731 def num_rx_rejected @num_rx_rejected end |
#num_rx_successful ⇒ Fixnum
Number of packets received that were successfully processed since the
beginning of the current BFD session.
Corresponds to the JSON property numRxSuccessful
6737 6738 6739 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6737 def num_rx_successful @num_rx_successful end |
#num_tx ⇒ Fixnum
Number of packets transmitted since the beginning of the current BFD
session.
Corresponds to the JSON property numTx
6743 6744 6745 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6743 def num_tx @num_tx end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6750 6751 6752 6753 6754 6755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6750 def update!(**args) @num_rx = args[:num_rx] if args.key?(:num_rx) @num_rx_rejected = args[:num_rx_rejected] if args.key?(:num_rx_rejected) @num_rx_successful = args[:num_rx_successful] if args.key?(:num_rx_successful) @num_tx = args[:num_tx] if args.key?(:num_tx) end |