Class: Google::Apis::ComputeV1::BfdStatusPacketCounts
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BfdStatusPacketCounts
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#num_rx ⇒ Fixnum
Number of packets received since the beginning of the current BFD session.
-
#num_rx_rejected ⇒ Fixnum
Number of packets received that were rejected because of errors since the beginning of the current BFD session.
-
#num_rx_successful ⇒ Fixnum
Number of packets received that were successfully processed since the beginning of the current BFD session.
-
#num_tx ⇒ Fixnum
Number of packets transmitted since the beginning of the current BFD session.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatusPacketCounts
constructor
A new instance of BfdStatusPacketCounts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatusPacketCounts
Returns a new instance of BfdStatusPacketCounts.
6705 6706 6707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#num_rx ⇒ Fixnum
Number of packets received since the beginning of the current BFD
session.
Corresponds to the JSON property numRx
6685 6686 6687 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6685 def num_rx @num_rx end |
#num_rx_rejected ⇒ Fixnum
Number of packets received that were rejected because of errors since the
beginning of the current BFD session.
Corresponds to the JSON property numRxRejected
6691 6692 6693 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6691 def num_rx_rejected @num_rx_rejected end |
#num_rx_successful ⇒ Fixnum
Number of packets received that were successfully processed since the
beginning of the current BFD session.
Corresponds to the JSON property numRxSuccessful
6697 6698 6699 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6697 def num_rx_successful @num_rx_successful end |
#num_tx ⇒ Fixnum
Number of packets transmitted since the beginning of the current BFD
session.
Corresponds to the JSON property numTx
6703 6704 6705 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6703 def num_tx @num_tx end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6710 6711 6712 6713 6714 6715 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6710 def update!(**args) @num_rx = args[:num_rx] if args.key?(:num_rx) @num_rx_rejected = args[:num_rx_rejected] if args.key?(:num_rx_rejected) @num_rx_successful = args[:num_rx_successful] if args.key?(:num_rx_successful) @num_tx = args[:num_tx] if args.key?(:num_tx) end |