Class: Google::Apis::ComputeV1::BfdStatusPacketCounts

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdStatusPacketCounts

Returns a new instance of BfdStatusPacketCounts.



6710
6711
6712
# File 'lib/google/apis/compute_v1/classes.rb', line 6710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#num_rxFixnum

Number of packets received since the beginning of the current BFD session. Corresponds to the JSON property numRx

Returns:

  • (Fixnum)


6690
6691
6692
# File 'lib/google/apis/compute_v1/classes.rb', line 6690

def num_rx
  @num_rx
end

#num_rx_rejectedFixnum

Number of packets received that were rejected because of errors since the beginning of the current BFD session. Corresponds to the JSON property numRxRejected

Returns:

  • (Fixnum)


6696
6697
6698
# File 'lib/google/apis/compute_v1/classes.rb', line 6696

def num_rx_rejected
  @num_rx_rejected
end

#num_rx_successfulFixnum

Number of packets received that were successfully processed since the beginning of the current BFD session. Corresponds to the JSON property numRxSuccessful

Returns:

  • (Fixnum)


6702
6703
6704
# File 'lib/google/apis/compute_v1/classes.rb', line 6702

def num_rx_successful
  @num_rx_successful
end

#num_txFixnum

Number of packets transmitted since the beginning of the current BFD session. Corresponds to the JSON property numTx

Returns:

  • (Fixnum)


6708
6709
6710
# File 'lib/google/apis/compute_v1/classes.rb', line 6708

def num_tx
  @num_tx
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6715
6716
6717
6718
6719
6720
# File 'lib/google/apis/compute_v1/classes.rb', line 6715

def update!(**args)
  @num_rx = args[:num_rx] if args.key?(:num_rx)
  @num_rx_rejected = args[:num_rx_rejected] if args.key?(:num_rx_rejected)
  @num_rx_successful = args[:num_rx_successful] if args.key?(:num_rx_successful)
  @num_tx = args[:num_tx] if args.key?(:num_tx)
end