Class: Google::Apis::ComputeV1::BfdStatusPacketCounts

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdStatusPacketCounts

Returns a new instance of BfdStatusPacketCounts.



4358
4359
4360
# File 'lib/google/apis/compute_v1/classes.rb', line 4358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#num_rxFixnum

Number of packets received since the beginning of the current BFD session. Corresponds to the JSON property numRx

Returns:

  • (Fixnum)


4339
4340
4341
# File 'lib/google/apis/compute_v1/classes.rb', line 4339

def num_rx
  @num_rx
end

#num_rx_rejectedFixnum

Number of packets received that were rejected because of errors since the beginning of the current BFD session. Corresponds to the JSON property numRxRejected

Returns:

  • (Fixnum)


4345
4346
4347
# File 'lib/google/apis/compute_v1/classes.rb', line 4345

def num_rx_rejected
  @num_rx_rejected
end

#num_rx_successfulFixnum

Number of packets received that were successfully processed since the beginning of the current BFD session. Corresponds to the JSON property numRxSuccessful

Returns:

  • (Fixnum)


4351
4352
4353
# File 'lib/google/apis/compute_v1/classes.rb', line 4351

def num_rx_successful
  @num_rx_successful
end

#num_txFixnum

Number of packets transmitted since the beginning of the current BFD session. Corresponds to the JSON property numTx

Returns:

  • (Fixnum)


4356
4357
4358
# File 'lib/google/apis/compute_v1/classes.rb', line 4356

def num_tx
  @num_tx
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4363
4364
4365
4366
4367
4368
# File 'lib/google/apis/compute_v1/classes.rb', line 4363

def update!(**args)
  @num_rx = args[:num_rx] if args.key?(:num_rx)
  @num_rx_rejected = args[:num_rx_rejected] if args.key?(:num_rx_rejected)
  @num_rx_successful = args[:num_rx_successful] if args.key?(:num_rx_successful)
  @num_tx = args[:num_tx] if args.key?(:num_tx)
end