Class: Google::Apis::ComputeV1::BulkSetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::BulkSetLabelsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#label_fingerprint ⇒ String
The fingerprint of the previous set of labels for this resource, used to detect conflicts.
-
#labels ⇒ Hash<String,String>
The labels to set for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkSetLabelsRequest
constructor
A new instance of BulkSetLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkSetLabelsRequest
Returns a new instance of BulkSetLabelsRequest.
7200 7201 7202 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#label_fingerprint ⇒ String
The fingerprint of the previous set of labels for this resource,
used to detect conflicts. The fingerprint is initially generated by Compute
Engine and changes after every request to modify or update labels. You may
optionally provide an up-to-date fingerprint hash in order to update or
change labels. Make a get() request to the resource to get the
latest fingerprint.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
7193 7194 7195 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7193 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
The labels to set for this resource.
Corresponds to the JSON property labels
7198 7199 7200 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7198 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7205 7206 7207 7208 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7205 def update!(**args) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) end |