Class: Google::Apis::ComputeV1::CacheInvalidationRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CacheInvalidationRule

Returns a new instance of CacheInvalidationRule.



6873
6874
6875
# File 'lib/google/apis/compute_v1/classes.rb', line 6873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_tagsArray<String>

A list of cache tags used to identify cached objects.

  • Cache tags are specified when the response is first cached, by setting the Cache-Tag response header at the origin.
  • Multiple cache tags in the same invalidation request are treated as Boolean OR - for example, tag1 OR tag2 OR tag3.
  • If other fields are also specified, these are treated as Boolean AND with any tags. Up to 10 tags can be specified in a single invalidation request. Corresponds to the JSON property cacheTags

Returns:

  • (Array<String>)


6860
6861
6862
# File 'lib/google/apis/compute_v1/classes.rb', line 6860

def cache_tags
  @cache_tags
end

#hostString

If set, this invalidation rule will only apply to requests with a Host header matching host. Corresponds to the JSON property host

Returns:

  • (String)


6866
6867
6868
# File 'lib/google/apis/compute_v1/classes.rb', line 6866

def host
  @host
end

#pathString

Corresponds to the JSON property path

Returns:

  • (String)


6871
6872
6873
# File 'lib/google/apis/compute_v1/classes.rb', line 6871

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6878
6879
6880
6881
6882
# File 'lib/google/apis/compute_v1/classes.rb', line 6878

def update!(**args)
  @cache_tags = args[:cache_tags] if args.key?(:cache_tags)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end