Class: Google::Apis::ComputeV1::CacheInvalidationRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CacheInvalidationRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#cache_tags ⇒ Array<String>
A list of cache tags used to identify cached objects.
-
#host ⇒ String
If set, this invalidation rule will only apply to requests with a Host header matching host.
-
#path ⇒ String
Corresponds to the JSON property
path.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CacheInvalidationRule
constructor
A new instance of CacheInvalidationRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CacheInvalidationRule
Returns a new instance of CacheInvalidationRule.
6787 6788 6789 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_tags ⇒ Array<String>
A list of cache tags used to identify cached objects.
- Cache tags are specified when the response is first cached, by setting
the
Cache-Tagresponse header at the origin. - Multiple cache tags in the same invalidation request are treated as
Boolean
OR- for example,tag1 OR tag2 OR tag3. - If other fields are also specified, these are treated as Boolean
ANDwith any tags. Up to 10 tags can be specified in a single invalidation request. Corresponds to the JSON propertycacheTags
6774 6775 6776 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6774 def @cache_tags end |
#host ⇒ String
If set, this invalidation rule will only apply to requests with a Host
header matching host.
Corresponds to the JSON property host
6780 6781 6782 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6780 def host @host end |
#path ⇒ String
Corresponds to the JSON property path
6785 6786 6787 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6785 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6792 6793 6794 6795 6796 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6792 def update!(**args) @cache_tags = args[:cache_tags] if args.key?(:cache_tags) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) end |