Class: Google::Apis::ComputeV1::CacheKeyPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Message containing what to include in the cache key for a request for Cloud CDN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CacheKeyPolicy

Returns a new instance of CacheKeyPolicy.



6852
6853
6854
# File 'lib/google/apis/compute_v1/classes.rb', line 6852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_hostBoolean Also known as: include_host?

If true, requests to different hosts will be cached separately. Corresponds to the JSON property includeHost

Returns:

  • (Boolean)


6807
6808
6809
# File 'lib/google/apis/compute_v1/classes.rb', line 6807

def include_host
  @include_host
end

#include_http_headersArray<String>

Allows HTTP request headers (by name) to be used in the cache key. Corresponds to the JSON property includeHttpHeaders

Returns:

  • (Array<String>)


6813
6814
6815
# File 'lib/google/apis/compute_v1/classes.rb', line 6813

def include_http_headers
  @include_http_headers
end

#include_named_cookiesArray<String>

Allows HTTP cookies (by name) to be used in the cache key. The name=value pair will be used in the cache key Cloud CDN generates. Corresponds to the JSON property includeNamedCookies

Returns:

  • (Array<String>)


6819
6820
6821
# File 'lib/google/apis/compute_v1/classes.rb', line 6819

def include_named_cookies
  @include_named_cookies
end

#include_protocolBoolean Also known as: include_protocol?

If true, http and https requests will be cached separately. Corresponds to the JSON property includeProtocol

Returns:

  • (Boolean)


6824
6825
6826
# File 'lib/google/apis/compute_v1/classes.rb', line 6824

def include_protocol
  @include_protocol
end

#include_query_stringBoolean Also known as: include_query_string?

If true, include query string parameters in the cache key according to query_string_whitelist and query_string_blacklist. If neither is set, the entire query string will be included. If false, the query string will be excluded from the cache key entirely. Corresponds to the JSON property includeQueryString

Returns:

  • (Boolean)


6833
6834
6835
# File 'lib/google/apis/compute_v1/classes.rb', line 6833

def include_query_string
  @include_query_string
end

#query_string_blacklistArray<String>

Names of query string parameters to exclude in cache keys. All other parameters will be included. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters. Corresponds to the JSON property queryStringBlacklist

Returns:

  • (Array<String>)


6842
6843
6844
# File 'lib/google/apis/compute_v1/classes.rb', line 6842

def query_string_blacklist
  @query_string_blacklist
end

#query_string_whitelistArray<String>

Names of query string parameters to include in cache keys. All other parameters will be excluded. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters. Corresponds to the JSON property queryStringWhitelist

Returns:

  • (Array<String>)


6850
6851
6852
# File 'lib/google/apis/compute_v1/classes.rb', line 6850

def query_string_whitelist
  @query_string_whitelist
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6857
6858
6859
6860
6861
6862
6863
6864
6865
# File 'lib/google/apis/compute_v1/classes.rb', line 6857

def update!(**args)
  @include_host = args[:include_host] if args.key?(:include_host)
  @include_http_headers = args[:include_http_headers] if args.key?(:include_http_headers)
  @include_named_cookies = args[:include_named_cookies] if args.key?(:include_named_cookies)
  @include_protocol = args[:include_protocol] if args.key?(:include_protocol)
  @include_query_string = args[:include_query_string] if args.key?(:include_query_string)
  @query_string_blacklist = args[:query_string_blacklist] if args.key?(:query_string_blacklist)
  @query_string_whitelist = args[:query_string_whitelist] if args.key?(:query_string_whitelist)
end