Class: Google::Apis::ComputeV1::CachePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Message containing CachePolicy configuration for URL Map's Route Action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CachePolicy

Returns a new instance of CachePolicy.



7460
7461
7462
# File 'lib/google/apis/compute_v1/classes.rb', line 7460

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_bypass_request_header_namesArray<String>

Bypass the cache when the specified request headers are matched by name, e.g. Pragma or Authorization headers. Values are case-insensitive. Up to 5 header names can be specified. The cache is bypassed for all cacheMode values. Corresponds to the JSON property cacheBypassRequestHeaderNames

Returns:

  • (Array<String>)


7374
7375
7376
# File 'lib/google/apis/compute_v1/classes.rb', line 7374

def cache_bypass_request_header_names
  @cache_bypass_request_header_names
end

#cache_key_policyGoogle::Apis::ComputeV1::CachePolicyCacheKeyPolicy

Message containing what to include in the cache key for a request for Cache Policy defined on Route Action. Corresponds to the JSON property cacheKeyPolicy



7380
7381
7382
# File 'lib/google/apis/compute_v1/classes.rb', line 7380

def cache_key_policy
  @cache_key_policy
end

#cache_modeString

Specifies the cache setting for all responses from this route. If not specified, Cloud CDN uses CACHE_ALL_STATIC mode. Corresponds to the JSON property cacheMode

Returns:

  • (String)


7386
7387
7388
# File 'lib/google/apis/compute_v1/classes.rb', line 7386

def cache_mode
  @cache_mode
end

#client_ttlGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property clientTtl



7394
7395
7396
# File 'lib/google/apis/compute_v1/classes.rb', line 7394

def client_ttl
  @client_ttl
end

#default_ttlGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property defaultTtl



7402
7403
7404
# File 'lib/google/apis/compute_v1/classes.rb', line 7402

def default_ttl
  @default_ttl
end

#max_ttlGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxTtl



7410
7411
7412
# File 'lib/google/apis/compute_v1/classes.rb', line 7410

def max_ttl
  @max_ttl
end

#negative_cachingBoolean Also known as: negative_caching?

Negative caching allows per-status code TTLs to be set, in order to apply fine-grained caching for common errors or redirects. This can reduce the load on your origin and improve end-user experience by reducing response latency. When the cacheMode is set to CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, negative caching applies to responses with the specified response code that lack any Cache-Control, Expires, or Pragma: no-cache directives. When the cacheMode is set to FORCE_CACHE_ALL, negative caching applies to all responses with the specified response code, and overrides any caching headers. By default, Cloud CDN applies the following TTLs to these HTTP status codes:

  • 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m
  • 404 (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s
  • 405 (Method Not Found), 501 (Not Implemented): 60s These defaults can be overridden in negativeCachingPolicy. If not specified, Cloud CDN applies negative caching by default. Corresponds to the JSON property negativeCaching

Returns:

  • (Boolean)


7430
7431
7432
# File 'lib/google/apis/compute_v1/classes.rb', line 7430

def negative_caching
  @negative_caching
end

#negative_caching_policyArray<Google::Apis::ComputeV1::CachePolicyNegativeCachingPolicy>

Sets a cache TTL for the specified HTTP status code. negativeCaching must be enabled to configure negativeCachingPolicy. Omitting the policy and leaving negativeCaching enabled will use Cloud CDN's default cache TTLs. Note that when specifying an explicit negativeCachingPolicy, you should take care to specify a cache TTL for all response codes that you wish to cache. Cloud CDN will not apply any default negative caching when a policy exists. Corresponds to the JSON property negativeCachingPolicy



7442
7443
7444
# File 'lib/google/apis/compute_v1/classes.rb', line 7442

def negative_caching_policy
  @negative_caching_policy
end

#request_coalescingBoolean Also known as: request_coalescing?

If true then Cloud CDN will combine multiple concurrent cache fill requests into a small number of requests to the origin. If not specified, Cloud CDN applies request coalescing by default. Corresponds to the JSON property requestCoalescing

Returns:

  • (Boolean)


7449
7450
7451
# File 'lib/google/apis/compute_v1/classes.rb', line 7449

def request_coalescing
  @request_coalescing
end

#serve_while_staleGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property serveWhileStale



7458
7459
7460
# File 'lib/google/apis/compute_v1/classes.rb', line 7458

def serve_while_stale
  @serve_while_stale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7465
7466
7467
7468
7469
7470
7471
7472
7473
7474
7475
7476
# File 'lib/google/apis/compute_v1/classes.rb', line 7465

def update!(**args)
  @cache_bypass_request_header_names = args[:cache_bypass_request_header_names] if args.key?(:cache_bypass_request_header_names)
  @cache_key_policy = args[:cache_key_policy] if args.key?(:cache_key_policy)
  @cache_mode = args[:cache_mode] if args.key?(:cache_mode)
  @client_ttl = args[:client_ttl] if args.key?(:client_ttl)
  @default_ttl = args[:default_ttl] if args.key?(:default_ttl)
  @max_ttl = args[:max_ttl] if args.key?(:max_ttl)
  @negative_caching = args[:negative_caching] if args.key?(:negative_caching)
  @negative_caching_policy = args[:negative_caching_policy] if args.key?(:negative_caching_policy)
  @request_coalescing = args[:request_coalescing] if args.key?(:request_coalescing)
  @serve_while_stale = args[:serve_while_stale] if args.key?(:serve_while_stale)
end