Class: Google::Apis::ComputeV1::CachePolicyNegativeCachingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CachePolicyNegativeCachingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specify CDN TTLs for response error codes.
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
The HTTP status code to define a TTL against.
-
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CachePolicyNegativeCachingPolicy
constructor
A new instance of CachePolicyNegativeCachingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CachePolicyNegativeCachingPolicy
Returns a new instance of CachePolicyNegativeCachingPolicy.
7607 7608 7609 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
The HTTP status code to define a TTL against. Only HTTP status codes
300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 can be
specified as values, and you cannot specify a status code more than
once.
Corresponds to the JSON property code
7597 7598 7599 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7597 def code @code end |
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property ttl
7605 7606 7607 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7605 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7612 7613 7614 7615 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7612 def update!(**args) @code = args[:code] if args.key?(:code) @ttl = args[:ttl] if args.key?(:ttl) end |