Class: Google::Apis::ComputeV1::CalendarModeAdviceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A request to recommend the best way to consume the specified resources in the future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeAdviceRequest

Returns a new instance of CalendarModeAdviceRequest.



6881
6882
6883
# File 'lib/google/apis/compute_v1/classes.rb', line 6881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#future_resources_specsHash<String,Google::Apis::ComputeV1::FutureResourcesSpec>

Specification of resources to create in the future. The key of the map is an arbitrary string specified by the caller. Value of the map is a specification of required resources and their constraints. Currently only one value is allowed in this map. Corresponds to the JSON property futureResourcesSpecs



6879
6880
6881
# File 'lib/google/apis/compute_v1/classes.rb', line 6879

def future_resources_specs
  @future_resources_specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6886
6887
6888
# File 'lib/google/apis/compute_v1/classes.rb', line 6886

def update!(**args)
  @future_resources_specs = args[:future_resources_specs] if args.key?(:future_resources_specs)
end