Class: Google::Apis::ComputeV1::CalendarModeAdviceResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A response containing the recommended way of creating the specified resources in the future. It contains (will contain) multiple recommendations that can be analyzed by the customer and the best one can be picked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeAdviceResponse

Returns a new instance of CalendarModeAdviceResponse.



7653
7654
7655
# File 'lib/google/apis/compute_v1/classes.rb', line 7653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#recommendationsArray<Google::Apis::ComputeV1::CalendarModeRecommendation>

Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost. Corresponds to the JSON property recommendations



7651
7652
7653
# File 'lib/google/apis/compute_v1/classes.rb', line 7651

def recommendations
  @recommendations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7658
7659
7660
# File 'lib/google/apis/compute_v1/classes.rb', line 7658

def update!(**args)
  @recommendations = args[:recommendations] if args.key?(:recommendations)
end