Class: Google::Apis::ComputeV1::CalendarModeAdviceResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CalendarModeAdviceResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A response containing the recommended way of creating the specified resources in the future. It contains (will contain) multiple recommendations that can be analyzed by the customer and the best one can be picked.
Instance Attribute Summary collapse
-
#recommendations ⇒ Array<Google::Apis::ComputeV1::CalendarModeRecommendation>
Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CalendarModeAdviceResponse
constructor
A new instance of CalendarModeAdviceResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CalendarModeAdviceResponse
Returns a new instance of CalendarModeAdviceResponse.
7622 7623 7624 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7622 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recommendations ⇒ Array<Google::Apis::ComputeV1::CalendarModeRecommendation>
Recommendations where, how and when to create the requested resources
in order to maximize their obtainability and minimize cost.
Corresponds to the JSON property recommendations
7620 7621 7622 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7620 def recommendations @recommendations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7627 7628 7629 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7627 def update!(**args) @recommendations = args[:recommendations] if args.key?(:recommendations) end |