Class: Google::Apis::ComputeV1::CalendarModeAdviceResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A response containing the recommended way of creating the specified resources in the future. It contains (will contain) multiple recommendations that can be analyzed by the customer and the best one can be picked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeAdviceResponse

Returns a new instance of CalendarModeAdviceResponse.



6903
6904
6905
# File 'lib/google/apis/compute_v1/classes.rb', line 6903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#recommendationsArray<Google::Apis::ComputeV1::CalendarModeRecommendation>

Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost. Corresponds to the JSON property recommendations



6901
6902
6903
# File 'lib/google/apis/compute_v1/classes.rb', line 6901

def recommendations
  @recommendations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6908
6909
6910
# File 'lib/google/apis/compute_v1/classes.rb', line 6908

def update!(**args)
  @recommendations = args[:recommendations] if args.key?(:recommendations)
end