Class: Google::Apis::ComputeV1::Commitment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a regional resource-based commitment resource. Creating this commitment resource means that you are purchasing a resource-based committed use contract, with an explicit start and end time. You can purchase resource-based commitments for both hardware and software resources. For more information, read Resource-based committed use discounts

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Commitment

Returns a new instance of Commitment.



7274
7275
7276
# File 'lib/google/apis/compute_v1/classes.rb', line 7274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_renewBoolean Also known as: auto_renew?

Specifies whether to automatically renew the commitment at the end of its current term. The default value is false. If you set the field to true, each time your commitment reaches the end of its term, Compute Engine automatically renews it for another term. You can update this field anytime before the commitment expires. For example, if the commitment is set to expire at 12 AM UTC-8 on January 3, 2027, you can update this field until 11:59 PM UTC-8 on January 2, 2027. Corresponds to the JSON property autoRenew

Returns:

  • (Boolean)


7099
7100
7101
# File 'lib/google/apis/compute_v1/classes.rb', line 7099

def auto_renew
  @auto_renew
end

#categoryString

The category of the commitment; specifies whether the commitment is for hardware or software resources. Category MACHINE specifies that you are committing to hardware machine resources such asVCPU or MEMORY, listed in resources. Category LICENSE specifies that you are committing to software licenses, listed in licenseResources. Note that if you specify MACHINE commitments, then you must also specify a type to indicate the machine series of the hardware resource that you are committing to. Corresponds to the JSON property category

Returns:

  • (String)


7113
7114
7115
# File 'lib/google/apis/compute_v1/classes.rb', line 7113

def category
  @category
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


7119
7120
7121
# File 'lib/google/apis/compute_v1/classes.rb', line 7119

def creation_timestamp
  @creation_timestamp
end

#custom_end_timestampString

[Input Only] Optional, specifies the requested commitment end time inRFC3339 text format. Use this option when the desired commitment's end date is later than the start date + term duration. Corresponds to the JSON property customEndTimestamp

Returns:

  • (String)


7126
7127
7128
# File 'lib/google/apis/compute_v1/classes.rb', line 7126

def custom_end_timestamp
  @custom_end_timestamp
end

#descriptionString

An optional description of the commitment. You can provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


7132
7133
7134
# File 'lib/google/apis/compute_v1/classes.rb', line 7132

def description
  @description
end

#end_timestampString

Output only. [Output Only] Commitment end time inRFC3339 text format. Corresponds to the JSON property endTimestamp

Returns:

  • (String)


7138
7139
7140
# File 'lib/google/apis/compute_v1/classes.rb', line 7138

def end_timestamp
  @end_timestamp
end

#existing_reservationsArray<String>

Corresponds to the JSON property existingReservations

Returns:

  • (Array<String>)


7143
7144
7145
# File 'lib/google/apis/compute_v1/classes.rb', line 7143

def existing_reservations
  @existing_reservations
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


7150
7151
7152
# File 'lib/google/apis/compute_v1/classes.rb', line 7150

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#commitment for commitments. Corresponds to the JSON property kind

Returns:

  • (String)


7156
7157
7158
# File 'lib/google/apis/compute_v1/classes.rb', line 7156

def kind
  @kind
end

#license_resourceGoogle::Apis::ComputeV1::LicenseResourceCommitment

Commitment for a particular license resource. Corresponds to the JSON property licenseResource



7161
7162
7163
# File 'lib/google/apis/compute_v1/classes.rb', line 7161

def license_resource
  @license_resource
end

#merge_source_commitmentsArray<String>

The list of source commitments that you are merging to create the new merged commitment. For more information, see Merging commitments. Corresponds to the JSON property mergeSourceCommitments

Returns:

  • (Array<String>)


7168
7169
7170
# File 'lib/google/apis/compute_v1/classes.rb', line 7168

def merge_source_commitments
  @merge_source_commitments
end

#nameString

Name of the commitment. You must specify a name when you purchase the commitment. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


7179
7180
7181
# File 'lib/google/apis/compute_v1/classes.rb', line 7179

def name
  @name
end

#planString

The minimum time duration that you commit to purchasing resources. The plan that you choose determines the preset term length of the commitment (which is 1 year or 3 years) and affects the discount rate that you receive for your resources. Committing to a longer time duration typically gives you a higher discount rate. The supported values for this field are TWELVE_MONTH (1 year), andTHIRTY_SIX_MONTH (3 years). Corresponds to the JSON property plan

Returns:

  • (String)


7189
7190
7191
# File 'lib/google/apis/compute_v1/classes.rb', line 7189

def plan
  @plan
end

#regionString

Output only. [Output Only] URL of the region where the commitment and committed resources are located. Corresponds to the JSON property region

Returns:

  • (String)


7196
7197
7198
# File 'lib/google/apis/compute_v1/classes.rb', line 7196

def region
  @region
end

#reservationsArray<Google::Apis::ComputeV1::Reservation>

The list of new reservations that you want to create and attach to this commitment. You must attach reservations to your commitment if your commitment specifies any GPUs or Local SSD disks. For more information, see Attach reservations to resource-based commitments. Specify this property only if you want to create new reservations to attach. To attach existing reservations, specify theexistingReservations property instead. Corresponds to the JSON property reservations



7208
7209
7210
# File 'lib/google/apis/compute_v1/classes.rb', line 7208

def reservations
  @reservations
end

#resource_statusGoogle::Apis::ComputeV1::CommitmentResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property resourceStatus



7213
7214
7215
# File 'lib/google/apis/compute_v1/classes.rb', line 7213

def resource_status
  @resource_status
end

#resourcesArray<Google::Apis::ComputeV1::ResourceCommitment>

The list of all the hardware resources, with their types and amounts, that you want to commit to. Specify as a separate entry in the list for each individual resource type. Corresponds to the JSON property resources



7220
7221
7222
# File 'lib/google/apis/compute_v1/classes.rb', line 7220

def resources
  @resources
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


7225
7226
7227
# File 'lib/google/apis/compute_v1/classes.rb', line 7225

def self_link
  @self_link
end

#split_source_commitmentString

The source commitment from which you are transferring resources to create the new split commitment. For more information, see Split commitments. Corresponds to the JSON property splitSourceCommitment

Returns:

  • (String)


7232
7233
7234
# File 'lib/google/apis/compute_v1/classes.rb', line 7232

def split_source_commitment
  @split_source_commitment
end

#start_timestampString

Output only. [Output Only] Commitment start time inRFC3339 text format. Corresponds to the JSON property startTimestamp

Returns:

  • (String)


7238
7239
7240
# File 'lib/google/apis/compute_v1/classes.rb', line 7238

def start_timestamp
  @start_timestamp
end

#statusString

Output only. [Output Only] Status of the commitment with regards to eventual expiration (each commitment has an end date defined). Status can be one of the following values: NOT_YET_ACTIVE, ACTIVE, orEXPIRED. Corresponds to the JSON property status

Returns:

  • (String)


7246
7247
7248
# File 'lib/google/apis/compute_v1/classes.rb', line 7246

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


7252
7253
7254
# File 'lib/google/apis/compute_v1/classes.rb', line 7252

def status_message
  @status_message
end

#typeString

The type of commitment; specifies the machine series for which you want to commit to purchasing resources. The choice of machine series affects the discount rate and the eligible resource types. The type must be one of the following:ACCELERATOR_OPTIMIZED, ACCELERATOR_OPTIMIZED_A3,ACCELERATOR_OPTIMIZED_A3_MEGA,COMPUTE_OPTIMIZED, COMPUTE_OPTIMIZED_C2D, COMPUTE_OPTIMIZED_C3, COMPUTE_OPTIMIZED_C3D,COMPUTE_OPTIMIZED_H3, GENERAL_PURPOSE,GENERAL_PURPOSE_C4, GENERAL_PURPOSE_E2,GENERAL_PURPOSE_N2, GENERAL_PURPOSE_N2D,GENERAL_PURPOSE_N4, GENERAL_PURPOSE_T2D,GRAPHICS_OPTIMIZED, GRAPHICS_OPTIMIZED_G4,MEMORY_OPTIMIZED, MEMORY_OPTIMIZED_M3, MEMORY_OPTIMIZED_X4, STORAGE_OPTIMIZED_Z3. For example, type MEMORY_OPTIMIZED specifies a commitment that applies only to eligible resources of memory optimized M1 and M2 machine series. Type GENERAL_PURPOSE specifies a commitment that applies only to eligible resources of general purpose N1 machine series. Corresponds to the JSON property type

Returns:

  • (String)


7272
7273
7274
# File 'lib/google/apis/compute_v1/classes.rb', line 7272

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7279
7280
7281
7282
7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
7298
7299
7300
7301
7302
7303
# File 'lib/google/apis/compute_v1/classes.rb', line 7279

def update!(**args)
  @auto_renew = args[:auto_renew] if args.key?(:auto_renew)
  @category = args[:category] if args.key?(:category)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @custom_end_timestamp = args[:custom_end_timestamp] if args.key?(:custom_end_timestamp)
  @description = args[:description] if args.key?(:description)
  @end_timestamp = args[:end_timestamp] if args.key?(:end_timestamp)
  @existing_reservations = args[:existing_reservations] if args.key?(:existing_reservations)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @license_resource = args[:license_resource] if args.key?(:license_resource)
  @merge_source_commitments = args[:merge_source_commitments] if args.key?(:merge_source_commitments)
  @name = args[:name] if args.key?(:name)
  @plan = args[:plan] if args.key?(:plan)
  @region = args[:region] if args.key?(:region)
  @reservations = args[:reservations] if args.key?(:reservations)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @resources = args[:resources] if args.key?(:resources)
  @self_link = args[:self_link] if args.key?(:self_link)
  @split_source_commitment = args[:split_source_commitment] if args.key?(:split_source_commitment)
  @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @type = args[:type] if args.key?(:type)
end