Class: Google::Apis::ComputeV1::Commitment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a regional Commitment resource. Creating a commitment resource means that you are purchasing a committed use contract with an explicit start and end time. You can create commitments based on vCPUs and memory usage and receive discounted rates. For full details, read Signing Up for Committed Use Discounts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Commitment

Returns a new instance of Commitment.



4823
4824
4825
# File 'lib/google/apis/compute_v1/classes.rb', line 4823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_renewBoolean Also known as: auto_renew?

Specifies whether to enable automatic renewal for the commitment. The default value is false if not specified. The field can be updated until the day of the commitment expiration at 12:00am PST. If the field is set to true, the commitment will be automatically renewed for either one or three years according to the terms of the existing commitment. Corresponds to the JSON property autoRenew

Returns:

  • (Boolean)


4716
4717
4718
# File 'lib/google/apis/compute_v1/classes.rb', line 4716

def auto_renew
  @auto_renew
end

#categoryString

The category of the commitment. Category MACHINE specifies commitments composed of machine resources such as VCPU or MEMORY, listed in resources. Category LICENSE specifies commitments composed of software licenses, listed in licenseResources. Note that only MACHINE commitments should have a Type specified. Corresponds to the JSON property category

Returns:

  • (String)


4726
4727
4728
# File 'lib/google/apis/compute_v1/classes.rb', line 4726

def category
  @category
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


4731
4732
4733
# File 'lib/google/apis/compute_v1/classes.rb', line 4731

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


4737
4738
4739
# File 'lib/google/apis/compute_v1/classes.rb', line 4737

def description
  @description
end

#end_timestampString

[Output Only] Commitment end time in RFC3339 text format. Corresponds to the JSON property endTimestamp

Returns:

  • (String)


4742
4743
4744
# File 'lib/google/apis/compute_v1/classes.rb', line 4742

def end_timestamp
  @end_timestamp
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


4748
4749
4750
# File 'lib/google/apis/compute_v1/classes.rb', line 4748

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#commitment for commitments. Corresponds to the JSON property kind

Returns:

  • (String)


4753
4754
4755
# File 'lib/google/apis/compute_v1/classes.rb', line 4753

def kind
  @kind
end

#license_resourceGoogle::Apis::ComputeV1::LicenseResourceCommitment

Commitment for a particular license resource. Corresponds to the JSON property licenseResource



4758
4759
4760
# File 'lib/google/apis/compute_v1/classes.rb', line 4758

def license_resource
  @license_resource
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


4768
4769
4770
# File 'lib/google/apis/compute_v1/classes.rb', line 4768

def name
  @name
end

#planString

The plan for this commitment, which determines duration and discount rate. The currently supported plans are TWELVE_MONTH (1 year), and THIRTY_SIX_MONTH (3 years). Corresponds to the JSON property plan

Returns:

  • (String)


4775
4776
4777
# File 'lib/google/apis/compute_v1/classes.rb', line 4775

def plan
  @plan
end

#regionString

[Output Only] URL of the region where this commitment may be used. Corresponds to the JSON property region

Returns:

  • (String)


4780
4781
4782
# File 'lib/google/apis/compute_v1/classes.rb', line 4780

def region
  @region
end

#reservationsArray<Google::Apis::ComputeV1::Reservation>

List of reservations in this commitment. Corresponds to the JSON property reservations



4785
4786
4787
# File 'lib/google/apis/compute_v1/classes.rb', line 4785

def reservations
  @reservations
end

#resourcesArray<Google::Apis::ComputeV1::ResourceCommitment>

A list of commitment amounts for particular resources. Note that VCPU and MEMORY resource commitments must occur together. Corresponds to the JSON property resources



4791
4792
4793
# File 'lib/google/apis/compute_v1/classes.rb', line 4791

def resources
  @resources
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4796
4797
4798
# File 'lib/google/apis/compute_v1/classes.rb', line 4796

def self_link
  @self_link
end

#start_timestampString

[Output Only] Commitment start time in RFC3339 text format. Corresponds to the JSON property startTimestamp

Returns:

  • (String)


4801
4802
4803
# File 'lib/google/apis/compute_v1/classes.rb', line 4801

def start_timestamp
  @start_timestamp
end

#statusString

[Output Only] Status of the commitment with regards to eventual expiration ( each commitment has an end date defined). One of the following values: NOT_YET_ACTIVE, ACTIVE, EXPIRED. Corresponds to the JSON property status

Returns:

  • (String)


4808
4809
4810
# File 'lib/google/apis/compute_v1/classes.rb', line 4808

def status
  @status
end

#status_messageString

[Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


4813
4814
4815
# File 'lib/google/apis/compute_v1/classes.rb', line 4813

def status_message
  @status_message
end

#typeString

The type of commitment, which affects the discount rate and the eligible resources. Type MEMORY_OPTIMIZED specifies a commitment that will only apply to memory optimized machines. Type ACCELERATOR_OPTIMIZED specifies a commitment that will only apply to accelerator optimized machines. Corresponds to the JSON property type

Returns:

  • (String)


4821
4822
4823
# File 'lib/google/apis/compute_v1/classes.rb', line 4821

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
# File 'lib/google/apis/compute_v1/classes.rb', line 4828

def update!(**args)
  @auto_renew = args[:auto_renew] if args.key?(:auto_renew)
  @category = args[:category] if args.key?(:category)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @end_timestamp = args[:end_timestamp] if args.key?(:end_timestamp)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @license_resource = args[:license_resource] if args.key?(:license_resource)
  @name = args[:name] if args.key?(:name)
  @plan = args[:plan] if args.key?(:plan)
  @region = args[:region] if args.key?(:region)
  @reservations = args[:reservations] if args.key?(:reservations)
  @resources = args[:resources] if args.key?(:resources)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @type = args[:type] if args.key?(:type)
end