Class: Google::Apis::ComputeV1::CommitmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CommitmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Commitment resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Commitment>
A list of Commitment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::CommitmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentList
constructor
A new instance of CommitmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentList
Returns a new instance of CommitmentList.
8210 8211 8212 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8177 8178 8179 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8177 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Commitment>
A list of Commitment resources.
Corresponds to the JSON property items
8182 8183 8184 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8182 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#commitmentList
for lists of commitments.
Corresponds to the JSON property kind
8188 8189 8190 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8188 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8198 8199 8200 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8198 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8203 8204 8205 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8203 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::CommitmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8208 8209 8210 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8208 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8215 8216 8217 8218 8219 8220 8221 8222 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8215 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |