Class: Google::Apis::ComputeV1::CommitmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CommitmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Commitment resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Commitment>
A list of Commitment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::CommitmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentList
constructor
A new instance of CommitmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentList
Returns a new instance of CommitmentList.
8157 8158 8159 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8124 8125 8126 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8124 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Commitment>
A list of Commitment resources.
Corresponds to the JSON property items
8129 8130 8131 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8129 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#commitmentList
for lists of commitments.
Corresponds to the JSON property kind
8135 8136 8137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8135 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8145 8146 8147 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8145 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8150 8151 8152 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8150 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::CommitmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8155 8156 8157 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8155 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8162 8163 8164 8165 8166 8167 8168 8169 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8162 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |