Class: Google::Apis::ComputeV1::CommitmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CommitmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Commitment resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Commitment>
A list of Commitment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::CommitmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentList
constructor
A new instance of CommitmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentList
Returns a new instance of CommitmentList.
8117 8118 8119 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8084 8085 8086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8084 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Commitment>
A list of Commitment resources.
Corresponds to the JSON property items
8089 8090 8091 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8089 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#commitmentList
for lists of commitments.
Corresponds to the JSON property kind
8095 8096 8097 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8095 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8105 8106 8107 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8105 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8110 8111 8112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8110 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::CommitmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8115 8116 8117 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8115 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8122 8123 8124 8125 8126 8127 8128 8129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8122 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |