Class: Google::Apis::ComputeV1::CommitmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Commitment resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentList

Returns a new instance of CommitmentList.



7478
7479
7480
# File 'lib/google/apis/compute_v1/classes.rb', line 7478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


7445
7446
7447
# File 'lib/google/apis/compute_v1/classes.rb', line 7445

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Commitment>

A list of Commitment resources. Corresponds to the JSON property items



7450
7451
7452
# File 'lib/google/apis/compute_v1/classes.rb', line 7450

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#commitmentList for lists of commitments. Corresponds to the JSON property kind

Returns:

  • (String)


7456
7457
7458
# File 'lib/google/apis/compute_v1/classes.rb', line 7456

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7466
7467
7468
# File 'lib/google/apis/compute_v1/classes.rb', line 7466

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


7471
7472
7473
# File 'lib/google/apis/compute_v1/classes.rb', line 7471

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::CommitmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



7476
7477
7478
# File 'lib/google/apis/compute_v1/classes.rb', line 7476

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7483
7484
7485
7486
7487
7488
7489
7490
# File 'lib/google/apis/compute_v1/classes.rb', line 7483

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end