Class: Google::Apis::ComputeV1::CommitmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CommitmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Commitment resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Commitment>
A list of Commitment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::CommitmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentList
constructor
A new instance of CommitmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentList
Returns a new instance of CommitmentList.
7392 7393 7394 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
7359 7360 7361 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7359 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Commitment>
A list of Commitment resources.
Corresponds to the JSON property items
7364 7365 7366 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7364 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#commitmentList
for lists of commitments.
Corresponds to the JSON property kind
7370 7371 7372 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7370 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
7380 7381 7382 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7380 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
7385 7386 7387 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7385 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::CommitmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
7390 7391 7392 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7390 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7397 7398 7399 7400 7401 7402 7403 7404 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7397 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |