Class: Google::Apis::ComputeV1::CommitmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Commitment resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentList

Returns a new instance of CommitmentList.



5013
5014
5015
# File 'lib/google/apis/compute_v1/classes.rb', line 5013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4981
4982
4983
# File 'lib/google/apis/compute_v1/classes.rb', line 4981

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Commitment>

A list of Commitment resources. Corresponds to the JSON property items



4986
4987
4988
# File 'lib/google/apis/compute_v1/classes.rb', line 4986

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#commitmentList for lists of commitments. Corresponds to the JSON property kind

Returns:

  • (String)


4992
4993
4994
# File 'lib/google/apis/compute_v1/classes.rb', line 4992

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5001
5002
5003
# File 'lib/google/apis/compute_v1/classes.rb', line 5001

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5006
5007
5008
# File 'lib/google/apis/compute_v1/classes.rb', line 5006

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::CommitmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



5011
5012
5013
# File 'lib/google/apis/compute_v1/classes.rb', line 5011

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5018
5019
5020
5021
5022
5023
5024
5025
# File 'lib/google/apis/compute_v1/classes.rb', line 5018

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end