Class: Google::Apis::ComputeV1::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



8543
8544
8545
# File 'lib/google/apis/compute_v1/classes.rb', line 8543

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8506
8507
8508
# File 'lib/google/apis/compute_v1/classes.rb', line 8506

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



8511
8512
8513
# File 'lib/google/apis/compute_v1/classes.rb', line 8511

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


8516
8517
8518
# File 'lib/google/apis/compute_v1/classes.rb', line 8516

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8526
8527
8528
# File 'lib/google/apis/compute_v1/classes.rb', line 8526

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8531
8532
8533
# File 'lib/google/apis/compute_v1/classes.rb', line 8531

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


8536
8537
8538
# File 'lib/google/apis/compute_v1/classes.rb', line 8536

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8541
8542
8543
# File 'lib/google/apis/compute_v1/classes.rb', line 8541

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/google/apis/compute_v1/classes.rb', line 8548

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end