Class: Google::Apis::ComputeV1::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



8534
8535
8536
# File 'lib/google/apis/compute_v1/classes.rb', line 8534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8497
8498
8499
# File 'lib/google/apis/compute_v1/classes.rb', line 8497

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



8502
8503
8504
# File 'lib/google/apis/compute_v1/classes.rb', line 8502

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


8507
8508
8509
# File 'lib/google/apis/compute_v1/classes.rb', line 8507

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8517
8518
8519
# File 'lib/google/apis/compute_v1/classes.rb', line 8517

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8522
8523
8524
# File 'lib/google/apis/compute_v1/classes.rb', line 8522

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


8527
8528
8529
# File 'lib/google/apis/compute_v1/classes.rb', line 8527

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8532
8533
8534
# File 'lib/google/apis/compute_v1/classes.rb', line 8532

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8539
8540
8541
8542
8543
8544
8545
8546
8547
# File 'lib/google/apis/compute_v1/classes.rb', line 8539

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end