Class: Google::Apis::ComputeV1::CompositeHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckList

Returns a new instance of CompositeHealthCheckList.



8749
8750
8751
# File 'lib/google/apis/compute_v1/classes.rb', line 8749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8716
8717
8718
# File 'lib/google/apis/compute_v1/classes.rb', line 8716

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::CompositeHealthCheck>

A list of CompositeHealthCheck resources. Corresponds to the JSON property items



8721
8722
8723
# File 'lib/google/apis/compute_v1/classes.rb', line 8721

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# compositeHealthCheck for composite health checks. Corresponds to the JSON property kind

Returns:

  • (String)


8727
8728
8729
# File 'lib/google/apis/compute_v1/classes.rb', line 8727

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8737
8738
8739
# File 'lib/google/apis/compute_v1/classes.rb', line 8737

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8742
8743
8744
# File 'lib/google/apis/compute_v1/classes.rb', line 8742

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::CompositeHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8747
8748
8749
# File 'lib/google/apis/compute_v1/classes.rb', line 8747

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8754
8755
8756
8757
8758
8759
8760
8761
# File 'lib/google/apis/compute_v1/classes.rb', line 8754

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end