Class: Google::Apis::ComputeV1::CompositeHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CompositeHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthCheckList
constructor
A new instance of CompositeHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthCheckList
Returns a new instance of CompositeHealthCheckList.
8702 8703 8704 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8669 8670 8671 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8669 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
Corresponds to the JSON property items
8674 8675 8676 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8674 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
compositeHealthCheck for composite health checks.
Corresponds to the JSON property kind
8680 8681 8682 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8680 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8690 8691 8692 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8690 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8695 8696 8697 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8695 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8700 8701 8702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8700 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8707 8708 8709 8710 8711 8712 8713 8714 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8707 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |