Class: Google::Apis::ComputeV1::CompositeHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CompositeHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthCheckList
constructor
A new instance of CompositeHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthCheckList
Returns a new instance of CompositeHealthCheckList.
8679 8680 8681 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8646 8647 8648 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8646 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
Corresponds to the JSON property items
8651 8652 8653 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8651 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
compositeHealthCheck for composite health checks.
Corresponds to the JSON property kind
8657 8658 8659 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8657 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8667 8668 8669 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8667 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8672 8673 8674 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8672 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8677 8678 8679 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8677 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8684 8685 8686 8687 8688 8689 8690 8691 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8684 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |