Class: Google::Apis::ComputeV1::ConsistentHashLoadBalancerSettingsHttpCookie
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ConsistentHashLoadBalancerSettingsHttpCookie
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the cookie.
-
#path ⇒ String
Path to set for the cookie.
-
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettingsHttpCookie
constructor
A new instance of ConsistentHashLoadBalancerSettingsHttpCookie.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettingsHttpCookie
Returns a new instance of ConsistentHashLoadBalancerSettingsHttpCookie.
9068 9069 9070 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the cookie.
Corresponds to the JSON property name
9053 9054 9055 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9053 def name @name end |
#path ⇒ String
Path to set for the cookie.
Corresponds to the JSON property path
9058 9059 9060 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9058 def path @path end |
#ttl ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property ttl
9066 9067 9068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9066 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9073 9074 9075 9076 9077 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9073 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @ttl = args[:ttl] if args.key?(:ttl) end |