Class: Google::Apis::ComputeV1::CrossSiteNetwork
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CrossSiteNetwork
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A resource that represents a cross-site network. You can use cross-site networks to connect your on-premises networks to each other through Interconnect connections.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of the cross-site network.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrossSiteNetwork
constructor
A new instance of CrossSiteNetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrossSiteNetwork
Returns a new instance of CrossSiteNetwork.
7844 7845 7846 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
7808 7809 7810 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7808 def @creation_timestamp end |
#description ⇒ String
An optional description of the cross-site network.
Corresponds to the JSON property description
7813 7814 7815 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7813 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
7820 7821 7822 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7820 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
crossSiteNetwork for cross-site networks.
Corresponds to the JSON property kind
7826 7827 7828 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7826 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
7837 7838 7839 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7837 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
7842 7843 7844 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7842 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7849 7850 7851 7852 7853 7854 7855 7856 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7849 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) end |