Class: Google::Apis::ComputeV1::CrossSiteNetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request that contains a list of cross-site networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetworkList

Returns a new instance of CrossSiteNetworkList.



9270
9271
9272
# File 'lib/google/apis/compute_v1/classes.rb', line 9270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


9226
9227
9228
# File 'lib/google/apis/compute_v1/classes.rb', line 9226

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9231
9232
9233
# File 'lib/google/apis/compute_v1/classes.rb', line 9231

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::CrossSiteNetwork>

A list of CrossSiteNetwork resources. Corresponds to the JSON property items



9236
9237
9238
# File 'lib/google/apis/compute_v1/classes.rb', line 9236

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


9242
9243
9244
# File 'lib/google/apis/compute_v1/classes.rb', line 9242

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9252
9253
9254
# File 'lib/google/apis/compute_v1/classes.rb', line 9252

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9257
9258
9259
# File 'lib/google/apis/compute_v1/classes.rb', line 9257

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


9263
9264
9265
# File 'lib/google/apis/compute_v1/classes.rb', line 9263

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::CrossSiteNetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9268
9269
9270
# File 'lib/google/apis/compute_v1/classes.rb', line 9268

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
# File 'lib/google/apis/compute_v1/classes.rb', line 9275

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end