Class: Google::Apis::ComputeV1::CrossSiteNetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CrossSiteNetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request that contains a list of cross-site networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrossSiteNetworkList
constructor
A new instance of CrossSiteNetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrossSiteNetworkList
Returns a new instance of CrossSiteNetworkList.
9188 9189 9190 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9188 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
9144 9145 9146 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9144 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
9149 9150 9151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9149 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
Corresponds to the JSON property items
9154 9155 9156 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9154 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
crossSiteNetwork for cross-site networks.
Corresponds to the JSON property kind
9160 9161 9162 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9160 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9170 9171 9172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9170 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9175 9176 9177 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9175 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
9181 9182 9183 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9181 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
9186 9187 9188 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9186 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9193 9194 9195 9196 9197 9198 9199 9200 9201 9202 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9193 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |