Class: Google::Apis::ComputeV1::CrossSiteNetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CrossSiteNetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request that contains a list of cross-site networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrossSiteNetworkList
constructor
A new instance of CrossSiteNetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrossSiteNetworkList
Returns a new instance of CrossSiteNetworkList.
7996 7997 7998 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
7952 7953 7954 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7952 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
7957 7958 7959 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7957 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
Corresponds to the JSON property items
7962 7963 7964 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7962 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
crossSiteNetwork for cross-site networks.
Corresponds to the JSON property kind
7968 7969 7970 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7968 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
7978 7979 7980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7978 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
7983 7984 7985 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7983 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
7989 7990 7991 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7989 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
7994 7995 7996 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7994 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8001 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |