Class: Google::Apis::ComputeV1::CustomerEncryptionKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CustomerEncryptionKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
The name of the encryption key that is stored in Google Cloud KMS.
-
#kms_key_service_account ⇒ String
The service account being used for the encryption request for the given KMS key.
-
#raw_key ⇒ String
Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
-
#rsa_encrypted_key ⇒ String
Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource.
-
#sha256 ⇒ String
[Output only] TheRFC 4648 base64 encoded SHA-256 hash of the customer-supplied encryption key that protects this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomerEncryptionKey
constructor
A new instance of CustomerEncryptionKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomerEncryptionKey
Returns a new instance of CustomerEncryptionKey.
8170 8171 8172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
The name of the encryption key that is stored in Google Cloud KMS.
For example:
"kmsKeyName": "projects/kms_project_id/locations/region/keyRings/
key_region/cryptoKeys/key
The fully-qualifed key name may be returned for resource GET requests. For
example:
"kmsKeyName": "projects/kms_project_id/locations/region/keyRings/
key_region/cryptoKeys/key
/cryptoKeyVersions/1
Corresponds to the JSON property kmsKeyName
8121 8122 8123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8121 def kms_key_name @kms_key_name end |
#kms_key_service_account ⇒ String
The service account being used for the encryption request for the given KMS
key. If absent, the Compute Engine default service account is used.
For example:
"kmsKeyServiceAccount": "name@project_id.iam.gserviceaccount.com/
Corresponds to the JSON property kmsKeyServiceAccount
8129 8130 8131 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8129 def kms_key_service_account @kms_key_service_account end |
#raw_key ⇒ String
Specifies a 256-bit customer-supplied
encryption key, encoded in RFC
4648 base64 to either encrypt or decrypt this resource. You can
provide either the rawKey or thersaEncryptedKey.
For example:
"rawKey":
"SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0="
Corresponds to the JSON property rawKey
8140 8141 8142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8140 def raw_key @raw_key end |
#rsa_encrypted_key ⇒ String
Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource. You can provide either the rawKey or thersaEncryptedKey. For example: "rsaEncryptedKey": "ieCx/NcW06PcT7Ep1X6LUTc/hLvUDYyzSZPPVCVPTVEohpeHASqC8uw5TzyO9U+Fka9JFH z0mBibXUInrC/jEk014kCK/NPjYgEMOyssZ4ZINPKxlUh2zn1bV+MCaTICrdmuSBTWlUUiFoD D6PYznLwh8ZNdaheCeZ8ewEXgFQ8V+sDroLaN3Xs3MDTXQEMMoNUXMCZEIpg9Vtp9x2oe==" The key must meet the following requirements before you can provide it to Compute Engine:
- The key is wrapped using a RSA public key certificate provided by Google.
- After being wrapped, the key must be encoded in RFC 4648 base64
encoding.
Gets the RSA public key certificate provided by Google at:
https://cloud-certs.storage.googleapis.com/google-cloud-csek-ingress.pem
Corresponds to the JSON property
rsaEncryptedKey
8161 8162 8163 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8161 def rsa_encrypted_key @rsa_encrypted_key end |
#sha256 ⇒ String
[Output only] TheRFC
4648 base64 encoded SHA-256 hash of the customer-supplied
encryption key that protects this resource.
Corresponds to the JSON property sha256
8168 8169 8170 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8168 def sha256 @sha256 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8175 8176 8177 8178 8179 8180 8181 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8175 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_service_account = args[:kms_key_service_account] if args.key?(:kms_key_service_account) @raw_key = args[:raw_key] if args.key?(:raw_key) @rsa_encrypted_key = args[:rsa_encrypted_key] if args.key?(:rsa_encrypted_key) @sha256 = args[:sha256] if args.key?(:sha256) end |