Class: Google::Apis::ComputeV1::CustomerEncryptionKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::CustomerEncryptionKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
The name of the encryption key that is stored in Google Cloud KMS.
-
#kms_key_service_account ⇒ String
The service account being used for the encryption request for the given KMS key.
-
#raw_key ⇒ String
Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
-
#rsa_encrypted_key ⇒ String
Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource.
-
#sha256 ⇒ String
[Output only] The RFC 4648 base64 encoded SHA-256 hash of the customer- supplied encryption key that protects this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomerEncryptionKey
constructor
A new instance of CustomerEncryptionKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomerEncryptionKey
Returns a new instance of CustomerEncryptionKey.
5459 5460 5461 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
The name of the encryption key that is stored in Google Cloud KMS. For example:
"kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/
cryptoKeys/key
Corresponds to the JSON property kmsKeyName
5421 5422 5423 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5421 def kms_key_name @kms_key_name end |
#kms_key_service_account ⇒ String
The service account being used for the encryption request for the given KMS
key. If absent, the Compute Engine default service account is used. For
example: "kmsKeyServiceAccount": "name@project_id.iam.gserviceaccount.com/
Corresponds to the JSON property kmsKeyServiceAccount
5428 5429 5430 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5428 def kms_key_service_account @kms_key_service_account end |
#raw_key ⇒ String
Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648
base64 to either encrypt or decrypt this resource. You can provide either the
rawKey or the rsaEncryptedKey. For example: "rawKey": "
SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0="
Corresponds to the JSON property rawKey
5436 5437 5438 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5436 def raw_key @raw_key end |
#rsa_encrypted_key ⇒ String
Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied
encryption key to either encrypt or decrypt this resource. You can provide
either the rawKey or the rsaEncryptedKey. For example: "rsaEncryptedKey": "
ieCx/NcW06PcT7Ep1X6LUTc/hLvUDYyzSZPPVCVPTVEohpeHASqC8uw5TzyO9U+Fka9JFH
z0mBibXUInrC/jEk014kCK/NPjYgEMOyssZ4ZINPKxlUh2zn1bV+MCaTICrdmuSBTWlUUiFoD
D6PYznLwh8ZNdaheCeZ8ewEXgFQ8V+sDroLaN3Xs3MDTXQEMMoNUXMCZEIpg9Vtp9x2oe==" The
key must meet the following requirements before you can provide it to Compute
Engine: 1. The key is wrapped using a RSA public key certificate provided by
Google. 2. After being wrapped, the key must be encoded in RFC 4648 base64
encoding. Gets the RSA public key certificate provided by Google at: https://
cloud-certs.storage.googleapis.com/google-cloud-csek-ingress.pem
Corresponds to the JSON property rsaEncryptedKey
5451 5452 5453 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5451 def rsa_encrypted_key @rsa_encrypted_key end |
#sha256 ⇒ String
[Output only] The RFC 4648 base64 encoded SHA-256 hash of the customer-
supplied encryption key that protects this resource.
Corresponds to the JSON property sha256
5457 5458 5459 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5457 def sha256 @sha256 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5464 5465 5466 5467 5468 5469 5470 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5464 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_service_account = args[:kms_key_service_account] if args.key?(:kms_key_service_account) @raw_key = args[:raw_key] if args.key?(:raw_key) @rsa_encrypted_key = args[:rsa_encrypted_key] if args.key?(:rsa_encrypted_key) @sha256 = args[:sha256] if args.key?(:sha256) end |