Class: Google::Apis::ComputeV1::DateTime
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DateTime
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:
- When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
- When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
- When neither time_zone nor utc_offset is set: a civil time on a calendar
day in local time.
The date is relative to the Proleptic Gregorian Calendar.
If year, month, or day are 0, the DateTime is considered not to have a
specific year, month, or day respectively.
This type may also be used to represent a physical time if all the date and
time fields are set and either case of the
time_offsetoneof is set. Consider usingTimestampmessage for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations.
Instance Attribute Summary collapse
-
#day ⇒ Fixnum
Optional.
-
#hours ⇒ Fixnum
Optional.
-
#minutes ⇒ Fixnum
Optional.
-
#month ⇒ Fixnum
Optional.
-
#nanos ⇒ Fixnum
Optional.
-
#seconds ⇒ Fixnum
Optional.
-
#time_zone ⇒ Google::Apis::ComputeV1::TimeZone
Represents a time zone from the IANA Time Zone Database.
-
#utc_offset ⇒ String
UTC offset.
-
#year ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DateTime
constructor
A new instance of DateTime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DateTime
Returns a new instance of DateTime.
9641 9642 9643 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ Fixnum
Optional. Day of month. Must be from 1 to 31 and valid for the year and
month, or 0 if specifying a datetime without a day.
Corresponds to the JSON property day
9590 9591 9592 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9590 def day @day end |
#hours ⇒ Fixnum
Optional. Hours of day in 24 hour format. Should be from 0 to 23, defaults
to 0 (midnight). An API may choose to allow the value "24:00:00" for
scenarios like business closing time.
Corresponds to the JSON property hours
9597 9598 9599 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9597 def hours @hours end |
#minutes ⇒ Fixnum
Optional. Minutes of hour of day. Must be from 0 to 59, defaults to 0.
Corresponds to the JSON property minutes
9602 9603 9604 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9602 def minutes @minutes end |
#month ⇒ Fixnum
Optional. Month of year. Must be from 1 to 12, or 0 if specifying a
datetime without a month.
Corresponds to the JSON property month
9608 9609 9610 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9608 def month @month end |
#nanos ⇒ Fixnum
Optional. Fractions of seconds in nanoseconds. Must be from 0 to
999,999,999, defaults to 0.
Corresponds to the JSON property nanos
9614 9615 9616 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9614 def nanos @nanos end |
#seconds ⇒ Fixnum
Optional. Seconds of minutes of the time. Must normally be from 0 to 59,
defaults to 0. An API may allow the value 60 if it allows leap-seconds.
Corresponds to the JSON property seconds
9620 9621 9622 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9620 def seconds @seconds end |
#time_zone ⇒ Google::Apis::ComputeV1::TimeZone
Represents a time zone from the
IANA Time Zone Database.
Corresponds to the JSON property timeZone
9626 9627 9628 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9626 def time_zone @time_zone end |
#utc_offset ⇒ String
UTC offset. Must be whole seconds, between -18 hours and +18 hours.
For example, a UTC offset of -4:00 would be represented as
seconds: -14400.
Corresponds to the JSON property utcOffset
9633 9634 9635 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9633 def utc_offset @utc_offset end |
#year ⇒ Fixnum
Optional. Year of date. Must be from 1 to 9999, or 0 if specifying a
datetime without a year.
Corresponds to the JSON property year
9639 9640 9641 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9639 def year @year end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9646 def update!(**args) @day = args[:day] if args.key?(:day) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @month = args[:month] if args.key?(:month) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) @time_zone = args[:time_zone] if args.key?(:time_zone) @utc_offset = args[:utc_offset] if args.key?(:utc_offset) @year = args[:year] if args.key?(:year) end |