Class: Google::Apis::ComputeV1::DeprecationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Deprecation status for a public resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeprecationStatus

Returns a new instance of DeprecationStatus.



9581
9582
9583
# File 'lib/google/apis/compute_v1/classes.rb', line 9581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deletedString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property deleted

Returns:

  • (String)


9544
9545
9546
# File 'lib/google/apis/compute_v1/classes.rb', line 9544

def deleted
  @deleted
end

#deprecatedString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property deprecated

Returns:

  • (String)


9552
9553
9554
# File 'lib/google/apis/compute_v1/classes.rb', line 9552

def deprecated
  @deprecated
end

#obsoleteString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property obsolete

Returns:

  • (String)


9560
9561
9562
# File 'lib/google/apis/compute_v1/classes.rb', line 9560

def obsolete
  @obsolete
end

#replacementString

The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource. Corresponds to the JSON property replacement

Returns:

  • (String)


9567
9568
9569
# File 'lib/google/apis/compute_v1/classes.rb', line 9567

def replacement
  @replacement
end

#stateString

The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. Corresponds to the JSON property state

Returns:

  • (String)


9579
9580
9581
# File 'lib/google/apis/compute_v1/classes.rb', line 9579

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9586
9587
9588
9589
9590
9591
9592
# File 'lib/google/apis/compute_v1/classes.rb', line 9586

def update!(**args)
  @deleted = args[:deleted] if args.key?(:deleted)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @obsolete = args[:obsolete] if args.key?(:obsolete)
  @replacement = args[:replacement] if args.key?(:replacement)
  @state = args[:state] if args.key?(:state)
end