Class: Google::Apis::ComputeV1::DeprecationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DeprecationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Deprecation status for a public resource.
Instance Attribute Summary collapse
-
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED.
-
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED.
-
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE.
-
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
-
#state ⇒ String
The deprecation state of this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeprecationStatus
constructor
A new instance of DeprecationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeprecationStatus
Returns a new instance of DeprecationStatus.
9598 9599 9600 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DELETED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deleted
9561 9562 9563 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9561 def deleted @deleted end |
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DEPRECATED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deprecated
9569 9570 9571 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9569 def deprecated @deprecated end |
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to OBSOLETE. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property obsolete
9577 9578 9579 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9577 def obsolete @obsolete end |
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
The suggested replacement resource must be the same kind of resource as the
deprecated resource.
Corresponds to the JSON property replacement
9584 9585 9586 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9584 def replacement @replacement end |
#state ⇒ String
The deprecation state of this resource. This can be ACTIVE,DEPRECATED,
OBSOLETE, or DELETED.
Operations which communicate the end of life date for an image, can useACTIVE.
Operations which create a new resource using aDEPRECATED resource will return
successfully, but with a
warning indicating the deprecated resource and recommending its
replacement. Operations which use OBSOLETE orDELETED resources will be
rejected and result in an error.
Corresponds to the JSON property state
9596 9597 9598 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9596 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9603 def update!(**args) @deleted = args[:deleted] if args.key?(:deleted) @deprecated = args[:deprecated] if args.key?(:deprecated) @obsolete = args[:obsolete] if args.key?(:obsolete) @replacement = args[:replacement] if args.key?(:replacement) @state = args[:state] if args.key?(:state) end |