Class: Google::Apis::ComputeV1::DeprecationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DeprecationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Deprecation status for a public resource.
Instance Attribute Summary collapse
-
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED.
-
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED.
-
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE.
-
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
-
#state ⇒ String
The deprecation state of this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeprecationStatus
constructor
A new instance of DeprecationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeprecationStatus
Returns a new instance of DeprecationStatus.
8308 8309 8310 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DELETED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deleted
8271 8272 8273 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8271 def deleted @deleted end |
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DEPRECATED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deprecated
8279 8280 8281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8279 def deprecated @deprecated end |
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to OBSOLETE. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property obsolete
8287 8288 8289 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8287 def obsolete @obsolete end |
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
The suggested replacement resource must be the same kind of resource as the
deprecated resource.
Corresponds to the JSON property replacement
8294 8295 8296 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8294 def replacement @replacement end |
#state ⇒ String
The deprecation state of this resource. This can be ACTIVE,DEPRECATED,
OBSOLETE, or DELETED.
Operations which communicate the end of life date for an image, can useACTIVE.
Operations which create a new resource using aDEPRECATED resource will return
successfully, but with a
warning indicating the deprecated resource and recommending its
replacement. Operations which use OBSOLETE orDELETED resources will be
rejected and result in an error.
Corresponds to the JSON property state
8306 8307 8308 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8306 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8313 8314 8315 8316 8317 8318 8319 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8313 def update!(**args) @deleted = args[:deleted] if args.key?(:deleted) @deprecated = args[:deprecated] if args.key?(:deprecated) @obsolete = args[:obsolete] if args.key?(:obsolete) @replacement = args[:replacement] if args.key?(:replacement) @state = args[:state] if args.key?(:state) end |