Class: Google::Apis::ComputeV1::DeprecationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DeprecationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Deprecation status for a public resource.
Instance Attribute Summary collapse
-
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED.
-
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED.
-
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE.
-
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
-
#state ⇒ String
The deprecation state of this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeprecationStatus
constructor
A new instance of DeprecationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeprecationStatus
Returns a new instance of DeprecationStatus.
5542 5543 5544 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is
intended to change to DELETED. This is only informational and the status will
not change unless the client explicitly changes it.
Corresponds to the JSON property deleted
5509 5510 5511 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5509 def deleted @deleted end |
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is
intended to change to DEPRECATED. This is only informational and the status
will not change unless the client explicitly changes it.
Corresponds to the JSON property deprecated
5516 5517 5518 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5516 def deprecated @deprecated end |
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is
intended to change to OBSOLETE. This is only informational and the status will
not change unless the client explicitly changes it.
Corresponds to the JSON property obsolete
5523 5524 5525 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5523 def obsolete @obsolete end |
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource. The suggested
replacement resource must be the same kind of resource as the deprecated
resource.
Corresponds to the JSON property replacement
5530 5531 5532 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5530 def replacement @replacement end |
#state ⇒ String
The deprecation state of this resource. This can be ACTIVE, DEPRECATED,
OBSOLETE, or DELETED. Operations which communicate the end of life date for an
image, can use ACTIVE. Operations which create a new resource using a
DEPRECATED resource will return successfully, but with a warning indicating
the deprecated resource and recommending its replacement. Operations which use
OBSOLETE or DELETED resources will be rejected and result in an error.
Corresponds to the JSON property state
5540 5541 5542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5540 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5547 5548 5549 5550 5551 5552 5553 |
# File 'lib/google/apis/compute_v1/classes.rb', line 5547 def update!(**args) @deleted = args[:deleted] if args.key?(:deleted) @deprecated = args[:deprecated] if args.key?(:deprecated) @obsolete = args[:obsolete] if args.key?(:obsolete) @replacement = args[:replacement] if args.key?(:replacement) @state = args[:state] if args.key?(:state) end |