Class: Google::Apis::ComputeV1::Disk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Persistent Disk resource. Google Compute Engine has two Disk resources:

  • Zonal
  • Regional Persistent disks are required for running your VM instances. Create both boot and non-boot (data) persistent disks. For more information, read Persistent Disks. For more storage options, read Storage options. The disks resource represents a zonal persistent disk. For more information, readZonal persistent disks. The regionDisks resource represents a regional persistent disk. For more information, read Regional resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Disk

Returns a new instance of Disk.



10187
10188
10189
# File 'lib/google/apis/compute_v1/classes.rb', line 10187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_modeString

The access mode of the disk.

  • READ_WRITE_SINGLE: The default AccessMode, means the disk can be attached to single instance in RW mode.
  • READ_WRITE_MANY: The AccessMode means the disk can be attached to multiple instances in RW mode.
  • READ_ONLY_MANY: The AccessMode means the disk can be attached to multiple instances in RO mode. The AccessMode is only valid for Hyperdisk disk types. Corresponds to the JSON property accessMode

Returns:

  • (String)


9757
9758
9759
# File 'lib/google/apis/compute_v1/classes.rb', line 9757

def access_mode
  @access_mode
end

#architectureString

The architecture of the disk. Valid values are ARM64 or X86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


9763
9764
9765
# File 'lib/google/apis/compute_v1/classes.rb', line 9763

def architecture
  @architecture
end

#async_primary_diskGoogle::Apis::ComputeV1::DiskAsyncReplication

Disk asynchronously replicated into this disk. Corresponds to the JSON property asyncPrimaryDisk



9768
9769
9770
# File 'lib/google/apis/compute_v1/classes.rb', line 9768

def async_primary_disk
  @async_primary_disk
end

#async_secondary_disksHash<String,Google::Apis::ComputeV1::DiskAsyncReplicationList>

Output only. [Output Only] A list of disks this disk is asynchronously replicated to. Corresponds to the JSON property asyncSecondaryDisks



9774
9775
9776
# File 'lib/google/apis/compute_v1/classes.rb', line 9774

def async_secondary_disks
  @async_secondary_disks
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


9780
9781
9782
# File 'lib/google/apis/compute_v1/classes.rb', line 9780

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


9786
9787
9788
# File 'lib/google/apis/compute_v1/classes.rb', line 9786

def description
  @description
end

#disk_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Encrypts the disk using a customer-supplied encryption key or a customer-managed encryption key. Encryption keys do not protect access to metadata of the disk. After you encrypt a disk with a customer-supplied key, you must provide the same key if you use the disk later. For example, to create a disk snapshot, to create a disk image, to create a machine image, or to attach the disk to a virtual machine. After you encrypt a disk with a customer-managed key, thediskEncryptionKey. kmsKeyName is set to a key version name once the disk is created. The disk is encrypted with this version of the key. In the response, diskEncryptionKey.kmsKeyName appears in the following format: "diskEncryptionKey.kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key /cryptoKeysVersions/version If you do not provide an encryption key when creating the disk, then the disk is encrypted using an automatically generated key and you don't need to provide a key to use the disk later. Corresponds to the JSON property diskEncryptionKey



9810
9811
9812
# File 'lib/google/apis/compute_v1/classes.rb', line 9810

def disk_encryption_key
  @disk_encryption_key
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Whether this disk is using confidential compute mode. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


9815
9816
9817
# File 'lib/google/apis/compute_v1/classes.rb', line 9815

def enable_confidential_compute
  @enable_confidential_compute
end

#guest_os_featuresArray<Google::Apis::ComputeV1::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



9824
9825
9826
# File 'lib/google/apis/compute_v1/classes.rb', line 9824

def guest_os_features
  @guest_os_features
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


9831
9832
9833
# File 'lib/google/apis/compute_v1/classes.rb', line 9831

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#disk for disks. Corresponds to the JSON property kind

Returns:

  • (String)


9837
9838
9839
# File 'lib/google/apis/compute_v1/classes.rb', line 9837

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this disk, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a disk. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


9850
9851
9852
# File 'lib/google/apis/compute_v1/classes.rb', line 9850

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this disk. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


9856
9857
9858
# File 'lib/google/apis/compute_v1/classes.rb', line 9856

def labels
  @labels
end

#last_attach_timestampString

Output only. [Output Only] Last attach timestamp inRFC3339 text format. Corresponds to the JSON property lastAttachTimestamp

Returns:

  • (String)


9862
9863
9864
# File 'lib/google/apis/compute_v1/classes.rb', line 9862

def last_attach_timestamp
  @last_attach_timestamp
end

#last_detach_timestampString

Output only. [Output Only] Last detach timestamp inRFC3339 text format. Corresponds to the JSON property lastDetachTimestamp

Returns:

  • (String)


9868
9869
9870
# File 'lib/google/apis/compute_v1/classes.rb', line 9868

def last_detach_timestamp
  @last_detach_timestamp
end

#license_codesArray<Fixnum>

Integer license codes indicating which licenses are attached to this disk. Corresponds to the JSON property licenseCodes

Returns:

  • (Array<Fixnum>)


9873
9874
9875
# File 'lib/google/apis/compute_v1/classes.rb', line 9873

def license_codes
  @license_codes
end

#licensesArray<String>

A list of publicly visible licenses. Reserved for Google's use. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


9878
9879
9880
# File 'lib/google/apis/compute_v1/classes.rb', line 9878

def licenses
  @licenses
end

#location_hintString

An opaque location hint used to place the disk close to other resources. This field is for use by internal tools that use the public API. Corresponds to the JSON property locationHint

Returns:

  • (String)


9884
9885
9886
# File 'lib/google/apis/compute_v1/classes.rb', line 9884

def location_hint
  @location_hint
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


9895
9896
9897
# File 'lib/google/apis/compute_v1/classes.rb', line 9895

def name
  @name
end

#optionsString

Internal use only. Corresponds to the JSON property options

Returns:

  • (String)


9900
9901
9902
# File 'lib/google/apis/compute_v1/classes.rb', line 9900

def options
  @options
end

#paramsGoogle::Apis::ComputeV1::DiskParams

Additional disk params. Corresponds to the JSON property params



9905
9906
9907
# File 'lib/google/apis/compute_v1/classes.rb', line 9905

def params
  @params
end

#physical_block_size_bytesFixnum

Physical block size of the persistent disk, in bytes. If not present in a request, a default value is used. The currently supported size is 4096, other sizes may be added in the future. If an unsupported value is requested, the error message will list the supported values for the caller's project. Corresponds to the JSON property physicalBlockSizeBytes

Returns:

  • (Fixnum)


9915
9916
9917
# File 'lib/google/apis/compute_v1/classes.rb', line 9915

def physical_block_size_bytes
  @physical_block_size_bytes
end

#provisioned_iopsFixnum

Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation. Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


9923
9924
9925
# File 'lib/google/apis/compute_v1/classes.rb', line 9923

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must be greater than or equal to 1. Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


9930
9931
9932
# File 'lib/google/apis/compute_v1/classes.rb', line 9930

def provisioned_throughput
  @provisioned_throughput
end

#regionString

Output only. [Output Only] URL of the region where the disk resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


9939
9940
9941
# File 'lib/google/apis/compute_v1/classes.rb', line 9939

def region
  @region
end

#replica_zonesArray<String>

URLs of the zones where the disk should be replicated to. Only applicable for regional resources. Corresponds to the JSON property replicaZones

Returns:

  • (Array<String>)


9945
9946
9947
# File 'lib/google/apis/compute_v1/classes.rb', line 9945

def replica_zones
  @replica_zones
end

#resource_policiesArray<String>

Resource policies applied to this disk for automatic snapshot creations. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


9950
9951
9952
# File 'lib/google/apis/compute_v1/classes.rb', line 9950

def resource_policies
  @resource_policies
end

#resource_statusGoogle::Apis::ComputeV1::DiskResourceStatus

Output only. [Output Only] Status information for the disk resource. Corresponds to the JSON property resourceStatus



9955
9956
9957
# File 'lib/google/apis/compute_v1/classes.rb', line 9955

def resource_status
  @resource_status
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


9960
9961
9962
# File 'lib/google/apis/compute_v1/classes.rb', line 9960

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


9966
9967
9968
# File 'lib/google/apis/compute_v1/classes.rb', line 9966

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9973
9974
9975
# File 'lib/google/apis/compute_v1/classes.rb', line 9973

def self_link
  @self_link
end

#size_gbFixnum

Size, in GB, of the persistent disk. You can specify this field when creating a persistent disk using thesourceImage, sourceSnapshot, orsourceDisk parameter, or specify it alone to create an empty persistent disk. If you specify this field along with a source, the value ofsizeGb must not be less than the size of the source. Acceptable values are greater than 0. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


9985
9986
9987
# File 'lib/google/apis/compute_v1/classes.rb', line 9985

def size_gb
  @size_gb
end

#source_consistency_group_policyString

Output only. [Output Only] URL of the DiskConsistencyGroupPolicy for a secondary disk that was created using a consistency group. Corresponds to the JSON property sourceConsistencyGroupPolicy

Returns:

  • (String)


9992
9993
9994
# File 'lib/google/apis/compute_v1/classes.rb', line 9992

def source_consistency_group_policy
  @source_consistency_group_policy
end

#source_consistency_group_policy_idString

Output only. [Output Only] ID of the DiskConsistencyGroupPolicy for a secondary disk that was created using a consistency group. Corresponds to the JSON property sourceConsistencyGroupPolicyId

Returns:

  • (String)


9999
10000
10001
# File 'lib/google/apis/compute_v1/classes.rb', line 9999

def source_consistency_group_policy_id
  @source_consistency_group_policy_id
end

#source_diskString

The source disk used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk

- https://www.googleapis.com/compute/v1/projects/project/regions/region/ disks/disk

- projects/project/zones/zone/disks/disk

- projects/project/regions/region/disks/disk

- zones/zone/disks/disk

- regions/region/disks/disk Corresponds to the JSON property sourceDisk

Returns:

  • (String)


10027
10028
10029
# File 'lib/google/apis/compute_v1/classes.rb', line 10027

def source_disk
  @source_disk
end

#source_disk_idString

Output only. [Output Only] The unique ID of the disk used to create this disk. This value identifies the exact disk that was used to create this persistent disk. For example, if you created the persistent disk from a disk that was later deleted and recreated under the same name, the source disk ID would identify the exact version of the disk that was used. Corresponds to the JSON property sourceDiskId

Returns:

  • (String)


10037
10038
10039
# File 'lib/google/apis/compute_v1/classes.rb', line 10037

def source_disk_id
  @source_disk_id
end

#source_imageString

The source image used to create this disk. If the source image is deleted, this field will not be set. To create a disk with one of the public operating system images, specify the image by its family name. For example, specifyfamily/debian-9 to use the latest Debian 9 image: projects/debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my-custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family Corresponds to the JSON property sourceImage

Returns:

  • (String)


10056
10057
10058
# File 'lib/google/apis/compute_v1/classes.rb', line 10056

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceImageEncryptionKey



10063
10064
10065
# File 'lib/google/apis/compute_v1/classes.rb', line 10063

def source_image_encryption_key
  @source_image_encryption_key
end

#source_image_idString

Output only. [Output Only] The ID value of the image used to create this disk. This value identifies the exact image that was used to create this persistent disk. For example, if you created the persistent disk from an image that was later deleted and recreated under the same name, the source image ID would identify the exact version of the image that was used. Corresponds to the JSON property sourceImageId

Returns:

  • (String)


10073
10074
10075
# File 'lib/google/apis/compute_v1/classes.rb', line 10073

def source_image_id
  @source_image_id
end

#source_instant_snapshotString

The source instant snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


10086
10087
10088
# File 'lib/google/apis/compute_v1/classes.rb', line 10086

def source_instant_snapshot
  @source_instant_snapshot
end

#source_instant_snapshot_idString

Output only. [Output Only] The unique ID of the instant snapshot used to create this disk. This value identifies the exact instant snapshot that was used to create this persistent disk. For example, if you created the persistent disk from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact version of the instant snapshot that was used. Corresponds to the JSON property sourceInstantSnapshotId

Returns:

  • (String)


10097
10098
10099
# File 'lib/google/apis/compute_v1/classes.rb', line 10097

def source_instant_snapshot_id
  @source_instant_snapshot_id
end

#source_snapshotString

The source snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


10110
10111
10112
# File 'lib/google/apis/compute_v1/classes.rb', line 10110

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceSnapshotEncryptionKey



10117
10118
10119
# File 'lib/google/apis/compute_v1/classes.rb', line 10117

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

#source_snapshot_idString

Output only. [Output Only] The unique ID of the snapshot used to create this disk. This value identifies the exact snapshot that was used to create this persistent disk. For example, if you created the persistent disk from a snapshot that was later deleted and recreated under the same name, the source snapshot ID would identify the exact version of the snapshot that was used. Corresponds to the JSON property sourceSnapshotId

Returns:

  • (String)


10127
10128
10129
# File 'lib/google/apis/compute_v1/classes.rb', line 10127

def source_snapshot_id
  @source_snapshot_id
end

#source_storage_objectString

The full Google Cloud Storage URI where the disk image is stored. This file must be a gzip-compressed tarball whose name ends in .tar.gz or virtual machine disk whose name ends in vmdk. Valid URIs may start with gs:// or https://storage.googleapis.com/. This flag is not optimized for creating multiple disks from a source storage object. To create many disks from a source storage object, use gcloud compute images import instead. Corresponds to the JSON property sourceStorageObject

Returns:

  • (String)


10138
10139
10140
# File 'lib/google/apis/compute_v1/classes.rb', line 10138

def source_storage_object
  @source_storage_object
end

#statusString

Output only. [Output Only] The status of disk creation.

  • CREATING: Disk is provisioning.
  • RESTORING: Source data is being copied into the disk.
  • FAILED: Disk creation failed.
  • READY: Disk is ready for use.
  • DELETING: Disk is deleting. Corresponds to the JSON property status

Returns:

  • (String)


10151
10152
10153
# File 'lib/google/apis/compute_v1/classes.rb', line 10151

def status
  @status
end

#storage_poolString

The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


10164
10165
10166
# File 'lib/google/apis/compute_v1/classes.rb', line 10164

def storage_pool
  @storage_pool
end

#typeString

URL of the disk type resource describing which disk type to use to create the disk. Provide this when creating the disk. For example:projects/project/ zones/zone/diskTypes/pd-ssd. See Persistent disk types. Corresponds to the JSON property type

Returns:

  • (String)


10172
10173
10174
# File 'lib/google/apis/compute_v1/classes.rb', line 10172

def type
  @type
end

#usersArray<String>

Output only. [Output Only] Links to the users of the disk (attached instances) in form:projects/project/zones/zone/instances/instance Corresponds to the JSON property users

Returns:

  • (Array<String>)


10178
10179
10180
# File 'lib/google/apis/compute_v1/classes.rb', line 10178

def users
  @users
end

#zoneString

Output only. [Output Only] URL of the zone where the disk resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


10185
10186
10187
# File 'lib/google/apis/compute_v1/classes.rb', line 10185

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10192
10193
10194
10195
10196
10197
10198
10199
10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
10241
10242
10243
# File 'lib/google/apis/compute_v1/classes.rb', line 10192

def update!(**args)
  @access_mode = args[:access_mode] if args.key?(:access_mode)
  @architecture = args[:architecture] if args.key?(:architecture)
  @async_primary_disk = args[:async_primary_disk] if args.key?(:async_primary_disk)
  @async_secondary_disks = args[:async_secondary_disks] if args.key?(:async_secondary_disks)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @last_attach_timestamp = args[:last_attach_timestamp] if args.key?(:last_attach_timestamp)
  @last_detach_timestamp = args[:last_detach_timestamp] if args.key?(:last_detach_timestamp)
  @license_codes = args[:license_codes] if args.key?(:license_codes)
  @licenses = args[:licenses] if args.key?(:licenses)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @params = args[:params] if args.key?(:params)
  @physical_block_size_bytes = args[:physical_block_size_bytes] if args.key?(:physical_block_size_bytes)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @region = args[:region] if args.key?(:region)
  @replica_zones = args[:replica_zones] if args.key?(:replica_zones)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @source_consistency_group_policy = args[:source_consistency_group_policy] if args.key?(:source_consistency_group_policy)
  @source_consistency_group_policy_id = args[:source_consistency_group_policy_id] if args.key?(:source_consistency_group_policy_id)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_image_id = args[:source_image_id] if args.key?(:source_image_id)
  @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot)
  @source_instant_snapshot_id = args[:source_instant_snapshot_id] if args.key?(:source_instant_snapshot_id)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
  @source_snapshot_id = args[:source_snapshot_id] if args.key?(:source_snapshot_id)
  @source_storage_object = args[:source_storage_object] if args.key?(:source_storage_object)
  @status = args[:status] if args.key?(:status)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
  @type = args[:type] if args.key?(:type)
  @users = args[:users] if args.key?(:users)
  @zone = args[:zone] if args.key?(:zone)
end