Class: Google::Apis::ComputeV1::DiskAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DiskAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::DisksScopedList>
A list of DisksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskAggregatedList
constructor
A new instance of DiskAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskAggregatedList
Returns a new instance of DiskAggregatedList.
10342 10343 10344 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10303 10304 10305 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10303 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::DisksScopedList>
A list of DisksScopedList resources.
Corresponds to the JSON property items
10308 10309 10310 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10308 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList
for aggregated lists of persistent
disks.
Corresponds to the JSON property kind
10315 10316 10317 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10315 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10325 10326 10327 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10325 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10330 10331 10332 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10330 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
10335 10336 10337 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10335 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10340 10341 10342 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10340 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10347 10348 10349 10350 10351 10352 10353 10354 10355 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10347 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |