Class: Google::Apis::ComputeV1::DiskAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DiskAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::DisksScopedList>
A list of DisksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskAggregatedList
constructor
A new instance of DiskAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskAggregatedList
Returns a new instance of DiskAggregatedList.
10292 10293 10294 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10253 10254 10255 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10253 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::DisksScopedList>
A list of DisksScopedList resources.
Corresponds to the JSON property items
10258 10259 10260 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10258 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList
for aggregated lists of persistent
disks.
Corresponds to the JSON property kind
10265 10266 10267 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10265 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10275 10276 10277 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10275 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10280 10281 10282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10280 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
10285 10286 10287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10285 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10290 10291 10292 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10290 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10297 10298 10299 10300 10301 10302 10303 10304 10305 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10297 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |