Class: Google::Apis::ComputeV1::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



8971
8972
8973
# File 'lib/google/apis/compute_v1/classes.rb', line 8971

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8932
8933
8934
# File 'lib/google/apis/compute_v1/classes.rb', line 8932

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



8937
8938
8939
# File 'lib/google/apis/compute_v1/classes.rb', line 8937

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


8944
8945
8946
# File 'lib/google/apis/compute_v1/classes.rb', line 8944

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8954
8955
8956
# File 'lib/google/apis/compute_v1/classes.rb', line 8954

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8959
8960
8961
# File 'lib/google/apis/compute_v1/classes.rb', line 8959

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


8964
8965
8966
# File 'lib/google/apis/compute_v1/classes.rb', line 8964

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8969
8970
8971
# File 'lib/google/apis/compute_v1/classes.rb', line 8969

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8976
8977
8978
8979
8980
8981
8982
8983
8984
# File 'lib/google/apis/compute_v1/classes.rb', line 8976

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end