Class: Google::Apis::ComputeV1::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



5926
5927
5928
# File 'lib/google/apis/compute_v1/classes.rb', line 5926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


5889
5890
5891
# File 'lib/google/apis/compute_v1/classes.rb', line 5889

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



5894
5895
5896
# File 'lib/google/apis/compute_v1/classes.rb', line 5894

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


5900
5901
5902
# File 'lib/google/apis/compute_v1/classes.rb', line 5900

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5909
5910
5911
# File 'lib/google/apis/compute_v1/classes.rb', line 5909

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5914
5915
5916
# File 'lib/google/apis/compute_v1/classes.rb', line 5914

def self_link
  @self_link
end

#unreachablesArray<String>

[Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


5919
5920
5921
# File 'lib/google/apis/compute_v1/classes.rb', line 5919

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



5924
5925
5926
# File 'lib/google/apis/compute_v1/classes.rb', line 5924

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5931
5932
5933
5934
5935
5936
5937
5938
5939
# File 'lib/google/apis/compute_v1/classes.rb', line 5931

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end