Class: Google::Apis::ComputeV1::DiskAsyncReplication

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAsyncReplication

Returns a new instance of DiskAsyncReplication.



9013
9014
9015
# File 'lib/google/apis/compute_v1/classes.rb', line 9013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consistency_group_policyString

Output only. [Output Only] URL of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group. Corresponds to the JSON property consistencyGroupPolicy

Returns:

  • (String)


8980
8981
8982
# File 'lib/google/apis/compute_v1/classes.rb', line 8980

def consistency_group_policy
  @consistency_group_policy
end

#consistency_group_policy_idString

Output only. [Output Only] ID of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group. Corresponds to the JSON property consistencyGroupPolicyId

Returns:

  • (String)


8987
8988
8989
# File 'lib/google/apis/compute_v1/classes.rb', line 8987

def consistency_group_policy_id
  @consistency_group_policy_id
end

#diskString

The other disk asynchronously replicated to or from the current disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


9000
9001
9002
# File 'lib/google/apis/compute_v1/classes.rb', line 9000

def disk
  @disk
end

#disk_idString

Output only. [Output Only] The unique ID of the other disk asynchronously replicated to or from the current disk. This value identifies the exact disk that was used to create this replication. For example, if you started replicating the persistent disk from a disk that was later deleted and recreated under the same name, the disk ID would identify the exact version of the disk that was used. Corresponds to the JSON property diskId

Returns:

  • (String)


9011
9012
9013
# File 'lib/google/apis/compute_v1/classes.rb', line 9011

def disk_id
  @disk_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9018
9019
9020
9021
9022
9023
# File 'lib/google/apis/compute_v1/classes.rb', line 9018

def update!(**args)
  @consistency_group_policy = args[:consistency_group_policy] if args.key?(:consistency_group_policy)
  @consistency_group_policy_id = args[:consistency_group_policy_id] if args.key?(:consistency_group_policy_id)
  @disk = args[:disk] if args.key?(:disk)
  @disk_id = args[:disk_id] if args.key?(:disk_id)
end