Class: Google::Apis::ComputeV1::DiskList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of Disk resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskList

Returns a new instance of DiskList.



10600
10601
10602
# File 'lib/google/apis/compute_v1/classes.rb', line 10600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10567
10568
10569
# File 'lib/google/apis/compute_v1/classes.rb', line 10567

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Disk>

A list of Disk resources. Corresponds to the JSON property items

Returns:



10572
10573
10574
# File 'lib/google/apis/compute_v1/classes.rb', line 10572

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#diskList for lists of disks. Corresponds to the JSON property kind

Returns:

  • (String)


10578
10579
10580
# File 'lib/google/apis/compute_v1/classes.rb', line 10578

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10588
10589
10590
# File 'lib/google/apis/compute_v1/classes.rb', line 10588

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10593
10594
10595
# File 'lib/google/apis/compute_v1/classes.rb', line 10593

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::DiskList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10598
10599
10600
# File 'lib/google/apis/compute_v1/classes.rb', line 10598

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10605
10606
10607
10608
10609
10610
10611
10612
# File 'lib/google/apis/compute_v1/classes.rb', line 10605

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end