Class: Google::Apis::ComputeV1::DiskList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DiskList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of Disk resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Disk>
A list of Disk resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::DiskList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskList
constructor
A new instance of DiskList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskList
Returns a new instance of DiskList.
10550 10551 10552 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10517 10518 10519 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10517 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Disk>
A list of Disk resources.
Corresponds to the JSON property items
10522 10523 10524 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10522 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#diskList for
lists of disks.
Corresponds to the JSON property kind
10528 10529 10530 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10528 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10538 10539 10540 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10538 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10543 10544 10545 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10543 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::DiskList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10548 10549 10550 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10548 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10555 10556 10557 10558 10559 10560 10561 10562 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10555 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |