Class: Google::Apis::ComputeV1::DiskList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of Disk resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskList

Returns a new instance of DiskList.



10416
10417
10418
# File 'lib/google/apis/compute_v1/classes.rb', line 10416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10383
10384
10385
# File 'lib/google/apis/compute_v1/classes.rb', line 10383

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Disk>

A list of Disk resources. Corresponds to the JSON property items

Returns:



10388
10389
10390
# File 'lib/google/apis/compute_v1/classes.rb', line 10388

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#diskList for lists of disks. Corresponds to the JSON property kind

Returns:

  • (String)


10394
10395
10396
# File 'lib/google/apis/compute_v1/classes.rb', line 10394

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10404
10405
10406
# File 'lib/google/apis/compute_v1/classes.rb', line 10404

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10409
10410
10411
# File 'lib/google/apis/compute_v1/classes.rb', line 10409

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::DiskList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10414
10415
10416
# File 'lib/google/apis/compute_v1/classes.rb', line 10414

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10421
10422
10423
10424
10425
10426
10427
10428
# File 'lib/google/apis/compute_v1/classes.rb', line 10421

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end