Class: Google::Apis::ComputeV1::DiskList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DiskList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of Disk resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Disk>
A list of Disk resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::DiskList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskList
constructor
A new instance of DiskList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskList
Returns a new instance of DiskList.
9143 9144 9145 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
9110 9111 9112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9110 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Disk>
A list of Disk resources.
Corresponds to the JSON property items
9115 9116 9117 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9115 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#diskList for
lists of disks.
Corresponds to the JSON property kind
9121 9122 9123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9121 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9131 9132 9133 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9131 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9136 9137 9138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9136 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::DiskList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
9141 9142 9143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9141 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9148 9149 9150 9151 9152 9153 9154 9155 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9148 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |