Class: Google::Apis::ComputeV1::DiskList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of Disk resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskList

Returns a new instance of DiskList.



6094
6095
6096
# File 'lib/google/apis/compute_v1/classes.rb', line 6094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6063
6064
6065
# File 'lib/google/apis/compute_v1/classes.rb', line 6063

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Disk>

A list of Disk resources. Corresponds to the JSON property items

Returns:



6068
6069
6070
# File 'lib/google/apis/compute_v1/classes.rb', line 6068

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#diskList for lists of disks. Corresponds to the JSON property kind

Returns:

  • (String)


6073
6074
6075
# File 'lib/google/apis/compute_v1/classes.rb', line 6073

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6082
6083
6084
# File 'lib/google/apis/compute_v1/classes.rb', line 6082

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6087
6088
6089
# File 'lib/google/apis/compute_v1/classes.rb', line 6087

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::DiskList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



6092
6093
6094
# File 'lib/google/apis/compute_v1/classes.rb', line 6092

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6099
6100
6101
6102
6103
6104
6105
6106
# File 'lib/google/apis/compute_v1/classes.rb', line 6099

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end