Class: Google::Apis::ComputeV1::DiskType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Disk Type resource. Google Compute Engine has two Disk Type resources:

  • Regional
  • Zonal You can choose from a variety of disk types based on your needs. For more information, readStorage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskType

Returns a new instance of DiskType.



10701
10702
10703
# File 'lib/google/apis/compute_v1/classes.rb', line 10701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


10641
10642
10643
# File 'lib/google/apis/compute_v1/classes.rb', line 10641

def creation_timestamp
  @creation_timestamp
end

#default_disk_size_gbFixnum

[Output Only] Server-defined default disk size in GB. Corresponds to the JSON property defaultDiskSizeGb

Returns:

  • (Fixnum)


10646
10647
10648
# File 'lib/google/apis/compute_v1/classes.rb', line 10646

def default_disk_size_gb
  @default_disk_size_gb
end

#deprecatedGoogle::Apis::ComputeV1::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



10651
10652
10653
# File 'lib/google/apis/compute_v1/classes.rb', line 10651

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


10656
10657
10658
# File 'lib/google/apis/compute_v1/classes.rb', line 10656

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


10662
10663
10664
# File 'lib/google/apis/compute_v1/classes.rb', line 10662

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#diskType for disk types. Corresponds to the JSON property kind

Returns:

  • (String)


10668
10669
10670
# File 'lib/google/apis/compute_v1/classes.rb', line 10668

def kind
  @kind
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


10673
10674
10675
# File 'lib/google/apis/compute_v1/classes.rb', line 10673

def name
  @name
end

#regionString

[Output Only] URL of the region where the disk type resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


10681
10682
10683
# File 'lib/google/apis/compute_v1/classes.rb', line 10681

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10686
10687
10688
# File 'lib/google/apis/compute_v1/classes.rb', line 10686

def self_link
  @self_link
end

#valid_disk_sizeString

[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB". Corresponds to the JSON property validDiskSize

Returns:

  • (String)


10692
10693
10694
# File 'lib/google/apis/compute_v1/classes.rb', line 10692

def valid_disk_size
  @valid_disk_size
end

#zoneString

[Output Only] URL of the zone where the disk type resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


10699
10700
10701
# File 'lib/google/apis/compute_v1/classes.rb', line 10699

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10706
10707
10708
10709
10710
10711
10712
10713
10714
10715
10716
10717
10718
# File 'lib/google/apis/compute_v1/classes.rb', line 10706

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size)
  @zone = args[:zone] if args.key?(:zone)
end