Class: Google::Apis::ComputeV1::DiskType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DiskType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Disk Type resource. Google Compute Engine has two Disk Type resources: * Regional * Zonal You can choose from a variety of disk types based on your needs. For more information, read Storage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, read Zonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
-
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] URL of the region where the disk type resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size, such as " 10GB-10TB".
-
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskType
constructor
A new instance of DiskType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskType
Returns a new instance of DiskType.
6276 6277 6278 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6276 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
6218 6219 6220 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6218 def @creation_timestamp end |
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
Corresponds to the JSON property defaultDiskSizeGb
6223 6224 6225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6223 def default_disk_size_gb @default_disk_size_gb end |
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
6228 6229 6230 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6228 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional description of this resource.
Corresponds to the JSON property description
6233 6234 6235 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6233 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
6239 6240 6241 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6239 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#diskType for disk types.
Corresponds to the JSON property kind
6244 6245 6246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6244 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
6249 6250 6251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6249 def name @name end |
#region ⇒ String
[Output Only] URL of the region where the disk type resides. Only applicable
for regional resources. You must specify this field as part of the HTTP
request URL. It is not settable as a field in the request body.
Corresponds to the JSON property region
6256 6257 6258 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6256 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
6261 6262 6263 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6261 def self_link @self_link end |
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size, such as "
10GB-10TB".
Corresponds to the JSON property validDiskSize
6267 6268 6269 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6267 def valid_disk_size @valid_disk_size end |
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides. You must specify
this field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property zone
6274 6275 6276 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6274 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6281 6282 6283 6284 6285 6286 6287 6288 6289 6290 6291 6292 6293 |
# File 'lib/google/apis/compute_v1/classes.rb', line 6281 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size) @zone = args[:zone] if args.key?(:zone) end |