Class: Google::Apis::ComputeV1::DistributionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DistributionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or on resize events (depending on the value set inupdatePolicy. instanceRedistributionType).
-
#zones ⇒ Array<Google::Apis::ComputeV1::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage its instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DistributionPolicy
constructor
A new instance of DistributionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DistributionPolicy
Returns a new instance of DistributionPolicy.
10137 10138 10139 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or
on resize events (depending on the value set inupdatePolicy.
instanceRedistributionType).
Corresponds to the JSON property targetShape
10129 10130 10131 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10129 def target_shape @target_shape end |
#zones ⇒ Array<Google::Apis::ComputeV1::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage
its instances.
Corresponds to the JSON property zones
10135 10136 10137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10135 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10142 10143 10144 10145 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10142 def update!(**args) @target_shape = args[:target_shape] if args.key?(:target_shape) @zones = args[:zones] if args.key?(:zones) end |