Class: Google::Apis::ComputeV1::ExchangedPeeringRoute

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoute

Returns a new instance of ExchangedPeeringRoute.



10215
10216
10217
# File 'lib/google/apis/compute_v1/classes.rb', line 10215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_rangeString

The destination range of the route. Corresponds to the JSON property destRange

Returns:

  • (String)


10188
10189
10190
# File 'lib/google/apis/compute_v1/classes.rb', line 10188

def dest_range
  @dest_range
end

#importedBoolean Also known as: imported?

True if the peering route has been imported from a peer. The actual import happens if the field networkPeering.importCustomRoutes is true for this network, and networkPeering.exportCustomRoutes is true for the peer network, and the import does not result in a route conflict. Corresponds to the JSON property imported

Returns:

  • (Boolean)


10197
10198
10199
# File 'lib/google/apis/compute_v1/classes.rb', line 10197

def imported
  @imported
end

#next_hop_regionString

The region of peering route next hop, only applies to dynamic routes. Corresponds to the JSON property nextHopRegion

Returns:

  • (String)


10203
10204
10205
# File 'lib/google/apis/compute_v1/classes.rb', line 10203

def next_hop_region
  @next_hop_region
end

#priorityFixnum

The priority of the peering route. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


10208
10209
10210
# File 'lib/google/apis/compute_v1/classes.rb', line 10208

def priority
  @priority
end

#typeString

The type of the peering route. Corresponds to the JSON property type

Returns:

  • (String)


10213
10214
10215
# File 'lib/google/apis/compute_v1/classes.rb', line 10213

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10220
10221
10222
10223
10224
10225
10226
# File 'lib/google/apis/compute_v1/classes.rb', line 10220

def update!(**args)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @imported = args[:imported] if args.key?(:imported)
  @next_hop_region = args[:next_hop_region] if args.key?(:next_hop_region)
  @priority = args[:priority] if args.key?(:priority)
  @type = args[:type] if args.key?(:type)
end