Class: Google::Apis::ComputeV1::ExchangedPeeringRoutesList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ExchangedPeeringRoutesList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExchangedPeeringRoutesList
constructor
A new instance of ExchangedPeeringRoutesList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExchangedPeeringRoutesList
Returns a new instance of ExchangedPeeringRoutesList.
11760 11761 11762 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
11726 11727 11728 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11726 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
Corresponds to the JSON property items
11731 11732 11733 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11731 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
exchangedPeeringRoutesList for exchanged peering
routes lists.
Corresponds to the JSON property kind
11738 11739 11740 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11738 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11748 11749 11750 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11748 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
11753 11754 11755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11753 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
11758 11759 11760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11758 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11765 11766 11767 11768 11769 11770 11771 11772 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11765 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |