Class: Google::Apis::ComputeV1::ExchangedPeeringRoutesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoutesList

Returns a new instance of ExchangedPeeringRoutesList.



11710
11711
11712
# File 'lib/google/apis/compute_v1/classes.rb', line 11710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11676
11677
11678
# File 'lib/google/apis/compute_v1/classes.rb', line 11676

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ExchangedPeeringRoute>

A list of ExchangedPeeringRoute resources. Corresponds to the JSON property items



11681
11682
11683
# File 'lib/google/apis/compute_v1/classes.rb', line 11681

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# exchangedPeeringRoutesList for exchanged peering routes lists. Corresponds to the JSON property kind

Returns:

  • (String)


11688
11689
11690
# File 'lib/google/apis/compute_v1/classes.rb', line 11688

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11698
11699
11700
# File 'lib/google/apis/compute_v1/classes.rb', line 11698

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11703
11704
11705
# File 'lib/google/apis/compute_v1/classes.rb', line 11703

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ExchangedPeeringRoutesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11708
11709
11710
# File 'lib/google/apis/compute_v1/classes.rb', line 11708

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11715
11716
11717
11718
11719
11720
11721
11722
# File 'lib/google/apis/compute_v1/classes.rb', line 11715

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end