Class: Google::Apis::ComputeV1::ExchangedPeeringRoutesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoutesList

Returns a new instance of ExchangedPeeringRoutesList.



11581
11582
11583
# File 'lib/google/apis/compute_v1/classes.rb', line 11581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11547
11548
11549
# File 'lib/google/apis/compute_v1/classes.rb', line 11547

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ExchangedPeeringRoute>

A list of ExchangedPeeringRoute resources. Corresponds to the JSON property items



11552
11553
11554
# File 'lib/google/apis/compute_v1/classes.rb', line 11552

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# exchangedPeeringRoutesList for exchanged peering routes lists. Corresponds to the JSON property kind

Returns:

  • (String)


11559
11560
11561
# File 'lib/google/apis/compute_v1/classes.rb', line 11559

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11569
11570
11571
# File 'lib/google/apis/compute_v1/classes.rb', line 11569

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11574
11575
11576
# File 'lib/google/apis/compute_v1/classes.rb', line 11574

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ExchangedPeeringRoutesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11579
11580
11581
# File 'lib/google/apis/compute_v1/classes.rb', line 11579

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11586
11587
11588
11589
11590
11591
11592
11593
# File 'lib/google/apis/compute_v1/classes.rb', line 11586

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end