Class: Google::Apis::ComputeV1::ExchangedPeeringRoutesList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ExchangedPeeringRoutesList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExchangedPeeringRoutesList
constructor
A new instance of ExchangedPeeringRoutesList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExchangedPeeringRoutesList
Returns a new instance of ExchangedPeeringRoutesList.
10270 10271 10272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10236 10237 10238 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10236 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
Corresponds to the JSON property items
10241 10242 10243 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10241 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
exchangedPeeringRoutesList for exchanged peering
routes lists.
Corresponds to the JSON property kind
10248 10249 10250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10248 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10258 10259 10260 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10258 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10263 10264 10265 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10263 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10268 10269 10270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10268 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10275 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |