Class: Google::Apis::ComputeV1::Expr

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: "Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example (Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Expr

Returns a new instance of Expr.



10491
10492
10493
# File 'lib/google/apis/compute_v1/classes.rb', line 10491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI. Corresponds to the JSON property description

Returns:

  • (String)


10470
10471
10472
# File 'lib/google/apis/compute_v1/classes.rb', line 10470

def description
  @description
end

#expressionString

Textual representation of an expression in Common Expression Language syntax. Corresponds to the JSON property expression

Returns:

  • (String)


10476
10477
10478
# File 'lib/google/apis/compute_v1/classes.rb', line 10476

def expression
  @expression
end

#locationString

Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file. Corresponds to the JSON property location

Returns:

  • (String)


10482
10483
10484
# File 'lib/google/apis/compute_v1/classes.rb', line 10482

def location
  @location
end

#titleString

Optional. Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression. Corresponds to the JSON property title

Returns:

  • (String)


10489
10490
10491
# File 'lib/google/apis/compute_v1/classes.rb', line 10489

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10496
10497
10498
10499
10500
10501
# File 'lib/google/apis/compute_v1/classes.rb', line 10496

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @expression = args[:expression] if args.key?(:expression)
  @location = args[:location] if args.key?(:location)
  @title = args[:title] if args.key?(:title)
end