Class: Google::Apis::ComputeV1::ExternalVpnGateway

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an external VPN gateway. External VPN gateway is the on-premises VPN gateway(s) or another cloud provider's VPN gateway that connects to your Google Cloud VPN gateway. To create a highly available VPN from Google Cloud Platform to your VPN gateway or another cloud provider's VPN gateway, you must create a external VPN gateway resource with information about the other gateway. For more information about using external VPN gateways, see Creating an HA VPN gateway and tunnel pair to a peer VPN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGateway

Returns a new instance of ExternalVpnGateway.



10504
10505
10506
# File 'lib/google/apis/compute_v1/classes.rb', line 10504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


10433
10434
10435
# File 'lib/google/apis/compute_v1/classes.rb', line 10433

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


10439
10440
10441
# File 'lib/google/apis/compute_v1/classes.rb', line 10439

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


10446
10447
10448
# File 'lib/google/apis/compute_v1/classes.rb', line 10446

def id
  @id
end

#interfacesArray<Google::Apis::ComputeV1::ExternalVpnGatewayInterface>

A list of interfaces for this external VPN gateway. If your peer-side gateway is an on-premises gateway and non-AWS cloud providers' gateway, at most two interfaces can be provided for an external VPN gateway. If your peer side is an AWS virtual private gateway, four interfaces should be provided for an external VPN gateway. Corresponds to the JSON property interfaces



10455
10456
10457
# File 'lib/google/apis/compute_v1/classes.rb', line 10455

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# externalVpnGateway for externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


10461
10462
10463
# File 'lib/google/apis/compute_v1/classes.rb', line 10461

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this ExternalVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an ExternalVpnGateway. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


10474
10475
10476
# File 'lib/google/apis/compute_v1/classes.rb', line 10474

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


10481
10482
10483
# File 'lib/google/apis/compute_v1/classes.rb', line 10481

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


10492
10493
10494
# File 'lib/google/apis/compute_v1/classes.rb', line 10492

def name
  @name
end

#redundancy_typeString

Indicates the user-supplied redundancy type of this external VPN gateway. Corresponds to the JSON property redundancyType

Returns:

  • (String)


10497
10498
10499
# File 'lib/google/apis/compute_v1/classes.rb', line 10497

def redundancy_type
  @redundancy_type
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10502
10503
10504
# File 'lib/google/apis/compute_v1/classes.rb', line 10502

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
# File 'lib/google/apis/compute_v1/classes.rb', line 10509

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @redundancy_type = args[:redundancy_type] if args.key?(:redundancy_type)
  @self_link = args[:self_link] if args.key?(:self_link)
end