Class: Google::Apis::ComputeV1::ExternalVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of externalVpnGateways.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGatewayList

Returns a new instance of ExternalVpnGatewayList.



12111
12112
12113
# File 'lib/google/apis/compute_v1/classes.rb', line 12111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


12073
12074
12075
# File 'lib/google/apis/compute_v1/classes.rb', line 12073

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12078
12079
12080
# File 'lib/google/apis/compute_v1/classes.rb', line 12078

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ExternalVpnGateway>

A list of ExternalVpnGateway resources. Corresponds to the JSON property items



12083
12084
12085
# File 'lib/google/apis/compute_v1/classes.rb', line 12083

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# externalVpnGatewayList for lists of externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


12089
12090
12091
# File 'lib/google/apis/compute_v1/classes.rb', line 12089

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12099
12100
12101
# File 'lib/google/apis/compute_v1/classes.rb', line 12099

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12104
12105
12106
# File 'lib/google/apis/compute_v1/classes.rb', line 12104

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ExternalVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12109
12110
12111
# File 'lib/google/apis/compute_v1/classes.rb', line 12109

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12116
12117
12118
12119
12120
12121
12122
12123
12124
# File 'lib/google/apis/compute_v1/classes.rb', line 12116

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end