Class: Google::Apis::ComputeV1::ExternalVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ExternalVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of externalVpnGateways.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalVpnGatewayList
constructor
A new instance of ExternalVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalVpnGatewayList
Returns a new instance of ExternalVpnGatewayList.
12061 12062 12063 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
12023 12024 12025 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12023 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
12028 12029 12030 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12028 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
Corresponds to the JSON property items
12033 12034 12035 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12033 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
externalVpnGatewayList for lists of externalVpnGateways.
Corresponds to the JSON property kind
12039 12040 12041 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12039 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12049 12050 12051 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12049 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12054 12055 12056 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12054 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12059 12060 12061 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12059 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12066 12067 12068 12069 12070 12071 12072 12073 12074 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12066 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |