Class: Google::Apis::ComputeV1::ExternalVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of externalVpnGateways.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGatewayList

Returns a new instance of ExternalVpnGatewayList.



12052
12053
12054
# File 'lib/google/apis/compute_v1/classes.rb', line 12052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


12014
12015
12016
# File 'lib/google/apis/compute_v1/classes.rb', line 12014

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12019
12020
12021
# File 'lib/google/apis/compute_v1/classes.rb', line 12019

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ExternalVpnGateway>

A list of ExternalVpnGateway resources. Corresponds to the JSON property items



12024
12025
12026
# File 'lib/google/apis/compute_v1/classes.rb', line 12024

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# externalVpnGatewayList for lists of externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


12030
12031
12032
# File 'lib/google/apis/compute_v1/classes.rb', line 12030

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12040
12041
12042
# File 'lib/google/apis/compute_v1/classes.rb', line 12040

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12045
12046
12047
# File 'lib/google/apis/compute_v1/classes.rb', line 12045

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ExternalVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12050
12051
12052
# File 'lib/google/apis/compute_v1/classes.rb', line 12050

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12057
12058
12059
12060
12061
12062
12063
12064
12065
# File 'lib/google/apis/compute_v1/classes.rb', line 12057

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end