Class: Google::Apis::ComputeV1::ExternalVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ExternalVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of externalVpnGateways.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalVpnGatewayList
constructor
A new instance of ExternalVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalVpnGatewayList
Returns a new instance of ExternalVpnGatewayList.
11927 11928 11929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
11889 11890 11891 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11889 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
11894 11895 11896 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11894 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
Corresponds to the JSON property items
11899 11900 11901 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11899 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
externalVpnGatewayList for lists of externalVpnGateways.
Corresponds to the JSON property kind
11905 11906 11907 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11905 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11915 11916 11917 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11915 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
11920 11921 11922 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11920 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
11925 11926 11927 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11925 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11932 11933 11934 11935 11936 11937 11938 11939 11940 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11932 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |