Class: Google::Apis::ComputeV1::ExternalVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of externalVpnGateways.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGatewayList

Returns a new instance of ExternalVpnGatewayList.



11932
11933
11934
# File 'lib/google/apis/compute_v1/classes.rb', line 11932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


11894
11895
11896
# File 'lib/google/apis/compute_v1/classes.rb', line 11894

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11899
11900
11901
# File 'lib/google/apis/compute_v1/classes.rb', line 11899

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ExternalVpnGateway>

A list of ExternalVpnGateway resources. Corresponds to the JSON property items



11904
11905
11906
# File 'lib/google/apis/compute_v1/classes.rb', line 11904

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# externalVpnGatewayList for lists of externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


11910
11911
11912
# File 'lib/google/apis/compute_v1/classes.rb', line 11910

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11920
11921
11922
# File 'lib/google/apis/compute_v1/classes.rb', line 11920

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11925
11926
11927
# File 'lib/google/apis/compute_v1/classes.rb', line 11925

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ExternalVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11930
11931
11932
# File 'lib/google/apis/compute_v1/classes.rb', line 11930

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11937
11938
11939
11940
11941
11942
11943
11944
11945
# File 'lib/google/apis/compute_v1/classes.rb', line 11937

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end