Class: Google::Apis::ComputeV1::ExternalVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of externalVpnGateways.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGatewayList

Returns a new instance of ExternalVpnGatewayList.



10613
10614
10615
# File 'lib/google/apis/compute_v1/classes.rb', line 10613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


10575
10576
10577
# File 'lib/google/apis/compute_v1/classes.rb', line 10575

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10580
10581
10582
# File 'lib/google/apis/compute_v1/classes.rb', line 10580

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ExternalVpnGateway>

A list of ExternalVpnGateway resources. Corresponds to the JSON property items



10585
10586
10587
# File 'lib/google/apis/compute_v1/classes.rb', line 10585

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# externalVpnGatewayList for lists of externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


10591
10592
10593
# File 'lib/google/apis/compute_v1/classes.rb', line 10591

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10601
10602
10603
# File 'lib/google/apis/compute_v1/classes.rb', line 10601

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10606
10607
10608
# File 'lib/google/apis/compute_v1/classes.rb', line 10606

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ExternalVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10611
10612
10613
# File 'lib/google/apis/compute_v1/classes.rb', line 10611

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10618
10619
10620
10621
10622
10623
10624
10625
10626
# File 'lib/google/apis/compute_v1/classes.rb', line 10618

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end