Class: Google::Apis::ComputeV1::ExternalVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ExternalVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of externalVpnGateways.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalVpnGatewayList
constructor
A new instance of ExternalVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalVpnGatewayList
Returns a new instance of ExternalVpnGatewayList.
7270 7271 7272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
7233 7234 7235 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7233 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
7238 7239 7240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7238 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
Corresponds to the JSON property items
7243 7244 7245 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7243 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#externalVpnGatewayList for
lists of externalVpnGateways.
Corresponds to the JSON property kind
7249 7250 7251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7249 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
7258 7259 7260 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7258 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
7263 7264 7265 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7263 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
7268 7269 7270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7268 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7275 7276 7277 7278 7279 7280 7281 7282 7283 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7275 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |