Class: Google::Apis::ComputeV1::Firewall

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Firewall Rule resource. Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, readFirewall rules.

Defined Under Namespace

Classes: Allowed, Denied

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Firewall

Returns a new instance of Firewall.



10912
10913
10914
# File 'lib/google/apis/compute_v1/classes.rb', line 10912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedArray<Google::Apis::ComputeV1::Firewall::Allowed>

The list of ALLOW rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a permitted connection. Corresponds to the JSON property allowed



10735
10736
10737
# File 'lib/google/apis/compute_v1/classes.rb', line 10735

def allowed
  @allowed
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


10741
10742
10743
# File 'lib/google/apis/compute_v1/classes.rb', line 10741

def creation_timestamp
  @creation_timestamp
end

#deniedArray<Google::Apis::ComputeV1::Firewall::Denied>

The list of DENY rules specified by this firewall. Each rule specifies a protocol and port-range tuple that describes a denied connection. Corresponds to the JSON property denied



10747
10748
10749
# File 'lib/google/apis/compute_v1/classes.rb', line 10747

def denied
  @denied
end

#descriptionString

An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


10753
10754
10755
# File 'lib/google/apis/compute_v1/classes.rb', line 10753

def description
  @description
end

#destination_rangesArray<String>

If destination ranges are specified, the firewall rule applies only to traffic that has destination IP address in these ranges. These ranges must be expressed inCIDR format. Both IPv4 and IPv6 are supported. Corresponds to the JSON property destinationRanges

Returns:

  • (Array<String>)


10760
10761
10762
# File 'lib/google/apis/compute_v1/classes.rb', line 10760

def destination_ranges
  @destination_ranges
end

#directionString

Direction of traffic to which this firewall applies, either INGRESS or EGRESS. The default is INGRESS. For EGRESS traffic, you cannot specify the sourceTags fields. Corresponds to the JSON property direction

Returns:

  • (String)


10767
10768
10769
# File 'lib/google/apis/compute_v1/classes.rb', line 10767

def direction
  @direction
end

#disabledBoolean Also known as: disabled?

Denotes whether the firewall rule is disabled. When set to true, the firewall rule is not enforced and the network behaves as if it did not exist. If this is unspecified, the firewall rule will be enabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


10774
10775
10776
# File 'lib/google/apis/compute_v1/classes.rb', line 10774

def disabled
  @disabled
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


10782
10783
10784
# File 'lib/google/apis/compute_v1/classes.rb', line 10782

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#firewall for firewall rules. Corresponds to the JSON property kind

Returns:

  • (String)


10788
10789
10790
# File 'lib/google/apis/compute_v1/classes.rb', line 10788

def kind
  @kind
end

#log_configGoogle::Apis::ComputeV1::FirewallLogConfig

The available logging options for a firewall rule. Corresponds to the JSON property logConfig



10793
10794
10795
# File 'lib/google/apis/compute_v1/classes.rb', line 10793

def log_config
  @log_config
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit. Corresponds to the JSON property name

Returns:

  • (String)


10804
10805
10806
# File 'lib/google/apis/compute_v1/classes.rb', line 10804

def name
  @name
end

#networkString

URL of the network resource for this firewall rule. If not specified when creating a firewall rule, the default network is used: global/networks/default If you choose to specify this field, you can specify the network as a full or partial URL. For example, the following are all valid URLs:

- https://www.googleapis.com/compute/v1/projects/myproject/global/networks/my- network

  • projects/myproject/global/networks/my-network
  • global/networks/default Corresponds to the JSON property network

Returns:

  • (String)


10820
10821
10822
# File 'lib/google/apis/compute_v1/classes.rb', line 10820

def network
  @network
end

#paramsGoogle::Apis::ComputeV1::FirewallParams

Additional firewall parameters. Corresponds to the JSON property params



10825
10826
10827
# File 'lib/google/apis/compute_v1/classes.rb', line 10825

def params
  @params
end

#priorityFixnum

Priority for this rule. This is an integer between 0 and 65535, both inclusive. The default value is 1000. Relative priorities determine which rule takes effect if multiple rules apply. Lower values indicate higher priority. For example, a rule with priority 0 has higher precedence than a rule with priority 1. DENY rules take precedence over ALLOW rules if they have equal priority. Note that VPC networks have implied rules with a priority of 65535. To avoid conflicts with the implied rules, use a priority number less than 65535. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


10839
10840
10841
# File 'lib/google/apis/compute_v1/classes.rb', line 10839

def priority
  @priority
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10844
10845
10846
# File 'lib/google/apis/compute_v1/classes.rb', line 10844

def self_link
  @self_link
end

#source_rangesArray<String>

If source ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed inCIDR format. One or both of sourceRanges and sourceTags may be set. If both fields are set, the rule applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in thesourceTags field. The connection does not need to match both fields for the rule to apply. Both IPv4 and IPv6 are supported. Corresponds to the JSON property sourceRanges

Returns:

  • (Array<String>)


10858
10859
10860
# File 'lib/google/apis/compute_v1/classes.rb', line 10858

def source_ranges
  @source_ranges
end

#source_service_accountsArray<String>

If source service accounts are specified, the firewall rules apply only to traffic originating from an instance with a service account in this list. Source service accounts cannot be used to control traffic to an instance's external IP address because service accounts are associated with an instance, not an IP address.sourceRanges can be set at the same time assourceServiceAccounts. If both are set, the firewall applies to traffic that has a source IP address within the sourceRanges OR a source IP that belongs to an instance with service account listed insourceServiceAccount. The connection does not need to match both fields for the firewall to apply.sourceServiceAccounts cannot be used at the same time assourceTags or targetTags. Corresponds to the JSON property sourceServiceAccounts

Returns:

  • (Array<String>)


10874
10875
10876
# File 'lib/google/apis/compute_v1/classes.rb', line 10874

def source_service_accounts
  @source_service_accounts
end

#source_tagsArray<String>

If source tags are specified, the firewall rule applies only to traffic with source IPs that match the primary network interfaces of VM instances that have the tag and are in the same VPC network. Source tags cannot be used to control traffic to an instance's external IP address, it only applies to traffic between instances in the same virtual network. Because tags are associated with instances, not IP addresses. One or both of sourceRanges and sourceTags may be set. If both fields are set, the firewall applies to traffic that has a source IP address within sourceRanges OR a source IP from a resource with a matching tag listed in the sourceTags field. The connection does not need to match both fields for the firewall to apply. Corresponds to the JSON property sourceTags

Returns:

  • (Array<String>)


10890
10891
10892
# File 'lib/google/apis/compute_v1/classes.rb', line 10890

def source_tags
  @source_tags
end

#target_service_accountsArray<String>

A list of service accounts indicating sets of instances located in the network that may make network connections as specified inallowed[]. targetServiceAccounts cannot be used at the same time astargetTags or sourceTags. If neither targetServiceAccounts nor targetTags are specified, the firewall rule applies to all instances on the specified network. Corresponds to the JSON property targetServiceAccounts

Returns:

  • (Array<String>)


10901
10902
10903
# File 'lib/google/apis/compute_v1/classes.rb', line 10901

def target_service_accounts
  @target_service_accounts
end

#target_tagsArray<String>

A list of tags that controls which instances the firewall rule applies to. If targetTags are specified, then the firewall rule applies only to instances in the VPC network that have one of those tags. If no targetTags are specified, the firewall rule applies to all instances on the specified network. Corresponds to the JSON property targetTags

Returns:

  • (Array<String>)


10910
10911
10912
# File 'lib/google/apis/compute_v1/classes.rb', line 10910

def target_tags
  @target_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10917
10918
10919
10920
10921
10922
10923
10924
10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
# File 'lib/google/apis/compute_v1/classes.rb', line 10917

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @denied = args[:denied] if args.key?(:denied)
  @description = args[:description] if args.key?(:description)
  @destination_ranges = args[:destination_ranges] if args.key?(:destination_ranges)
  @direction = args[:direction] if args.key?(:direction)
  @disabled = args[:disabled] if args.key?(:disabled)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @log_config = args[:log_config] if args.key?(:log_config)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @priority = args[:priority] if args.key?(:priority)
  @self_link = args[:self_link] if args.key?(:self_link)
  @source_ranges = args[:source_ranges] if args.key?(:source_ranges)
  @source_service_accounts = args[:source_service_accounts] if args.key?(:source_service_accounts)
  @source_tags = args[:source_tags] if args.key?(:source_tags)
  @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts)
  @target_tags = args[:target_tags] if args.key?(:target_tags)
end