Class: Google::Apis::ComputeV1::Firewall::Allowed
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Firewall::Allowed
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#ip_protocol ⇒ String
The IP protocol to which this rule applies.
-
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Allowed
constructor
A new instance of Allowed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Allowed
Returns a new instance of Allowed.
12498 12499 12500 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12498 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_protocol ⇒ String
The IP protocol to which this rule applies. The protocol type is
required when creating a firewall rule. This value can either be one of the
following well known protocol strings (tcp, udp,icmp, esp, ah, ipip,sctp) or
the IP protocol number.
Corresponds to the JSON property IPProtocol
12486 12487 12488 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12486 def ip_protocol @ip_protocol end |
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
This field is only applicable for the UDP or TCP protocol.
Each entry must be either an integer or a range.
If not specified, this rule applies to connections through any port.
Example inputs include: ["22"], ["80","443"],
and ["12345-12349"].
Corresponds to the JSON property ports
12496 12497 12498 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12496 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12503 12504 12505 12506 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12503 def update!(**args) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @ports = args[:ports] if args.key?(:ports) end |