Class: Google::Apis::ComputeV1::Firewall::Denied

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Denied

Returns a new instance of Denied.



11121
11122
11123
# File 'lib/google/apis/compute_v1/classes.rb', line 11121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_protocolString

The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp,icmp, esp, ah, ipip,sctp) or the IP protocol number. Corresponds to the JSON property IPProtocol

Returns:

  • (String)


11109
11110
11111
# File 'lib/google/apis/compute_v1/classes.rb', line 11109

def ip_protocol
  @ip_protocol
end

#portsArray<String>

An optional list of ports to which this rule applies. This field is only applicable for the UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"], ["80","443"], and ["12345-12349"]. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


11119
11120
11121
# File 'lib/google/apis/compute_v1/classes.rb', line 11119

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11126
11127
11128
11129
# File 'lib/google/apis/compute_v1/classes.rb', line 11126

def update!(**args)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @ports = args[:ports] if args.key?(:ports)
end