Class: Google::Apis::ComputeV1::Firewall::Denied
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Firewall::Denied
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#ip_protocol ⇒ String
The IP protocol to which this rule applies.
-
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Denied
constructor
A new instance of Denied.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Denied
Returns a new instance of Denied.
7616 7617 7618 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_protocol ⇒ String
The IP protocol to which this rule applies. The protocol type is required when
creating a firewall rule. This value can either be one of the following well
known protocol strings (tcp, udp, icmp, esp, ah, ipip, sctp) or the IP
protocol number.
Corresponds to the JSON property IPProtocol
7606 7607 7608 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7606 def ip_protocol @ip_protocol end |
#ports ⇒ Array<String>
An optional list of ports to which this rule applies. This field is only
applicable for the UDP or TCP protocol. Each entry must be either an integer
or a range. If not specified, this rule applies to connections through any
port. Example inputs include: ["22"], ["80","443"], and ["12345-12349"].
Corresponds to the JSON property ports
7614 7615 7616 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7614 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7621 7622 7623 7624 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7621 def update!(**args) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @ports = args[:ports] if args.key?(:ports) end |