Class: Google::Apis::ComputeV1::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



12518
12519
12520
# File 'lib/google/apis/compute_v1/classes.rb', line 12518

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12485
12486
12487
# File 'lib/google/apis/compute_v1/classes.rb', line 12485

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



12490
12491
12492
# File 'lib/google/apis/compute_v1/classes.rb', line 12490

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


12496
12497
12498
# File 'lib/google/apis/compute_v1/classes.rb', line 12496

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12506
12507
12508
# File 'lib/google/apis/compute_v1/classes.rb', line 12506

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12511
12512
12513
# File 'lib/google/apis/compute_v1/classes.rb', line 12511

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12516
12517
12518
# File 'lib/google/apis/compute_v1/classes.rb', line 12516

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12523
12524
12525
12526
12527
12528
12529
12530
# File 'lib/google/apis/compute_v1/classes.rb', line 12523

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end