Class: Google::Apis::ComputeV1::FirewallList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of firewalls.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Firewall>
A list of Firewall resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::FirewallList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallList
constructor
A new instance of FirewallList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallList
Returns a new instance of FirewallList.
12393 12394 12395 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
12360 12361 12362 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12360 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Firewall>
A list of Firewall resources.
Corresponds to the JSON property items
12365 12366 12367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12365 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#firewallList
for lists of firewalls.
Corresponds to the JSON property kind
12371 12372 12373 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12371 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12381 12382 12383 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12381 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12386 12387 12388 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12386 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::FirewallList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12391 12392 12393 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12391 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12398 12399 12400 12401 12402 12403 12404 12405 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12398 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |