Class: Google::Apis::ComputeV1::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



12410
12411
12412
# File 'lib/google/apis/compute_v1/classes.rb', line 12410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12377
12378
12379
# File 'lib/google/apis/compute_v1/classes.rb', line 12377

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



12382
12383
12384
# File 'lib/google/apis/compute_v1/classes.rb', line 12382

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


12388
12389
12390
# File 'lib/google/apis/compute_v1/classes.rb', line 12388

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12398
12399
12400
# File 'lib/google/apis/compute_v1/classes.rb', line 12398

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12403
12404
12405
# File 'lib/google/apis/compute_v1/classes.rb', line 12403

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12408
12409
12410
# File 'lib/google/apis/compute_v1/classes.rb', line 12408

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12415
12416
12417
12418
12419
12420
12421
12422
# File 'lib/google/apis/compute_v1/classes.rb', line 12415

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end