Class: Google::Apis::ComputeV1::FirewallList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of firewalls.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Firewall>
A list of Firewall resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::FirewallList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallList
constructor
A new instance of FirewallList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallList
Returns a new instance of FirewallList.
11173 11174 11175 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
11140 11141 11142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11140 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Firewall>
A list of Firewall resources.
Corresponds to the JSON property items
11145 11146 11147 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11145 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#firewallList
for lists of firewalls.
Corresponds to the JSON property kind
11151 11152 11153 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11151 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11161 11162 11163 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11161 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
11166 11167 11168 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11166 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::FirewallList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
11171 11172 11173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11171 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11178 11179 11180 11181 11182 11183 11184 11185 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11178 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |