Class: Google::Apis::ComputeV1::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



7667
7668
7669
# File 'lib/google/apis/compute_v1/classes.rb', line 7667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


7635
7636
7637
# File 'lib/google/apis/compute_v1/classes.rb', line 7635

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



7640
7641
7642
# File 'lib/google/apis/compute_v1/classes.rb', line 7640

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


7646
7647
7648
# File 'lib/google/apis/compute_v1/classes.rb', line 7646

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7655
7656
7657
# File 'lib/google/apis/compute_v1/classes.rb', line 7655

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


7660
7661
7662
# File 'lib/google/apis/compute_v1/classes.rb', line 7660

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



7665
7666
7667
# File 'lib/google/apis/compute_v1/classes.rb', line 7665

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/google/apis/compute_v1/classes.rb', line 7672

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end