Class: Google::Apis::ComputeV1::FirewallLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The available logging options for a firewall rule.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
This field denotes whether to enable logging for a particular firewall rule.
-
#metadata ⇒ String
This field can only be specified for a particular firewall rule if logging is enabled for that rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallLogConfig
constructor
A new instance of FirewallLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallLogConfig
Returns a new instance of FirewallLogConfig.
12621 12622 12623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
This field denotes whether to enable logging for a particular firewall
rule.
Corresponds to the JSON property enable
12611 12612 12613 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12611 def enable @enable end |
#metadata ⇒ String
This field can only be specified for a particular firewall rule if
logging is enabled for that rule. This field denotes whether to include
or exclude metadata for firewall logs.
Corresponds to the JSON property metadata
12619 12620 12621 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12619 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12626 12627 12628 12629 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12626 def update!(**args) @enable = args[:enable] if args.key?(:enable) @metadata = args[:metadata] if args.key?(:metadata) end |