Class: Google::Apis::ComputeV1::FirewallLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The available logging options for a firewall rule.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
This field denotes whether to enable logging for a particular firewall rule.
-
#metadata ⇒ String
This field can only be specified for a particular firewall rule if logging is enabled for that rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallLogConfig
constructor
A new instance of FirewallLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallLogConfig
Returns a new instance of FirewallLogConfig.
7763 7764 7765 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
This field denotes whether to enable logging for a particular firewall rule.
Corresponds to the JSON property enable
7753 7754 7755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7753 def enable @enable end |
#metadata ⇒ String
This field can only be specified for a particular firewall rule if logging is
enabled for that rule. This field denotes whether to include or exclude
metadata for firewall logs.
Corresponds to the JSON property metadata
7761 7762 7763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7761 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7768 7769 7770 7771 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7768 def update!(**args) @enable = args[:enable] if args.key?(:enable) @metadata = args[:metadata] if args.key?(:metadata) end |