Class: Google::Apis::ComputeV1::FirewallPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Firewall Policy resource.
Instance Attribute Summary collapse
-
#associations ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyAssociation>
A list of associations that belong to this firewall policy.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#display_name ⇒ String
Deprecated, please use short name instead.
-
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#packet_mirroring_rules ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRule>
A list of packet mirroring rules that belong to this policy.
-
#parent ⇒ String
Output only.
-
#policy_type ⇒ String
The type of the firewall policy.
-
#region ⇒ String
Output only.
-
#rule_tuple_count ⇒ Fixnum
Output only.
-
#rules ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRule>
A list of rules that belong to this policy.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#short_name ⇒ String
User-provided name of the Organization firewall policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicy
constructor
A new instance of FirewallPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicy
Returns a new instance of FirewallPolicy.
12930 12931 12932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12930 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associations ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyAssociation>
A list of associations that belong to this firewall policy.
Corresponds to the JSON property associations
12802 12803 12804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12802 def associations @associations end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
12808 12809 12810 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12808 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
12814 12815 12816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12814 def description @description end |
#display_name ⇒ String
Deprecated, please use short name instead. User-provided name of the
Organization firewall policy. The name should be unique in the organization
in which the firewall policy is created.
This field is not applicable to network firewall policies.
This name must be set on creation and cannot be changed.
The name must be 1-63 characters long, and comply
with RFC1035. Specifically, the name must be 1-63 characters
long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which
means the first character must be a lowercase letter, and all following
characters must be a dash, lowercase letter, or digit, except the last
character, which cannot be a dash.
Corresponds to the JSON property displayName
12829 12830 12831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12829 def display_name @display_name end |
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of
the metadata's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update metadata. You must always provide an
up-to-date fingerprint hash in order to update or change metadata,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make get() request to the
firewall policy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
12842 12843 12844 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12842 def fingerprint @fingerprint end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
12848 12849 12850 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12848 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#
firewallPolicyfor firewall policies
Corresponds to the JSON property kind
12854 12855 12856 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12854 def kind @kind end |
#name ⇒ String
Name of the resource. For Organization Firewall Policies it's a
[Output Only] numeric ID allocated by Google Cloud which uniquely
identifies the Organization Firewall Policy.
Corresponds to the JSON property name
12861 12862 12863 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12861 def name @name end |
#packet_mirroring_rules ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRule>
A list of packet mirroring rules that belong to this policy.
Corresponds to the JSON property packetMirroringRules
12866 12867 12868 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12866 def packet_mirroring_rules @packet_mirroring_rules end |
#parent ⇒ String
Output only. [Output Only] The parent of the firewall policy.
This field is not applicable to network firewall policies.
Corresponds to the JSON property parent
12872 12873 12874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12872 def parent @parent end |
#policy_type ⇒ String
The type of the firewall policy. This field can be one of
VPC_POLICY, RDMA_ROCE_POLICY or ULL_POLICY.
Note: if not specified then VPC_POLICY will be used.
Corresponds to the JSON property policyType
12879 12880 12881 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12879 def policy_type @policy_type end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional firewall
policy resides.
This field is not applicable to global firewall policies.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
12888 12889 12890 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12888 def region @region end |
#rule_tuple_count ⇒ Fixnum
Output only. [Output Only] Total count of all firewall policy rule tuples. A
firewall
policy can not exceed a set number of tuples.
Corresponds to the JSON property ruleTupleCount
12895 12896 12897 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12895 def rule_tuple_count @rule_tuple_count end |
#rules ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRule>
A list of rules that belong to this policy.
There must always be a default rule (rule with priority 2147483647 and
match "*"). If no rules are provided when creating a firewall policy, a
default rule with action "allow" will be added.
Corresponds to the JSON property rules
12903 12904 12905 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12903 def rules @rules end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
12908 12909 12910 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12908 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
12914 12915 12916 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12914 def self_link_with_id @self_link_with_id end |
#short_name ⇒ String
User-provided name of the Organization firewall policy. The name should be
unique in the organization in which the firewall policy is created.
This field is not applicable to network firewall policies.
This name must be set on creation and cannot be changed. The name must be
1-63 characters long, and comply with RFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property shortName
12928 12929 12930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12928 def short_name @short_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12935 12936 12937 12938 12939 12940 12941 12942 12943 12944 12945 12946 12947 12948 12949 12950 12951 12952 12953 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12935 def update!(**args) @associations = args[:associations] if args.key?(:associations) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules) @parent = args[:parent] if args.key?(:parent) @policy_type = args[:policy_type] if args.key?(:policy_type) @region = args[:region] if args.key?(:region) @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @short_name = args[:short_name] if args.key?(:short_name) end |