Class: Google::Apis::ComputeV1::FirewallPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Firewall Policy resource.
Instance Attribute Summary collapse
-
#associations ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyAssociation>
A list of associations that belong to this firewall policy.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#display_name ⇒ String
Deprecated, please use short name instead.
-
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output only] Type of the resource.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#parent ⇒ String
[Output Only] The parent of the firewall policy.
-
#region ⇒ String
[Output Only] URL of the region where the regional firewall policy resides.
-
#rule_tuple_count ⇒ Fixnum
[Output Only] Total count of all firewall policy rule tuples.
-
#rules ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRule>
A list of rules that belong to this policy.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
[Output Only] Server-defined URL for this resource with the resource id.
-
#short_name ⇒ String
User-provided name of the Organization firewall plicy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicy
constructor
A new instance of FirewallPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicy
Returns a new instance of FirewallPolicy.
7912 7913 7914 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associations ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyAssociation>
A list of associations that belong to this firewall policy.
Corresponds to the JSON property associations
7807 7808 7809 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7807 def associations @associations end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
7812 7813 7814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7812 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
7818 7819 7820 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7818 def description @description end |
#display_name ⇒ String
Deprecated, please use short name instead. User-provided name of the
Organization firewall policy. The name should be unique in the organization in
which the firewall policy is created. This name must be set on creation and
cannot be changed. The name must be 1-63 characters long, and comply with
RFC1035. Specifically, the name must be 1-63 characters long and match the
regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be a
dash, lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property displayName
7831 7832 7833 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7831 def display_name @display_name end |
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of the
metadata's contents and used for optimistic locking. The fingerprint is
initially generated by Compute Engine and changes after every request to
modify or update metadata. You must always provide an up-to-date fingerprint
hash in order to update or change metadata, otherwise the request will fail
with error 412 conditionNotMet. To see the latest fingerprint, make get()
request to the firewall policy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
7843 7844 7845 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7843 def fingerprint @fingerprint end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
7849 7850 7851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7849 def id @id end |
#kind ⇒ String
[Output only] Type of the resource. Always compute#firewallPolicyfor firewall
policies
Corresponds to the JSON property kind
7855 7856 7857 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7855 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource. It is a numeric ID allocated by GCP which
uniquely identifies the Firewall Policy.
Corresponds to the JSON property name
7861 7862 7863 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7861 def name @name end |
#parent ⇒ String
[Output Only] The parent of the firewall policy.
Corresponds to the JSON property parent
7866 7867 7868 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7866 def parent @parent end |
#region ⇒ String
[Output Only] URL of the region where the regional firewall policy resides.
This field is not applicable to global firewall policies. You must specify
this field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
7874 7875 7876 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7874 def region @region end |
#rule_tuple_count ⇒ Fixnum
[Output Only] Total count of all firewall policy rule tuples. A firewall
policy can not exceed a set number of tuples.
Corresponds to the JSON property ruleTupleCount
7880 7881 7882 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7880 def rule_tuple_count @rule_tuple_count end |
#rules ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRule>
A list of rules that belong to this policy. There must always be a default
rule (rule with priority 2147483647 and match "*"). If no rules are provided
when creating a firewall policy, a default rule with action "allow" will be
added.
Corresponds to the JSON property rules
7888 7889 7890 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7888 def rules @rules end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
7893 7894 7895 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7893 def self_link @self_link end |
#self_link_with_id ⇒ String
[Output Only] Server-defined URL for this resource with the resource id.
Corresponds to the JSON property selfLinkWithId
7898 7899 7900 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7898 def self_link_with_id @self_link_with_id end |
#short_name ⇒ String
User-provided name of the Organization firewall plicy. The name should be
unique in the organization in which the firewall policy is created. This name
must be set on creation and cannot be changed. The name must be 1-63
characters long, and comply with RFC1035. Specifically, the name must be 1-63
characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all following
characters must be a dash, lowercase letter, or digit, except the last
character, which cannot be a dash.
Corresponds to the JSON property shortName
7910 7911 7912 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7910 def short_name @short_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7917 def update!(**args) @associations = args[:associations] if args.key?(:associations) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @region = args[:region] if args.key?(:region) @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @short_name = args[:short_name] if args.key?(:short_name) end |