Class: Google::Apis::ComputeV1::FirewallPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicyAssociation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#attachment_target ⇒ String
The target that the firewall policy is attached to.
-
#display_name ⇒ String
[Output Only] Deprecated, please use short name instead.
-
#firewall_policy_id ⇒ String
Output only.
-
#name ⇒ String
The name for an association.
-
#short_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyAssociation
constructor
A new instance of FirewallPolicyAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyAssociation
Returns a new instance of FirewallPolicyAssociation.
12987 12988 12989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_target ⇒ String
The target that the firewall policy is attached to.
Corresponds to the JSON property attachmentTarget
12963 12964 12965 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12963 def @attachment_target end |
#display_name ⇒ String
[Output Only] Deprecated, please use short name instead. The display name
of the firewall policy of the association.
Corresponds to the JSON property displayName
12969 12970 12971 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12969 def display_name @display_name end |
#firewall_policy_id ⇒ String
Output only. [Output Only] The firewall policy ID of the association.
Corresponds to the JSON property firewallPolicyId
12974 12975 12976 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12974 def firewall_policy_id @firewall_policy_id end |
#name ⇒ String
The name for an association.
Corresponds to the JSON property name
12979 12980 12981 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12979 def name @name end |
#short_name ⇒ String
Output only. [Output Only] The short name of the firewall policy of the
association.
Corresponds to the JSON property shortName
12985 12986 12987 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12985 def short_name @short_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12992 12993 12994 12995 12996 12997 12998 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12992 def update!(**args) @attachment_target = args[:attachment_target] if args.key?(:attachment_target) @display_name = args[:display_name] if args.key?(:display_name) @firewall_policy_id = args[:firewall_policy_id] if args.key?(:firewall_policy_id) @name = args[:name] if args.key?(:name) @short_name = args[:short_name] if args.key?(:short_name) end |