Class: Google::Apis::ComputeV1::FirewallPolicyAssociation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyAssociation

Returns a new instance of FirewallPolicyAssociation.



7966
7967
7968
# File 'lib/google/apis/compute_v1/classes.rb', line 7966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_targetString

The target that the firewall policy is attached to. Corresponds to the JSON property attachmentTarget

Returns:

  • (String)


7943
7944
7945
# File 'lib/google/apis/compute_v1/classes.rb', line 7943

def attachment_target
  @attachment_target
end

#display_nameString

[Output Only] Deprecated, please use short name instead. The display name of the firewall policy of the association. Corresponds to the JSON property displayName

Returns:

  • (String)


7949
7950
7951
# File 'lib/google/apis/compute_v1/classes.rb', line 7949

def display_name
  @display_name
end

#firewall_policy_idString

[Output Only] The firewall policy ID of the association. Corresponds to the JSON property firewallPolicyId

Returns:

  • (String)


7954
7955
7956
# File 'lib/google/apis/compute_v1/classes.rb', line 7954

def firewall_policy_id
  @firewall_policy_id
end

#nameString

The name for an association. Corresponds to the JSON property name

Returns:

  • (String)


7959
7960
7961
# File 'lib/google/apis/compute_v1/classes.rb', line 7959

def name
  @name
end

#short_nameString

[Output Only] The short name of the firewall policy of the association. Corresponds to the JSON property shortName

Returns:

  • (String)


7964
7965
7966
# File 'lib/google/apis/compute_v1/classes.rb', line 7964

def short_name
  @short_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7971
7972
7973
7974
7975
7976
7977
# File 'lib/google/apis/compute_v1/classes.rb', line 7971

def update!(**args)
  @attachment_target = args[:attachment_target] if args.key?(:attachment_target)
  @display_name = args[:display_name] if args.key?(:display_name)
  @firewall_policy_id = args[:firewall_policy_id] if args.key?(:firewall_policy_id)
  @name = args[:name] if args.key?(:name)
  @short_name = args[:short_name] if args.key?(:short_name)
end