Class: Google::Apis::ComputeV1::FirewallPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::FirewallPolicy>
A list of FirewallPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyList
constructor
A new instance of FirewallPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyList
Returns a new instance of FirewallPolicyList.
13086 13087 13088 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
13058 13059 13060 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13058 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::FirewallPolicy>
A list of FirewallPolicy resources.
Corresponds to the JSON property items
13063 13064 13065 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13063 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList
for listsof FirewallPolicies
Corresponds to the JSON property kind
13069 13070 13071 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13069 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
13079 13080 13081 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13079 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
13084 13085 13086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13084 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13091 13092 13093 13094 13095 13096 13097 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13091 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |