Class: Google::Apis::ComputeV1::FirewallPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::FirewallPolicy>
A list of FirewallPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyList
constructor
A new instance of FirewallPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyList
Returns a new instance of FirewallPolicyList.
13036 13037 13038 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13036 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
13008 13009 13010 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13008 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::FirewallPolicy>
A list of FirewallPolicy resources.
Corresponds to the JSON property items
13013 13014 13015 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13013 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList
for listsof FirewallPolicies
Corresponds to the JSON property kind
13019 13020 13021 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13019 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
13029 13030 13031 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13029 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
13034 13035 13036 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13034 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13041 13042 13043 13044 13045 13046 13047 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13041 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |