Class: Google::Apis::ComputeV1::FirewallPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyList

Returns a new instance of FirewallPolicyList.



13027
13028
13029
# File 'lib/google/apis/compute_v1/classes.rb', line 13027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12999
13000
13001
# File 'lib/google/apis/compute_v1/classes.rb', line 12999

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::FirewallPolicy>

A list of FirewallPolicy resources. Corresponds to the JSON property items



13004
13005
13006
# File 'lib/google/apis/compute_v1/classes.rb', line 13004

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList for listsof FirewallPolicies Corresponds to the JSON property kind

Returns:

  • (String)


13010
13011
13012
# File 'lib/google/apis/compute_v1/classes.rb', line 13010

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


13020
13021
13022
# File 'lib/google/apis/compute_v1/classes.rb', line 13020

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::FirewallPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



13025
13026
13027
# File 'lib/google/apis/compute_v1/classes.rb', line 13025

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13032
13033
13034
13035
13036
13037
13038
# File 'lib/google/apis/compute_v1/classes.rb', line 13032

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end