Class: Google::Apis::ComputeV1::FirewallPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::FirewallPolicy>
A list of FirewallPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyList
constructor
A new instance of FirewallPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyList
Returns a new instance of FirewallPolicyList.
12919 12920 12921 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
12891 12892 12893 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12891 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::FirewallPolicy>
A list of FirewallPolicy resources.
Corresponds to the JSON property items
12896 12897 12898 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12896 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList
for listsof FirewallPolicies
Corresponds to the JSON property kind
12902 12903 12904 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12902 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12912 12913 12914 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12912 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12917 12918 12919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12917 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12924 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |