Class: Google::Apis::ComputeV1::FirewallPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyList

Returns a new instance of FirewallPolicyList.



12907
12908
12909
# File 'lib/google/apis/compute_v1/classes.rb', line 12907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12879
12880
12881
# File 'lib/google/apis/compute_v1/classes.rb', line 12879

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::FirewallPolicy>

A list of FirewallPolicy resources. Corresponds to the JSON property items



12884
12885
12886
# File 'lib/google/apis/compute_v1/classes.rb', line 12884

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList for listsof FirewallPolicies Corresponds to the JSON property kind

Returns:

  • (String)


12890
12891
12892
# File 'lib/google/apis/compute_v1/classes.rb', line 12890

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12900
12901
12902
# File 'lib/google/apis/compute_v1/classes.rb', line 12900

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::FirewallPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12905
12906
12907
# File 'lib/google/apis/compute_v1/classes.rb', line 12905

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12912
12913
12914
12915
12916
12917
12918
# File 'lib/google/apis/compute_v1/classes.rb', line 12912

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end