Class: Google::Apis::ComputeV1::FirewallPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::FirewallPolicy>
A list of FirewallPolicy resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyList
constructor
A new instance of FirewallPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyList
Returns a new instance of FirewallPolicyList.
8014 8015 8016 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
7987 7988 7989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7987 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::FirewallPolicy>
A list of FirewallPolicy resources.
Corresponds to the JSON property items
7992 7993 7994 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7992 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#firewallPolicyList for listsof
FirewallPolicies
Corresponds to the JSON property kind
7998 7999 8000 |
# File 'lib/google/apis/compute_v1/classes.rb', line 7998 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8007 8008 8009 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8007 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8012 8013 8014 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8012 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8019 8020 8021 8022 8023 8024 8025 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8019 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |