Class: Google::Apis::ComputeV1::FirewallPolicyRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicyRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).
Instance Attribute Summary collapse
-
#action ⇒ String
The Action to perform when the client connection triggers the rule.
-
#description ⇒ String
An optional description for this resource.
-
#direction ⇒ String
The direction in which this rule applies.
-
#disabled ⇒ Boolean
(also: #disabled?)
Denotes whether the firewall policy rule is disabled.
-
#enable_logging ⇒ Boolean
(also: #enable_logging?)
Denotes whether to enable logging for a particular rule.
-
#kind ⇒ String
[Output only] Type of the resource.
-
#match ⇒ Google::Apis::ComputeV1::FirewallPolicyRuleMatcher
Represents a match condition that incoming traffic is evaluated against.
-
#priority ⇒ Fixnum
An integer indicating the priority of a rule in the list.
-
#rule_tuple_count ⇒ Fixnum
[Output Only] Calculation of the complexity of a single firewall policy rule.
-
#target_resources ⇒ Array<String>
A list of network resource URLs to which this rule applies.
-
#target_secure_tags ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRuleSecureTag>
A list of secure tags that controls which instances the firewall rule applies to.
-
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating the sets of instances that are applied with this rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRule
constructor
A new instance of FirewallPolicyRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRule
Returns a new instance of FirewallPolicyRule.
8181 8182 8183 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The Action to perform when the client connection triggers the rule. Can
currently be either "allow" or "deny()" where valid values for status are 403,
404, and 502.
Corresponds to the JSON property action
8102 8103 8104 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8102 def action @action end |
#description ⇒ String
An optional description for this resource.
Corresponds to the JSON property description
8107 8108 8109 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8107 def description @description end |
#direction ⇒ String
The direction in which this rule applies.
Corresponds to the JSON property direction
8112 8113 8114 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8112 def direction @direction end |
#disabled ⇒ Boolean Also known as: disabled?
Denotes whether the firewall policy rule is disabled. When set to true, the
firewall policy rule is not enforced and traffic behaves as if it did not
exist. If this is unspecified, the firewall policy rule will be enabled.
Corresponds to the JSON property disabled
8119 8120 8121 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8119 def disabled @disabled end |
#enable_logging ⇒ Boolean Also known as: enable_logging?
Denotes whether to enable logging for a particular rule. If logging is enabled,
logs will be exported to the configured export destination in Stackdriver.
Logs may be exported to BigQuery or Pub/Sub. Note: you cannot enable logging
on "goto_next" rules.
Corresponds to the JSON property enableLogging
8128 8129 8130 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8128 def enable_logging @enable_logging end |
#kind ⇒ String
[Output only] Type of the resource. Always compute#firewallPolicyRule for
firewall policy rules
Corresponds to the JSON property kind
8135 8136 8137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8135 def kind @kind end |
#match ⇒ Google::Apis::ComputeV1::FirewallPolicyRuleMatcher
Represents a match condition that incoming traffic is evaluated against.
Exactly one field must be specified.
Corresponds to the JSON property match
8141 8142 8143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8141 def match @match end |
#priority ⇒ Fixnum
An integer indicating the priority of a rule in the list. The priority must be
a positive value between 0 and 2147483647. Rules are evaluated from highest to
lowest priority where 0 is the highest priority and 2147483647 is the lowest
prority.
Corresponds to the JSON property priority
8149 8150 8151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8149 def priority @priority end |
#rule_tuple_count ⇒ Fixnum
[Output Only] Calculation of the complexity of a single firewall policy rule.
Corresponds to the JSON property ruleTupleCount
8154 8155 8156 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8154 def rule_tuple_count @rule_tuple_count end |
#target_resources ⇒ Array<String>
A list of network resource URLs to which this rule applies. This field allows
you to control which network's VMs get this rule. If this field is left blank,
all VMs within the organization will receive the rule.
Corresponds to the JSON property targetResources
8161 8162 8163 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8161 def target_resources @target_resources end |
#target_secure_tags ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRuleSecureTag>
A list of secure tags that controls which instances the firewall rule applies
to. If targetSecureTag are specified, then the firewall rule applies only to
instances in the VPC network that have one of those EFFECTIVE secure tags, if
all the target_secure_tag are in INEFFECTIVE state, then this rule will be
ignored. targetSecureTag may not be set at the same time as
targetServiceAccounts. If neither targetServiceAccounts nor targetSecureTag
are specified, the firewall rule applies to all instances on the specified
network. Maximum number of target label tags allowed is 256.
Corresponds to the JSON property targetSecureTags
8173 8174 8175 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8173 def @target_secure_tags end |
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating the sets of instances that are applied
with this rule.
Corresponds to the JSON property targetServiceAccounts
8179 8180 8181 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8179 def target_service_accounts @target_service_accounts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8186 def update!(**args) @action = args[:action] if args.key?(:action) @description = args[:description] if args.key?(:description) @direction = args[:direction] if args.key?(:direction) @disabled = args[:disabled] if args.key?(:disabled) @enable_logging = args[:enable_logging] if args.key?(:enable_logging) @kind = args[:kind] if args.key?(:kind) @match = args[:match] if args.key?(:match) @priority = args[:priority] if args.key?(:priority) @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count) @target_resources = args[:target_resources] if args.key?(:target_resources) @target_secure_tags = args[:target_secure_tags] if args.key?(:target_secure_tags) @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts) end |