Class: Google::Apis::ComputeV1::FirewallPolicyRuleMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicyRuleMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
Instance Attribute Summary collapse
-
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#layer4_configs ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
-
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#src_secure_tags ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRuleSecureTag>
List of secure tag values, which should be matched at the source of the traffic.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRuleMatcher
constructor
A new instance of FirewallPolicyRuleMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRuleMatcher
Returns a new instance of FirewallPolicyRuleMatcher.
8231 8232 8233 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is
5000.
Corresponds to the JSON property destIpRanges
8211 8212 8213 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8211 def dest_ip_ranges @dest_ip_ranges end |
#layer4_configs ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
Corresponds to the JSON property layer4Configs
8216 8217 8218 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8216 def layer4_configs @layer4_configs end |
#src_ip_ranges ⇒ Array<String>
CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.
Corresponds to the JSON property srcIpRanges
8221 8222 8223 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8221 def src_ip_ranges @src_ip_ranges end |
#src_secure_tags ⇒ Array<Google::Apis::ComputeV1::FirewallPolicyRuleSecureTag>
List of secure tag values, which should be matched at the source of the
traffic. For INGRESS rule, if all the srcSecureTag are INEFFECTIVE, and there
is no srcIpRange, this rule will be ignored. Maximum number of source tag
values allowed is 256.
Corresponds to the JSON property srcSecureTags
8229 8230 8231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8229 def @src_secure_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8236 8237 8238 8239 8240 8241 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8236 def update!(**args) @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges) @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs) @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges) @src_secure_tags = args[:src_secure_tags] if args.key?(:src_secure_tags) end |