Class: Google::Apis::ComputeV1::FirewallPolicyRuleMatcherLayer4Config
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallPolicyRuleMatcherLayer4Config
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#ip_protocol ⇒ String
The IP protocol to which this rule applies.
-
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRuleMatcherLayer4Config
constructor
A new instance of FirewallPolicyRuleMatcherLayer4Config.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRuleMatcherLayer4Config
Returns a new instance of FirewallPolicyRuleMatcherLayer4Config.
8264 8265 8266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_protocol ⇒ String
The IP protocol to which this rule applies. The protocol type is required when
creating a firewall rule. This value can either be one of the following well
known protocol strings (tcp, udp, icmp, esp, ah, ipip, sctp), or the IP
protocol number.
Corresponds to the JSON property ipProtocol
8254 8255 8256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8254 def ip_protocol @ip_protocol end |
#ports ⇒ Array<String>
An optional list of ports to which this rule applies. This field is only
applicable for UDP or TCP protocol. Each entry must be either an integer or a
range. If not specified, this rule applies to connections through any port.
Example inputs include: ["22"], ["80","443"], and ["12345-12349"].
Corresponds to the JSON property ports
8262 8263 8264 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8262 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8269 8270 8271 8272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8269 def update!(**args) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @ports = args[:ports] if args.key?(:ports) end |