Class: Google::Apis::ComputeV1::FlexibleTimeRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FlexibleTimeRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.
Instance Attribute Summary collapse
-
#max_duration ⇒ String
Corresponds to the JSON property
maxDuration. -
#min_duration ⇒ String
Corresponds to the JSON property
minDuration. -
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property
startTimeNotEarlierThan. -
#start_time_not_later_than ⇒ String
Corresponds to the JSON property
startTimeNotLaterThan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlexibleTimeRange
constructor
A new instance of FlexibleTimeRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlexibleTimeRange
Returns a new instance of FlexibleTimeRange.
13570 13571 13572 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ String
Corresponds to the JSON property maxDuration
13553 13554 13555 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13553 def max_duration @max_duration end |
#min_duration ⇒ String
Corresponds to the JSON property minDuration
13558 13559 13560 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13558 def min_duration @min_duration end |
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property startTimeNotEarlierThan
13563 13564 13565 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13563 def start_time_not_earlier_than @start_time_not_earlier_than end |
#start_time_not_later_than ⇒ String
Corresponds to the JSON property startTimeNotLaterThan
13568 13569 13570 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13568 def start_time_not_later_than @start_time_not_later_than end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13575 13576 13577 13578 13579 13580 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13575 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @min_duration = args[:min_duration] if args.key?(:min_duration) @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than) @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than) end |