Class: Google::Apis::ComputeV1::FlexibleTimeRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlexibleTimeRange

Returns a new instance of FlexibleTimeRange.



13426
13427
13428
# File 'lib/google/apis/compute_v1/classes.rb', line 13426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_durationString

Corresponds to the JSON property maxDuration

Returns:

  • (String)


13409
13410
13411
# File 'lib/google/apis/compute_v1/classes.rb', line 13409

def max_duration
  @max_duration
end

#min_durationString

Corresponds to the JSON property minDuration

Returns:

  • (String)


13414
13415
13416
# File 'lib/google/apis/compute_v1/classes.rb', line 13414

def min_duration
  @min_duration
end

#start_time_not_earlier_thanString

Corresponds to the JSON property startTimeNotEarlierThan

Returns:

  • (String)


13419
13420
13421
# File 'lib/google/apis/compute_v1/classes.rb', line 13419

def start_time_not_earlier_than
  @start_time_not_earlier_than
end

#start_time_not_later_thanString

Corresponds to the JSON property startTimeNotLaterThan

Returns:

  • (String)


13424
13425
13426
# File 'lib/google/apis/compute_v1/classes.rb', line 13424

def start_time_not_later_than
  @start_time_not_later_than
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13431
13432
13433
13434
13435
13436
# File 'lib/google/apis/compute_v1/classes.rb', line 13431

def update!(**args)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @min_duration = args[:min_duration] if args.key?(:min_duration)
  @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than)
  @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than)
end