Class: Google::Apis::ComputeV1::FlexibleTimeRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FlexibleTimeRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.
Instance Attribute Summary collapse
-
#max_duration ⇒ String
Corresponds to the JSON property
maxDuration. -
#min_duration ⇒ String
Corresponds to the JSON property
minDuration. -
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property
startTimeNotEarlierThan. -
#start_time_not_later_than ⇒ String
Corresponds to the JSON property
startTimeNotLaterThan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlexibleTimeRange
constructor
A new instance of FlexibleTimeRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlexibleTimeRange
Returns a new instance of FlexibleTimeRange.
12201 12202 12203 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ String
Corresponds to the JSON property maxDuration
12184 12185 12186 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12184 def max_duration @max_duration end |
#min_duration ⇒ String
Corresponds to the JSON property minDuration
12189 12190 12191 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12189 def min_duration @min_duration end |
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property startTimeNotEarlierThan
12194 12195 12196 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12194 def start_time_not_earlier_than @start_time_not_earlier_than end |
#start_time_not_later_than ⇒ String
Corresponds to the JSON property startTimeNotLaterThan
12199 12200 12201 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12199 def start_time_not_later_than @start_time_not_later_than end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12206 12207 12208 12209 12210 12211 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12206 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @min_duration = args[:min_duration] if args.key?(:min_duration) @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than) @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than) end |