Class: Google::Apis::ComputeV1::FlexibleTimeRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FlexibleTimeRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A flexible specification of a time range that has 3 points of flexibility: (1) a flexible start time, (2) a flexible end time, (3) a flexible duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.
Instance Attribute Summary collapse
-
#max_duration ⇒ String
Corresponds to the JSON property
maxDuration. -
#min_duration ⇒ String
Corresponds to the JSON property
minDuration. -
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property
startTimeNotEarlierThan. -
#start_time_not_later_than ⇒ String
Corresponds to the JSON property
startTimeNotLaterThan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlexibleTimeRange
constructor
A new instance of FlexibleTimeRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlexibleTimeRange
Returns a new instance of FlexibleTimeRange.
12077 12078 12079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ String
Corresponds to the JSON property maxDuration
12060 12061 12062 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12060 def max_duration @max_duration end |
#min_duration ⇒ String
Corresponds to the JSON property minDuration
12065 12066 12067 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12065 def min_duration @min_duration end |
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property startTimeNotEarlierThan
12070 12071 12072 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12070 def start_time_not_earlier_than @start_time_not_earlier_than end |
#start_time_not_later_than ⇒ String
Corresponds to the JSON property startTimeNotLaterThan
12075 12076 12077 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12075 def start_time_not_later_than @start_time_not_later_than end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12082 12083 12084 12085 12086 12087 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12082 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @min_duration = args[:min_duration] if args.key?(:min_duration) @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than) @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than) end |