Class: Google::Apis::ComputeV1::ForwardingRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Forwarding Rule resource. Forwarding rule resources in Google Cloud can be either regional or global in scope:

  • Global
  • Regional A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud load balancer. Forwarding rules can also reference target instances and Cloud VPN Classic gateways (targetVpnGateway). For more information, read Forwarding rule concepts and Using protocol forwarding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRule

Returns a new instance of ForwardingRule.



13916
13917
13918
# File 'lib/google/apis/compute_v1/classes.rb', line 13916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_portsBoolean Also known as: all_ports?

The ports, portRange, and allPorts fields are mutually exclusive. Only packets addressed to ports in the specified range will be forwarded to the backends configured with this forwarding rule. The allPorts field has the following limitations:

  • It requires that the forwarding rule IPProtocol be TCP, UDP, SCTP, or L3_DEFAULT.
  • It's applicable only to the following products: internal passthrough Network Load Balancers, backend service-based external passthrough Network Load Balancers, and internal and external protocol forwarding.
  • Set this field to true to allow packets addressed to any port or packets lacking destination port information (for example, UDP fragments after the first fragment) to be forwarded to the backends configured with this forwarding rule. The L3_DEFAULT protocol requiresallPorts be set to true. Corresponds to the JSON property allPorts

Returns:

  • (Boolean)


13533
13534
13535
# File 'lib/google/apis/compute_v1/classes.rb', line 13533

def all_ports
  @all_ports
end

#allow_global_accessBoolean Also known as: allow_global_access?

If set to true, clients can access the internal passthrough Network Load Balancers, the regional internal Application Load Balancer, and the regional internal proxy Network Load Balancer from all regions. If false, only allows access from the local region the load balancer is located at. Note that for INTERNAL_MANAGED forwarding rules, this field cannot be changed after the forwarding rule is created. Corresponds to the JSON property allowGlobalAccess

Returns:

  • (Boolean)


13544
13545
13546
# File 'lib/google/apis/compute_v1/classes.rb', line 13544

def allow_global_access
  @allow_global_access
end

#allow_psc_global_accessBoolean Also known as: allow_psc_global_access?

This is used in PSC consumer ForwardingRule to control whether the PSC endpoint can be accessed from another region. Corresponds to the JSON property allowPscGlobalAccess

Returns:

  • (Boolean)


13551
13552
13553
# File 'lib/google/apis/compute_v1/classes.rb', line 13551

def allow_psc_global_access
  @allow_psc_global_access
end

#backend_serviceString

Identifies the backend service to which the forwarding rule sends traffic. Required for internal and external passthrough Network Load Balancers; must be omitted for all other load balancer types. Corresponds to the JSON property backendService

Returns:

  • (String)


13559
13560
13561
# File 'lib/google/apis/compute_v1/classes.rb', line 13559

def backend_service
  @backend_service
end

#base_forwarding_ruleString

Output only. [Output Only] The URL for the corresponding base forwarding rule. By base forwarding rule, we mean the forwarding rule that has the same IP address, protocol, and port settings with the current forwarding rule, but without sourceIPRanges specified. Always empty if the current forwarding rule does not have sourceIPRanges specified. Corresponds to the JSON property baseForwardingRule

Returns:

  • (String)


13570
13571
13572
# File 'lib/google/apis/compute_v1/classes.rb', line 13570

def base_forwarding_rule
  @base_forwarding_rule
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


13576
13577
13578
# File 'lib/google/apis/compute_v1/classes.rb', line 13576

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


13582
13583
13584
# File 'lib/google/apis/compute_v1/classes.rb', line 13582

def description
  @description
end

#external_managed_backend_bucket_migration_stateString

Specifies the canary migration state for the backend buckets attached to this forwarding rule. Possible values are PREPARE, TEST_BY_PERCENTAGE, and TEST_ALL_TRAFFIC. To begin the migration from EXTERNAL to EXTERNAL_MANAGED, the state must be changed to PREPARE. The state must be changed to TEST_ALL_TRAFFIC before the loadBalancingScheme can be changed to EXTERNAL_MANAGED. Optionally, the TEST_BY_PERCENTAGE state can be used to migrate traffic to backend buckets attached to this forwarding rule by percentage using externalManagedBackendBucketMigrationTestingPercentage. Rolling back a migration requires the states to be set in reverse order. So changing the scheme from EXTERNAL_MANAGED to EXTERNAL requires the state to be set to TEST_ALL_TRAFFIC at the same time. Optionally, the TEST_BY_PERCENTAGE state can be used to migrate some traffic back to EXTERNAL or PREPARE can be used to migrate all traffic back to EXTERNAL. Corresponds to the JSON property externalManagedBackendBucketMigrationState

Returns:

  • (String)


13600
13601
13602
# File 'lib/google/apis/compute_v1/classes.rb', line 13600

def external_managed_backend_bucket_migration_state
  @external_managed_backend_bucket_migration_state
end

#external_managed_backend_bucket_migration_testing_percentageFloat

Determines the fraction of requests to backend buckets that should be processed by the global external Application Load Balancer. The value of this field must be in the range [0, 100]. This value can only be set if the loadBalancingScheme in the BackendService is set to EXTERNAL (when using the classic Application Load Balancer) and the migration state is TEST_BY_PERCENTAGE. Corresponds to the JSON property externalManagedBackendBucketMigrationTestingPercentage

Returns:

  • (Float)


13610
13611
13612
# File 'lib/google/apis/compute_v1/classes.rb', line 13610

def external_managed_backend_bucket_migration_testing_percentage
  @external_managed_backend_bucket_migration_testing_percentage
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ForwardingRule. Include the fingerprint in patch request to ensure that you do not overwrite changes that were applied from another concurrent request. To see the latest fingerprint, make a get() request to retrieve a ForwardingRule. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


13622
13623
13624
# File 'lib/google/apis/compute_v1/classes.rb', line 13622

def fingerprint
  @fingerprint
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13628
13629
13630
# File 'lib/google/apis/compute_v1/classes.rb', line 13628

def id
  @id
end

#ip_addressString

IP address for which this forwarding rule accepts traffic. When a client sends traffic to this IP address, the forwarding rule directs the traffic to the referenced target or backendService. While creating a forwarding rule, specifying an IPAddress is required under the following circumstances:

  • When the target is set to targetGrpcProxy andvalidateForProxyless is set to true, theIPAddress should be set to 0.0.0.0.
  • When the target is a Private Service Connect Google APIs bundle, you must specify an IPAddress. Otherwise, you can optionally specify an IP address that references an existing static (reserved) IP address resource. When omitted, Google Cloud assigns an ephemeral IP address. Use one of the following formats to specify an IP address while creating a forwarding rule:
  • IP address number, as in 100.1.2.3
  • IPv6 address range, as in 2600:1234::/96
  • Full resource URL, as inhttps://www.googleapis.com/compute/v1/projects/ project_id/regions/region/addresses/address-name
  • Partial URL or by name, as in:

  • projects/project_id/regions/region/addresses/address-name

  • regions/region/addresses/address-name

  • global/addresses/address-name

  • address-name The forwarding rule's target or backendService, and in most cases, also the loadBalancingScheme, determine the type of IP address that you can use. For detailed information, see IP address specifications. When reading an IPAddress, the API always returns the IP address number. Corresponds to the JSON property IPAddress

Returns:

  • (String)


13502
13503
13504
# File 'lib/google/apis/compute_v1/classes.rb', line 13502

def ip_address
  @ip_address
end

#ip_collectionString

Resource reference of a PublicDelegatedPrefix. The PDP must be a sub-PDP in EXTERNAL_IPV6_FORWARDING_RULE_CREATION mode. Use one of the following formats to specify a sub-PDP when creating an IPv6 NetLB forwarding rule using BYOIP: Full resource URL, as inhttps://www.googleapis.com/compute/v1/projects/ project_id/regions/region/publicDelegatedPrefixes/sub-pdp-name Partial URL, as in:

  • projects/project_id/regions/region/publicDelegatedPrefixes/sub-pdp-name
  • regions/region/publicDelegatedPrefixes/sub-pdp-name Corresponds to the JSON property ipCollection

Returns:

  • (String)


13642
13643
13644
# File 'lib/google/apis/compute_v1/classes.rb', line 13642

def ip_collection
  @ip_collection
end

#ip_protocolString

The IP protocol to which this rule applies. For protocol forwarding, valid options are TCP, UDP, ESP,AH, SCTP, ICMP andL3_DEFAULT. The valid IP protocols are different for different load balancing products as described in Load balancing features. Corresponds to the JSON property IPProtocol

Returns:

  • (String)


13513
13514
13515
# File 'lib/google/apis/compute_v1/classes.rb', line 13513

def ip_protocol
  @ip_protocol
end

#ip_versionString

The IP Version that will be used by this forwarding rule. Valid options are IPV4 or IPV6. Corresponds to the JSON property ipVersion

Returns:

  • (String)


13648
13649
13650
# File 'lib/google/apis/compute_v1/classes.rb', line 13648

def ip_version
  @ip_version
end

#is_mirroring_collectorBoolean Also known as: is_mirroring_collector?

Indicates whether or not this load balancer can be used as a collector for packet mirroring. To prevent mirroring loops, instances behind this load balancer will not have their traffic mirrored even if aPacketMirroring rule applies to them. This can only be set to true for load balancers that have theirloadBalancingScheme set to INTERNAL. Corresponds to the JSON property isMirroringCollector

Returns:

  • (Boolean)


13658
13659
13660
# File 'lib/google/apis/compute_v1/classes.rb', line 13658

def is_mirroring_collector
  @is_mirroring_collector
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#forwardingRule for forwarding rule resources. Corresponds to the JSON property kind

Returns:

  • (String)


13665
13666
13667
# File 'lib/google/apis/compute_v1/classes.rb', line 13665

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this resource, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a ForwardingRule. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


13678
13679
13680
# File 'lib/google/apis/compute_v1/classes.rb', line 13678

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


13685
13686
13687
# File 'lib/google/apis/compute_v1/classes.rb', line 13685

def labels
  @labels
end

#load_balancing_schemeString

Specifies the forwarding rule type. For more information about forwarding rules, refer to Forwarding rule concepts. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


13692
13693
13694
# File 'lib/google/apis/compute_v1/classes.rb', line 13692

def load_balancing_scheme
  @load_balancing_scheme
end

#metadata_filtersArray<Google::Apis::ComputeV1::MetadataFilter>

Opaque filter criteria used by load balancer to restrict routing configuration to a limited set of xDS compliant clients. In their xDS requests to load balancer, xDS clients present node metadata. When there is a match, the relevant configuration is made available to those proxies. Otherwise, all the resources (e.g. TargetHttpProxy, UrlMap) referenced by the ForwardingRule are not visible to those proxies. For each metadataFilter in this list, if itsfilterMatchCriteria is set to MATCH_ANY, at least one of thefilterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. If multiplemetadataFilters are specified, all of them need to be satisfied in order to be considered a match. metadataFilters specified here will be applifed before those specified in the UrlMap that thisForwardingRule references. metadataFilters only applies to Loadbalancers that have their loadBalancingScheme set toINTERNAL_SELF_MANAGED. Corresponds to the JSON property metadataFilters



13717
13718
13719
# File 'lib/google/apis/compute_v1/classes.rb', line 13717

def 
  @metadata_filters
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. For Private Service Connect forwarding rules that forward traffic to Google APIs, the forwarding rule name must be a 1-20 characters string with lowercase letters and numbers and must start with a letter. Corresponds to the JSON property name

Returns:

  • (String)


13731
13732
13733
# File 'lib/google/apis/compute_v1/classes.rb', line 13731

def name
  @name
end

#networkString

This field is not used for global external load balancing. For internal passthrough Network Load Balancers, this field identifies the network that the load balanced IP should belong to for this forwarding rule. If the subnetwork is specified, the network of the subnetwork will be used. If neither subnetwork nor this field is specified, the default network will be used. For Private Service Connect forwarding rules that forward traffic to Google APIs, a network must be provided. Corresponds to the JSON property network

Returns:

  • (String)


13744
13745
13746
# File 'lib/google/apis/compute_v1/classes.rb', line 13744

def network
  @network
end

#network_tierString

This signifies the networking tier used for configuring this load balancer and can only take the following values:PREMIUM, STANDARD. For regional ForwardingRule, the valid values are PREMIUM andSTANDARD. For GlobalForwardingRule, the valid value isPREMIUM. If this field is not specified, it is assumed to be PREMIUM. If IPAddress is specified, this value must be equal to the networkTier of the Address. Corresponds to the JSON property networkTier

Returns:

  • (String)


13755
13756
13757
# File 'lib/google/apis/compute_v1/classes.rb', line 13755

def network_tier
  @network_tier
end

#no_automate_dns_zoneBoolean Also known as: no_automate_dns_zone?

This is used in PSC consumer ForwardingRule to control whether it should try to auto-generate a DNS zone or not. Non-PSC forwarding rules do not use this field. Once set, this field is not mutable. Corresponds to the JSON property noAutomateDnsZone

Returns:

  • (Boolean)


13762
13763
13764
# File 'lib/google/apis/compute_v1/classes.rb', line 13762

def no_automate_dns_zone
  @no_automate_dns_zone
end

#port_rangeString

The ports, portRange, and allPorts fields are mutually exclusive. Only packets addressed to ports in the specified range will be forwarded to the backends configured with this forwarding rule. The portRange field has the following limitations:

  • It requires that the forwarding rule IPProtocol be TCP, UDP, or SCTP, and
  • It's applicable only to the following products: external passthrough Network Load Balancers, internal and external proxy Network Load Balancers, internal and external Application Load Balancers, external protocol forwarding, and Classic VPN.
  • Some products have restrictions on what ports can be used. See port specifications for details. For external forwarding rules, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot have overlappingportRanges. For internal forwarding rules within the same VPC network, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair, and cannot have overlapping portRanges. @pattern: \d+(?:-\d+)? Corresponds to the JSON property portRange

Returns:

  • (String)


13787
13788
13789
# File 'lib/google/apis/compute_v1/classes.rb', line 13787

def port_range
  @port_range
end

#portsArray<String>

The ports, portRange, and allPorts fields are mutually exclusive. Only packets addressed to ports in the specified range will be forwarded to the backends configured with this forwarding rule. The ports field has the following limitations:

  • It requires that the forwarding rule IPProtocol be TCP, UDP, or SCTP, and
  • It's applicable only to the following products: internal passthrough Network Load Balancers, backend service-based external passthrough Network Load Balancers, and internal protocol forwarding.
  • You can specify a list of up to five ports by number, separated by commas. The ports can be contiguous or discontiguous. For external forwarding rules, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair if they share at least one port number. For internal forwarding rules within the same VPC network, two or more forwarding rules cannot use the same [IPAddress, IPProtocol] pair if they share at least one port number. @pattern: \d+(?:-\d+)? Corresponds to the JSON property ports

Returns:

  • (Array<String>)


13811
13812
13813
# File 'lib/google/apis/compute_v1/classes.rb', line 13811

def ports
  @ports
end

#psc_connection_idFixnum

[Output Only] The PSC connection id of the PSC forwarding rule. Corresponds to the JSON property pscConnectionId

Returns:

  • (Fixnum)


13816
13817
13818
# File 'lib/google/apis/compute_v1/classes.rb', line 13816

def psc_connection_id
  @psc_connection_id
end

#psc_connection_statusString

Corresponds to the JSON property pscConnectionStatus

Returns:

  • (String)


13821
13822
13823
# File 'lib/google/apis/compute_v1/classes.rb', line 13821

def psc_connection_status
  @psc_connection_status
end

#regionString

Output only. [Output Only] URL of the region where the regional forwarding rule resides. This field is not applicable to global forwarding rules. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


13830
13831
13832
# File 'lib/google/apis/compute_v1/classes.rb', line 13830

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13835
13836
13837
# File 'lib/google/apis/compute_v1/classes.rb', line 13835

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


13841
13842
13843
# File 'lib/google/apis/compute_v1/classes.rb', line 13841

def self_link_with_id
  @self_link_with_id
end

#service_directory_registrationsArray<Google::Apis::ComputeV1::ForwardingRuleServiceDirectoryRegistration>

Service Directory resources to register this forwarding rule with. Currently, only supports a single Service Directory resource. Corresponds to the JSON property serviceDirectoryRegistrations



13847
13848
13849
# File 'lib/google/apis/compute_v1/classes.rb', line 13847

def service_directory_registrations
  @service_directory_registrations
end

#service_labelString

An optional prefix to the service name for this forwarding rule. If specified, the prefix is the first label of the fully qualified service name. The label must be 1-63 characters long, and comply withRFC1035. Specifically, the label must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. This field is only used for internal load balancing. Corresponds to the JSON property serviceLabel

Returns:

  • (String)


13861
13862
13863
# File 'lib/google/apis/compute_v1/classes.rb', line 13861

def service_label
  @service_label
end

#service_nameString

[Output Only] The internal fully qualified service name for this forwarding rule. This field is only used for internal load balancing. Corresponds to the JSON property serviceName

Returns:

  • (String)


13868
13869
13870
# File 'lib/google/apis/compute_v1/classes.rb', line 13868

def service_name
  @service_name
end

#source_ip_rangesArray<String>

If not empty, this forwarding rule will only forward the traffic when the source IP address matches one of the IP addresses or CIDR ranges set here. Note that a forwarding rule can only have up to 64 source IP ranges, and this field can only be used with a regional forwarding rule whose scheme isEXTERNAL. Each source_ip_range entry should be either an IP address (for example, 1.2.3.4) or a CIDR range (for example, 1.2.3.0/24). Corresponds to the JSON property sourceIpRanges

Returns:

  • (Array<String>)


13879
13880
13881
# File 'lib/google/apis/compute_v1/classes.rb', line 13879

def source_ip_ranges
  @source_ip_ranges
end

#subnetworkString

This field identifies the subnetwork that the load balanced IP should belong to for this forwarding rule, used with internal load balancers and external passthrough Network Load Balancers with IPv6. If the network specified is in auto subnet mode, this field is optional. However, a subnetwork must be specified if the network is in custom subnet mode or when creating external forwarding rule with IPv6. Corresponds to the JSON property subnetwork

Returns:

  • (String)


13889
13890
13891
# File 'lib/google/apis/compute_v1/classes.rb', line 13889

def subnetwork
  @subnetwork
end

#targetString

The URL of the target resource to receive the matched traffic. For regional forwarding rules, this target must be in the same region as the forwarding rule. For global forwarding rules, this target must be a global load balancing resource. The forwarded traffic must be of a type appropriate to the target object.

  • For load balancers, see the "Target" column in Port specifications.
  • For Private Service Connect forwarding rules that forward traffic to Google APIs, provide the name of a supported Google API bundle:

  • vpc-sc - APIs that support VPC Service Controls.

  • all-apis - All supported Google APIs.

  • For Private Service Connect forwarding rules that forward traffic to managed services, the target must be a service attachment. The target is not mutable once set as a service attachment. Corresponds to the JSON property target

Returns:

  • (String)


13914
13915
13916
# File 'lib/google/apis/compute_v1/classes.rb', line 13914

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13921
13922
13923
13924
13925
13926
13927
13928
13929
13930
13931
13932
13933
13934
13935
13936
13937
13938
13939
13940
13941
13942
13943
13944
13945
13946
13947
13948
13949
13950
13951
13952
13953
13954
13955
13956
13957
13958
13959
13960
# File 'lib/google/apis/compute_v1/classes.rb', line 13921

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @all_ports = args[:all_ports] if args.key?(:all_ports)
  @allow_global_access = args[:allow_global_access] if args.key?(:allow_global_access)
  @allow_psc_global_access = args[:allow_psc_global_access] if args.key?(:allow_psc_global_access)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @base_forwarding_rule = args[:base_forwarding_rule] if args.key?(:base_forwarding_rule)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @external_managed_backend_bucket_migration_state = args[:external_managed_backend_bucket_migration_state] if args.key?(:external_managed_backend_bucket_migration_state)
  @external_managed_backend_bucket_migration_testing_percentage = args[:external_managed_backend_bucket_migration_testing_percentage] if args.key?(:external_managed_backend_bucket_migration_testing_percentage)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @ip_collection = args[:ip_collection] if args.key?(:ip_collection)
  @ip_version = args[:ip_version] if args.key?(:ip_version)
  @is_mirroring_collector = args[:is_mirroring_collector] if args.key?(:is_mirroring_collector)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @metadata_filters = args[:metadata_filters] if args.key?(:metadata_filters)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_tier = args[:network_tier] if args.key?(:network_tier)
  @no_automate_dns_zone = args[:no_automate_dns_zone] if args.key?(:no_automate_dns_zone)
  @port_range = args[:port_range] if args.key?(:port_range)
  @ports = args[:ports] if args.key?(:ports)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @service_directory_registrations = args[:service_directory_registrations] if args.key?(:service_directory_registrations)
  @service_label = args[:service_label] if args.key?(:service_label)
  @service_name = args[:service_name] if args.key?(:service_name)
  @source_ip_ranges = args[:source_ip_ranges] if args.key?(:source_ip_ranges)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @target = args[:target] if args.key?(:target)
end