Class: Google::Apis::ComputeV1::ForwardingRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Forwarding Rule resource. Forwarding rule resources in Google Cloud can be either regional or global in scope: * Global * Regional A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud Platform load balancer. Forwarding rules can also reference target instances and Cloud VPN Classic gateways ( targetVpnGateway). For more information, read Forwarding rule concepts and Using protocol forwarding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRule

Returns a new instance of ForwardingRule.



8618
8619
8620
# File 'lib/google/apis/compute_v1/classes.rb', line 8618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_portsBoolean Also known as: all_ports?

This field is used along with the backend_service field for Internal TCP/UDP Load Balancing or Network Load Balancing, or with the target field for internal and external TargetInstance. You can only use one of ports and port_range, or allPorts. The three are mutually exclusive. For TCP, UDP and SCTP traffic, packets addressed to any ports will be forwarded to the target or backendService. Corresponds to the JSON property allPorts

Returns:

  • (Boolean)


8386
8387
8388
# File 'lib/google/apis/compute_v1/classes.rb', line 8386

def all_ports
  @all_ports
end

#allow_global_accessBoolean Also known as: allow_global_access?

This field is used along with the backend_service field for internal load balancing or with the target field for internal TargetInstance. If the field is set to TRUE, clients can access ILB from all regions. Otherwise only allows access from clients in the same region as the internal load balancer. Corresponds to the JSON property allowGlobalAccess

Returns:

  • (Boolean)


8395
8396
8397
# File 'lib/google/apis/compute_v1/classes.rb', line 8395

def allow_global_access
  @allow_global_access
end

#backend_serviceString

Identifies the backend service to which the forwarding rule sends traffic. Required for Internal TCP/UDP Load Balancing and Network Load Balancing; must be omitted for all other load balancer types. Corresponds to the JSON property backendService

Returns:

  • (String)


8403
8404
8405
# File 'lib/google/apis/compute_v1/classes.rb', line 8403

def backend_service
  @backend_service
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


8408
8409
8410
# File 'lib/google/apis/compute_v1/classes.rb', line 8408

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


8414
8415
8416
# File 'lib/google/apis/compute_v1/classes.rb', line 8414

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ForwardingRule. Include the fingerprint in patch request to ensure that you do not overwrite changes that were applied from another concurrent request. To see the latest fingerprint, make a get() request to retrieve a ForwardingRule. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


8425
8426
8427
# File 'lib/google/apis/compute_v1/classes.rb', line 8425

def fingerprint
  @fingerprint
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


8431
8432
8433
# File 'lib/google/apis/compute_v1/classes.rb', line 8431

def id
  @id
end

#ip_addressString

IP address that this forwarding rule serves. When a client sends traffic to this IP address, the forwarding rule directs the traffic to the target that you specify in the forwarding rule. If you don't specify a reserved IP address, an ephemeral IP address is assigned. Methods for specifying an IP address: * IPv4 dotted decimal, as in 100.1.2.3 * Full URL, as in https://www. googleapis.com/compute/v1/projects/project_id/regions/region /addresses/ address-name * Partial URL or by name, as in: - projects/project_id/regions/ region/addresses/address-name - regions/region/addresses/address-name - global/ addresses/address-name - address-name The loadBalancingScheme and the forwarding rule's target determine the type of IP address that you can use. For detailed information, see IP address specifications. Must be set to 0.0.0.0 when the target is targetGrpcProxy that has validateForProxyless field set to true. For Private Service Connect forwarding rules that forward traffic to Google APIs, IP address must be provided. Corresponds to the JSON property IPAddress

Returns:

  • (String)


8367
8368
8369
# File 'lib/google/apis/compute_v1/classes.rb', line 8367

def ip_address
  @ip_address
end

#ip_protocolString

The IP protocol to which this rule applies. For protocol forwarding, valid options are TCP, UDP, ESP, AH, SCTP, ICMP and L3_DEFAULT. The valid IP protocols are different for different load balancing products as described in Load balancing features. Corresponds to the JSON property IPProtocol

Returns:

  • (String)


8376
8377
8378
# File 'lib/google/apis/compute_v1/classes.rb', line 8376

def ip_protocol
  @ip_protocol
end

#ip_versionString

The IP Version that will be used by this forwarding rule. Valid options are IPV4 or IPV6. This can only be specified for an external global forwarding rule. Corresponds to the JSON property ipVersion

Returns:

  • (String)


8438
8439
8440
# File 'lib/google/apis/compute_v1/classes.rb', line 8438

def ip_version
  @ip_version
end

#is_mirroring_collectorBoolean Also known as: is_mirroring_collector?

Indicates whether or not this load balancer can be used as a collector for packet mirroring. To prevent mirroring loops, instances behind this load balancer will not have their traffic mirrored even if a PacketMirroring rule applies to them. This can only be set to true for load balancers that have their loadBalancingScheme set to INTERNAL. Corresponds to the JSON property isMirroringCollector

Returns:

  • (Boolean)


8447
8448
8449
# File 'lib/google/apis/compute_v1/classes.rb', line 8447

def is_mirroring_collector
  @is_mirroring_collector
end

#kindString

[Output Only] Type of the resource. Always compute#forwardingRule for Forwarding Rule resources. Corresponds to the JSON property kind

Returns:

  • (String)


8454
8455
8456
# File 'lib/google/apis/compute_v1/classes.rb', line 8454

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this resource, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a ForwardingRule. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


8466
8467
8468
# File 'lib/google/apis/compute_v1/classes.rb', line 8466

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8473
8474
8475
# File 'lib/google/apis/compute_v1/classes.rb', line 8473

def labels
  @labels
end

#load_balancing_schemeString

Specifies the forwarding rule type. For more information about forwarding rules, refer to Forwarding rule concepts. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


8479
8480
8481
# File 'lib/google/apis/compute_v1/classes.rb', line 8479

def load_balancing_scheme
  @load_balancing_scheme
end

#metadata_filtersArray<Google::Apis::ComputeV1::MetadataFilter>

Opaque filter criteria used by load balancer to restrict routing configuration to a limited set of xDS compliant clients. In their xDS requests to load balancer, xDS clients present node metadata. When there is a match, the relevant configuration is made available to those proxies. Otherwise, all the resources (e.g. TargetHttpProxy, UrlMap) referenced by the ForwardingRule are not visible to those proxies. For each metadataFilter in this list, if its filterMatchCriteria is set to MATCH_ANY, at least one of the filterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. If multiple metadataFilters are specified, all of them need to be satisfied in order to be considered a match. metadataFilters specified here will be applifed before those specified in the UrlMap that this ForwardingRule references. metadataFilters only applies to Loadbalancers that have their loadBalancingScheme set to INTERNAL_SELF_MANAGED. Corresponds to the JSON property metadataFilters



8498
8499
8500
# File 'lib/google/apis/compute_v1/classes.rb', line 8498

def 
  @metadata_filters
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. For Private Service Connect forwarding rules that forward traffic to Google APIs, the forwarding rule name must be a 1-20 characters string with lowercase letters and numbers and must start with a letter. Corresponds to the JSON property name

Returns:

  • (String)


8511
8512
8513
# File 'lib/google/apis/compute_v1/classes.rb', line 8511

def name
  @name
end

#networkString

This field is not used for external load balancing. For Internal TCP/UDP Load Balancing, this field identifies the network that the load balanced IP should belong to for this Forwarding Rule. If this field is not specified, the default network will be used. For Private Service Connect forwarding rules that forward traffic to Google APIs, a network must be provided. Corresponds to the JSON property network

Returns:

  • (String)


8520
8521
8522
# File 'lib/google/apis/compute_v1/classes.rb', line 8520

def network
  @network
end

#network_tierString

This signifies the networking tier used for configuring this load balancer and can only take the following values: PREMIUM, STANDARD. For regional ForwardingRule, the valid values are PREMIUM and STANDARD. For GlobalForwardingRule, the valid value is PREMIUM. If this field is not specified, it is assumed to be PREMIUM. If IPAddress is specified, this value must be equal to the networkTier of the Address. Corresponds to the JSON property networkTier

Returns:

  • (String)


8530
8531
8532
# File 'lib/google/apis/compute_v1/classes.rb', line 8530

def network_tier
  @network_tier
end

#port_rangeString

This field can be used only if: - Load balancing scheme is one of EXTERNAL, INTERNAL_SELF_MANAGED or INTERNAL_MANAGED - IPProtocol is one of TCP, UDP, or SCTP. Packets addressed to ports in the specified range will be forwarded to target or backend_service. You can only use one of ports, port_range, or allPorts. The three are mutually exclusive. Forwarding rules with the same [ IPAddress, IPProtocol] pair must have disjoint ports. Some types of forwarding target have constraints on the acceptable ports. For more information, see Port specifications. @pattern: \d+(?:-\d+)? Corresponds to the JSON property portRange

Returns:

  • (String)


8543
8544
8545
# File 'lib/google/apis/compute_v1/classes.rb', line 8543

def port_range
  @port_range
end

#portsArray<String>

The ports field is only supported when the forwarding rule references a backend_service directly. Only packets addressed to the specified list of ports are forwarded to backends. You can only use one of ports and port_range, or allPorts. The three are mutually exclusive. You can specify a list of up to five ports, which can be non-contiguous. Forwarding rules with the same [IPAddress, IPProtocol] pair must have disjoint ports. @pattern: \d+( ?:-\d+)? Corresponds to the JSON property ports

Returns:

  • (Array<String>)


8555
8556
8557
# File 'lib/google/apis/compute_v1/classes.rb', line 8555

def ports
  @ports
end

#psc_connection_idFixnum

[Output Only] The PSC connection id of the PSC Forwarding Rule. Corresponds to the JSON property pscConnectionId

Returns:

  • (Fixnum)


8560
8561
8562
# File 'lib/google/apis/compute_v1/classes.rb', line 8560

def psc_connection_id
  @psc_connection_id
end

#psc_connection_statusString

Corresponds to the JSON property pscConnectionStatus

Returns:

  • (String)


8565
8566
8567
# File 'lib/google/apis/compute_v1/classes.rb', line 8565

def psc_connection_status
  @psc_connection_status
end

#regionString

[Output Only] URL of the region where the regional forwarding rule resides. This field is not applicable to global forwarding rules. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


8573
8574
8575
# File 'lib/google/apis/compute_v1/classes.rb', line 8573

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8578
8579
8580
# File 'lib/google/apis/compute_v1/classes.rb', line 8578

def self_link
  @self_link
end

#service_directory_registrationsArray<Google::Apis::ComputeV1::ForwardingRuleServiceDirectoryRegistration>

Service Directory resources to register this forwarding rule with. Currently, only supports a single Service Directory resource. Corresponds to the JSON property serviceDirectoryRegistrations



8584
8585
8586
# File 'lib/google/apis/compute_v1/classes.rb', line 8584

def service_directory_registrations
  @service_directory_registrations
end

#service_labelString

An optional prefix to the service name for this Forwarding Rule. If specified, the prefix is the first label of the fully qualified service name. The label must be 1-63 characters long, and comply with RFC1035. Specifically, the label must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]* [a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. This field is only used for internal load balancing. Corresponds to the JSON property serviceLabel

Returns:

  • (String)


8596
8597
8598
# File 'lib/google/apis/compute_v1/classes.rb', line 8596

def service_label
  @service_label
end

#service_nameString

[Output Only] The internal fully qualified service name for this Forwarding Rule. This field is only used for internal load balancing. Corresponds to the JSON property serviceName

Returns:

  • (String)


8602
8603
8604
# File 'lib/google/apis/compute_v1/classes.rb', line 8602

def service_name
  @service_name
end

#subnetworkString

This field identifies the subnetwork that the load balanced IP should belong to for this Forwarding Rule, used in internal load balancing and network load balancing with IPv6. If the network specified is in auto subnet mode, this field is optional. However, a subnetwork must be specified if the network is in custom subnet mode or when creating external forwarding rule with IPv6. Corresponds to the JSON property subnetwork

Returns:

  • (String)


8611
8612
8613
# File 'lib/google/apis/compute_v1/classes.rb', line 8611

def subnetwork
  @subnetwork
end

#targetString

Corresponds to the JSON property target

Returns:

  • (String)


8616
8617
8618
# File 'lib/google/apis/compute_v1/classes.rb', line 8616

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8623
8624
8625
8626
8627
8628
8629
8630
8631
8632
8633
8634
8635
8636
8637
8638
8639
8640
8641
8642
8643
8644
8645
8646
8647
8648
8649
8650
8651
8652
8653
8654
# File 'lib/google/apis/compute_v1/classes.rb', line 8623

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @all_ports = args[:all_ports] if args.key?(:all_ports)
  @allow_global_access = args[:allow_global_access] if args.key?(:allow_global_access)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @ip_version = args[:ip_version] if args.key?(:ip_version)
  @is_mirroring_collector = args[:is_mirroring_collector] if args.key?(:is_mirroring_collector)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @metadata_filters = args[:metadata_filters] if args.key?(:metadata_filters)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_tier = args[:network_tier] if args.key?(:network_tier)
  @port_range = args[:port_range] if args.key?(:port_range)
  @ports = args[:ports] if args.key?(:ports)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service_directory_registrations = args[:service_directory_registrations] if args.key?(:service_directory_registrations)
  @service_label = args[:service_label] if args.key?(:service_label)
  @service_name = args[:service_name] if args.key?(:service_name)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @target = args[:target] if args.key?(:target)
end