Class: Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
14160 14161 14162 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
14122 14123 14124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14122 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
Corresponds to the JSON property items
14127 14128 14129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14127 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
forwardingRuleAggregatedList for lists of forwarding rules.
Corresponds to the JSON property kind
14133 14134 14135 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14133 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
14143 14144 14145 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14143 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
14148 14149 14150 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14148 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
14153 14154 14155 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14153 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
14158 14159 14160 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14158 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14165 14166 14167 14168 14169 14170 14171 14172 14173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14165 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |