Class: Google::Apis::ComputeV1::ForwardingRuleAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleAggregatedList

Returns a new instance of ForwardingRuleAggregatedList.



14016
14017
14018
# File 'lib/google/apis/compute_v1/classes.rb', line 14016

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


13978
13979
13980
# File 'lib/google/apis/compute_v1/classes.rb', line 13978

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>

A list of ForwardingRulesScopedList resources. Corresponds to the JSON property items



13983
13984
13985
# File 'lib/google/apis/compute_v1/classes.rb', line 13983

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# forwardingRuleAggregatedList for lists of forwarding rules. Corresponds to the JSON property kind

Returns:

  • (String)


13989
13990
13991
# File 'lib/google/apis/compute_v1/classes.rb', line 13989

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


13999
14000
14001
# File 'lib/google/apis/compute_v1/classes.rb', line 13999

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14004
14005
14006
# File 'lib/google/apis/compute_v1/classes.rb', line 14004

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


14009
14010
14011
# File 'lib/google/apis/compute_v1/classes.rb', line 14009

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14014
14015
14016
# File 'lib/google/apis/compute_v1/classes.rb', line 14014

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14021
14022
14023
14024
14025
14026
14027
14028
14029
# File 'lib/google/apis/compute_v1/classes.rb', line 14021

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end