Class: Google::Apis::ComputeV1::ForwardingRuleAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleAggregatedList

Returns a new instance of ForwardingRuleAggregatedList.



13997
13998
13999
# File 'lib/google/apis/compute_v1/classes.rb', line 13997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


13959
13960
13961
# File 'lib/google/apis/compute_v1/classes.rb', line 13959

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>

A list of ForwardingRulesScopedList resources. Corresponds to the JSON property items



13964
13965
13966
# File 'lib/google/apis/compute_v1/classes.rb', line 13964

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# forwardingRuleAggregatedList for lists of forwarding rules. Corresponds to the JSON property kind

Returns:

  • (String)


13970
13971
13972
# File 'lib/google/apis/compute_v1/classes.rb', line 13970

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


13980
13981
13982
# File 'lib/google/apis/compute_v1/classes.rb', line 13980

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13985
13986
13987
# File 'lib/google/apis/compute_v1/classes.rb', line 13985

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


13990
13991
13992
# File 'lib/google/apis/compute_v1/classes.rb', line 13990

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



13995
13996
13997
# File 'lib/google/apis/compute_v1/classes.rb', line 13995

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14002
14003
14004
14005
14006
14007
14008
14009
14010
# File 'lib/google/apis/compute_v1/classes.rb', line 14002

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end