Class: Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
12772 12773 12774 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
12734 12735 12736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12734 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
Corresponds to the JSON property items
12739 12740 12741 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12739 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
forwardingRuleAggregatedList for lists of forwarding rules.
Corresponds to the JSON property kind
12745 12746 12747 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12745 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12755 12756 12757 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12755 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12760 12761 12762 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12760 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
12765 12766 12767 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12765 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12770 12771 12772 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12770 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12777 12778 12779 12780 12781 12782 12783 12784 12785 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12777 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |