Class: Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
12648 12649 12650 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12648 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
12610 12611 12612 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12610 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
Corresponds to the JSON property items
12615 12616 12617 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12615 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
forwardingRuleAggregatedList for lists of forwarding rules.
Corresponds to the JSON property kind
12621 12622 12623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12621 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12631 12632 12633 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12631 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12636 12637 12638 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12636 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
12641 12642 12643 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12641 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12646 12647 12648 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12646 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12653 12654 12655 12656 12657 12658 12659 12660 12661 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12653 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |