Class: Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
8701 8702 8703 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8664 8665 8666 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8664 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
Corresponds to the JSON property items
8669 8670 8671 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8669 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#forwardingRuleAggregatedList
for lists of forwarding rules.
Corresponds to the JSON property kind
8675 8676 8677 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8675 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8684 8685 8686 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8684 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8689 8690 8691 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8689 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
8694 8695 8696 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8694 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8699 8700 8701 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8699 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8706 8707 8708 8709 8710 8711 8712 8713 8714 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8706 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |