Class: Google::Apis::ComputeV1::ForwardingRuleList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of ForwardingRule resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleList

Returns a new instance of ForwardingRuleList.



14354
14355
14356
# File 'lib/google/apis/compute_v1/classes.rb', line 14354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14322
14323
14324
# File 'lib/google/apis/compute_v1/classes.rb', line 14322

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ForwardingRule>

A list of ForwardingRule resources. Corresponds to the JSON property items



14327
14328
14329
# File 'lib/google/apis/compute_v1/classes.rb', line 14327

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


14332
14333
14334
# File 'lib/google/apis/compute_v1/classes.rb', line 14332

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14342
14343
14344
# File 'lib/google/apis/compute_v1/classes.rb', line 14342

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14347
14348
14349
# File 'lib/google/apis/compute_v1/classes.rb', line 14347

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ForwardingRuleList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14352
14353
14354
# File 'lib/google/apis/compute_v1/classes.rb', line 14352

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14359
14360
14361
14362
14363
14364
14365
14366
# File 'lib/google/apis/compute_v1/classes.rb', line 14359

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end