Class: Google::Apis::ComputeV1::ForwardingRuleList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of ForwardingRule resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleList

Returns a new instance of ForwardingRuleList.



14292
14293
14294
# File 'lib/google/apis/compute_v1/classes.rb', line 14292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14260
14261
14262
# File 'lib/google/apis/compute_v1/classes.rb', line 14260

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ForwardingRule>

A list of ForwardingRule resources. Corresponds to the JSON property items



14265
14266
14267
# File 'lib/google/apis/compute_v1/classes.rb', line 14265

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


14270
14271
14272
# File 'lib/google/apis/compute_v1/classes.rb', line 14270

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14280
14281
14282
# File 'lib/google/apis/compute_v1/classes.rb', line 14280

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14285
14286
14287
# File 'lib/google/apis/compute_v1/classes.rb', line 14285

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ForwardingRuleList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14290
14291
14292
# File 'lib/google/apis/compute_v1/classes.rb', line 14290

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14297
14298
14299
14300
14301
14302
14303
14304
# File 'lib/google/apis/compute_v1/classes.rb', line 14297

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end