Class: Google::Apis::ComputeV1::ForwardingRuleList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of ForwardingRule resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ForwardingRule>
A list of ForwardingRule resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleList
constructor
A new instance of ForwardingRuleList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleList
Returns a new instance of ForwardingRuleList.
14122 14123 14124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
14090 14091 14092 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14090 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ForwardingRule>
A list of ForwardingRule resources.
Corresponds to the JSON property items
14095 14096 14097 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14095 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
14100 14101 14102 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14100 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
14110 14111 14112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14110 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
14115 14116 14117 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14115 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
14120 14121 14122 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14120 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14127 14128 14129 14130 14131 14132 14133 14134 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14127 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |