Class: Google::Apis::ComputeV1::ForwardingRuleList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of ForwardingRule resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleList

Returns a new instance of ForwardingRuleList.



12897
12898
12899
# File 'lib/google/apis/compute_v1/classes.rb', line 12897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12865
12866
12867
# File 'lib/google/apis/compute_v1/classes.rb', line 12865

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ForwardingRule>

A list of ForwardingRule resources. Corresponds to the JSON property items



12870
12871
12872
# File 'lib/google/apis/compute_v1/classes.rb', line 12870

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


12875
12876
12877
# File 'lib/google/apis/compute_v1/classes.rb', line 12875

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12885
12886
12887
# File 'lib/google/apis/compute_v1/classes.rb', line 12885

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12890
12891
12892
# File 'lib/google/apis/compute_v1/classes.rb', line 12890

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ForwardingRuleList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12895
12896
12897
# File 'lib/google/apis/compute_v1/classes.rb', line 12895

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12902
12903
12904
12905
12906
12907
12908
12909
# File 'lib/google/apis/compute_v1/classes.rb', line 12902

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end