Class: Google::Apis::ComputeV1::ForwardingRuleList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of ForwardingRule resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ForwardingRule>
A list of ForwardingRule resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleList
constructor
A new instance of ForwardingRuleList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleList
Returns a new instance of ForwardingRuleList.
8819 8820 8821 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8788 8789 8790 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8788 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ForwardingRule>
A list of ForwardingRule resources.
Corresponds to the JSON property items
8793 8794 8795 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8793 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
8798 8799 8800 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8798 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8807 8808 8809 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8807 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8812 8813 8814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8812 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8817 8818 8819 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8817 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8824 8825 8826 8827 8828 8829 8830 8831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 8824 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |