Class: Google::Apis::ComputeV1::ForwardingRuleServiceDirectoryRegistration
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleServiceDirectoryRegistration
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Describes the auto-registration of the forwarding rule to Service Directory. The region and project of the Service Directory resource generated from this registration will be the same as this forwarding rule.
Instance Attribute Summary collapse
-
#namespace ⇒ String
Service Directory namespace to register the forwarding rule under.
-
#service ⇒ String
Service Directory service to register the forwarding rule under.
-
#service_directory_region ⇒ String
[Optional] Service Directory region to register this global forwarding rule under.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleServiceDirectoryRegistration
constructor
A new instance of ForwardingRuleServiceDirectoryRegistration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleServiceDirectoryRegistration
Returns a new instance of ForwardingRuleServiceDirectoryRegistration.
14482 14483 14484 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#namespace ⇒ String
Service Directory namespace to register the forwarding rule under.
Corresponds to the JSON property namespace
14467 14468 14469 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14467 def namespace @namespace end |
#service ⇒ String
Service Directory service to register the forwarding rule under.
Corresponds to the JSON property service
14472 14473 14474 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14472 def service @service end |
#service_directory_region ⇒ String
[Optional] Service Directory region to register this global forwarding
rule under. Default to "us-central1". Only used for PSC for Google APIs.
All PSC for Google APIs forwarding rules on the same network should use
the same Service Directory region.
Corresponds to the JSON property serviceDirectoryRegion
14480 14481 14482 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14480 def service_directory_region @service_directory_region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14487 14488 14489 14490 14491 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14487 def update!(**args) @namespace = args[:namespace] if args.key?(:namespace) @service = args[:service] if args.key?(:service) @service_directory_region = args[:service_directory_region] if args.key?(:service_directory_region) end |