Class: Google::Apis::ComputeV1::ForwardingRuleServiceDirectoryRegistration
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleServiceDirectoryRegistration
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Describes the auto-registration of the forwarding rule to Service Directory. The region and project of the Service Directory resource generated from this registration will be the same as this forwarding rule.
Instance Attribute Summary collapse
-
#namespace ⇒ String
Service Directory namespace to register the forwarding rule under.
-
#service ⇒ String
Service Directory service to register the forwarding rule under.
-
#service_directory_region ⇒ String
[Optional] Service Directory region to register this global forwarding rule under.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleServiceDirectoryRegistration
constructor
A new instance of ForwardingRuleServiceDirectoryRegistration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleServiceDirectoryRegistration
Returns a new instance of ForwardingRuleServiceDirectoryRegistration.
13025 13026 13027 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#namespace ⇒ String
Service Directory namespace to register the forwarding rule under.
Corresponds to the JSON property namespace
13010 13011 13012 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13010 def namespace @namespace end |
#service ⇒ String
Service Directory service to register the forwarding rule under.
Corresponds to the JSON property service
13015 13016 13017 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13015 def service @service end |
#service_directory_region ⇒ String
[Optional] Service Directory region to register this global forwarding
rule under. Default to "us-central1". Only used for PSC for Google APIs.
All PSC for Google APIs forwarding rules on the same network should use
the same Service Directory region.
Corresponds to the JSON property serviceDirectoryRegion
13023 13024 13025 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13023 def service_directory_region @service_directory_region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13030 13031 13032 13033 13034 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13030 def update!(**args) @namespace = args[:namespace] if args.key?(:namespace) @service = args[:service] if args.key?(:service) @service_directory_region = args[:service_directory_region] if args.key?(:service_directory_region) end |