Class: Google::Apis::ComputeV1::FutureReservation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#aggregate_reservation ⇒ Google::Apis::ComputeV1::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs.
-
#auto_created_reservations_delete_time ⇒ String
Future timestamp when the FR auto-created reservations will be deleted by Compute Engine.
-
#auto_created_reservations_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#auto_delete_auto_created_reservations ⇒ Boolean
(also: #auto_delete_auto_created_reservations?)
Setting for enabling or disabling automatic deletion for auto-created reservation.
-
#commitment_info ⇒ Google::Apis::ComputeV1::FutureReservationCommitmentInfo
If not present, then FR will not deliver a new commitment or update an existing commitment.
-
#confidential_compute_type ⇒ String
Corresponds to the JSON property
confidentialComputeType. -
#creation_timestamp ⇒ String
Output only.
-
#deployment_type ⇒ String
Type of the deployment requested as part of future reservation.
-
#description ⇒ String
An optional description of this resource.
-
#enable_emergent_maintenance ⇒ Boolean
(also: #enable_emergent_maintenance?)
Indicates if this group of VMs have emergent maintenance enabled.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#name_prefix ⇒ String
Name prefix for the reservations to be created at the time of delivery.
-
#params ⇒ Google::Apis::ComputeV1::FutureReservationParams
Additional future reservation params.
-
#planning_status ⇒ String
Planning state before being submitted for evaluation Corresponds to the JSON property
planningStatus. -
#reservation_mode ⇒ String
The reservation mode which determines reservation-termination behavior and expected pricing.
-
#reservation_name ⇒ String
Name of reservations where the capacity is provisioned at the time of delivery of future reservations.
-
#resource_metadata ⇒ Google::Apis::ComputeV1::ResourceMetadata
Standardized resource metadata common to all compute resources.
-
#scheduling_type ⇒ String
Maintenance information for this reservation Corresponds to the JSON property
schedulingType. -
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#specific_reservation_required ⇒ Boolean
(also: #specific_reservation_required?)
Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation.
-
#specific_sku_properties ⇒ Google::Apis::ComputeV1::FutureReservationSpecificSkuProperties
Future Reservation configuration to indicate instance properties and total count.
-
#status ⇒ Google::Apis::ComputeV1::FutureReservationStatus
[Output only] Represents status related to the future reservation.
-
#time_window ⇒ Google::Apis::ComputeV1::FutureReservationTimeWindow
Time window for this Future Reservation.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservation
constructor
A new instance of FutureReservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservation
Returns a new instance of FutureReservation.
14786 14787 14788 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_reservation ⇒ Google::Apis::ComputeV1::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total
count of CPUs) and can account for multiple instance SKUs. In other words,
one can create instances of varying shapes against this reservation.
Corresponds to the JSON property aggregateReservation
14606 14607 14608 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14606 def aggregate_reservation @aggregate_reservation end |
#auto_created_reservations_delete_time ⇒ String
Future timestamp when the FR auto-created reservations will be deleted by
Compute Engine. Format of this field must be a valid
href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value.
Corresponds to the JSON property autoCreatedReservationsDeleteTime
14613 14614 14615 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14613 def auto_created_reservations_delete_time @auto_created_reservations_delete_time end |
#auto_created_reservations_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property autoCreatedReservationsDuration
14621 14622 14623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14621 def auto_created_reservations_duration @auto_created_reservations_duration end |
#auto_delete_auto_created_reservations ⇒ Boolean Also known as: auto_delete_auto_created_reservations?
Setting for enabling or disabling automatic deletion for auto-created
reservation. If set to true, auto-created reservations will be
deleted at Future Reservation's end time (default) or at user's defined
timestamp if any of the
[auto_created_reservations_delete_time, auto_created_reservations_duration]
values is specified.
For keeping auto-created reservation indefinitely, this value should be set
to false.
Corresponds to the JSON property autoDeleteAutoCreatedReservations
14633 14634 14635 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14633 def auto_delete_auto_created_reservations @auto_delete_auto_created_reservations end |
#commitment_info ⇒ Google::Apis::ComputeV1::FutureReservationCommitmentInfo
If not present, then FR will not deliver a new commitment or update an
existing commitment.
Corresponds to the JSON property commitmentInfo
14640 14641 14642 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14640 def commitment_info @commitment_info end |
#confidential_compute_type ⇒ String
Corresponds to the JSON property confidentialComputeType
14645 14646 14647 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14645 def confidential_compute_type @confidential_compute_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this future reservation
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
14652 14653 14654 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14652 def @creation_timestamp end |
#deployment_type ⇒ String
Type of the deployment requested as part of future reservation.
Corresponds to the JSON property deploymentType
14657 14658 14659 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14657 def deployment_type @deployment_type end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the future reservation.
Corresponds to the JSON property description
14663 14664 14665 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14663 def description @description end |
#enable_emergent_maintenance ⇒ Boolean Also known as: enable_emergent_maintenance?
Indicates if this group of VMs have emergent maintenance enabled.
Corresponds to the JSON property enableEmergentMaintenance
14668 14669 14670 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14668 def enable_emergent_maintenance @enable_emergent_maintenance end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this future reservation.
The server
defines this identifier.
Corresponds to the JSON property id
14676 14677 14678 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14676 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
futureReservation for future reservations.
Corresponds to the JSON property kind
14682 14683 14684 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14682 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
14694 14695 14696 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14694 def name @name end |
#name_prefix ⇒ String
Name prefix for the reservations to be created at the time of
delivery. The name prefix must comply with RFC1035.
Maximum allowed length for name prefix is 20. Automatically created
reservations name format will be -date-####.
Corresponds to the JSON property namePrefix
14702 14703 14704 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14702 def name_prefix @name_prefix end |
#params ⇒ Google::Apis::ComputeV1::FutureReservationParams
Additional future reservation params.
Corresponds to the JSON property params
14707 14708 14709 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14707 def params @params end |
#planning_status ⇒ String
Planning state before being submitted for evaluation
Corresponds to the JSON property planningStatus
14712 14713 14714 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14712 def planning_status @planning_status end |
#reservation_mode ⇒ String
The reservation mode which determines reservation-termination behavior and
expected pricing.
Corresponds to the JSON property reservationMode
14718 14719 14720 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14718 def reservation_mode @reservation_mode end |
#reservation_name ⇒ String
Name of reservations where the capacity is provisioned at the time of
delivery of future reservations. If the reservation with the given name
does not exist already, it is created automatically at the time of Approval
with INACTIVE state till specified start-time. Either provide the
reservation_name or a name_prefix.
Corresponds to the JSON property reservationName
14727 14728 14729 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14727 def reservation_name @reservation_name end |
#resource_metadata ⇒ Google::Apis::ComputeV1::ResourceMetadata
Standardized resource metadata common to all compute resources.
Corresponds to the JSON property resourceMetadata
14732 14733 14734 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14732 def @resource_metadata end |
#scheduling_type ⇒ String
Maintenance information for this reservation
Corresponds to the JSON property schedulingType
14737 14738 14739 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14737 def scheduling_type @scheduling_type end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
14743 14744 14745 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14743 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
14749 14750 14751 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14749 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
14754 14755 14756 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14754 def share_settings @share_settings end |
#specific_reservation_required ⇒ Boolean Also known as: specific_reservation_required?
Indicates whether the auto-created reservation can be consumed by VMs with
affinity for "any" reservation. If the field is set, then only VMs that
target the reservation by name can consume from the delivered reservation.
Corresponds to the JSON property specificReservationRequired
14761 14762 14763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14761 def specific_reservation_required @specific_reservation_required end |
#specific_sku_properties ⇒ Google::Apis::ComputeV1::FutureReservationSpecificSkuProperties
Future Reservation configuration to indicate instance properties and
total count.
Corresponds to the JSON property specificSkuProperties
14768 14769 14770 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14768 def specific_sku_properties @specific_sku_properties end |
#status ⇒ Google::Apis::ComputeV1::FutureReservationStatus
[Output only] Represents status related to the future reservation.
Corresponds to the JSON property status
14773 14774 14775 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14773 def status @status end |
#time_window ⇒ Google::Apis::ComputeV1::FutureReservationTimeWindow
Time window for this Future Reservation.
Corresponds to the JSON property timeWindow
14778 14779 14780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14778 def time_window @time_window end |
#zone ⇒ String
Output only. [Output Only] URL of the Zone where this future reservation
resides.
Corresponds to the JSON property zone
14784 14785 14786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14784 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14791 14792 14793 14794 14795 14796 14797 14798 14799 14800 14801 14802 14803 14804 14805 14806 14807 14808 14809 14810 14811 14812 14813 14814 14815 14816 14817 14818 14819 14820 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14791 def update!(**args) @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation) @auto_created_reservations_delete_time = args[:auto_created_reservations_delete_time] if args.key?(:auto_created_reservations_delete_time) @auto_created_reservations_duration = args[:auto_created_reservations_duration] if args.key?(:auto_created_reservations_duration) @auto_delete_auto_created_reservations = args[:auto_delete_auto_created_reservations] if args.key?(:auto_delete_auto_created_reservations) @commitment_info = args[:commitment_info] if args.key?(:commitment_info) @confidential_compute_type = args[:confidential_compute_type] if args.key?(:confidential_compute_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @description = args[:description] if args.key?(:description) @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @name_prefix = args[:name_prefix] if args.key?(:name_prefix) @params = args[:params] if args.key?(:params) @planning_status = args[:planning_status] if args.key?(:planning_status) @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode) @reservation_name = args[:reservation_name] if args.key?(:reservation_name) @resource_metadata = args[:resource_metadata] if args.key?(:resource_metadata) @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) @status = args[:status] if args.key?(:status) @time_window = args[:time_window] if args.key?(:time_window) @zone = args[:zone] if args.key?(:zone) end |