Class: Google::Apis::ComputeV1::FutureReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservation

Returns a new instance of FutureReservation.



13308
13309
13310
# File 'lib/google/apis/compute_v1/classes.rb', line 13308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregate_reservationGoogle::Apis::ComputeV1::AllocationAggregateReservation

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation. Corresponds to the JSON property aggregateReservation



13143
13144
13145
# File 'lib/google/apis/compute_v1/classes.rb', line 13143

def aggregate_reservation
  @aggregate_reservation
end

#auto_created_reservations_delete_timeString

Future timestamp when the FR auto-created reservations will be deleted by Compute Engine. Format of this field must be a valid href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value. Corresponds to the JSON property autoCreatedReservationsDeleteTime

Returns:

  • (String)


13150
13151
13152
# File 'lib/google/apis/compute_v1/classes.rb', line 13150

def auto_created_reservations_delete_time
  @auto_created_reservations_delete_time
end

#auto_created_reservations_durationGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property autoCreatedReservationsDuration



13158
13159
13160
# File 'lib/google/apis/compute_v1/classes.rb', line 13158

def auto_created_reservations_duration
  @auto_created_reservations_duration
end

#auto_delete_auto_created_reservationsBoolean Also known as: auto_delete_auto_created_reservations?

Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the [auto_created_reservations_delete_time, auto_created_reservations_duration] values is specified. For keeping auto-created reservation indefinitely, this value should be set to false. Corresponds to the JSON property autoDeleteAutoCreatedReservations

Returns:

  • (Boolean)


13170
13171
13172
# File 'lib/google/apis/compute_v1/classes.rb', line 13170

def auto_delete_auto_created_reservations
  @auto_delete_auto_created_reservations
end

#commitment_infoGoogle::Apis::ComputeV1::FutureReservationCommitmentInfo

If not present, then FR will not deliver a new commitment or update an existing commitment. Corresponds to the JSON property commitmentInfo



13177
13178
13179
# File 'lib/google/apis/compute_v1/classes.rb', line 13177

def commitment_info
  @commitment_info
end

#creation_timestampString

Output only. [Output Only] The creation timestamp for this future reservation inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


13184
13185
13186
# File 'lib/google/apis/compute_v1/classes.rb', line 13184

def creation_timestamp
  @creation_timestamp
end

#deployment_typeString

Type of the deployment requested as part of future reservation. Corresponds to the JSON property deploymentType

Returns:

  • (String)


13189
13190
13191
# File 'lib/google/apis/compute_v1/classes.rb', line 13189

def deployment_type
  @deployment_type
end

#descriptionString

An optional description of this resource. Provide this property when you create the future reservation. Corresponds to the JSON property description

Returns:

  • (String)


13195
13196
13197
# File 'lib/google/apis/compute_v1/classes.rb', line 13195

def description
  @description
end

#enable_emergent_maintenanceBoolean Also known as: enable_emergent_maintenance?

Indicates if this group of VMs have emergent maintenance enabled. Corresponds to the JSON property enableEmergentMaintenance

Returns:

  • (Boolean)


13200
13201
13202
# File 'lib/google/apis/compute_v1/classes.rb', line 13200

def enable_emergent_maintenance
  @enable_emergent_maintenance
end

#idFixnum

Output only. [Output Only] A unique identifier for this future reservation. The server defines this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13208
13209
13210
# File 'lib/google/apis/compute_v1/classes.rb', line 13208

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# futureReservation for future reservations. Corresponds to the JSON property kind

Returns:

  • (String)


13214
13215
13216
# File 'lib/google/apis/compute_v1/classes.rb', line 13214

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


13226
13227
13228
# File 'lib/google/apis/compute_v1/classes.rb', line 13226

def name
  @name
end

#name_prefixString

Name prefix for the reservations to be created at the time of delivery. The name prefix must comply with RFC1035. Maximum allowed length for name prefix is 20. Automatically created reservations name format will be -date-####. Corresponds to the JSON property namePrefix

Returns:

  • (String)


13234
13235
13236
# File 'lib/google/apis/compute_v1/classes.rb', line 13234

def name_prefix
  @name_prefix
end

#planning_statusString

Planning state before being submitted for evaluation Corresponds to the JSON property planningStatus

Returns:

  • (String)


13239
13240
13241
# File 'lib/google/apis/compute_v1/classes.rb', line 13239

def planning_status
  @planning_status
end

#reservation_modeString

The reservation mode which determines reservation-termination behavior and expected pricing. Corresponds to the JSON property reservationMode

Returns:

  • (String)


13245
13246
13247
# File 'lib/google/apis/compute_v1/classes.rb', line 13245

def reservation_mode
  @reservation_mode
end

#reservation_nameString

Name of reservations where the capacity is provisioned at the time of delivery of future reservations. If the reservation with the given name does not exist already, it is created automatically at the time of Approval with INACTIVE state till specified start-time. Either provide the reservation_name or a name_prefix. Corresponds to the JSON property reservationName

Returns:

  • (String)


13254
13255
13256
# File 'lib/google/apis/compute_v1/classes.rb', line 13254

def reservation_name
  @reservation_name
end

#scheduling_typeString

Maintenance information for this reservation Corresponds to the JSON property schedulingType

Returns:

  • (String)


13259
13260
13261
# File 'lib/google/apis/compute_v1/classes.rb', line 13259

def scheduling_type
  @scheduling_type
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13265
13266
13267
# File 'lib/google/apis/compute_v1/classes.rb', line 13265

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


13271
13272
13273
# File 'lib/google/apis/compute_v1/classes.rb', line 13271

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeV1::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



13276
13277
13278
# File 'lib/google/apis/compute_v1/classes.rb', line 13276

def share_settings
  @share_settings
end

#specific_reservation_requiredBoolean Also known as: specific_reservation_required?

Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from the delivered reservation. Corresponds to the JSON property specificReservationRequired

Returns:

  • (Boolean)


13283
13284
13285
# File 'lib/google/apis/compute_v1/classes.rb', line 13283

def specific_reservation_required
  @specific_reservation_required
end

#specific_sku_propertiesGoogle::Apis::ComputeV1::FutureReservationSpecificSkuProperties

Future Reservation configuration to indicate instance properties and total count. Corresponds to the JSON property specificSkuProperties



13290
13291
13292
# File 'lib/google/apis/compute_v1/classes.rb', line 13290

def specific_sku_properties
  @specific_sku_properties
end

#statusGoogle::Apis::ComputeV1::FutureReservationStatus

[Output only] Represents status related to the future reservation. Corresponds to the JSON property status



13295
13296
13297
# File 'lib/google/apis/compute_v1/classes.rb', line 13295

def status
  @status
end

#time_windowGoogle::Apis::ComputeV1::FutureReservationTimeWindow

Time window for this Future Reservation. Corresponds to the JSON property timeWindow



13300
13301
13302
# File 'lib/google/apis/compute_v1/classes.rb', line 13300

def time_window
  @time_window
end

#zoneString

Output only. [Output Only] URL of the Zone where this future reservation resides. Corresponds to the JSON property zone

Returns:

  • (String)


13306
13307
13308
# File 'lib/google/apis/compute_v1/classes.rb', line 13306

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13313
13314
13315
13316
13317
13318
13319
13320
13321
13322
13323
13324
13325
13326
13327
13328
13329
13330
13331
13332
13333
13334
13335
13336
13337
13338
13339
# File 'lib/google/apis/compute_v1/classes.rb', line 13313

def update!(**args)
  @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation)
  @auto_created_reservations_delete_time = args[:auto_created_reservations_delete_time] if args.key?(:auto_created_reservations_delete_time)
  @auto_created_reservations_duration = args[:auto_created_reservations_duration] if args.key?(:auto_created_reservations_duration)
  @auto_delete_auto_created_reservations = args[:auto_delete_auto_created_reservations] if args.key?(:auto_delete_auto_created_reservations)
  @commitment_info = args[:commitment_info] if args.key?(:commitment_info)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @name_prefix = args[:name_prefix] if args.key?(:name_prefix)
  @planning_status = args[:planning_status] if args.key?(:planning_status)
  @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode)
  @reservation_name = args[:reservation_name] if args.key?(:reservation_name)
  @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @status = args[:status] if args.key?(:status)
  @time_window = args[:time_window] if args.key?(:time_window)
  @zone = args[:zone] if args.key?(:zone)
end