Class: Google::Apis::ComputeV1::FutureReservationCommitmentInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationCommitmentInfo

Returns a new instance of FutureReservationCommitmentInfo.



14834
14835
14836
# File 'lib/google/apis/compute_v1/classes.rb', line 14834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitment_nameString

name of the commitment where capacity is being delivered to. Corresponds to the JSON property commitmentName

Returns:

  • (String)


14818
14819
14820
# File 'lib/google/apis/compute_v1/classes.rb', line 14818

def commitment_name
  @commitment_name
end

#commitment_planString

Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created. Corresponds to the JSON property commitmentPlan

Returns:

  • (String)


14825
14826
14827
# File 'lib/google/apis/compute_v1/classes.rb', line 14825

def commitment_plan
  @commitment_plan
end

#previous_commitment_termsString

Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment. Corresponds to the JSON property previousCommitmentTerms

Returns:

  • (String)


14832
14833
14834
# File 'lib/google/apis/compute_v1/classes.rb', line 14832

def previous_commitment_terms
  @previous_commitment_terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14839
14840
14841
14842
14843
# File 'lib/google/apis/compute_v1/classes.rb', line 14839

def update!(**args)
  @commitment_name = args[:commitment_name] if args.key?(:commitment_name)
  @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan)
  @previous_commitment_terms = args[:previous_commitment_terms] if args.key?(:previous_commitment_terms)
end