Class: Google::Apis::ComputeV1::FutureReservationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output only] Represents status related to the future reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatus

Returns a new instance of FutureReservationStatus.



14960
14961
14962
# File 'lib/google/apis/compute_v1/classes.rb', line 14960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amendment_statusString

Output only. [Output Only] The current status of the requested amendment. Corresponds to the JSON property amendmentStatus

Returns:

  • (String)


14913
14914
14915
# File 'lib/google/apis/compute_v1/classes.rb', line 14913

def amendment_status
  @amendment_status
end

#auto_created_reservationsArray<String>

Output only. Fully qualified urls of the automatically created reservations at start_time. Corresponds to the JSON property autoCreatedReservations

Returns:

  • (Array<String>)


14919
14920
14921
# File 'lib/google/apis/compute_v1/classes.rb', line 14919

def auto_created_reservations
  @auto_created_reservations
end

#existing_matching_usage_infoGoogle::Apis::ComputeV1::FutureReservationStatusExistingMatchingUsageInfo

[Output Only] Represents the existing matching usage for the future reservation. Corresponds to the JSON property existingMatchingUsageInfo



14925
14926
14927
# File 'lib/google/apis/compute_v1/classes.rb', line 14925

def existing_matching_usage_info
  @existing_matching_usage_info
end

#fulfilled_countFixnum

Output only. This count indicates the fulfilled capacity so far. This is set during "PROVISIONING" state. This count also includes capacity delivered as part of existing matching reservations. Corresponds to the JSON property fulfilledCount

Returns:

  • (Fixnum)


14933
14934
14935
# File 'lib/google/apis/compute_v1/classes.rb', line 14933

def fulfilled_count
  @fulfilled_count
end

#last_known_good_stateGoogle::Apis::ComputeV1::FutureReservationStatusLastKnownGoodState

The state that the future reservation will be reverted to should the amendment be declined. Corresponds to the JSON property lastKnownGoodState



14939
14940
14941
# File 'lib/google/apis/compute_v1/classes.rb', line 14939

def last_known_good_state
  @last_known_good_state
end

#lock_timeString

Output only. Time when Future Reservation would become LOCKED, after which no modifications to Future Reservation will be allowed. Applicable only after the Future Reservation is in the APPROVED state. The lock_time is an RFC3339 string. The procurement_status will transition to PROCURING state at this time. Corresponds to the JSON property lockTime

Returns:

  • (String)


14948
14949
14950
# File 'lib/google/apis/compute_v1/classes.rb', line 14948

def lock_time
  @lock_time
end

#procurement_statusString

Output only. Current state of this Future Reservation Corresponds to the JSON property procurementStatus

Returns:

  • (String)


14953
14954
14955
# File 'lib/google/apis/compute_v1/classes.rb', line 14953

def procurement_status
  @procurement_status
end

#specific_sku_propertiesGoogle::Apis::ComputeV1::FutureReservationStatusSpecificSkuProperties

Properties to be set for the Future Reservation. Corresponds to the JSON property specificSkuProperties



14958
14959
14960
# File 'lib/google/apis/compute_v1/classes.rb', line 14958

def specific_sku_properties
  @specific_sku_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14965
14966
14967
14968
14969
14970
14971
14972
14973
14974
# File 'lib/google/apis/compute_v1/classes.rb', line 14965

def update!(**args)
  @amendment_status = args[:amendment_status] if args.key?(:amendment_status)
  @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations)
  @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info)
  @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count)
  @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state)
  @lock_time = args[:lock_time] if args.key?(:lock_time)
  @procurement_status = args[:procurement_status] if args.key?(:procurement_status)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
end