Class: Google::Apis::ComputeV1::FutureReservationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output only] Represents status related to the future reservation.
Instance Attribute Summary collapse
-
#amendment_status ⇒ String
Output only.
-
#auto_created_reservations ⇒ Array<String>
Output only.
-
#existing_matching_usage_info ⇒ Google::Apis::ComputeV1::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#fulfilled_count ⇒ Fixnum
Output only.
-
#last_known_good_state ⇒ Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the amendment be declined.
-
#lock_time ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
-
#specific_sku_properties ⇒ Google::Apis::ComputeV1::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatus
constructor
A new instance of FutureReservationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatus
Returns a new instance of FutureReservationStatus.
14898 14899 14900 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amendment_status ⇒ String
Output only. [Output Only] The current status of the requested amendment.
Corresponds to the JSON property amendmentStatus
14851 14852 14853 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14851 def amendment_status @amendment_status end |
#auto_created_reservations ⇒ Array<String>
Output only. Fully qualified urls of the automatically created reservations at
start_time.
Corresponds to the JSON property autoCreatedReservations
14857 14858 14859 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14857 def auto_created_reservations @auto_created_reservations end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeV1::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
14863 14864 14865 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14863 def existing_matching_usage_info @existing_matching_usage_info end |
#fulfilled_count ⇒ Fixnum
Output only. This count indicates the fulfilled capacity so far. This is set
during
"PROVISIONING" state. This count also includes capacity delivered as part
of existing matching reservations.
Corresponds to the JSON property fulfilledCount
14871 14872 14873 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14871 def fulfilled_count @fulfilled_count end |
#last_known_good_state ⇒ Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the
amendment be declined.
Corresponds to the JSON property lastKnownGoodState
14877 14878 14879 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14877 def last_known_good_state @last_known_good_state end |
#lock_time ⇒ String
Output only. Time when Future Reservation would become LOCKED, after which no
modifications to Future Reservation will be allowed. Applicable only
after the Future Reservation is in the APPROVED state. The lock_time is
an RFC3339 string. The procurement_status will transition to PROCURING
state at this time.
Corresponds to the JSON property lockTime
14886 14887 14888 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14886 def lock_time @lock_time end |
#procurement_status ⇒ String
Output only. Current state of this Future Reservation
Corresponds to the JSON property procurementStatus
14891 14892 14893 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14891 def procurement_status @procurement_status end |
#specific_sku_properties ⇒ Google::Apis::ComputeV1::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Corresponds to the JSON property specificSkuProperties
14896 14897 14898 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14896 def specific_sku_properties @specific_sku_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14903 14904 14905 14906 14907 14908 14909 14910 14911 14912 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14903 def update!(**args) @amendment_status = args[:amendment_status] if args.key?(:amendment_status) @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count) @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state) @lock_time = args[:lock_time] if args.key?(:lock_time) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) end |