Class: Google::Apis::ComputeV1::FutureReservationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output only] Represents status related to the future reservation.
Instance Attribute Summary collapse
-
#amendment_status ⇒ String
Output only.
-
#auto_created_reservations ⇒ Array<String>
Output only.
-
#existing_matching_usage_info ⇒ Google::Apis::ComputeV1::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#fulfilled_count ⇒ Fixnum
Output only.
-
#last_known_good_state ⇒ Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the amendment be declined.
-
#lock_time ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
-
#specific_sku_properties ⇒ Google::Apis::ComputeV1::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatus
constructor
A new instance of FutureReservationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatus
Returns a new instance of FutureReservationStatus.
13341 13342 13343 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amendment_status ⇒ String
Output only. [Output Only] The current status of the requested amendment.
Corresponds to the JSON property amendmentStatus
13294 13295 13296 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13294 def amendment_status @amendment_status end |
#auto_created_reservations ⇒ Array<String>
Output only. Fully qualified urls of the automatically created reservations at
start_time.
Corresponds to the JSON property autoCreatedReservations
13300 13301 13302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13300 def auto_created_reservations @auto_created_reservations end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeV1::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
13306 13307 13308 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13306 def existing_matching_usage_info @existing_matching_usage_info end |
#fulfilled_count ⇒ Fixnum
Output only. This count indicates the fulfilled capacity so far. This is set
during
"PROVISIONING" state. This count also includes capacity delivered as part
of existing matching reservations.
Corresponds to the JSON property fulfilledCount
13314 13315 13316 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13314 def fulfilled_count @fulfilled_count end |
#last_known_good_state ⇒ Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the
amendment be declined.
Corresponds to the JSON property lastKnownGoodState
13320 13321 13322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13320 def last_known_good_state @last_known_good_state end |
#lock_time ⇒ String
Output only. Time when Future Reservation would become LOCKED, after which no
modifications to Future Reservation will be allowed. Applicable only
after the Future Reservation is in the APPROVED state. The lock_time is
an RFC3339 string. The procurement_status will transition to PROCURING
state at this time.
Corresponds to the JSON property lockTime
13329 13330 13331 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13329 def lock_time @lock_time end |
#procurement_status ⇒ String
Output only. Current state of this Future Reservation
Corresponds to the JSON property procurementStatus
13334 13335 13336 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13334 def procurement_status @procurement_status end |
#specific_sku_properties ⇒ Google::Apis::ComputeV1::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Corresponds to the JSON property specificSkuProperties
13339 13340 13341 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13339 def specific_sku_properties @specific_sku_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13346 def update!(**args) @amendment_status = args[:amendment_status] if args.key?(:amendment_status) @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count) @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state) @lock_time = args[:lock_time] if args.key?(:lock_time) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) end |