Class: Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The state that the future reservation will be reverted to should the amendment be declined.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#existing_matching_usage_info ⇒ Google::Apis::ComputeV1::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#future_reservation_specs ⇒ Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
The properties of the last known good state for the Future Reservation.
-
#lock_time ⇒ String
Output only.
-
#name_prefix ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState
constructor
A new instance of FutureReservationStatusLastKnownGoodState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState
Returns a new instance of FutureReservationStatusLastKnownGoodState.
15045 15046 15047 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. [Output Only] The description of the FutureReservation before an
amendment was requested.
Corresponds to the JSON property description
15013 15014 15015 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15013 def description @description end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeV1::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
15019 15020 15021 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15019 def existing_matching_usage_info @existing_matching_usage_info end |
#future_reservation_specs ⇒ Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
The properties of the last known good state for the Future Reservation.
Corresponds to the JSON property futureReservationSpecs
15024 15025 15026 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15024 def future_reservation_specs @future_reservation_specs end |
#lock_time ⇒ String
Output only. [Output Only] The lock time of the FutureReservation before an
amendment was requested.
Corresponds to the JSON property lockTime
15030 15031 15032 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15030 def lock_time @lock_time end |
#name_prefix ⇒ String
Output only. [Output Only] The name prefix of the Future Reservation before an
amendment was requested.
Corresponds to the JSON property namePrefix
15036 15037 15038 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15036 def name_prefix @name_prefix end |
#procurement_status ⇒ String
Output only. [Output Only] The status of the last known good state for the
Future
Reservation.
Corresponds to the JSON property procurementStatus
15043 15044 15045 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15043 def procurement_status @procurement_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15050 15051 15052 15053 15054 15055 15056 15057 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15050 def update!(**args) @description = args[:description] if args.key?(:description) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @future_reservation_specs = args[:future_reservation_specs] if args.key?(:future_reservation_specs) @lock_time = args[:lock_time] if args.key?(:lock_time) @name_prefix = args[:name_prefix] if args.key?(:name_prefix) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) end |