Class: Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The state that the future reservation will be reverted to should the amendment be declined.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState

Returns a new instance of FutureReservationStatusLastKnownGoodState.



14832
14833
14834
# File 'lib/google/apis/compute_v1/classes.rb', line 14832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. [Output Only] The description of the FutureReservation before an amendment was requested. Corresponds to the JSON property description

Returns:

  • (String)


14800
14801
14802
# File 'lib/google/apis/compute_v1/classes.rb', line 14800

def description
  @description
end

#existing_matching_usage_infoGoogle::Apis::ComputeV1::FutureReservationStatusExistingMatchingUsageInfo

[Output Only] Represents the existing matching usage for the future reservation. Corresponds to the JSON property existingMatchingUsageInfo



14806
14807
14808
# File 'lib/google/apis/compute_v1/classes.rb', line 14806

def existing_matching_usage_info
  @existing_matching_usage_info
end

#future_reservation_specsGoogle::Apis::ComputeV1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

The properties of the last known good state for the Future Reservation. Corresponds to the JSON property futureReservationSpecs



14811
14812
14813
# File 'lib/google/apis/compute_v1/classes.rb', line 14811

def future_reservation_specs
  @future_reservation_specs
end

#lock_timeString

Output only. [Output Only] The lock time of the FutureReservation before an amendment was requested. Corresponds to the JSON property lockTime

Returns:

  • (String)


14817
14818
14819
# File 'lib/google/apis/compute_v1/classes.rb', line 14817

def lock_time
  @lock_time
end

#name_prefixString

Output only. [Output Only] The name prefix of the Future Reservation before an amendment was requested. Corresponds to the JSON property namePrefix

Returns:

  • (String)


14823
14824
14825
# File 'lib/google/apis/compute_v1/classes.rb', line 14823

def name_prefix
  @name_prefix
end

#procurement_statusString

Output only. [Output Only] The status of the last known good state for the Future Reservation. Corresponds to the JSON property procurementStatus

Returns:

  • (String)


14830
14831
14832
# File 'lib/google/apis/compute_v1/classes.rb', line 14830

def procurement_status
  @procurement_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14837
14838
14839
14840
14841
14842
14843
14844
# File 'lib/google/apis/compute_v1/classes.rb', line 14837

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info)
  @future_reservation_specs = args[:future_reservation_specs] if args.key?(:future_reservation_specs)
  @lock_time = args[:lock_time] if args.key?(:lock_time)
  @name_prefix = args[:name_prefix] if args.key?(:name_prefix)
  @procurement_status = args[:procurement_status] if args.key?(:procurement_status)
end