Class: Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The properties of the last known good state for the Future Reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

Returns a new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.



14848
14849
14850
# File 'lib/google/apis/compute_v1/classes.rb', line 14848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#share_settingsGoogle::Apis::ComputeV1::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



14835
14836
14837
# File 'lib/google/apis/compute_v1/classes.rb', line 14835

def share_settings
  @share_settings
end

#specific_sku_propertiesGoogle::Apis::ComputeV1::FutureReservationSpecificSkuProperties

Output only. [Output Only] The previous instance related properties of the Future Reservation. Corresponds to the JSON property specificSkuProperties



14841
14842
14843
# File 'lib/google/apis/compute_v1/classes.rb', line 14841

def specific_sku_properties
  @specific_sku_properties
end

#time_windowGoogle::Apis::ComputeV1::FutureReservationTimeWindow

Output only. [Output Only] The previous time window of the Future Reservation. Corresponds to the JSON property timeWindow



14846
14847
14848
# File 'lib/google/apis/compute_v1/classes.rb', line 14846

def time_window
  @time_window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14853
14854
14855
14856
14857
# File 'lib/google/apis/compute_v1/classes.rb', line 14853

def update!(**args)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @time_window = args[:time_window] if args.key?(:time_window)
end