Class: Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The properties of the last known good state for the Future Reservation.
Instance Attribute Summary collapse
-
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#specific_sku_properties ⇒ Google::Apis::ComputeV1::FutureReservationSpecificSkuProperties
Output only.
-
#time_window ⇒ Google::Apis::ComputeV1::FutureReservationTimeWindow
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
constructor
A new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
Returns a new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.
13461 13462 13463 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
13448 13449 13450 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13448 def share_settings @share_settings end |
#specific_sku_properties ⇒ Google::Apis::ComputeV1::FutureReservationSpecificSkuProperties
Output only. [Output Only] The previous instance related properties of the
Future Reservation.
Corresponds to the JSON property specificSkuProperties
13454 13455 13456 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13454 def specific_sku_properties @specific_sku_properties end |
#time_window ⇒ Google::Apis::ComputeV1::FutureReservationTimeWindow
Output only. [Output Only] The previous time window of the Future Reservation.
Corresponds to the JSON property timeWindow
13459 13460 13461 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13459 def time_window @time_window end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13466 13467 13468 13469 13470 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13466 def update!(**args) @share_settings = args[:share_settings] if args.key?(:share_settings) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) @time_window = args[:time_window] if args.key?(:time_window) end |