Class: Google::Apis::ComputeV1::FutureReservationTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#start_time ⇒ String
Start time of the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationTimeWindow
constructor
A new instance of FutureReservationTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationTimeWindow
Returns a new instance of FutureReservationTimeWindow.
15135 15136 15137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property duration
15122 15123 15124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15122 def duration @duration end |
#end_time ⇒ String
Corresponds to the JSON property endTime
15127 15128 15129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15127 def end_time @end_time end |
#start_time ⇒ String
Start time of the Future Reservation. The start_time is an RFC3339
string.
Corresponds to the JSON property startTime
15133 15134 15135 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15133 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15140 15141 15142 15143 15144 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15140 def update!(**args) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |