Class: Google::Apis::ComputeV1::FutureReservationTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#start_time ⇒ String
Start time of the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationTimeWindow
constructor
A new instance of FutureReservationTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationTimeWindow
Returns a new instance of FutureReservationTimeWindow.
15085 15086 15087 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property duration
15072 15073 15074 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15072 def duration @duration end |
#end_time ⇒ String
Corresponds to the JSON property endTime
15077 15078 15079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15077 def end_time @end_time end |
#start_time ⇒ String
Start time of the Future Reservation. The start_time is an RFC3339
string.
Corresponds to the JSON property startTime
15083 15084 15085 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15083 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15090 15091 15092 15093 15094 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15090 def update!(**args) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |