Class: Google::Apis::ComputeV1::FutureReservationTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#start_time ⇒ String
Start time of the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationTimeWindow
constructor
A new instance of FutureReservationTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationTimeWindow
Returns a new instance of FutureReservationTimeWindow.
14903 14904 14905 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14903 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property duration
14890 14891 14892 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14890 def duration @duration end |
#end_time ⇒ String
Corresponds to the JSON property endTime
14895 14896 14897 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14895 def end_time @end_time end |
#start_time ⇒ String
Start time of the Future Reservation. The start_time is an RFC3339
string.
Corresponds to the JSON property startTime
14901 14902 14903 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14901 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14908 14909 14910 14911 14912 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14908 def update!(**args) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |