Class: Google::Apis::ComputeV1::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



15136
15137
15138
# File 'lib/google/apis/compute_v1/classes.rb', line 15136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


15092
15093
15094
# File 'lib/google/apis/compute_v1/classes.rb', line 15092

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15097
15098
15099
# File 'lib/google/apis/compute_v1/classes.rb', line 15097

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



15102
15103
15104
# File 'lib/google/apis/compute_v1/classes.rb', line 15102

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


15109
15110
15111
# File 'lib/google/apis/compute_v1/classes.rb', line 15109

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15119
15120
15121
# File 'lib/google/apis/compute_v1/classes.rb', line 15119

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15124
15125
15126
# File 'lib/google/apis/compute_v1/classes.rb', line 15124

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


15129
15130
15131
# File 'lib/google/apis/compute_v1/classes.rb', line 15129

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15134
15135
15136
# File 'lib/google/apis/compute_v1/classes.rb', line 15134

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15141
15142
15143
15144
15145
15146
15147
15148
15149
15150
# File 'lib/google/apis/compute_v1/classes.rb', line 15141

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end