Class: Google::Apis::ComputeV1::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



14985
14986
14987
# File 'lib/google/apis/compute_v1/classes.rb', line 14985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


14941
14942
14943
# File 'lib/google/apis/compute_v1/classes.rb', line 14941

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14946
14947
14948
# File 'lib/google/apis/compute_v1/classes.rb', line 14946

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



14951
14952
14953
# File 'lib/google/apis/compute_v1/classes.rb', line 14951

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


14958
14959
14960
# File 'lib/google/apis/compute_v1/classes.rb', line 14958

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14968
14969
14970
# File 'lib/google/apis/compute_v1/classes.rb', line 14968

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14973
14974
14975
# File 'lib/google/apis/compute_v1/classes.rb', line 14973

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


14978
14979
14980
# File 'lib/google/apis/compute_v1/classes.rb', line 14978

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14983
14984
14985
# File 'lib/google/apis/compute_v1/classes.rb', line 14983

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14990
14991
14992
14993
14994
14995
14996
14997
14998
14999
# File 'lib/google/apis/compute_v1/classes.rb', line 14990

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end