Class: Google::Apis::ComputeV1::FutureReservationsAggregatedListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationsAggregatedListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of future reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::FutureReservationsScopedList>
A list of Future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsAggregatedListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsAggregatedListResponse
constructor
A new instance of FutureReservationsAggregatedListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsAggregatedListResponse
Returns a new instance of FutureReservationsAggregatedListResponse.
13703 13704 13705 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13703 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
13659 13660 13661 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13659 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
13664 13665 13666 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13664 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::FutureReservationsScopedList>
A list of Future reservation resources.
Corresponds to the JSON property items
13669 13670 13671 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13669 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
futureReservationsAggregatedListResponse for future
resevation aggregated list response.
Corresponds to the JSON property kind
13676 13677 13678 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13676 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
13686 13687 13688 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13686 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
13691 13692 13693 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13691 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
13696 13697 13698 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13696 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsAggregatedListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
13701 13702 13703 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13701 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13708 13709 13710 13711 13712 13713 13714 13715 13716 13717 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13708 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |