Class: Google::Apis::ComputeV1::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



15337
15338
15339
# File 'lib/google/apis/compute_v1/classes.rb', line 15337

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


15292
15293
15294
# File 'lib/google/apis/compute_v1/classes.rb', line 15292

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15298
15299
15300
# File 'lib/google/apis/compute_v1/classes.rb', line 15298

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



15303
15304
15305
# File 'lib/google/apis/compute_v1/classes.rb', line 15303

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


15310
15311
15312
# File 'lib/google/apis/compute_v1/classes.rb', line 15310

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15320
15321
15322
# File 'lib/google/apis/compute_v1/classes.rb', line 15320

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15325
15326
15327
# File 'lib/google/apis/compute_v1/classes.rb', line 15325

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


15330
15331
15332
# File 'lib/google/apis/compute_v1/classes.rb', line 15330

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15335
15336
15337
# File 'lib/google/apis/compute_v1/classes.rb', line 15335

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15342
15343
15344
15345
15346
15347
15348
15349
15350
15351
# File 'lib/google/apis/compute_v1/classes.rb', line 15342

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end