Class: Google::Apis::ComputeV1::FutureReservationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsListResponse
constructor
A new instance of FutureReservationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsListResponse
Returns a new instance of FutureReservationsListResponse.
15337 15338 15339 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
15292 15293 15294 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15292 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
15298 15299 15300 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15298 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
Corresponds to the JSON property items
15303 15304 15305 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15303 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
FutureReservationsListResponse for lists of
reservations
Corresponds to the JSON property kind
15310 15311 15312 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15310 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15320 15321 15322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15320 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15325 15326 15327 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15325 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
15330 15331 15332 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15330 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15335 15336 15337 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15335 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15342 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |