Class: Google::Apis::ComputeV1::FutureReservationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsListResponse
constructor
A new instance of FutureReservationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsListResponse
Returns a new instance of FutureReservationsListResponse.
15287 15288 15289 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
15242 15243 15244 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15242 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
15248 15249 15250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15248 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
Corresponds to the JSON property items
15253 15254 15255 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15253 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
FutureReservationsListResponse for lists of
reservations
Corresponds to the JSON property kind
15260 15261 15262 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15260 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15270 15271 15272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15270 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15275 15276 15277 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15275 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
15280 15281 15282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15280 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15285 15286 15287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15285 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15292 15293 15294 15295 15296 15297 15298 15299 15300 15301 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15292 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |