Class: Google::Apis::ComputeV1::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



15124
15125
15126
# File 'lib/google/apis/compute_v1/classes.rb', line 15124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


15079
15080
15081
# File 'lib/google/apis/compute_v1/classes.rb', line 15079

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15085
15086
15087
# File 'lib/google/apis/compute_v1/classes.rb', line 15085

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



15090
15091
15092
# File 'lib/google/apis/compute_v1/classes.rb', line 15090

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


15097
15098
15099
# File 'lib/google/apis/compute_v1/classes.rb', line 15097

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15107
15108
15109
# File 'lib/google/apis/compute_v1/classes.rb', line 15107

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15112
15113
15114
# File 'lib/google/apis/compute_v1/classes.rb', line 15112

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


15117
15118
15119
# File 'lib/google/apis/compute_v1/classes.rb', line 15117

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15122
15123
15124
# File 'lib/google/apis/compute_v1/classes.rb', line 15122

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
# File 'lib/google/apis/compute_v1/classes.rb', line 15129

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end