Class: Google::Apis::ComputeV1::FutureReservationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsListResponse
constructor
A new instance of FutureReservationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsListResponse
Returns a new instance of FutureReservationsListResponse.
15116 15117 15118 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
15071 15072 15073 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15071 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
15077 15078 15079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15077 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
Corresponds to the JSON property items
15082 15083 15084 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15082 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
FutureReservationsListResponse for lists of
reservations
Corresponds to the JSON property kind
15089 15090 15091 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15089 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15099 15100 15101 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15099 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15104 15105 15106 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15104 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
15109 15110 15111 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15109 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15114 15115 15116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15114 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15121 15122 15123 15124 15125 15126 15127 15128 15129 15130 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15121 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |