Class: Google::Apis::ComputeV1::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



15105
15106
15107
# File 'lib/google/apis/compute_v1/classes.rb', line 15105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


15060
15061
15062
# File 'lib/google/apis/compute_v1/classes.rb', line 15060

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15066
15067
15068
# File 'lib/google/apis/compute_v1/classes.rb', line 15066

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



15071
15072
15073
# File 'lib/google/apis/compute_v1/classes.rb', line 15071

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


15078
15079
15080
# File 'lib/google/apis/compute_v1/classes.rb', line 15078

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15088
15089
15090
# File 'lib/google/apis/compute_v1/classes.rb', line 15088

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15093
15094
15095
# File 'lib/google/apis/compute_v1/classes.rb', line 15093

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


15098
15099
15100
# File 'lib/google/apis/compute_v1/classes.rb', line 15098

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15103
15104
15105
# File 'lib/google/apis/compute_v1/classes.rb', line 15103

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
# File 'lib/google/apis/compute_v1/classes.rb', line 15110

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end