Class: Google::Apis::ComputeV1::FutureReservationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsListResponse
constructor
A new instance of FutureReservationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsListResponse
Returns a new instance of FutureReservationsListResponse.
15105 15106 15107 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15105 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
15060 15061 15062 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15060 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
15066 15067 15068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15066 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
Corresponds to the JSON property items
15071 15072 15073 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15071 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
FutureReservationsListResponse for lists of
reservations
Corresponds to the JSON property kind
15078 15079 15080 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15078 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15088 15089 15090 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15088 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15093 15094 15095 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15093 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
15098 15099 15100 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15098 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15103 15104 15105 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15103 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15110 15111 15112 15113 15114 15115 15116 15117 15118 15119 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15110 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |