Class: Google::Apis::ComputeV1::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



13842
13843
13844
# File 'lib/google/apis/compute_v1/classes.rb', line 13842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


13797
13798
13799
# File 'lib/google/apis/compute_v1/classes.rb', line 13797

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


13803
13804
13805
# File 'lib/google/apis/compute_v1/classes.rb', line 13803

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



13808
13809
13810
# File 'lib/google/apis/compute_v1/classes.rb', line 13808

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


13815
13816
13817
# File 'lib/google/apis/compute_v1/classes.rb', line 13815

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


13825
13826
13827
# File 'lib/google/apis/compute_v1/classes.rb', line 13825

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13830
13831
13832
# File 'lib/google/apis/compute_v1/classes.rb', line 13830

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


13835
13836
13837
# File 'lib/google/apis/compute_v1/classes.rb', line 13835

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



13840
13841
13842
# File 'lib/google/apis/compute_v1/classes.rb', line 13840

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13847
13848
13849
13850
13851
13852
13853
13854
13855
13856
# File 'lib/google/apis/compute_v1/classes.rb', line 13847

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end