Class: Google::Apis::ComputeV1::FutureReservationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureReservationsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsListResponse
constructor
A new instance of FutureReservationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsListResponse
Returns a new instance of FutureReservationsListResponse.
13718 13719 13720 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13718 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
13673 13674 13675 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13673 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
13679 13680 13681 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13679 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::FutureReservation>
[Output Only] A list of future reservation resources.
Corresponds to the JSON property items
13684 13685 13686 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13684 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
FutureReservationsListResponse for lists of
reservations
Corresponds to the JSON property kind
13691 13692 13693 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13691 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
13701 13702 13703 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13701 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
13706 13707 13708 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13706 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
13711 13712 13713 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13711 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
13716 13717 13718 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13716 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13723 13724 13725 13726 13727 13728 13729 13730 13731 13732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13723 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |