Class: Google::Apis::ComputeV1::FutureResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureResourcesRecommendation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Recommendation for single resources specification, to be created in the future.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#location ⇒ String
The advised location for resource usage.
-
#other_locations ⇒ Hash<String,Google::Apis::ComputeV1::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not recommended.
-
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
-
#recommendation_type ⇒ String
Type of recommendation.
-
#start_time ⇒ String
Corresponds to the JSON property
startTime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendation
constructor
A new instance of FutureResourcesRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendation
Returns a new instance of FutureResourcesRecommendation.
14066 14067 14068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Corresponds to the JSON property endTime
14034 14035 14036 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14034 def end_time @end_time end |
#location ⇒ String
The advised location for resource usage. When a zone, in format
'zones/'.
If not set, it means that no location is recommended - see
other_locations for details.
Corresponds to the JSON property location
14042 14043 14044 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14042 def location @location end |
#other_locations ⇒ Hash<String,Google::Apis::ComputeV1::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not
recommended. Keys of the map are zones, in format 'zones/'.
The values are status information indicating the recommendation status.
Corresponds to the JSON property otherLocations
14049 14050 14051 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14049 def other_locations @other_locations end |
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
Corresponds to the JSON property recommendationId
14054 14055 14056 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14054 def recommendation_id @recommendation_id end |
#recommendation_type ⇒ String
Type of recommendation. Currently only FUTURE_RESERVATION is supported.
Corresponds to the JSON property recommendationType
14059 14060 14061 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14059 def recommendation_type @recommendation_type end |
#start_time ⇒ String
Corresponds to the JSON property startTime
14064 14065 14066 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14064 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14071 14072 14073 14074 14075 14076 14077 14078 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14071 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @location = args[:location] if args.key?(:location) @other_locations = args[:other_locations] if args.key?(:other_locations) @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id) @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type) @start_time = args[:start_time] if args.key?(:start_time) end |