Class: Google::Apis::ComputeV1::FutureResourcesRecommendation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Recommendation for single resources specification, to be created in the future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesRecommendation

Returns a new instance of FutureResourcesRecommendation.



13942
13943
13944
# File 'lib/google/apis/compute_v1/classes.rb', line 13942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Corresponds to the JSON property endTime

Returns:

  • (String)


13910
13911
13912
# File 'lib/google/apis/compute_v1/classes.rb', line 13910

def end_time
  @end_time
end

#locationString

The advised location for resource usage. When a zone, in format 'zones/'. If not set, it means that no location is recommended - see other_locations for details. Corresponds to the JSON property location

Returns:

  • (String)


13918
13919
13920
# File 'lib/google/apis/compute_v1/classes.rb', line 13918

def location
  @location
end

#other_locationsHash<String,Google::Apis::ComputeV1::FutureResourcesRecommendationOtherLocation>

List of locations in the request scope that were not recommended. Keys of the map are zones, in format 'zones/'. The values are status information indicating the recommendation status. Corresponds to the JSON property otherLocations



13925
13926
13927
# File 'lib/google/apis/compute_v1/classes.rb', line 13925

def other_locations
  @other_locations
end

#recommendation_idString

Unique id of the recommendation, a UUID string generated by the API. Corresponds to the JSON property recommendationId

Returns:

  • (String)


13930
13931
13932
# File 'lib/google/apis/compute_v1/classes.rb', line 13930

def recommendation_id
  @recommendation_id
end

#recommendation_typeString

Type of recommendation. Currently only FUTURE_RESERVATION is supported. Corresponds to the JSON property recommendationType

Returns:

  • (String)


13935
13936
13937
# File 'lib/google/apis/compute_v1/classes.rb', line 13935

def recommendation_type
  @recommendation_type
end

#start_timeString

Corresponds to the JSON property startTime

Returns:

  • (String)


13940
13941
13942
# File 'lib/google/apis/compute_v1/classes.rb', line 13940

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13947
13948
13949
13950
13951
13952
13953
13954
# File 'lib/google/apis/compute_v1/classes.rb', line 13947

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @location = args[:location] if args.key?(:location)
  @other_locations = args[:other_locations] if args.key?(:other_locations)
  @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id)
  @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type)
  @start_time = args[:start_time] if args.key?(:start_time)
end