Class: Google::Apis::ComputeV1::FutureResourcesRecommendationOtherLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Information about recommendation status for locations that were allowed but not used by the response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation

Returns a new instance of FutureResourcesRecommendationOtherLocation.



15373
15374
15375
# File 'lib/google/apis/compute_v1/classes.rb', line 15373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsString

Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions. Corresponds to the JSON property details

Returns:

  • (String)


15366
15367
15368
# File 'lib/google/apis/compute_v1/classes.rb', line 15366

def details
  @details
end

#statusString

Status of recommendation in this location. Corresponds to the JSON property status

Returns:

  • (String)


15371
15372
15373
# File 'lib/google/apis/compute_v1/classes.rb', line 15371

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15378
15379
15380
15381
# File 'lib/google/apis/compute_v1/classes.rb', line 15378

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @status = args[:status] if args.key?(:status)
end