Class: Google::Apis::ComputeV1::FutureResourcesRecommendationOtherLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureResourcesRecommendationOtherLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Information about recommendation status for locations that were allowed but not used by the response.
Instance Attribute Summary collapse
-
#details ⇒ String
Details (human readable) describing the situation.
-
#status ⇒ String
Status of recommendation in this location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation
constructor
A new instance of FutureResourcesRecommendationOtherLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation
Returns a new instance of FutureResourcesRecommendationOtherLocation.
15362 15363 15364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ String
Details (human readable) describing the situation.
For example, if status is CONDITION_NOT_MET, then
details contain information about the parameters of the time window
that did not meet the required conditions.
Corresponds to the JSON property details
15355 15356 15357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15355 def details @details end |
#status ⇒ String
Status of recommendation in this location.
Corresponds to the JSON property status
15360 15361 15362 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15360 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15367 15368 15369 15370 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15367 def update!(**args) @details = args[:details] if args.key?(:details) @status = args[:status] if args.key?(:status) end |