Class: Google::Apis::ComputeV1::FutureResourcesSpec

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specification of resources to be created at some time in the future within an optionally specified set of locations, and within the specified time range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesSpec

Returns a new instance of FutureResourcesSpec.



15412
15413
15414
# File 'lib/google/apis/compute_v1/classes.rb', line 15412

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_typeString

Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD). Defaults to DENSE. Corresponds to the JSON property deploymentType

Returns:

  • (String)


15393
15394
15395
# File 'lib/google/apis/compute_v1/classes.rb', line 15393

def deployment_type
  @deployment_type
end

#location_policyGoogle::Apis::ComputeV1::FutureResourcesSpecLocationPolicy

Specification of locations to create resources in. Corresponds to the JSON property locationPolicy



15398
15399
15400
# File 'lib/google/apis/compute_v1/classes.rb', line 15398

def location_policy
  @location_policy
end

#target_resourcesGoogle::Apis::ComputeV1::FutureResourcesSpecTargetResources

Specification of reserved resources. Corresponds to the JSON property targetResources



15403
15404
15405
# File 'lib/google/apis/compute_v1/classes.rb', line 15403

def target_resources
  @target_resources
end

#time_range_specGoogle::Apis::ComputeV1::FlexibleTimeRange

Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error. Corresponds to the JSON property timeRangeSpec



15410
15411
15412
# File 'lib/google/apis/compute_v1/classes.rb', line 15410

def time_range_spec
  @time_range_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15417
15418
15419
15420
15421
15422
# File 'lib/google/apis/compute_v1/classes.rb', line 15417

def update!(**args)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @location_policy = args[:location_policy] if args.key?(:location_policy)
  @target_resources = args[:target_resources] if args.key?(:target_resources)
  @time_range_spec = args[:time_range_spec] if args.key?(:time_range_spec)
end