Class: Google::Apis::ComputeV1::FutureResourcesSpec
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FutureResourcesSpec
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specification of resources to be created at some time in the future within an optionally specified set of locations, and within the specified time range.
Instance Attribute Summary collapse
-
#deployment_type ⇒ String
Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD).
-
#location_policy ⇒ Google::Apis::ComputeV1::FutureResourcesSpecLocationPolicy
Specification of locations to create resources in.
-
#target_resources ⇒ Google::Apis::ComputeV1::FutureResourcesSpecTargetResources
Specification of reserved resources.
-
#time_range_spec ⇒ Google::Apis::ComputeV1::FlexibleTimeRange
Specifies a flexible time range with flexible start time and duration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesSpec
constructor
A new instance of FutureResourcesSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesSpec
Returns a new instance of FutureResourcesSpec.
14138 14139 14140 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_type ⇒ String
Indicates if the reservation allocation strategy is static (DENSE) or
dynamic (STANDARD). Defaults to DENSE.
Corresponds to the JSON property deploymentType
14119 14120 14121 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14119 def deployment_type @deployment_type end |
#location_policy ⇒ Google::Apis::ComputeV1::FutureResourcesSpecLocationPolicy
Specification of locations to create resources in.
Corresponds to the JSON property locationPolicy
14124 14125 14126 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14124 def location_policy @location_policy end |
#target_resources ⇒ Google::Apis::ComputeV1::FutureResourcesSpecTargetResources
Specification of reserved resources.
Corresponds to the JSON property targetResources
14129 14130 14131 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14129 def target_resources @target_resources end |
#time_range_spec ⇒ Google::Apis::ComputeV1::FlexibleTimeRange
Specifies a flexible time range with flexible start time and duration.
It is possible to specify a contradictory time range that cannot be matched
by any Interval. This causes a validation error.
Corresponds to the JSON property timeRangeSpec
14136 14137 14138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14136 def time_range_spec @time_range_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14143 14144 14145 14146 14147 14148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14143 def update!(**args) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @location_policy = args[:location_policy] if args.key?(:location_policy) @target_resources = args[:target_resources] if args.key?(:target_resources) @time_range_spec = args[:time_range_spec] if args.key?(:time_range_spec) end |