Class: Google::Apis::ComputeV1::GetVersionOperationMetadataSbomInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo

Returns a new instance of GetVersionOperationMetadataSbomInfo.



15734
15735
15736
# File 'lib/google/apis/compute_v1/classes.rb', line 15734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_component_versionsHash<String,String>

SBOM versions currently applied to the resource. The key is the component name and the value is the version. Corresponds to the JSON property currentComponentVersions

Returns:

  • (Hash<String,String>)


15726
15727
15728
# File 'lib/google/apis/compute_v1/classes.rb', line 15726

def current_component_versions
  @current_component_versions
end

#target_component_versionsHash<String,String>

SBOM versions scheduled for the next maintenance. The key is the component name and the value is the version. Corresponds to the JSON property targetComponentVersions

Returns:

  • (Hash<String,String>)


15732
15733
15734
# File 'lib/google/apis/compute_v1/classes.rb', line 15732

def target_component_versions
  @target_component_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15739
15740
15741
15742
# File 'lib/google/apis/compute_v1/classes.rb', line 15739

def update!(**args)
  @current_component_versions = args[:current_component_versions] if args.key?(:current_component_versions)
  @target_component_versions = args[:target_component_versions] if args.key?(:target_component_versions)
end