Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::GlobalVmExtensionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Message describing GlobalVmExtensionPolicy object.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#extension_policies ⇒ Hash<String,Google::Apis::ComputeV1::GlobalVmExtensionPolicyExtensionPolicy>
Required.
-
#id ⇒ Fixnum
Output only.
-
#instance_selectors ⇒ Array<Google::Apis::ComputeV1::GlobalVmExtensionPolicyInstanceSelector>
Optional.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#priority ⇒ Fixnum
Optional.
-
#rollout_operation ⇒ Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperation
Represents the rollout operation Corresponds to the JSON property
rolloutOperation. -
#scoped_resource_status ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#update_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicy
constructor
A new instance of GlobalVmExtensionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicy
Returns a new instance of GlobalVmExtensionPolicy.
16370 16371 16372 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16370 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
16288 16289 16290 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16288 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
16294 16295 16296 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16294 def description @description end |
#extension_policies ⇒ Hash<String,Google::Apis::ComputeV1::GlobalVmExtensionPolicyExtensionPolicy>
Required. Map from extension (eg: "cloudops") to its policy configuration.
The key is the name of the extension.
Corresponds to the JSON property extensionPolicies
16300 16301 16302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16300 def extension_policies @extension_policies end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
16307 16308 16309 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16307 def id @id end |
#instance_selectors ⇒ Array<Google::Apis::ComputeV1::GlobalVmExtensionPolicyInstanceSelector>
Optional. Selector to target VMs for a policy.
There is a logical "AND" between instance_selectors.
Corresponds to the JSON property instanceSelectors
16313 16314 16315 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16313 def instance_selectors @instance_selectors end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
globalVmExtensionPolicy for globalVmExtensionPolicies.
Corresponds to the JSON property kind
16319 16320 16321 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16319 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
16330 16331 16332 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16330 def name @name end |
#priority ⇒ Fixnum
Optional. Used to resolve conflicts when multiple policies are active for the
same
extension. Defaults to 0.
Larger the number, higher the priority. When the priority is the same,
the policy with the newer create time has higher priority.
Corresponds to the JSON property priority
16339 16340 16341 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16339 def priority @priority end |
#rollout_operation ⇒ Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperation
Represents the rollout operation
Corresponds to the JSON property rolloutOperation
16344 16345 16346 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16344 def rollout_operation @rollout_operation end |
#scoped_resource_status ⇒ String
Output only. [Output Only] The scoped resource status. It's only for tracking
the
purging status of the policy.
Corresponds to the JSON property scopedResourceStatus
16351 16352 16353 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16351 def scoped_resource_status @scoped_resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
16357 16358 16359 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16357 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
16362 16363 16364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16362 def self_link_with_id @self_link_with_id end |
#update_timestamp ⇒ String
Output only. [Output Only] Update timestamp inRFC3339
text format.
Corresponds to the JSON property updateTimestamp
16368 16369 16370 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16368 def @update_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16375 16376 16377 16378 16379 16380 16381 16382 16383 16384 16385 16386 16387 16388 16389 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16375 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @extension_policies = args[:extension_policies] if args.key?(:extension_policies) @id = args[:id] if args.key?(:id) @instance_selectors = args[:instance_selectors] if args.key?(:instance_selectors) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @priority = args[:priority] if args.key?(:priority) @rollout_operation = args[:rollout_operation] if args.key?(:rollout_operation) @scoped_resource_status = args[:scoped_resource_status] if args.key?(:scoped_resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp) end |