Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::GlobalVmExtensionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Message describing GlobalVmExtensionPolicy object.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#extension_policies ⇒ Hash<String,Google::Apis::ComputeV1::GlobalVmExtensionPolicyExtensionPolicy>
Required.
-
#id ⇒ Fixnum
Output only.
-
#instance_selectors ⇒ Array<Google::Apis::ComputeV1::GlobalVmExtensionPolicyInstanceSelector>
Optional.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#priority ⇒ Fixnum
Optional.
-
#rollout_operation ⇒ Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperation
Represents the rollout operation Corresponds to the JSON property
rolloutOperation. -
#scoped_resource_status ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#update_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicy
constructor
A new instance of GlobalVmExtensionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicy
Returns a new instance of GlobalVmExtensionPolicy.
16308 16309 16310 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
16226 16227 16228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16226 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
16232 16233 16234 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16232 def description @description end |
#extension_policies ⇒ Hash<String,Google::Apis::ComputeV1::GlobalVmExtensionPolicyExtensionPolicy>
Required. Map from extension (eg: "cloudops") to its policy configuration.
The key is the name of the extension.
Corresponds to the JSON property extensionPolicies
16238 16239 16240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16238 def extension_policies @extension_policies end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
16245 16246 16247 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16245 def id @id end |
#instance_selectors ⇒ Array<Google::Apis::ComputeV1::GlobalVmExtensionPolicyInstanceSelector>
Optional. Selector to target VMs for a policy.
There is a logical "AND" between instance_selectors.
Corresponds to the JSON property instanceSelectors
16251 16252 16253 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16251 def instance_selectors @instance_selectors end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
globalVmExtensionPolicy for globalVmExtensionPolicies.
Corresponds to the JSON property kind
16257 16258 16259 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16257 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
16268 16269 16270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16268 def name @name end |
#priority ⇒ Fixnum
Optional. Used to resolve conflicts when multiple policies are active for the
same
extension. Defaults to 0.
Larger the number, higher the priority. When the priority is the same,
the policy with the newer create time has higher priority.
Corresponds to the JSON property priority
16277 16278 16279 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16277 def priority @priority end |
#rollout_operation ⇒ Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperation
Represents the rollout operation
Corresponds to the JSON property rolloutOperation
16282 16283 16284 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16282 def rollout_operation @rollout_operation end |
#scoped_resource_status ⇒ String
Output only. [Output Only] The scoped resource status. It's only for tracking
the
purging status of the policy.
Corresponds to the JSON property scopedResourceStatus
16289 16290 16291 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16289 def scoped_resource_status @scoped_resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
16295 16296 16297 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16295 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
16300 16301 16302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16300 def self_link_with_id @self_link_with_id end |
#update_timestamp ⇒ String
Output only. [Output Only] Update timestamp inRFC3339
text format.
Corresponds to the JSON property updateTimestamp
16306 16307 16308 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16306 def @update_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16313 16314 16315 16316 16317 16318 16319 16320 16321 16322 16323 16324 16325 16326 16327 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16313 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @extension_policies = args[:extension_policies] if args.key?(:extension_policies) @id = args[:id] if args.key?(:id) @instance_selectors = args[:instance_selectors] if args.key?(:instance_selectors) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @priority = args[:priority] if args.key?(:priority) @rollout_operation = args[:rollout_operation] if args.key?(:rollout_operation) @scoped_resource_status = args[:scoped_resource_status] if args.key?(:scoped_resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp) end |