Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicyLabelSelector

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A LabelSelector is applicable for a VM only if it matches all labels in the LabelSelector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyLabelSelector

Returns a new instance of GlobalVmExtensionPolicyLabelSelector.



16231
16232
16233
# File 'lib/google/apis/compute_v1/classes.rb', line 16231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inclusion_labelsHash<String,String>

Optional. Labels as key value pairs. A VM should contain all the pairs specified in this map to be selected; Labels within the LabelSelector are OR'ed. Corresponds to the JSON property inclusionLabels

Returns:

  • (Hash<String,String>)


16229
16230
16231
# File 'lib/google/apis/compute_v1/classes.rb', line 16229

def inclusion_labels
  @inclusion_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16236
16237
16238
# File 'lib/google/apis/compute_v1/classes.rb', line 16236

def update!(**args)
  @inclusion_labels = args[:inclusion_labels] if args.key?(:inclusion_labels)
end