Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to list global VM extension policy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyList

Returns a new instance of GlobalVmExtensionPolicyList.



16511
16512
16513
# File 'lib/google/apis/compute_v1/classes.rb', line 16511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16469
16470
16471
# File 'lib/google/apis/compute_v1/classes.rb', line 16469

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16474
16475
16476
# File 'lib/google/apis/compute_v1/classes.rb', line 16474

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::GlobalVmExtensionPolicy>

A list of GlobalVmExtensionPolicy resources. Corresponds to the JSON property items



16479
16480
16481
# File 'lib/google/apis/compute_v1/classes.rb', line 16479

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


16484
16485
16486
# File 'lib/google/apis/compute_v1/classes.rb', line 16484

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16494
16495
16496
# File 'lib/google/apis/compute_v1/classes.rb', line 16494

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16499
16500
16501
# File 'lib/google/apis/compute_v1/classes.rb', line 16499

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16504
16505
16506
# File 'lib/google/apis/compute_v1/classes.rb', line 16504

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::GlobalVmExtensionPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16509
16510
16511
# File 'lib/google/apis/compute_v1/classes.rb', line 16509

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16516
16517
16518
16519
16520
16521
16522
16523
16524
16525
# File 'lib/google/apis/compute_v1/classes.rb', line 16516

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end