Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to list global VM extension policy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyList

Returns a new instance of GlobalVmExtensionPolicyList.



16461
16462
16463
# File 'lib/google/apis/compute_v1/classes.rb', line 16461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16419
16420
16421
# File 'lib/google/apis/compute_v1/classes.rb', line 16419

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16424
16425
16426
# File 'lib/google/apis/compute_v1/classes.rb', line 16424

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::GlobalVmExtensionPolicy>

A list of GlobalVmExtensionPolicy resources. Corresponds to the JSON property items



16429
16430
16431
# File 'lib/google/apis/compute_v1/classes.rb', line 16429

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


16434
16435
16436
# File 'lib/google/apis/compute_v1/classes.rb', line 16434

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16444
16445
16446
# File 'lib/google/apis/compute_v1/classes.rb', line 16444

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16449
16450
16451
# File 'lib/google/apis/compute_v1/classes.rb', line 16449

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16454
16455
16456
# File 'lib/google/apis/compute_v1/classes.rb', line 16454

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::GlobalVmExtensionPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16459
16460
16461
# File 'lib/google/apis/compute_v1/classes.rb', line 16459

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16466
16467
16468
16469
16470
16471
16472
16473
16474
16475
# File 'lib/google/apis/compute_v1/classes.rb', line 16466

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end