Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::GlobalVmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to list global VM extension policy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
constructor
A new instance of GlobalVmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
Returns a new instance of GlobalVmExtensionPolicyList.
16298 16299 16300 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
16256 16257 16258 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16256 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
16261 16262 16263 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16261 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
Corresponds to the JSON property items
16266 16267 16268 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16266 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
16271 16272 16273 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16271 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
16281 16282 16283 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16281 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
16286 16287 16288 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16286 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
16291 16292 16293 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16291 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
16296 16297 16298 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16296 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16303 16304 16305 16306 16307 16308 16309 16310 16311 16312 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16303 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |