Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutInput
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutInput
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#conflict_behavior ⇒ String
Optional.
-
#name ⇒ String
Optional.
-
#predefined_rollout_plan ⇒ String
Optional.
-
#retry_uuid ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutInput
constructor
A new instance of GlobalVmExtensionPolicyRolloutOperationRolloutInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutInput
Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutInput.
16611 16612 16613 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conflict_behavior ⇒ String
Optional. Specifies the behavior of the rollout if a conflict is detected in a
project during a rollout. This only applies to insert and update
methods.
A conflict occurs in the following cases:
insertmethod: If the zonal policy already exists when the insert happens.updatemethod: If the zonal policy was modified by a zonal API call outside of this rollout. Possible values are the following:""(empty string): If a conflict occurs, the local value is not overwritten. This is the default behavior."overwrite": If a conflict occurs, the local value is overwritten with the rollout value. Corresponds to the JSON propertyconflictBehavior
16580 16581 16582 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16580 def conflict_behavior @conflict_behavior end |
#name ⇒ String
Optional. The name of the rollout plan.
Ex.
projects//locations/global/rolloutPlans/.
Corresponds to the JSON property name
16587 16588 16589 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16587 def name @name end |
#predefined_rollout_plan ⇒ String
Optional. Specifies the predefined rollout plan for the policy. Valid values
are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is
SLOW_ROLLOUT for progressive rollout. For more information, see Rollout
plans for global policies.
Corresponds to the JSON property predefinedRolloutPlan
16595 16596 16597 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16595 def predefined_rollout_plan @predefined_rollout_plan end |
#retry_uuid ⇒ String
Optional. The UUID that identifies a policy rollout retry attempt for update and delete operations. Set this field only when retrying a rollout for an existing extension policy.
updatemethod: Lets you retry policy rollout without changes. An error occurs if you set retry_uuid but the policy is modified.deletemethod: Lets you retry policy deletion rollout if the previous deletion rollout is not finished and the policy is in the DELETING state. If you set this field when the policy is not in the DELETING state, an error occurs. Corresponds to the JSON propertyretryUuid
16609 16610 16611 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16609 def retry_uuid @retry_uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16616 16617 16618 16619 16620 16621 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16616 def update!(**args) @conflict_behavior = args[:conflict_behavior] if args.key?(:conflict_behavior) @name = args[:name] if args.key?(:name) @predefined_rollout_plan = args[:predefined_rollout_plan] if args.key?(:predefined_rollout_plan) @retry_uuid = args[:retry_uuid] if args.key?(:retry_uuid) end |