Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatus

Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatus.



16654
16655
16656
# File 'lib/google/apis/compute_v1/classes.rb', line 16654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_rolloutsArray<Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata>

Output only. [Output Only] The current rollouts for the latest version of the resource. There should be only one current rollout, but for scalability, we make it repeated. Corresponds to the JSON property currentRollouts



16645
16646
16647
# File 'lib/google/apis/compute_v1/classes.rb', line 16645

def current_rollouts
  @current_rollouts
end

#previous_rolloutGoogle::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Output only. [Output Only] The last completed rollout resource. This field will not be populated until the first rollout is completed. Corresponds to the JSON property previousRollout



16652
16653
16654
# File 'lib/google/apis/compute_v1/classes.rb', line 16652

def previous_rollout
  @previous_rollout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16659
16660
16661
16662
# File 'lib/google/apis/compute_v1/classes.rb', line 16659

def update!(**args)
  @current_rollouts = args[:current_rollouts] if args.key?(:current_rollouts)
  @previous_rollout = args[:previous_rollout] if args.key?(:previous_rollout)
end