Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatus

Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatus.



16642
16643
16644
# File 'lib/google/apis/compute_v1/classes.rb', line 16642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_rolloutsArray<Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata>

Output only. [Output Only] The current rollouts for the latest version of the resource. There should be only one current rollout, but for scalability, we make it repeated. Corresponds to the JSON property currentRollouts



16633
16634
16635
# File 'lib/google/apis/compute_v1/classes.rb', line 16633

def current_rollouts
  @current_rollouts
end

#previous_rolloutGoogle::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Output only. [Output Only] The last completed rollout resource. This field will not be populated until the first rollout is completed. Corresponds to the JSON property previousRollout



16640
16641
16642
# File 'lib/google/apis/compute_v1/classes.rb', line 16640

def previous_rollout
  @previous_rollout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16647
16648
16649
16650
# File 'lib/google/apis/compute_v1/classes.rb', line 16647

def update!(**args)
  @current_rollouts = args[:current_rollouts] if args.key?(:current_rollouts)
  @previous_rollout = args[:previous_rollout] if args.key?(:previous_rollout)
end