Class: Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata.



16531
16532
16533
# File 'lib/google/apis/compute_v1/classes.rb', line 16531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#location_rollout_statusHash<String,Google::Apis::ComputeV1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus>

Output only. [Output Only] The rollout status for each location. The list of the locations is the same as the list of locations in the rollout plan. Corresponds to the JSON property locationRolloutStatus



16511
16512
16513
# File 'lib/google/apis/compute_v1/classes.rb', line 16511

def location_rollout_status
  @location_rollout_status
end

#rolloutString

Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/. Corresponds to the JSON property rollout

Returns:

  • (String)


16517
16518
16519
# File 'lib/google/apis/compute_v1/classes.rb', line 16517

def rollout
  @rollout
end

#rollout_planString

Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/. Corresponds to the JSON property rolloutPlan

Returns:

  • (String)


16524
16525
16526
# File 'lib/google/apis/compute_v1/classes.rb', line 16524

def rollout_plan
  @rollout_plan
end

#stateString

Output only. [Output Only] The overall state of the rollout. Corresponds to the JSON property state

Returns:

  • (String)


16529
16530
16531
# File 'lib/google/apis/compute_v1/classes.rb', line 16529

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16536
16537
16538
16539
16540
16541
# File 'lib/google/apis/compute_v1/classes.rb', line 16536

def update!(**args)
  @location_rollout_status = args[:location_rollout_status] if args.key?(:location_rollout_status)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan)
  @state = args[:state] if args.key?(:state)
end