Class: Google::Apis::ComputeV1::GrpcHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcHealthCheck

Returns a new instance of GrpcHealthCheck.



15626
15627
15628
# File 'lib/google/apis/compute_v1/classes.rb', line 15626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#grpc_service_nameString

The gRPC service name for the health check. This field is optional. The value of grpc_service_name has the following meanings by convention:

  • Empty service_name means the overall status of all services at the backend.
  • Non-empty service_name means the health of that gRPC service, as defined by the owner of the service. The grpc_service_name can only be ASCII. Corresponds to the JSON property grpcServiceName

Returns:

  • (String)


15586
15587
15588
# File 'lib/google/apis/compute_v1/classes.rb', line 15586

def grpc_service_name
  @grpc_service_name
end

#portFixnum

The TCP port number to which the health check prober sends packets. Valid values are 1 through 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


15592
15593
15594
# File 'lib/google/apis/compute_v1/classes.rb', line 15592

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


15597
15598
15599
# File 'lib/google/apis/compute_v1/classes.rb', line 15597

def port_name
  @port_name
end

#port_specificationString

Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Corresponds to the JSON property portSpecification

Returns:

  • (String)


15624
15625
15626
# File 'lib/google/apis/compute_v1/classes.rb', line 15624

def port_specification
  @port_specification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15631
15632
15633
15634
15635
15636
# File 'lib/google/apis/compute_v1/classes.rb', line 15631

def update!(**args)
  @grpc_service_name = args[:grpc_service_name] if args.key?(:grpc_service_name)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
end