Class: Google::Apis::ComputeV1::GrpcHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcHealthCheck

Returns a new instance of GrpcHealthCheck.



9082
9083
9084
# File 'lib/google/apis/compute_v1/classes.rb', line 9082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#grpc_service_nameString

The gRPC service name for the health check. This field is optional. The value of grpc_service_name has the following meanings by convention: - Empty service_name means the overall status of all services at the backend. - Non- empty service_name means the health of that gRPC service, as defined by the owner of the service. The grpc_service_name can only be ASCII. Corresponds to the JSON property grpcServiceName

Returns:

  • (String)


9055
9056
9057
# File 'lib/google/apis/compute_v1/classes.rb', line 9055

def grpc_service_name
  @grpc_service_name
end

#portFixnum

The port number for the health check request. Must be specified if port_name and port_specification are not set or if port_specification is USE_FIXED_PORT. Valid values are 1 through 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


9062
9063
9064
# File 'lib/google/apis/compute_v1/classes.rb', line 9062

def port
  @port
end

#port_nameString

Port name as defined in InstanceGroup#NamedPort#name. If both port and port_name are defined, port takes precedence. The port_name should conform to RFC1035. Corresponds to the JSON property portName

Returns:

  • (String)


9069
9070
9071
# File 'lib/google/apis/compute_v1/classes.rb', line 9069

def port_name
  @port_name
end

#port_specificationString

Specifies how port is selected for health checking, can be one of following values: USE_FIXED_PORT: The port number in port is used for health checking. USE_NAMED_PORT: The portName is used for health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each network endpoint is used for health checking. For other backends, the port or named port specified in the Backend Service is used for health checking. If not specified, gRPC health check follows behavior specified in port and portName fields. Corresponds to the JSON property portSpecification

Returns:

  • (String)


9080
9081
9082
# File 'lib/google/apis/compute_v1/classes.rb', line 9080

def port_specification
  @port_specification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9087
9088
9089
9090
9091
9092
# File 'lib/google/apis/compute_v1/classes.rb', line 9087

def update!(**args)
  @grpc_service_name = args[:grpc_service_name] if args.key?(:grpc_service_name)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
end