Class: Google::Apis::ComputeV1::HealthAggregationPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthAggregationPoliciesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList

Returns a new instance of HealthAggregationPolicyAggregatedList.



17311
17312
17313
# File 'lib/google/apis/compute_v1/classes.rb', line 17311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17274
17275
17276
# File 'lib/google/apis/compute_v1/classes.rb', line 17274

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthAggregationPoliciesScopedList>

A list of HealthAggregationPoliciesScopedList resources. Corresponds to the JSON property items



17279
17280
17281
# File 'lib/google/apis/compute_v1/classes.rb', line 17279

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17284
17285
17286
# File 'lib/google/apis/compute_v1/classes.rb', line 17284

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17294
17295
17296
# File 'lib/google/apis/compute_v1/classes.rb', line 17294

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17299
17300
17301
# File 'lib/google/apis/compute_v1/classes.rb', line 17299

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17304
17305
17306
# File 'lib/google/apis/compute_v1/classes.rb', line 17304

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthAggregationPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17309
17310
17311
# File 'lib/google/apis/compute_v1/classes.rb', line 17309

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17316
17317
17318
17319
17320
17321
17322
17323
17324
# File 'lib/google/apis/compute_v1/classes.rb', line 17316

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end