Class: Google::Apis::ComputeV1::HealthAggregationPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthAggregationPoliciesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList

Returns a new instance of HealthAggregationPolicyAggregatedList.



16804
16805
16806
# File 'lib/google/apis/compute_v1/classes.rb', line 16804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16767
16768
16769
# File 'lib/google/apis/compute_v1/classes.rb', line 16767

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthAggregationPoliciesScopedList>

A list of HealthAggregationPoliciesScopedList resources. Corresponds to the JSON property items



16772
16773
16774
# File 'lib/google/apis/compute_v1/classes.rb', line 16772

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


16777
16778
16779
# File 'lib/google/apis/compute_v1/classes.rb', line 16777

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16787
16788
16789
# File 'lib/google/apis/compute_v1/classes.rb', line 16787

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16792
16793
16794
# File 'lib/google/apis/compute_v1/classes.rb', line 16792

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16797
16798
16799
# File 'lib/google/apis/compute_v1/classes.rb', line 16797

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthAggregationPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16802
16803
16804
# File 'lib/google/apis/compute_v1/classes.rb', line 16802

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16809
16810
16811
16812
16813
16814
16815
16816
16817
# File 'lib/google/apis/compute_v1/classes.rb', line 16809

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end