Class: Google::Apis::ComputeV1::HealthAggregationPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthAggregationPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HealthAggregationPoliciesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
constructor
A new instance of HealthAggregationPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
Returns a new instance of HealthAggregationPolicyAggregatedList.
15494 15495 15496 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
15457 15458 15459 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15457 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
Corresponds to the JSON property items
15462 15463 15464 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15462 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
15467 15468 15469 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15467 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15477 15478 15479 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15477 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15482 15483 15484 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15482 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
15487 15488 15489 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15487 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15492 15493 15494 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15492 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15499 15500 15501 15502 15503 15504 15505 15506 15507 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15499 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |