Class: Google::Apis::ComputeV1::HealthAggregationPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyList

Returns a new instance of HealthAggregationPolicyList.



17597
17598
17599
# File 'lib/google/apis/compute_v1/classes.rb', line 17597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17563
17564
17565
# File 'lib/google/apis/compute_v1/classes.rb', line 17563

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HealthAggregationPolicy>

A list of HealthAggregationPolicy resources. Corresponds to the JSON property items



17568
17569
17570
# File 'lib/google/apis/compute_v1/classes.rb', line 17568

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthAggregationPolicy for health aggregation policies. Corresponds to the JSON property kind

Returns:

  • (String)


17575
17576
17577
# File 'lib/google/apis/compute_v1/classes.rb', line 17575

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17585
17586
17587
# File 'lib/google/apis/compute_v1/classes.rb', line 17585

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17590
17591
17592
# File 'lib/google/apis/compute_v1/classes.rb', line 17590

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HealthAggregationPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17595
17596
17597
# File 'lib/google/apis/compute_v1/classes.rb', line 17595

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17602
17603
17604
17605
17606
17607
17608
17609
# File 'lib/google/apis/compute_v1/classes.rb', line 17602

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end