Class: Google::Apis::ComputeV1::HealthAggregationPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthAggregationPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyList
constructor
A new instance of HealthAggregationPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyList
Returns a new instance of HealthAggregationPolicyList.
17446 17447 17448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17412 17413 17414 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17412 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
Corresponds to the JSON property items
17417 17418 17419 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17417 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
healthAggregationPolicy for health aggregation
policies.
Corresponds to the JSON property kind
17424 17425 17426 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17424 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17434 17435 17436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17434 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17439 17440 17441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17439 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17444 17445 17446 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17444 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17451 17452 17453 17454 17455 17456 17457 17458 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17451 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |