Class: Google::Apis::ComputeV1::HealthAggregationPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyList

Returns a new instance of HealthAggregationPolicyList.



16931
16932
16933
# File 'lib/google/apis/compute_v1/classes.rb', line 16931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16897
16898
16899
# File 'lib/google/apis/compute_v1/classes.rb', line 16897

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HealthAggregationPolicy>

A list of HealthAggregationPolicy resources. Corresponds to the JSON property items



16902
16903
16904
# File 'lib/google/apis/compute_v1/classes.rb', line 16902

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthAggregationPolicy for health aggregation policies. Corresponds to the JSON property kind

Returns:

  • (String)


16909
16910
16911
# File 'lib/google/apis/compute_v1/classes.rb', line 16909

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16919
16920
16921
# File 'lib/google/apis/compute_v1/classes.rb', line 16919

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16924
16925
16926
# File 'lib/google/apis/compute_v1/classes.rb', line 16924

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HealthAggregationPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16929
16930
16931
# File 'lib/google/apis/compute_v1/classes.rb', line 16929

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16936
16937
16938
16939
16940
16941
16942
16943
# File 'lib/google/apis/compute_v1/classes.rb', line 16936

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end