Class: Google::Apis::ComputeV1::HealthAggregationPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyList

Returns a new instance of HealthAggregationPolicyList.



15621
15622
15623
# File 'lib/google/apis/compute_v1/classes.rb', line 15621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15587
15588
15589
# File 'lib/google/apis/compute_v1/classes.rb', line 15587

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HealthAggregationPolicy>

A list of HealthAggregationPolicy resources. Corresponds to the JSON property items



15592
15593
15594
# File 'lib/google/apis/compute_v1/classes.rb', line 15592

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthAggregationPolicy for health aggregation policies. Corresponds to the JSON property kind

Returns:

  • (String)


15599
15600
15601
# File 'lib/google/apis/compute_v1/classes.rb', line 15599

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15609
15610
15611
# File 'lib/google/apis/compute_v1/classes.rb', line 15609

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15614
15615
15616
# File 'lib/google/apis/compute_v1/classes.rb', line 15614

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HealthAggregationPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15619
15620
15621
# File 'lib/google/apis/compute_v1/classes.rb', line 15619

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15626
15627
15628
15629
15630
15631
15632
15633
# File 'lib/google/apis/compute_v1/classes.rb', line 15626

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end