Class: Google::Apis::ComputeV1::HealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a health check resource. Google Compute Engine has two health check resources:
- Regional
- Global These health check resources can be used for load balancing and for autohealing VMs in a managed instance group (MIG). Load balancing Health check requirements vary depending on the type of load balancer. For details about the type of health check supported for each load balancer and corresponding backend type, see Health checks overview: Load balancer guide. Autohealing in MIGs The health checks that you use for autohealing VMs in a MIG can be either regional or global. For more information, see Set up an application health check and autohealing. For more information, seeHealth checks overview.
Instance Attribute Summary collapse
-
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#grpc_health_check ⇒ Google::Apis::ComputeV1::GrpcHealthCheck
Corresponds to the JSON property
grpcHealthCheck. -
#grpc_tls_health_check ⇒ Google::Apis::ComputeV1::GrpctlsHealthCheck
Corresponds to the JSON property
grpcTlsHealthCheck. -
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this many consecutive successes.
-
#http2_health_check ⇒ Google::Apis::ComputeV1::Http2HealthCheck
Corresponds to the JSON property
http2HealthCheck. -
#http_health_check ⇒ Google::Apis::ComputeV1::HttpHealthCheck
Corresponds to the JSON property
httpHealthCheck. -
#https_health_check ⇒ Google::Apis::ComputeV1::HttpsHealthCheck
Corresponds to the JSON property
httpsHealthCheck. -
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#log_config ⇒ Google::Apis::ComputeV1::HealthCheckLogConfig
Configuration of logging on a health check.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#source_regions ⇒ Array<String>
The list of cloud regions from which health checks are performed.
-
#ssl_health_check ⇒ Google::Apis::ComputeV1::SslHealthCheck
Corresponds to the JSON property
sslHealthCheck. -
#tcp_health_check ⇒ Google::Apis::ComputeV1::TcpHealthCheck
Corresponds to the JSON property
tcpHealthCheck. -
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure.
-
#type ⇒ String
Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC.
-
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many consecutive failures.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheck
constructor
A new instance of HealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheck
Returns a new instance of HealthCheck.
15256 15257 15258 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check. The default value is 5
seconds.
Corresponds to the JSON property checkIntervalSec
15121 15122 15123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15121 def check_interval_sec @check_interval_sec end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in3339
text format.
Corresponds to the JSON property creationTimestamp
15127 15128 15129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15127 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
15133 15134 15135 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15133 def description @description end |
#grpc_health_check ⇒ Google::Apis::ComputeV1::GrpcHealthCheck
Corresponds to the JSON property grpcHealthCheck
15138 15139 15140 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15138 def grpc_health_check @grpc_health_check end |
#grpc_tls_health_check ⇒ Google::Apis::ComputeV1::GrpctlsHealthCheck
Corresponds to the JSON property grpcTlsHealthCheck
15143 15144 15145 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15143 def grpc_tls_health_check @grpc_tls_health_check end |
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this
many consecutive successes. The default value is 2.
Corresponds to the JSON property healthyThreshold
15149 15150 15151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15149 def healthy_threshold @healthy_threshold end |
#http2_health_check ⇒ Google::Apis::ComputeV1::Http2HealthCheck
Corresponds to the JSON property http2HealthCheck
15154 15155 15156 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15154 def http2_health_check @http2_health_check end |
#http_health_check ⇒ Google::Apis::ComputeV1::HttpHealthCheck
Corresponds to the JSON property httpHealthCheck
15159 15160 15161 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15159 def http_health_check @http_health_check end |
#https_health_check ⇒ Google::Apis::ComputeV1::HttpsHealthCheck
Corresponds to the JSON property httpsHealthCheck
15164 15165 15166 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15164 def https_health_check @https_health_check end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
15170 15171 15172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15170 def id @id end |
#kind ⇒ String
Output only. Type of the resource.
Corresponds to the JSON property kind
15175 15176 15177 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15175 def kind @kind end |
#log_config ⇒ Google::Apis::ComputeV1::HealthCheckLogConfig
Configuration of logging on a health check. If logging is enabled, logs
will be exported to Stackdriver.
Corresponds to the JSON property logConfig
15181 15182 15183 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15181 def log_config @log_config end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
For example, a name that is 1-63 characters long, matches the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?, and otherwise complies with
RFC1035. This regular expression describes a name where the first
character is a lowercase letter, and all following characters are a dash,
lowercase letter, or digit, except the last character, which isn't a dash.
Corresponds to the JSON property name
15192 15193 15194 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15192 def name @name end |
#region ⇒ String
Output only. [Output Only] Region where the health check resides. Not
applicable to
global health checks.
Corresponds to the JSON property region
15199 15200 15201 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15199 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
15204 15205 15206 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15204 def self_link @self_link end |
#source_regions ⇒ Array<String>
The list of cloud regions from which health checks are performed. If any regions are specified, then exactly 3 regions should be specified. The region names must be valid names of Google Cloud regions. This can only be set for global health check. If this list is non-empty, then there are restrictions on what other health check fields are supported and what other resources can use this health check:
- SSL, HTTP2, and GRPC protocols are not supported.
- The TCP request field is not supported.
- The proxyHeader field for HTTP, HTTPS, and TCP is not supported.
- The checkIntervalSec field must be at least 30.
- The health check cannot be used with BackendService nor with managed
instance group auto-healing.
Corresponds to the JSON property
sourceRegions
15223 15224 15225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15223 def source_regions @source_regions end |
#ssl_health_check ⇒ Google::Apis::ComputeV1::SslHealthCheck
Corresponds to the JSON property sslHealthCheck
15228 15229 15230 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15228 def ssl_health_check @ssl_health_check end |
#tcp_health_check ⇒ Google::Apis::ComputeV1::TcpHealthCheck
Corresponds to the JSON property tcpHealthCheck
15233 15234 15235 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15233 def tcp_health_check @tcp_health_check end |
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure. The default value is
5 seconds. It is invalid for timeoutSec to have greater
value than checkIntervalSec.
Corresponds to the JSON property timeoutSec
15240 15241 15242 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15240 def timeout_sec @timeout_sec end |
#type ⇒ String
Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or
GRPC. Exactly one of the
protocol-specific health check fields must be specified, which must matchtype
field.
Corresponds to the JSON property type
15248 15249 15250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15248 def type @type end |
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many
consecutive failures. The default value is 2.
Corresponds to the JSON property unhealthyThreshold
15254 15255 15256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15254 def unhealthy_threshold @unhealthy_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15261 15262 15263 15264 15265 15266 15267 15268 15269 15270 15271 15272 15273 15274 15275 15276 15277 15278 15279 15280 15281 15282 15283 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15261 def update!(**args) @check_interval_sec = args[:check_interval_sec] if args.key?(:check_interval_sec) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @grpc_health_check = args[:grpc_health_check] if args.key?(:grpc_health_check) @grpc_tls_health_check = args[:grpc_tls_health_check] if args.key?(:grpc_tls_health_check) @healthy_threshold = args[:healthy_threshold] if args.key?(:healthy_threshold) @http2_health_check = args[:http2_health_check] if args.key?(:http2_health_check) @http_health_check = args[:http_health_check] if args.key?(:http_health_check) @https_health_check = args[:https_health_check] if args.key?(:https_health_check) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @log_config = args[:log_config] if args.key?(:log_config) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @source_regions = args[:source_regions] if args.key?(:source_regions) @ssl_health_check = args[:ssl_health_check] if args.key?(:ssl_health_check) @tcp_health_check = args[:tcp_health_check] if args.key?(:tcp_health_check) @timeout_sec = args[:timeout_sec] if args.key?(:timeout_sec) @type = args[:type] if args.key?(:type) @unhealthy_threshold = args[:unhealthy_threshold] if args.key?(:unhealthy_threshold) end |