Class: Google::Apis::ComputeV1::HealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HealthCheck>
A list of HealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckList
constructor
A new instance of HealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckList
Returns a new instance of HealthCheckList.
17985 17986 17987 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17953 17954 17955 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17953 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HealthCheck>
A list of HealthCheck resources.
Corresponds to the JSON property items
17958 17959 17960 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17958 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
17963 17964 17965 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17963 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17973 17974 17975 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17973 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17978 17979 17980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17978 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17983 17984 17985 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17983 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17990 17991 17992 17993 17994 17995 17996 17997 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17990 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |