Class: Google::Apis::ComputeV1::HealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckList

Returns a new instance of HealthCheckList.



9811
9812
9813
# File 'lib/google/apis/compute_v1/classes.rb', line 9811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9780
9781
9782
# File 'lib/google/apis/compute_v1/classes.rb', line 9780

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HealthCheck>

A list of HealthCheck resources. Corresponds to the JSON property items



9785
9786
9787
# File 'lib/google/apis/compute_v1/classes.rb', line 9785

def items
  @items
end

#kindString

Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


9790
9791
9792
# File 'lib/google/apis/compute_v1/classes.rb', line 9790

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9799
9800
9801
# File 'lib/google/apis/compute_v1/classes.rb', line 9799

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9804
9805
9806
# File 'lib/google/apis/compute_v1/classes.rb', line 9804

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9809
9810
9811
# File 'lib/google/apis/compute_v1/classes.rb', line 9809

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9816
9817
9818
9819
9820
9821
9822
9823
# File 'lib/google/apis/compute_v1/classes.rb', line 9816

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end