Class: Google::Apis::ComputeV1::HealthCheckService
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthCheckService
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Health-Check as a Service resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#health_checks ⇒ Array<String>
A list of URLs to the HealthCheck resources.
-
#health_status_aggregation_policy ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#network_endpoint_groups ⇒ Array<String>
A list of URLs to the NetworkEndpointGroup resources.
-
#notification_endpoints ⇒ Array<String>
A list of URLs to the NotificationEndpoint resources.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckService
constructor
A new instance of HealthCheckService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckService
Returns a new instance of HealthCheckService.
18173 18174 18175 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
18063 18064 18065 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18063 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
18069 18070 18071 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18069 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthCheckService. An up-to-date fingerprint must
be provided in order to patch/update the HealthCheckService; Otherwise, the
request will fail with error 412 conditionNotMet. To see the
latest fingerprint, make a get() request to retrieve the
HealthCheckService.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
18081 18082 18083 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18081 def fingerprint @fingerprint end |
#health_checks ⇒ Array<String>
A list of URLs to the HealthCheck resources. Must have
at least one HealthCheck, and not more than 10 for regionalHealthCheckService,
and not more than 1 for globalHealthCheckService.HealthCheck resources must
haveportSpecification=USE_SERVING_PORT orportSpecification=USE_FIXED_PORT. For
regional HealthCheckService, theHealthCheck must be regional and in the same
region. For global HealthCheckService,HealthCheck must be global. Mix of
regional and globalHealthChecks is not supported. Multiple
regionalHealthChecks must belong to the same region. RegionalHealthChecks must
belong to the same region as zones ofNetworkEndpointGroups. For
globalHealthCheckService using globalINTERNET_IP_PORT NetworkEndpointGroups,
the
global HealthChecks must specify sourceRegions,
and HealthChecks that specify sourceRegions can
only be used with global INTERNET_IP_PORTNetworkEndpointGroups.
Corresponds to the JSON property healthChecks
18099 18100 18101 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18099 def health_checks @health_checks end |
#health_status_aggregation_policy ⇒ String
Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified.
- NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service.
- AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY
is theHealthState of the endpoint. If all health checks reportHEALTHY, the
HealthState of the endpoint isHEALTHY.
.
This is only allowed with regional HealthCheckService.
Corresponds to the JSON property
healthStatusAggregationPolicy
18115 18116 18117 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18115 def health_status_aggregation_policy @health_status_aggregation_policy end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
18122 18123 18124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18122 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#
healthCheckServicefor health check services.
Corresponds to the JSON property kind
18128 18129 18130 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18128 def kind @kind end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long, and comply
with RFC1035. Specifically, the name must be 1-63 characters
long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
18139 18140 18141 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18139 def name @name end |
#network_endpoint_groups ⇒ Array<String>
A list of URLs to the NetworkEndpointGroup
resources. Must not have more than 100. For regionalHealthCheckService, NEGs
must be in
zones in the region of the HealthCheckService. For globalHealthCheckServices,
the NetworkEndpointGroups
must be global INTERNET_IP_PORT.
Corresponds to the JSON property networkEndpointGroups
18149 18150 18151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18149 def network_endpoint_groups @network_endpoint_groups end |
#notification_endpoints ⇒ Array<String>
A list of URLs to the NotificationEndpoint
resources. Must not have more than 10. A list of endpoints for
receiving notifications of change in health status. For
regionalHealthCheckService,NotificationEndpoint must be regional and in the
same region. For global HealthCheckService,NotificationEndpoint must be global.
Corresponds to the JSON property notificationEndpoints
18158 18159 18160 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18158 def notification_endpoints @notification_endpoints end |
#region ⇒ String
Output only. [Output Only] URL of the region where the health check service
resides. This field is not applicable to global health check services.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
18166 18167 18168 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18166 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
18171 18172 18173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18171 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18178 18179 18180 18181 18182 18183 18184 18185 18186 18187 18188 18189 18190 18191 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18178 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @health_checks = args[:health_checks] if args.key?(:health_checks) @health_status_aggregation_policy = args[:health_status_aggregation_policy] if args.key?(:health_status_aggregation_policy) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network_endpoint_groups = args[:network_endpoint_groups] if args.key?(:network_endpoint_groups) @notification_endpoints = args[:notification_endpoints] if args.key?(:notification_endpoints) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |