Class: Google::Apis::ComputeV1::HealthCheckService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Health-Check as a Service resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckService

Returns a new instance of HealthCheckService.



18161
18162
18163
# File 'lib/google/apis/compute_v1/classes.rb', line 18161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


18051
18052
18053
# File 'lib/google/apis/compute_v1/classes.rb', line 18051

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


18057
18058
18059
# File 'lib/google/apis/compute_v1/classes.rb', line 18057

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthCheckService. An up-to-date fingerprint must be provided in order to patch/update the HealthCheckService; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthCheckService. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


18069
18070
18071
# File 'lib/google/apis/compute_v1/classes.rb', line 18069

def fingerprint
  @fingerprint
end

#health_checksArray<String>

A list of URLs to the HealthCheck resources. Must have at least one HealthCheck, and not more than 10 for regionalHealthCheckService, and not more than 1 for globalHealthCheckService.HealthCheck resources must haveportSpecification=USE_SERVING_PORT orportSpecification=USE_FIXED_PORT. For regional HealthCheckService, theHealthCheck must be regional and in the same region. For global HealthCheckService,HealthCheck must be global. Mix of regional and globalHealthChecks is not supported. Multiple regionalHealthChecks must belong to the same region. RegionalHealthChecks must belong to the same region as zones ofNetworkEndpointGroups. For globalHealthCheckService using globalINTERNET_IP_PORT NetworkEndpointGroups, the global HealthChecks must specify sourceRegions, and HealthChecks that specify sourceRegions can only be used with global INTERNET_IP_PORTNetworkEndpointGroups. Corresponds to the JSON property healthChecks

Returns:

  • (Array<String>)


18087
18088
18089
# File 'lib/google/apis/compute_v1/classes.rb', line 18087

def health_checks
  @health_checks
end

#health_status_aggregation_policyString

Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified.

  • NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service.
  • AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY. . This is only allowed with regional HealthCheckService. Corresponds to the JSON property healthStatusAggregationPolicy

Returns:

  • (String)


18103
18104
18105
# File 'lib/google/apis/compute_v1/classes.rb', line 18103

def health_status_aggregation_policy
  @health_status_aggregation_policy
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


18110
18111
18112
# File 'lib/google/apis/compute_v1/classes.rb', line 18110

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute# healthCheckServicefor health check services. Corresponds to the JSON property kind

Returns:

  • (String)


18116
18117
18118
# File 'lib/google/apis/compute_v1/classes.rb', line 18116

def kind
  @kind
end

#nameString

Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


18127
18128
18129
# File 'lib/google/apis/compute_v1/classes.rb', line 18127

def name
  @name
end

#network_endpoint_groupsArray<String>

A list of URLs to the NetworkEndpointGroup resources. Must not have more than 100. For regionalHealthCheckService, NEGs must be in zones in the region of the HealthCheckService. For globalHealthCheckServices, the NetworkEndpointGroups must be global INTERNET_IP_PORT. Corresponds to the JSON property networkEndpointGroups

Returns:

  • (Array<String>)


18137
18138
18139
# File 'lib/google/apis/compute_v1/classes.rb', line 18137

def network_endpoint_groups
  @network_endpoint_groups
end

#notification_endpointsArray<String>

A list of URLs to the NotificationEndpoint resources. Must not have more than 10. A list of endpoints for receiving notifications of change in health status. For regionalHealthCheckService,NotificationEndpoint must be regional and in the same region. For global HealthCheckService,NotificationEndpoint must be global. Corresponds to the JSON property notificationEndpoints

Returns:

  • (Array<String>)


18146
18147
18148
# File 'lib/google/apis/compute_v1/classes.rb', line 18146

def notification_endpoints
  @notification_endpoints
end

#regionString

Output only. [Output Only] URL of the region where the health check service resides. This field is not applicable to global health check services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


18154
18155
18156
# File 'lib/google/apis/compute_v1/classes.rb', line 18154

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18159
18160
18161
# File 'lib/google/apis/compute_v1/classes.rb', line 18159

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18166
18167
18168
18169
18170
18171
18172
18173
18174
18175
18176
18177
18178
18179
# File 'lib/google/apis/compute_v1/classes.rb', line 18166

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @health_checks = args[:health_checks] if args.key?(:health_checks)
  @health_status_aggregation_policy = args[:health_status_aggregation_policy] if args.key?(:health_status_aggregation_policy)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network_endpoint_groups = args[:network_endpoint_groups] if args.key?(:network_endpoint_groups)
  @notification_endpoints = args[:notification_endpoints] if args.key?(:notification_endpoints)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end