Class: Google::Apis::ComputeV1::HealthCheckService
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthCheckService
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Health-Check as a Service resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#health_checks ⇒ Array<String>
A list of URLs to the HealthCheck resources.
-
#health_status_aggregation_policy ⇒ String
Optional.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output only] Type of the resource.
-
#name ⇒ String
Name of the resource.
-
#network_endpoint_groups ⇒ Array<String>
A list of URLs to the NetworkEndpointGroup resources.
-
#notification_endpoints ⇒ Array<String>
A list of URLs to the NotificationEndpoint resources.
-
#region ⇒ String
[Output Only] URL of the region where the health check service resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckService
constructor
A new instance of HealthCheckService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckService
Returns a new instance of HealthCheckService.
10033 10034 10035 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
9941 9942 9943 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9941 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
9947 9948 9949 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9947 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthCheckService. An up-to-date fingerprint must be provided in
order to patch/update the HealthCheckService; Otherwise, the request will fail
with error 412 conditionNotMet. To see the latest fingerprint, make a get()
request to retrieve the HealthCheckService.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
9958 9959 9960 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9958 def fingerprint @fingerprint end |
#health_checks ⇒ Array<String>
A list of URLs to the HealthCheck resources. Must have at least one
HealthCheck, and not more than 10. HealthCheck resources must have
portSpecification=USE_SERVING_PORT or portSpecification=USE_FIXED_PORT. For
regional HealthCheckService, the HealthCheck must be regional and in the same
region. For global HealthCheckService, HealthCheck must be global. Mix of
regional and global HealthChecks is not supported. Multiple regional
HealthChecks must belong to the same region. Regional HealthChecks must belong
to the same region as zones of NEGs.
Corresponds to the JSON property healthChecks
9970 9971 9972 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9970 def health_checks @health_checks end |
#health_status_aggregation_policy ⇒ String
Optional. Policy for how the results from multiple health checks for the same
endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. -
NO_AGGREGATION. An EndpointHealth message is returned for each pair in the
health check service. - AND. If any health check of an endpoint reports
UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health
checks report HEALTHY, the HealthState of the endpoint is HEALTHY. .
Corresponds to the JSON property healthStatusAggregationPolicy
9980 9981 9982 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9980 def health_status_aggregation_policy @health_status_aggregation_policy end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
9986 9987 9988 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9986 def id @id end |
#kind ⇒ String
[Output only] Type of the resource. Always compute#healthCheckServicefor
health check services.
Corresponds to the JSON property kind
9992 9993 9994 |
# File 'lib/google/apis/compute_v1/classes.rb', line 9992 def kind @kind end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long, and comply with
RFC1035. Specifically, the name must be 1-63 characters long and match the
regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be a
dash, lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
10002 10003 10004 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10002 def name @name end |
#network_endpoint_groups ⇒ Array<String>
A list of URLs to the NetworkEndpointGroup resources. Must not have more than
- For regional HealthCheckService, NEGs must be in zones in the region of
the HealthCheckService.
Corresponds to the JSON property
networkEndpointGroups
10009 10010 10011 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10009 def network_endpoint_groups @network_endpoint_groups end |
#notification_endpoints ⇒ Array<String>
A list of URLs to the NotificationEndpoint resources. Must not have more than
- A list of endpoints for receiving notifications of change in health status.
For regional HealthCheckService, NotificationEndpoint must be regional and in
the same region. For global HealthCheckService, NotificationEndpoint must be
global.
Corresponds to the JSON property
notificationEndpoints
10018 10019 10020 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10018 def notification_endpoints @notification_endpoints end |
#region ⇒ String
[Output Only] URL of the region where the health check service resides. This
field is not applicable to global health check services. You must specify this
field as part of the HTTP request URL. It is not settable as a field in the
request body.
Corresponds to the JSON property region
10026 10027 10028 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10026 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
10031 10032 10033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10031 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10038 10039 10040 10041 10042 10043 10044 10045 10046 10047 10048 10049 10050 10051 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10038 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @health_checks = args[:health_checks] if args.key?(:health_checks) @health_status_aggregation_policy = args[:health_status_aggregation_policy] if args.key?(:health_status_aggregation_policy) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network_endpoint_groups = args[:network_endpoint_groups] if args.key?(:network_endpoint_groups) @notification_endpoints = args[:notification_endpoints] if args.key?(:notification_endpoints) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |