Class: Google::Apis::ComputeV1::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



18238
18239
18240
# File 'lib/google/apis/compute_v1/classes.rb', line 18238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18201
18202
18203
# File 'lib/google/apis/compute_v1/classes.rb', line 18201

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



18206
18207
18208
# File 'lib/google/apis/compute_v1/classes.rb', line 18206

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18211
18212
18213
# File 'lib/google/apis/compute_v1/classes.rb', line 18211

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18221
18222
18223
# File 'lib/google/apis/compute_v1/classes.rb', line 18221

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18226
18227
18228
# File 'lib/google/apis/compute_v1/classes.rb', line 18226

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18231
18232
18233
# File 'lib/google/apis/compute_v1/classes.rb', line 18231

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18236
18237
18238
# File 'lib/google/apis/compute_v1/classes.rb', line 18236

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18243
18244
18245
18246
18247
18248
18249
18250
18251
# File 'lib/google/apis/compute_v1/classes.rb', line 18243

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end