Class: Google::Apis::ComputeV1::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



18075
18076
18077
# File 'lib/google/apis/compute_v1/classes.rb', line 18075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18038
18039
18040
# File 'lib/google/apis/compute_v1/classes.rb', line 18038

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



18043
18044
18045
# File 'lib/google/apis/compute_v1/classes.rb', line 18043

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18048
18049
18050
# File 'lib/google/apis/compute_v1/classes.rb', line 18048

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18058
18059
18060
# File 'lib/google/apis/compute_v1/classes.rb', line 18058

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18063
18064
18065
# File 'lib/google/apis/compute_v1/classes.rb', line 18063

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18068
18069
18070
# File 'lib/google/apis/compute_v1/classes.rb', line 18068

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18073
18074
18075
# File 'lib/google/apis/compute_v1/classes.rb', line 18073

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18080
18081
18082
18083
18084
18085
18086
18087
18088
# File 'lib/google/apis/compute_v1/classes.rb', line 18080

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end