Class: Google::Apis::ComputeV1::HealthCheckServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthCheckServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HealthCheckServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
constructor
A new instance of HealthCheckServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
Returns a new instance of HealthCheckServiceAggregatedList.
18075 18076 18077 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18038 18039 18040 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18038 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
Corresponds to the JSON property items
18043 18044 18045 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18043 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18048 18049 18050 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18048 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18058 18059 18060 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18058 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18063 18064 18065 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18063 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18068 18069 18070 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18068 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18073 18074 18075 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18073 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18080 18081 18082 18083 18084 18085 18086 18087 18088 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18080 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |