Class: Google::Apis::ComputeV1::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



18067
18068
18069
# File 'lib/google/apis/compute_v1/classes.rb', line 18067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18030
18031
18032
# File 'lib/google/apis/compute_v1/classes.rb', line 18030

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



18035
18036
18037
# File 'lib/google/apis/compute_v1/classes.rb', line 18035

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18040
18041
18042
# File 'lib/google/apis/compute_v1/classes.rb', line 18040

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18050
18051
18052
# File 'lib/google/apis/compute_v1/classes.rb', line 18050

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18055
18056
18057
# File 'lib/google/apis/compute_v1/classes.rb', line 18055

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18060
18061
18062
# File 'lib/google/apis/compute_v1/classes.rb', line 18060

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18065
18066
18067
# File 'lib/google/apis/compute_v1/classes.rb', line 18065

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18072
18073
18074
18075
18076
18077
18078
18079
18080
# File 'lib/google/apis/compute_v1/classes.rb', line 18072

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end