Class: Google::Apis::ComputeV1::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



17560
17561
17562
# File 'lib/google/apis/compute_v1/classes.rb', line 17560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17523
17524
17525
# File 'lib/google/apis/compute_v1/classes.rb', line 17523

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



17528
17529
17530
# File 'lib/google/apis/compute_v1/classes.rb', line 17528

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17533
17534
17535
# File 'lib/google/apis/compute_v1/classes.rb', line 17533

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17543
17544
17545
# File 'lib/google/apis/compute_v1/classes.rb', line 17543

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17548
17549
17550
# File 'lib/google/apis/compute_v1/classes.rb', line 17548

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17553
17554
17555
# File 'lib/google/apis/compute_v1/classes.rb', line 17553

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17558
17559
17560
# File 'lib/google/apis/compute_v1/classes.rb', line 17558

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17565
17566
17567
17568
17569
17570
17571
17572
17573
# File 'lib/google/apis/compute_v1/classes.rb', line 17565

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end