Class: Google::Apis::ComputeV1::HealthCheckServicesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServicesList

Returns a new instance of HealthCheckServicesList.



18230
18231
18232
# File 'lib/google/apis/compute_v1/classes.rb', line 18230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18195
18196
18197
# File 'lib/google/apis/compute_v1/classes.rb', line 18195

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HealthCheckService>

Output only. A list of HealthCheckService resources. Corresponds to the JSON property items



18200
18201
18202
# File 'lib/google/apis/compute_v1/classes.rb', line 18200

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthCheckServicesList for lists of HealthCheckServices. Corresponds to the JSON property kind

Returns:

  • (String)


18207
18208
18209
# File 'lib/google/apis/compute_v1/classes.rb', line 18207

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18218
18219
18220
# File 'lib/google/apis/compute_v1/classes.rb', line 18218

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18223
18224
18225
# File 'lib/google/apis/compute_v1/classes.rb', line 18223

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HealthCheckServicesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18228
18229
18230
# File 'lib/google/apis/compute_v1/classes.rb', line 18228

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18235
18236
18237
18238
18239
18240
18241
18242
# File 'lib/google/apis/compute_v1/classes.rb', line 18235

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end