Class: Google::Apis::ComputeV1::HealthCheckServicesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServicesList

Returns a new instance of HealthCheckServicesList.



18222
18223
18224
# File 'lib/google/apis/compute_v1/classes.rb', line 18222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18187
18188
18189
# File 'lib/google/apis/compute_v1/classes.rb', line 18187

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HealthCheckService>

Output only. A list of HealthCheckService resources. Corresponds to the JSON property items



18192
18193
18194
# File 'lib/google/apis/compute_v1/classes.rb', line 18192

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthCheckServicesList for lists of HealthCheckServices. Corresponds to the JSON property kind

Returns:

  • (String)


18199
18200
18201
# File 'lib/google/apis/compute_v1/classes.rb', line 18199

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18210
18211
18212
# File 'lib/google/apis/compute_v1/classes.rb', line 18210

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18215
18216
18217
# File 'lib/google/apis/compute_v1/classes.rb', line 18215

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HealthCheckServicesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18220
18221
18222
# File 'lib/google/apis/compute_v1/classes.rb', line 18220

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18227
18228
18229
18230
18231
18232
18233
18234
# File 'lib/google/apis/compute_v1/classes.rb', line 18227

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end