Class: Google::Apis::ComputeV1::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



18619
18620
18621
# File 'lib/google/apis/compute_v1/classes.rb', line 18619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18582
18583
18584
# File 'lib/google/apis/compute_v1/classes.rb', line 18582

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



18587
18588
18589
# File 'lib/google/apis/compute_v1/classes.rb', line 18587

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18592
18593
18594
# File 'lib/google/apis/compute_v1/classes.rb', line 18592

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18602
18603
18604
# File 'lib/google/apis/compute_v1/classes.rb', line 18602

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18607
18608
18609
# File 'lib/google/apis/compute_v1/classes.rb', line 18607

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18612
18613
18614
# File 'lib/google/apis/compute_v1/classes.rb', line 18612

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18617
18618
18619
# File 'lib/google/apis/compute_v1/classes.rb', line 18617

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18624
18625
18626
18627
18628
18629
18630
18631
18632
# File 'lib/google/apis/compute_v1/classes.rb', line 18624

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end