Class: Google::Apis::ComputeV1::HealthChecksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthChecksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthChecksAggregatedList
constructor
A new instance of HealthChecksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthChecksAggregatedList
Returns a new instance of HealthChecksAggregatedList.
18607 18608 18609 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18570 18571 18572 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18570 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
Corresponds to the JSON property items
18575 18576 18577 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18575 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18580 18581 18582 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18580 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18590 18591 18592 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18590 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18595 18596 18597 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18595 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18600 18601 18602 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18600 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18605 18606 18607 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18605 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18612 18613 18614 18615 18616 18617 18618 18619 18620 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18612 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |