Class: Google::Apis::ComputeV1::HealthChecksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthChecksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthChecksAggregatedList
constructor
A new instance of HealthChecksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthChecksAggregatedList
Returns a new instance of HealthChecksAggregatedList.
18456 18457 18458 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18419 18420 18421 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18419 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
Corresponds to the JSON property items
18424 18425 18426 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18424 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18429 18430 18431 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18429 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18439 18440 18441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18439 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18444 18445 18446 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18444 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18449 18450 18451 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18449 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18454 18455 18456 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18454 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18461 18462 18463 18464 18465 18466 18467 18468 18469 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18461 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |