Class: Google::Apis::ComputeV1::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



18448
18449
18450
# File 'lib/google/apis/compute_v1/classes.rb', line 18448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18411
18412
18413
# File 'lib/google/apis/compute_v1/classes.rb', line 18411

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



18416
18417
18418
# File 'lib/google/apis/compute_v1/classes.rb', line 18416

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18421
18422
18423
# File 'lib/google/apis/compute_v1/classes.rb', line 18421

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18431
18432
18433
# File 'lib/google/apis/compute_v1/classes.rb', line 18431

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18436
18437
18438
# File 'lib/google/apis/compute_v1/classes.rb', line 18436

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18441
18442
18443
# File 'lib/google/apis/compute_v1/classes.rb', line 18441

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18446
18447
18448
# File 'lib/google/apis/compute_v1/classes.rb', line 18446

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18453
18454
18455
18456
18457
18458
18459
18460
18461
# File 'lib/google/apis/compute_v1/classes.rb', line 18453

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end