Class: Google::Apis::ComputeV1::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



17941
17942
17943
# File 'lib/google/apis/compute_v1/classes.rb', line 17941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17904
17905
17906
# File 'lib/google/apis/compute_v1/classes.rb', line 17904

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



17909
17910
17911
# File 'lib/google/apis/compute_v1/classes.rb', line 17909

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17914
17915
17916
# File 'lib/google/apis/compute_v1/classes.rb', line 17914

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17924
17925
17926
# File 'lib/google/apis/compute_v1/classes.rb', line 17924

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17929
17930
17931
# File 'lib/google/apis/compute_v1/classes.rb', line 17929

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17934
17935
17936
# File 'lib/google/apis/compute_v1/classes.rb', line 17934

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17939
17940
17941
# File 'lib/google/apis/compute_v1/classes.rb', line 17939

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17946
17947
17948
17949
17950
17951
17952
17953
17954
# File 'lib/google/apis/compute_v1/classes.rb', line 17946

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end