Class: Google::Apis::ComputeV1::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



16404
16405
16406
# File 'lib/google/apis/compute_v1/classes.rb', line 16404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16367
16368
16369
# File 'lib/google/apis/compute_v1/classes.rb', line 16367

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



16372
16373
16374
# File 'lib/google/apis/compute_v1/classes.rb', line 16372

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


16377
16378
16379
# File 'lib/google/apis/compute_v1/classes.rb', line 16377

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16387
16388
16389
# File 'lib/google/apis/compute_v1/classes.rb', line 16387

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16392
16393
16394
# File 'lib/google/apis/compute_v1/classes.rb', line 16392

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16397
16398
16399
# File 'lib/google/apis/compute_v1/classes.rb', line 16397

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16402
16403
16404
# File 'lib/google/apis/compute_v1/classes.rb', line 16402

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16409
16410
16411
16412
16413
16414
16415
16416
16417
# File 'lib/google/apis/compute_v1/classes.rb', line 16409

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end