Class: Google::Apis::ComputeV1::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



10238
10239
10240
# File 'lib/google/apis/compute_v1/classes.rb', line 10238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10202
10203
10204
# File 'lib/google/apis/compute_v1/classes.rb', line 10202

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



10207
10208
10209
# File 'lib/google/apis/compute_v1/classes.rb', line 10207

def items
  @items
end

#kindString

Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


10212
10213
10214
# File 'lib/google/apis/compute_v1/classes.rb', line 10212

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10221
10222
10223
# File 'lib/google/apis/compute_v1/classes.rb', line 10221

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10226
10227
10228
# File 'lib/google/apis/compute_v1/classes.rb', line 10226

def self_link
  @self_link
end

#unreachablesArray<String>

[Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10231
10232
10233
# File 'lib/google/apis/compute_v1/classes.rb', line 10231

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10236
10237
10238
# File 'lib/google/apis/compute_v1/classes.rb', line 10236

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10243
10244
10245
10246
10247
10248
10249
10250
10251
# File 'lib/google/apis/compute_v1/classes.rb', line 10243

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end