Class: Google::Apis::ComputeV1::HealthSource
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a health source. A health source resource specifies the source resources and the health aggregation policy applied to the source resources to determine the aggregated health status.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#health_aggregation_policy ⇒ String
URL to the HealthAggregationPolicy resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_type ⇒ String
Specifies the type of the HealthSource.
-
#sources ⇒ Array<String>
URLs to the source resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSource
constructor
A new instance of HealthSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSource
Returns a new instance of HealthSource.
18738 18739 18740 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18738 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
18650 18651 18652 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18650 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
18656 18657 18658 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18656 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthSource. An up-to-date fingerprint
must be provided in order to patch the HealthSource; Otherwise, the request
will fail with error 412 conditionNotMet. To see the latest
fingerprint, make a get() request to retrieve the
HealthSource.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
18668 18669 18670 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18668 def fingerprint @fingerprint end |
#health_aggregation_policy ⇒ String
URL to the HealthAggregationPolicy resource. Must be set. Must
be regional and in the same region as the HealthSource. Can be
mutated.
Corresponds to the JSON property healthAggregationPolicy
18675 18676 18677 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18675 def health_aggregation_policy @health_aggregation_policy end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
18682 18683 18684 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18682 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
18688 18689 18690 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18688 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
18699 18700 18701 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18699 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the health source resides.
This field applies only to the regional resource. You must specify this
field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
18707 18708 18709 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18707 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
18712 18713 18714 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18712 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL with id for the resource.
Corresponds to the JSON property selfLinkWithId
18717 18718 18719 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18717 def self_link_with_id @self_link_with_id end |
#source_type ⇒ String
Specifies the type of the HealthSource. The only allowed value
is BACKEND_SERVICE. Must be specified when theHealthSource is created, and
cannot be mutated.
Corresponds to the JSON property sourceType
18724 18725 18726 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18724 def source_type @source_type end |
#sources ⇒ Array<String>
URLs to the source resources. Must be size 1. Must be aBackendService if
the sourceType is BACKEND_SERVICE. TheBackendService must have load balancing
schemeINTERNAL or INTERNAL_MANAGED and must be regional
and in the same region as the HealthSource (cross-region
deployment for INTERNAL_MANAGED is not supported). TheBackendService may use
only IGs, MIGs, or NEGs of typeGCE_VM_IP or GCE_VM_IP_PORT. TheBackendService
may not use haPolicy. Can be
mutated.
Corresponds to the JSON property sources
18736 18737 18738 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18736 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18743 18744 18745 18746 18747 18748 18749 18750 18751 18752 18753 18754 18755 18756 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18743 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @health_aggregation_policy = args[:health_aggregation_policy] if args.key?(:health_aggregation_policy) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_type = args[:source_type] if args.key?(:source_type) @sources = args[:sources] if args.key?(:sources) end |