Class: Google::Apis::ComputeV1::HealthSourceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthSourceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HealthSourcesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceAggregatedList
constructor
A new instance of HealthSourceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceAggregatedList
Returns a new instance of HealthSourceAggregatedList.
19028 19029 19030 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18991 18992 18993 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18991 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
Corresponds to the JSON property items
18996 18997 18998 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18996 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19001 19002 19003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19001 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19011 19012 19013 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19011 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19016 19017 19018 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19016 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
19021 19022 19023 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19021 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19026 19027 19028 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19026 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19033 19034 19035 19036 19037 19038 19039 19040 19041 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19033 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |