Class: Google::Apis::ComputeV1::HealthSourceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthSourceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HealthSourcesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceAggregatedList
constructor
A new instance of HealthSourceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceAggregatedList
Returns a new instance of HealthSourceAggregatedList.
18954 18955 18956 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18917 18918 18919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18917 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
Corresponds to the JSON property items
18922 18923 18924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18922 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18927 18928 18929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18927 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18937 18938 18939 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18937 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18942 18943 18944 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18942 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18947 18948 18949 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18947 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18952 18953 18954 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18952 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18959 18960 18961 18962 18963 18964 18965 18966 18967 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18959 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |