Class: Google::Apis::ComputeV1::HealthSourceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthSourcesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceAggregatedList

Returns a new instance of HealthSourceAggregatedList.



18803
18804
18805
# File 'lib/google/apis/compute_v1/classes.rb', line 18803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18766
18767
18768
# File 'lib/google/apis/compute_v1/classes.rb', line 18766

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthSourcesScopedList>

A list of HealthSourcesScopedList resources. Corresponds to the JSON property items



18771
18772
18773
# File 'lib/google/apis/compute_v1/classes.rb', line 18771

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18776
18777
18778
# File 'lib/google/apis/compute_v1/classes.rb', line 18776

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18786
18787
18788
# File 'lib/google/apis/compute_v1/classes.rb', line 18786

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18791
18792
18793
# File 'lib/google/apis/compute_v1/classes.rb', line 18791

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18796
18797
18798
# File 'lib/google/apis/compute_v1/classes.rb', line 18796

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthSourceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18801
18802
18803
# File 'lib/google/apis/compute_v1/classes.rb', line 18801

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18808
18809
18810
18811
18812
18813
18814
18815
18816
# File 'lib/google/apis/compute_v1/classes.rb', line 18808

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end