Class: Google::Apis::ComputeV1::HealthSourceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HealthSourcesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceAggregatedList

Returns a new instance of HealthSourceAggregatedList.



18288
18289
18290
# File 'lib/google/apis/compute_v1/classes.rb', line 18288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18251
18252
18253
# File 'lib/google/apis/compute_v1/classes.rb', line 18251

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::HealthSourcesScopedList>

A list of HealthSourcesScopedList resources. Corresponds to the JSON property items



18256
18257
18258
# File 'lib/google/apis/compute_v1/classes.rb', line 18256

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18261
18262
18263
# File 'lib/google/apis/compute_v1/classes.rb', line 18261

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18271
18272
18273
# File 'lib/google/apis/compute_v1/classes.rb', line 18271

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18276
18277
18278
# File 'lib/google/apis/compute_v1/classes.rb', line 18276

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18281
18282
18283
# File 'lib/google/apis/compute_v1/classes.rb', line 18281

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HealthSourceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18286
18287
18288
# File 'lib/google/apis/compute_v1/classes.rb', line 18286

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18293
18294
18295
18296
18297
18298
18299
18300
18301
# File 'lib/google/apis/compute_v1/classes.rb', line 18293

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end