Class: Google::Apis::ComputeV1::HealthSourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthSourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HealthSource>
A list of HealthSource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::HealthSourceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceList
constructor
A new instance of HealthSourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceList
Returns a new instance of HealthSourceList.
19174 19175 19176 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19141 19142 19143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19141 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HealthSource>
A list of HealthSource resources.
Corresponds to the JSON property items
19146 19147 19148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19146 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
19152 19153 19154 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19152 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19162 19163 19164 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19162 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19167 19168 19169 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19167 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HealthSourceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19172 19173 19174 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19172 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19179 19180 19181 19182 19183 19184 19185 19186 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19179 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |