Class: Google::Apis::ComputeV1::HealthSourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthSourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HealthSource>
A list of HealthSource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::HealthSourceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceList
constructor
A new instance of HealthSourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceList
Returns a new instance of HealthSourceList.
19112 19113 19114 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19112 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19079 19080 19081 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19079 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HealthSource>
A list of HealthSource resources.
Corresponds to the JSON property items
19084 19085 19086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19084 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
19090 19091 19092 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19090 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19100 19101 19102 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19100 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19105 19106 19107 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19105 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HealthSourceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19110 19111 19112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19110 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19117 19118 19119 19120 19121 19122 19123 19124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19117 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |