Class: Google::Apis::ComputeV1::HealthSourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthSourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HealthSource>
A list of HealthSource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::HealthSourceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceList
constructor
A new instance of HealthSourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceList
Returns a new instance of HealthSourceList.
18961 18962 18963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18928 18929 18930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18928 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HealthSource>
A list of HealthSource resources.
Corresponds to the JSON property items
18933 18934 18935 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18933 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
18939 18940 18941 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18939 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18949 18950 18951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18949 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18954 18955 18956 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18954 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HealthSourceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18959 18960 18961 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18959 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18966 18967 18968 18969 18970 18971 18972 18973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18966 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |