Class: Google::Apis::ComputeV1::HealthSourceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceList

Returns a new instance of HealthSourceList.



18953
18954
18955
# File 'lib/google/apis/compute_v1/classes.rb', line 18953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18920
18921
18922
# File 'lib/google/apis/compute_v1/classes.rb', line 18920

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HealthSource>

A list of HealthSource resources. Corresponds to the JSON property items



18925
18926
18927
# File 'lib/google/apis/compute_v1/classes.rb', line 18925

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#healthSource for health sources. Corresponds to the JSON property kind

Returns:

  • (String)


18931
18932
18933
# File 'lib/google/apis/compute_v1/classes.rb', line 18931

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18941
18942
18943
# File 'lib/google/apis/compute_v1/classes.rb', line 18941

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18946
18947
18948
# File 'lib/google/apis/compute_v1/classes.rb', line 18946

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HealthSourceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18951
18952
18953
# File 'lib/google/apis/compute_v1/classes.rb', line 18951

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18958
18959
18960
18961
18962
18963
18964
18965
# File 'lib/google/apis/compute_v1/classes.rb', line 18958

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end