Class: Google::Apis::ComputeV1::HealthSourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthSourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HealthSource>
A list of HealthSource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::HealthSourceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceList
constructor
A new instance of HealthSourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceList
Returns a new instance of HealthSourceList.
18446 18447 18448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18413 18414 18415 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18413 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HealthSource>
A list of HealthSource resources.
Corresponds to the JSON property items
18418 18419 18420 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18418 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
18424 18425 18426 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18424 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18434 18435 18436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18434 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18439 18440 18441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18439 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HealthSourceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18444 18445 18446 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18444 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18451 18452 18453 18454 18455 18456 18457 18458 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18451 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |