Class: Google::Apis::ComputeV1::HealthSourcesGetHealthResponseSourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HealthSourcesGetHealthResponseSourceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#backends ⇒ Array<Google::Apis::ComputeV1::HealthSourcesGetHealthResponseSourceInfoBackendInfo>
Represents an instance group or network endpoint group behind the source backend service.
-
#forwarding_rule ⇒ String
Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.
-
#source ⇒ String
Fully qualified URL of the associated source resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfo
constructor
A new instance of HealthSourcesGetHealthResponseSourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfo
Returns a new instance of HealthSourcesGetHealthResponseSourceInfo.
18554 18555 18556 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backends ⇒ Array<Google::Apis::ComputeV1::HealthSourcesGetHealthResponseSourceInfoBackendInfo>
Represents an instance group or network endpoint group behind the source
backend service. Only used if the sourceType of the regionHealthSource
is BACKEND_SERVICE.
Corresponds to the JSON property backends
18540 18541 18542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18540 def backends @backends end |
#forwarding_rule ⇒ String
Fully qualified URL of the forwarding rule associated with the source
resource if it is a L4ILB backend service.
Corresponds to the JSON property forwardingRule
18546 18547 18548 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18546 def forwarding_rule @forwarding_rule end |
#source ⇒ String
Fully qualified URL of the associated source resource. This is always a
backend service URL.
Corresponds to the JSON property source
18552 18553 18554 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18552 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18559 18560 18561 18562 18563 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18559 def update!(**args) @backends = args[:backends] if args.key?(:backends) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @source = args[:source] if args.key?(:source) end |