Class: Google::Apis::ComputeV1::HealthSourcesGetHealthResponseSourceInfoBackendInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo

Returns a new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.



18588
18589
18590
# File 'lib/google/apis/compute_v1/classes.rb', line 18588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpoint_countFixnum

Total number of endpoints when determining the health of the regionHealthSource. Corresponds to the JSON property endpointCount

Returns:

  • (Fixnum)


18574
18575
18576
# File 'lib/google/apis/compute_v1/classes.rb', line 18574

def endpoint_count
  @endpoint_count
end

#groupString

Fully qualified URL of an instance group or network endpoint group behind the source backend service. Corresponds to the JSON property group

Returns:

  • (String)


18580
18581
18582
# File 'lib/google/apis/compute_v1/classes.rb', line 18580

def group
  @group
end

#healthy_endpoint_countFixnum

Number of endpoints considered healthy when determining health of the regionHealthSource. Corresponds to the JSON property healthyEndpointCount

Returns:

  • (Fixnum)


18586
18587
18588
# File 'lib/google/apis/compute_v1/classes.rb', line 18586

def healthy_endpoint_count
  @healthy_endpoint_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18593
18594
18595
18596
18597
# File 'lib/google/apis/compute_v1/classes.rb', line 18593

def update!(**args)
  @endpoint_count = args[:endpoint_count] if args.key?(:endpoint_count)
  @group = args[:group] if args.key?(:group)
  @healthy_endpoint_count = args[:healthy_endpoint_count] if args.key?(:healthy_endpoint_count)
end