Class: Google::Apis::ComputeV1::HealthStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatus

Returns a new instance of HealthStatus.



19488
19489
19490
# File 'lib/google/apis/compute_v1/classes.rb', line 19488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Metadata defined as annotations for network endpoint. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


19432
19433
19434
# File 'lib/google/apis/compute_v1/classes.rb', line 19432

def annotations
  @annotations
end

#forwarding_ruleString

URL of the forwarding rule associated with the health status of the instance. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


19438
19439
19440
# File 'lib/google/apis/compute_v1/classes.rb', line 19438

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_ipString

A forwarding rule IP address assigned to this instance. Corresponds to the JSON property forwardingRuleIp

Returns:

  • (String)


19443
19444
19445
# File 'lib/google/apis/compute_v1/classes.rb', line 19443

def forwarding_rule_ip
  @forwarding_rule_ip
end

#health_stateString

Health state of the IPv4 address of the instance. Corresponds to the JSON property healthState

Returns:

  • (String)


19448
19449
19450
# File 'lib/google/apis/compute_v1/classes.rb', line 19448

def health_state
  @health_state
end

#instanceString

URL of the instance resource. Corresponds to the JSON property instance

Returns:

  • (String)


19453
19454
19455
# File 'lib/google/apis/compute_v1/classes.rb', line 19453

def instance
  @instance
end

#ip_addressString

For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip. Corresponds to the JSON property ipAddress

Returns:

  • (String)


19460
19461
19462
# File 'lib/google/apis/compute_v1/classes.rb', line 19460

def ip_address
  @ip_address
end

#ipv6_addressString

Corresponds to the JSON property ipv6Address

Returns:

  • (String)


19465
19466
19467
# File 'lib/google/apis/compute_v1/classes.rb', line 19465

def ipv6_address
  @ipv6_address
end

#ipv6_health_stateString

Health state of the IPv6 address of the instance. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


19470
19471
19472
# File 'lib/google/apis/compute_v1/classes.rb', line 19470

def ipv6_health_state
  @ipv6_health_state
end

#portFixnum

The named port of the instance group, not necessarily the port that is health-checked. Corresponds to the JSON property port

Returns:

  • (Fixnum)


19476
19477
19478
# File 'lib/google/apis/compute_v1/classes.rb', line 19476

def port
  @port
end

#weightString

Corresponds to the JSON property weight

Returns:

  • (String)


19481
19482
19483
# File 'lib/google/apis/compute_v1/classes.rb', line 19481

def weight
  @weight
end

#weight_errorString

Corresponds to the JSON property weightError

Returns:

  • (String)


19486
19487
19488
# File 'lib/google/apis/compute_v1/classes.rb', line 19486

def weight_error
  @weight_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19493
19494
19495
19496
19497
19498
19499
19500
19501
19502
19503
19504
19505
# File 'lib/google/apis/compute_v1/classes.rb', line 19493

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip)
  @health_state = args[:health_state] if args.key?(:health_state)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
  @port = args[:port] if args.key?(:port)
  @weight = args[:weight] if args.key?(:weight)
  @weight_error = args[:weight_error] if args.key?(:weight_error)
end