Class: Google::Apis::ComputeV1::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatusForNetworkEndpoint

Returns a new instance of HealthStatusForNetworkEndpoint.



16111
16112
16113
# File 'lib/google/apis/compute_v1/classes.rb', line 16111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceGoogle::Apis::ComputeV1::BackendServiceReference

URL of the backend service associated with the health state of the network endpoint. Corresponds to the JSON property backendService



16068
16069
16070
# File 'lib/google/apis/compute_v1/classes.rb', line 16068

def backend_service
  @backend_service
end

#forwarding_ruleGoogle::Apis::ComputeV1::ForwardingRuleReference

URL of the forwarding rule associated with the health state of the network endpoint. Corresponds to the JSON property forwardingRule



16074
16075
16076
# File 'lib/google/apis/compute_v1/classes.rb', line 16074

def forwarding_rule
  @forwarding_rule
end

#health_checkGoogle::Apis::ComputeV1::HealthCheckReference

A full or valid partial URL to a health check. For example, the following are valid URLs:



16085
16086
16087
# File 'lib/google/apis/compute_v1/classes.rb', line 16085

def health_check
  @health_check
end

#health_check_serviceGoogle::Apis::ComputeV1::HealthCheckServiceReference

A full or valid partial URL to a health check service. For example, the following are valid URLs:



16097
16098
16099
# File 'lib/google/apis/compute_v1/classes.rb', line 16097

def health_check_service
  @health_check_service
end

#health_stateString

Health state of the network endpoint determined based on the health checks configured. Corresponds to the JSON property healthState

Returns:

  • (String)


16103
16104
16105
# File 'lib/google/apis/compute_v1/classes.rb', line 16103

def health_state
  @health_state
end

#ipv6_health_stateString

Health state of the ipv6 network endpoint determined based on the health checks configured. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


16109
16110
16111
# File 'lib/google/apis/compute_v1/classes.rb', line 16109

def ipv6_health_state
  @ipv6_health_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16116
16117
16118
16119
16120
16121
16122
16123
# File 'lib/google/apis/compute_v1/classes.rb', line 16116

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @health_check = args[:health_check] if args.key?(:health_check)
  @health_check_service = args[:health_check_service] if args.key?(:health_check_service)
  @health_state = args[:health_state] if args.key?(:health_state)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
end