Class: Google::Apis::ComputeV1::HostPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HostPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The unique identifier of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation sub-block.
-
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
-
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostPhysicalTopology
constructor
A new instance of HostPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostPhysicalTopology
Returns a new instance of HostPhysicalTopology.
19728 19729 19730 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19728 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The unique identifier of the capacity block within the cluster.
Corresponds to the JSON property block
19710 19711 19712 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19710 def block @block end |
#cluster ⇒ String
The cluster name of the reservation sub-block.
Corresponds to the JSON property cluster
19715 19716 19717 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19715 def cluster @cluster end |
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
Corresponds to the JSON property host
19720 19721 19722 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19720 def host @host end |
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity
block.
Corresponds to the JSON property subBlock
19726 19727 19728 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19726 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19733 19734 19735 19736 19737 19738 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19733 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |