Class: Google::Apis::ComputeV1::HostRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HostRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
UrlMaps A host-matching rule for a URL. If matched, will use the namedPathMatcher to select the BackendService.
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of this resource.
-
#hosts ⇒ Array<String>
The list of host patterns to match.
-
#path_matcher ⇒ String
The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostRule
constructor
A new instance of HostRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostRule
Returns a new instance of HostRule.
19439 19440 19441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
19418 19419 19420 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19418 def description @description end |
#hosts ⇒ Array<String>
The list of host patterns to match. They must be valid hostnames with optional port numbers in the format host:port.* matches any string of ([a-z0-9- .]*). In that case, * must be the first character, and if followed by anything, the immediate following character must be either - or ..
- based matching is not supported when the URL map is bound
to a target gRPC proxy that has the validateForProxyless field
set to true.
Corresponds to the JSON property
hosts
19431 19432 19433 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19431 def hosts @hosts end |
#path_matcher ⇒ String
The name of the PathMatcher to use to match the path portion
of the URL if the hostRule matches the URL's host portion.
Corresponds to the JSON property pathMatcher
19437 19438 19439 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19437 def path_matcher @path_matcher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19444 19445 19446 19447 19448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19444 def update!(**args) @description = args[:description] if args.key?(:description) @hosts = args[:hosts] if args.key?(:hosts) @path_matcher = args[:path_matcher] if args.key?(:path_matcher) end |