Class: Google::Apis::ComputeV1::HostRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

UrlMaps A host-matching rule for a URL. If matched, will use the namedPathMatcher to select the BackendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostRule

Returns a new instance of HostRule.



18924
18925
18926
# File 'lib/google/apis/compute_v1/classes.rb', line 18924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


18903
18904
18905
# File 'lib/google/apis/compute_v1/classes.rb', line 18903

def description
  @description
end

#hostsArray<String>

The list of host patterns to match. They must be valid hostnames with optional port numbers in the format host:port.* matches any string of ([a-z0-9- .]*). In that case, * must be the first character, and if followed by anything, the immediate following character must be either - or ..

  • based matching is not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property hosts

Returns:

  • (Array<String>)


18916
18917
18918
# File 'lib/google/apis/compute_v1/classes.rb', line 18916

def hosts
  @hosts
end

#path_matcherString

The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion. Corresponds to the JSON property pathMatcher

Returns:

  • (String)


18922
18923
18924
# File 'lib/google/apis/compute_v1/classes.rb', line 18922

def path_matcher
  @path_matcher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18929
18930
18931
18932
18933
# File 'lib/google/apis/compute_v1/classes.rb', line 18929

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @hosts = args[:hosts] if args.key?(:hosts)
  @path_matcher = args[:path_matcher] if args.key?(:path_matcher)
end