Class: Google::Apis::ComputeV1::HostsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostsListResponse

Returns a new instance of HostsListResponse.



19879
19880
19881
# File 'lib/google/apis/compute_v1/classes.rb', line 19879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


19836
19837
19838
# File 'lib/google/apis/compute_v1/classes.rb', line 19836

def etag
  @etag
end

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19841
19842
19843
# File 'lib/google/apis/compute_v1/classes.rb', line 19841

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Host>

A list of host resources. Corresponds to the JSON property items

Returns:



19846
19847
19848
# File 'lib/google/apis/compute_v1/classes.rb', line 19846

def items
  @items
end

#kindString

The type of resource. Always compute#host for a list of hosts. Corresponds to the JSON property kind

Returns:

  • (String)


19851
19852
19853
# File 'lib/google/apis/compute_v1/classes.rb', line 19851

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19861
19862
19863
# File 'lib/google/apis/compute_v1/classes.rb', line 19861

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19866
19867
19868
# File 'lib/google/apis/compute_v1/classes.rb', line 19866

def self_link
  @self_link
end

#unreachablesArray<String>

Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


19872
19873
19874
# File 'lib/google/apis/compute_v1/classes.rb', line 19872

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::HostsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



19877
19878
19879
# File 'lib/google/apis/compute_v1/classes.rb', line 19877

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19884
19885
19886
19887
19888
19889
19890
19891
19892
19893
# File 'lib/google/apis/compute_v1/classes.rb', line 19884

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end