Class: Google::Apis::ComputeV1::Http2HealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Http2HealthCheck

Returns a new instance of Http2HealthCheck.



9466
9467
9468
# File 'lib/google/apis/compute_v1/classes.rb', line 9466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

The value of the host header in the HTTP/2 health check request. If left empty (default value), the IP on behalf of which this health check is performed will be used. Corresponds to the JSON property host

Returns:

  • (String)


9423
9424
9425
# File 'lib/google/apis/compute_v1/classes.rb', line 9423

def host
  @host
end

#portFixnum

The TCP port number for the health check request. The default value is 443. Valid values are 1 through 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


9429
9430
9431
# File 'lib/google/apis/compute_v1/classes.rb', line 9429

def port
  @port
end

#port_nameString

Port name as defined in InstanceGroup#NamedPort#name. If both port and port_name are defined, port takes precedence. Corresponds to the JSON property portName

Returns:

  • (String)


9435
9436
9437
# File 'lib/google/apis/compute_v1/classes.rb', line 9435

def port_name
  @port_name
end

#port_specificationString

Specifies how port is selected for health checking, can be one of following values: USE_FIXED_PORT: The port number in port is used for health checking. USE_NAMED_PORT: The portName is used for health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each network endpoint is used for health checking. For other backends, the port or named port specified in the Backend Service is used for health checking. If not specified, HTTP2 health check follows behavior specified in port and portName fields. Corresponds to the JSON property portSpecification

Returns:

  • (String)


9446
9447
9448
# File 'lib/google/apis/compute_v1/classes.rb', line 9446

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


9452
9453
9454
# File 'lib/google/apis/compute_v1/classes.rb', line 9452

def proxy_header
  @proxy_header
end

#request_pathString

The request path of the HTTP/2 health check request. The default value is /. Corresponds to the JSON property requestPath

Returns:

  • (String)


9457
9458
9459
# File 'lib/google/apis/compute_v1/classes.rb', line 9457

def request_path
  @request_path
end

#responseString

The string to match anywhere in the first 1024 bytes of the response body. If left empty (the default value), the status code determines health. The response data can only be ASCII. Corresponds to the JSON property response

Returns:

  • (String)


9464
9465
9466
# File 'lib/google/apis/compute_v1/classes.rb', line 9464

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9471
9472
9473
9474
9475
9476
9477
9478
9479
# File 'lib/google/apis/compute_v1/classes.rb', line 9471

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request_path = args[:request_path] if args.key?(:request_path)
  @response = args[:response] if args.key?(:response)
end