Class: Google::Apis::ComputeV1::HttpFaultAbort
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpFaultAbort
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specification for how requests are aborted as part of fault injection.
Instance Attribute Summary collapse
-
#http_status ⇒ Fixnum
The HTTP status code used to abort the request.
-
#percentage ⇒ Float
The percentage of traffic for connections, operations, or requests that is aborted as part of fault injection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpFaultAbort
constructor
A new instance of HttpFaultAbort.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpFaultAbort
Returns a new instance of HttpFaultAbort.
19988 19989 19990 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#http_status ⇒ Fixnum
The HTTP status code used to abort the request.
The value must be from 200 to 599 inclusive.
For gRPC protocol, the gRPC status code is mapped to HTTP status code
according to this
mapping table. HTTP status 200 is mapped to gRPC status
UNKNOWN. Injecting an OK status is currently not supported by
Traffic Director.
Corresponds to the JSON property httpStatus
19979 19980 19981 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19979 def http_status @http_status end |
#percentage ⇒ Float
The percentage of traffic for connections, operations, or requests
that is aborted as part of fault injection.
The value must be from 0.0 to 100.0 inclusive.
Corresponds to the JSON property percentage
19986 19987 19988 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19986 def percentage @percentage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19993 19994 19995 19996 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19993 def update!(**args) @http_status = args[:http_status] if args.key?(:http_status) @percentage = args[:percentage] if args.key?(:percentage) end |