Class: Google::Apis::ComputeV1::HttpFaultAbort

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specification for how requests are aborted as part of fault injection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFaultAbort

Returns a new instance of HttpFaultAbort.



19636
19637
19638
# File 'lib/google/apis/compute_v1/classes.rb', line 19636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_statusFixnum

The HTTP status code used to abort the request. The value must be from 200 to 599 inclusive. For gRPC protocol, the gRPC status code is mapped to HTTP status code according to this mapping table. HTTP status 200 is mapped to gRPC status UNKNOWN. Injecting an OK status is currently not supported by Traffic Director. Corresponds to the JSON property httpStatus

Returns:

  • (Fixnum)


19627
19628
19629
# File 'lib/google/apis/compute_v1/classes.rb', line 19627

def http_status
  @http_status
end

#percentageFloat

The percentage of traffic for connections, operations, or requests that is aborted as part of fault injection. The value must be from 0.0 to 100.0 inclusive. Corresponds to the JSON property percentage

Returns:

  • (Float)


19634
19635
19636
# File 'lib/google/apis/compute_v1/classes.rb', line 19634

def percentage
  @percentage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19641
19642
19643
19644
# File 'lib/google/apis/compute_v1/classes.rb', line 19641

def update!(**args)
  @http_status = args[:http_status] if args.key?(:http_status)
  @percentage = args[:percentage] if args.key?(:percentage)
end