Class: Google::Apis::ComputeV1::HttpFaultDelay
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpFaultDelay
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection.
Instance Attribute Summary collapse
-
#fixed_delay ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#percentage ⇒ Float
The percentage of traffic for connections, operations, or requests for which a delay is introduced as part of fault injection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpFaultDelay
constructor
A new instance of HttpFaultDelay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpFaultDelay
Returns a new instance of HttpFaultDelay.
19667 19668 19669 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fixed_delay ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property fixedDelay
19658 19659 19660 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19658 def fixed_delay @fixed_delay end |
#percentage ⇒ Float
The percentage of traffic for connections, operations, or requests for
which a delay is introduced as part of fault injection.
The value must be from 0.0 to 100.0 inclusive.
Corresponds to the JSON property percentage
19665 19666 19667 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19665 def percentage @percentage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19672 19673 19674 19675 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19672 def update!(**args) @fixed_delay = args[:fixed_delay] if args.key?(:fixed_delay) @percentage = args[:percentage] if args.key?(:percentage) end |