Class: Google::Apis::ComputeV1::HttpFaultDelay

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFaultDelay

Returns a new instance of HttpFaultDelay.



16879
16880
16881
# File 'lib/google/apis/compute_v1/classes.rb', line 16879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixed_delayGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property fixedDelay



16870
16871
16872
# File 'lib/google/apis/compute_v1/classes.rb', line 16870

def fixed_delay
  @fixed_delay
end

#percentageFloat

The percentage of traffic for connections, operations, or requests for which a delay is introduced as part of fault injection. The value must be from 0.0 to 100.0 inclusive. Corresponds to the JSON property percentage

Returns:

  • (Float)


16877
16878
16879
# File 'lib/google/apis/compute_v1/classes.rb', line 16877

def percentage
  @percentage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16884
16885
16886
16887
# File 'lib/google/apis/compute_v1/classes.rb', line 16884

def update!(**args)
  @fixed_delay = args[:fixed_delay] if args.key?(:fixed_delay)
  @percentage = args[:percentage] if args.key?(:percentage)
end