Class: Google::Apis::ComputeV1::HttpFaultInjection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFaultInjection

Returns a new instance of HttpFaultInjection.



19527
19528
19529
# File 'lib/google/apis/compute_v1/classes.rb', line 19527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abortGoogle::Apis::ComputeV1::HttpFaultAbort

Specification for how requests are aborted as part of fault injection. Corresponds to the JSON property abort



19519
19520
19521
# File 'lib/google/apis/compute_v1/classes.rb', line 19519

def abort
  @abort
end

#delayGoogle::Apis::ComputeV1::HttpFaultDelay

Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection. Corresponds to the JSON property delay



19525
19526
19527
# File 'lib/google/apis/compute_v1/classes.rb', line 19525

def delay
  @delay
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19532
19533
19534
19535
# File 'lib/google/apis/compute_v1/classes.rb', line 19532

def update!(**args)
  @abort = args[:abort] if args.key?(:abort)
  @delay = args[:delay] if args.key?(:delay)
end