Class: Google::Apis::ComputeV1::HttpHeaderAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The request and response header transformations that take effect before the request is passed along to the selected backendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderAction

Returns a new instance of HttpHeaderAction.



19060
19061
19062
# File 'lib/google/apis/compute_v1/classes.rb', line 19060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_headers_to_addArray<Google::Apis::ComputeV1::HttpHeaderOption>

Headers to add to a matching request before forwarding the request to thebackendService. Corresponds to the JSON property requestHeadersToAdd



19040
19041
19042
# File 'lib/google/apis/compute_v1/classes.rb', line 19040

def request_headers_to_add
  @request_headers_to_add
end

#request_headers_to_removeArray<String>

A list of header names for headers that need to be removed from the request before forwarding the request to the backendService. Corresponds to the JSON property requestHeadersToRemove

Returns:

  • (Array<String>)


19046
19047
19048
# File 'lib/google/apis/compute_v1/classes.rb', line 19046

def request_headers_to_remove
  @request_headers_to_remove
end

#response_headers_to_addArray<Google::Apis::ComputeV1::HttpHeaderOption>

Headers to add the response before sending the response back to the client. Corresponds to the JSON property responseHeadersToAdd



19052
19053
19054
# File 'lib/google/apis/compute_v1/classes.rb', line 19052

def response_headers_to_add
  @response_headers_to_add
end

#response_headers_to_removeArray<String>

A list of header names for headers that need to be removed from the response before sending the response back to the client. Corresponds to the JSON property responseHeadersToRemove

Returns:

  • (Array<String>)


19058
19059
19060
# File 'lib/google/apis/compute_v1/classes.rb', line 19058

def response_headers_to_remove
  @response_headers_to_remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19065
19066
19067
19068
19069
19070
# File 'lib/google/apis/compute_v1/classes.rb', line 19065

def update!(**args)
  @request_headers_to_add = args[:request_headers_to_add] if args.key?(:request_headers_to_add)
  @request_headers_to_remove = args[:request_headers_to_remove] if args.key?(:request_headers_to_remove)
  @response_headers_to_add = args[:response_headers_to_add] if args.key?(:response_headers_to_add)
  @response_headers_to_remove = args[:response_headers_to_remove] if args.key?(:response_headers_to_remove)
end