Class: Google::Apis::ComputeV1::HttpHeaderAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The request and response header transformations that take effect before the request is passed along to the selected backendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderAction

Returns a new instance of HttpHeaderAction.



16950
16951
16952
# File 'lib/google/apis/compute_v1/classes.rb', line 16950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_headers_to_addArray<Google::Apis::ComputeV1::HttpHeaderOption>

Headers to add to a matching request before forwarding the request to thebackendService. Corresponds to the JSON property requestHeadersToAdd



16930
16931
16932
# File 'lib/google/apis/compute_v1/classes.rb', line 16930

def request_headers_to_add
  @request_headers_to_add
end

#request_headers_to_removeArray<String>

A list of header names for headers that need to be removed from the request before forwarding the request to the backendService. Corresponds to the JSON property requestHeadersToRemove

Returns:

  • (Array<String>)


16936
16937
16938
# File 'lib/google/apis/compute_v1/classes.rb', line 16936

def request_headers_to_remove
  @request_headers_to_remove
end

#response_headers_to_addArray<Google::Apis::ComputeV1::HttpHeaderOption>

Headers to add the response before sending the response back to the client. Corresponds to the JSON property responseHeadersToAdd



16942
16943
16944
# File 'lib/google/apis/compute_v1/classes.rb', line 16942

def response_headers_to_add
  @response_headers_to_add
end

#response_headers_to_removeArray<String>

A list of header names for headers that need to be removed from the response before sending the response back to the client. Corresponds to the JSON property responseHeadersToRemove

Returns:

  • (Array<String>)


16948
16949
16950
# File 'lib/google/apis/compute_v1/classes.rb', line 16948

def response_headers_to_remove
  @response_headers_to_remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16955
16956
16957
16958
16959
16960
# File 'lib/google/apis/compute_v1/classes.rb', line 16955

def update!(**args)
  @request_headers_to_add = args[:request_headers_to_add] if args.key?(:request_headers_to_add)
  @request_headers_to_remove = args[:request_headers_to_remove] if args.key?(:request_headers_to_remove)
  @response_headers_to_add = args[:response_headers_to_add] if args.key?(:response_headers_to_add)
  @response_headers_to_remove = args[:response_headers_to_remove] if args.key?(:response_headers_to_remove)
end