Class: Google::Apis::ComputeV1::HttpHeaderAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpHeaderAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The request and response header transformations that take effect before the request is passed along to the selected backendService.
Instance Attribute Summary collapse
-
#request_headers_to_add ⇒ Array<Google::Apis::ComputeV1::HttpHeaderOption>
Headers to add to a matching request before forwarding the request to thebackendService.
-
#request_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the request before forwarding the request to the backendService.
-
#response_headers_to_add ⇒ Array<Google::Apis::ComputeV1::HttpHeaderOption>
Headers to add the response before sending the response back to the client.
-
#response_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the response before sending the response back to the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderAction
constructor
A new instance of HttpHeaderAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderAction
Returns a new instance of HttpHeaderAction.
16340 16341 16342 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16340 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_headers_to_add ⇒ Array<Google::Apis::ComputeV1::HttpHeaderOption>
Headers to add to a matching request before forwarding the request to
thebackendService.
Corresponds to the JSON property requestHeadersToAdd
16320 16321 16322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16320 def request_headers_to_add @request_headers_to_add end |
#request_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the
request before forwarding the request to the backendService.
Corresponds to the JSON property requestHeadersToRemove
16326 16327 16328 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16326 def request_headers_to_remove @request_headers_to_remove end |
#response_headers_to_add ⇒ Array<Google::Apis::ComputeV1::HttpHeaderOption>
Headers to add the response before sending the response back to the
client.
Corresponds to the JSON property responseHeadersToAdd
16332 16333 16334 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16332 def response_headers_to_add @response_headers_to_add end |
#response_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the
response before sending the response back to the client.
Corresponds to the JSON property responseHeadersToRemove
16338 16339 16340 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16338 def response_headers_to_remove @response_headers_to_remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16345 16346 16347 16348 16349 16350 |
# File 'lib/google/apis/compute_v1/classes.rb', line 16345 def update!(**args) @request_headers_to_add = args[:request_headers_to_add] if args.key?(:request_headers_to_add) @request_headers_to_remove = args[:request_headers_to_remove] if args.key?(:request_headers_to_remove) @response_headers_to_add = args[:response_headers_to_add] if args.key?(:response_headers_to_add) @response_headers_to_remove = args[:response_headers_to_remove] if args.key?(:response_headers_to_remove) end |