Class: Google::Apis::ComputeV1::HttpHeaderOption

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specification determining how headers are added to requests or responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderOption

Returns a new instance of HttpHeaderOption.



19878
19879
19880
# File 'lib/google/apis/compute_v1/classes.rb', line 19878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_nameString

The name of the header. Corresponds to the JSON property headerName

Returns:

  • (String)


19858
19859
19860
# File 'lib/google/apis/compute_v1/classes.rb', line 19858

def header_name
  @header_name
end

#header_valueString

The value of the header to add. Corresponds to the JSON property headerValue

Returns:

  • (String)


19863
19864
19865
# File 'lib/google/apis/compute_v1/classes.rb', line 19863

def header_value
  @header_value
end

#replaceBoolean Also known as: replace?

If false, headerValue is appended to any values that already exist for the header. If true, headerValue is set for the header, discarding any values that were set for that header. The default value is true, unless a variable is present in headerValue, in which case the default value is false. . Corresponds to the JSON property replace

Returns:

  • (Boolean)


19875
19876
19877
# File 'lib/google/apis/compute_v1/classes.rb', line 19875

def replace
  @replace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19883
19884
19885
19886
19887
# File 'lib/google/apis/compute_v1/classes.rb', line 19883

def update!(**args)
  @header_name = args[:header_name] if args.key?(:header_name)
  @header_value = args[:header_value] if args.key?(:header_value)
  @replace = args[:replace] if args.key?(:replace)
end