Class: Google::Apis::ComputeV1::HttpHeaderOption
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpHeaderOption
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specification determining how headers are added to requests or responses.
Instance Attribute Summary collapse
-
#header_name ⇒ String
The name of the header.
-
#header_value ⇒ String
The value of the header to add.
-
#replace ⇒ Boolean
(also: #replace?)
If false, headerValue is appended to any values that already exist for the header.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderOption
constructor
A new instance of HttpHeaderOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderOption
Returns a new instance of HttpHeaderOption.
19715 19716 19717 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#header_name ⇒ String
The name of the header.
Corresponds to the JSON property headerName
19695 19696 19697 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19695 def header_name @header_name end |
#header_value ⇒ String
The value of the header to add.
Corresponds to the JSON property headerValue
19700 19701 19702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19700 def header_value @header_value end |
#replace ⇒ Boolean Also known as: replace?
If false, headerValue is appended to any values
that already
exist for the header. If true, headerValue is set for the
header, discarding any values that were set for that header.
The default value is true,
unless a variable is present in headerValue,
in which case the default value is false.
.
Corresponds to the JSON property replace
19712 19713 19714 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19712 def replace @replace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19720 19721 19722 19723 19724 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19720 def update!(**args) @header_name = args[:header_name] if args.key?(:header_name) @header_value = args[:header_value] if args.key?(:header_value) @replace = args[:replace] if args.key?(:replace) end |