Class: Google::Apis::ComputeV1::HttpHeaderOption

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specification determining how headers are added to requests or responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderOption

Returns a new instance of HttpHeaderOption.



16480
16481
16482
# File 'lib/google/apis/compute_v1/classes.rb', line 16480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_nameString

The name of the header. Corresponds to the JSON property headerName

Returns:

  • (String)


16460
16461
16462
# File 'lib/google/apis/compute_v1/classes.rb', line 16460

def header_name
  @header_name
end

#header_valueString

The value of the header to add. Corresponds to the JSON property headerValue

Returns:

  • (String)


16465
16466
16467
# File 'lib/google/apis/compute_v1/classes.rb', line 16465

def header_value
  @header_value
end

#replaceBoolean Also known as: replace?

If false, headerValue is appended to any values that already exist for the header. If true, headerValue is set for the header, discarding any values that were set for that header. The default value is true, unless a variable is present in headerValue, in which case the default value is false. . Corresponds to the JSON property replace

Returns:

  • (Boolean)


16477
16478
16479
# File 'lib/google/apis/compute_v1/classes.rb', line 16477

def replace
  @replace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16485
16486
16487
16488
16489
# File 'lib/google/apis/compute_v1/classes.rb', line 16485

def update!(**args)
  @header_name = args[:header_name] if args.key?(:header_name)
  @header_value = args[:header_value] if args.key?(:header_value)
  @replace = args[:replace] if args.key?(:replace)
end