Class: Google::Apis::ComputeV1::HttpHeaderOption
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpHeaderOption
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specification determining how headers are added to requests or responses.
Instance Attribute Summary collapse
-
#header_name ⇒ String
The name of the header.
-
#header_value ⇒ String
The value of the header to add.
-
#replace ⇒ Boolean
(also: #replace?)
If false, headerValue is appended to any values that already exist for the header.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderOption
constructor
A new instance of HttpHeaderOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderOption
Returns a new instance of HttpHeaderOption.
10816 10817 10818 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#header_name ⇒ String
The name of the header.
Corresponds to the JSON property headerName
10801 10802 10803 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10801 def header_name @header_name end |
#header_value ⇒ String
The value of the header to add.
Corresponds to the JSON property headerValue
10806 10807 10808 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10806 def header_value @header_value end |
#replace ⇒ Boolean Also known as: replace?
If false, headerValue is appended to any values that already exist for the
header. If true, headerValue is set for the header, discarding any values that
were set for that header. The default value is false.
Corresponds to the JSON property replace
10813 10814 10815 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10813 def replace @replace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10821 10822 10823 10824 10825 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10821 def update!(**args) @header_name = args[:header_name] if args.key?(:header_name) @header_value = args[:header_value] if args.key?(:header_value) @replace = args[:replace] if args.key?(:replace) end |