Class: Google::Apis::ComputeV1::HttpHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HttpHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheckList

Returns a new instance of HttpHealthCheckList.



20396
20397
20398
# File 'lib/google/apis/compute_v1/classes.rb', line 20396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20364
20365
20366
# File 'lib/google/apis/compute_v1/classes.rb', line 20364

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HttpHealthCheck>

A list of HttpHealthCheck resources. Corresponds to the JSON property items



20369
20370
20371
# File 'lib/google/apis/compute_v1/classes.rb', line 20369

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


20374
20375
20376
# File 'lib/google/apis/compute_v1/classes.rb', line 20374

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20384
20385
20386
# File 'lib/google/apis/compute_v1/classes.rb', line 20384

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20389
20390
20391
# File 'lib/google/apis/compute_v1/classes.rb', line 20389

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HttpHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20394
20395
20396
# File 'lib/google/apis/compute_v1/classes.rb', line 20394

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20401
20402
20403
20404
20405
20406
20407
20408
# File 'lib/google/apis/compute_v1/classes.rb', line 20401

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end