Class: Google::Apis::ComputeV1::HttpHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HttpHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheckList

Returns a new instance of HttpHealthCheckList.



20044
20045
20046
# File 'lib/google/apis/compute_v1/classes.rb', line 20044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20012
20013
20014
# File 'lib/google/apis/compute_v1/classes.rb', line 20012

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HttpHealthCheck>

A list of HttpHealthCheck resources. Corresponds to the JSON property items



20017
20018
20019
# File 'lib/google/apis/compute_v1/classes.rb', line 20017

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


20022
20023
20024
# File 'lib/google/apis/compute_v1/classes.rb', line 20022

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20032
20033
20034
# File 'lib/google/apis/compute_v1/classes.rb', line 20032

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20037
20038
20039
# File 'lib/google/apis/compute_v1/classes.rb', line 20037

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HttpHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20042
20043
20044
# File 'lib/google/apis/compute_v1/classes.rb', line 20042

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/google/apis/compute_v1/classes.rb', line 20049

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end