Class: Google::Apis::ComputeV1::HttpHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HttpHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheckList

Returns a new instance of HttpHealthCheckList.



20032
20033
20034
# File 'lib/google/apis/compute_v1/classes.rb', line 20032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20000
20001
20002
# File 'lib/google/apis/compute_v1/classes.rb', line 20000

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HttpHealthCheck>

A list of HttpHealthCheck resources. Corresponds to the JSON property items



20005
20006
20007
# File 'lib/google/apis/compute_v1/classes.rb', line 20005

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


20010
20011
20012
# File 'lib/google/apis/compute_v1/classes.rb', line 20010

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20020
20021
20022
# File 'lib/google/apis/compute_v1/classes.rb', line 20020

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20025
20026
20027
# File 'lib/google/apis/compute_v1/classes.rb', line 20025

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HttpHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20030
20031
20032
# File 'lib/google/apis/compute_v1/classes.rb', line 20030

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20037
20038
20039
20040
20041
20042
20043
20044
# File 'lib/google/apis/compute_v1/classes.rb', line 20037

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end