Class: Google::Apis::ComputeV1::HttpHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HttpHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HttpHealthCheck>
A list of HttpHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHealthCheckList
constructor
A new instance of HttpHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHealthCheckList
Returns a new instance of HttpHealthCheckList.
19881 19882 19883 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19849 19850 19851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19849 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HttpHealthCheck>
A list of HttpHealthCheck resources.
Corresponds to the JSON property items
19854 19855 19856 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19854 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19859 19860 19861 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19859 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19869 19870 19871 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19869 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19874 19875 19876 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19874 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19879 19880 19881 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19879 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19886 19887 19888 19889 19890 19891 19892 19893 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19886 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |