Class: Google::Apis::ComputeV1::HttpHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HttpHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheckList

Returns a new instance of HttpHealthCheckList.



19873
19874
19875
# File 'lib/google/apis/compute_v1/classes.rb', line 19873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19841
19842
19843
# File 'lib/google/apis/compute_v1/classes.rb', line 19841

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HttpHealthCheck>

A list of HttpHealthCheck resources. Corresponds to the JSON property items



19846
19847
19848
# File 'lib/google/apis/compute_v1/classes.rb', line 19846

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


19851
19852
19853
# File 'lib/google/apis/compute_v1/classes.rb', line 19851

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19861
19862
19863
# File 'lib/google/apis/compute_v1/classes.rb', line 19861

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19866
19867
19868
# File 'lib/google/apis/compute_v1/classes.rb', line 19866

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HttpHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



19871
19872
19873
# File 'lib/google/apis/compute_v1/classes.rb', line 19871

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19878
19879
19880
19881
19882
19883
19884
19885
# File 'lib/google/apis/compute_v1/classes.rb', line 19878

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end