Class: Google::Apis::ComputeV1::HttpHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HttpHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheckList

Returns a new instance of HttpHealthCheckList.



17256
17257
17258
# File 'lib/google/apis/compute_v1/classes.rb', line 17256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17224
17225
17226
# File 'lib/google/apis/compute_v1/classes.rb', line 17224

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HttpHealthCheck>

A list of HttpHealthCheck resources. Corresponds to the JSON property items



17229
17230
17231
# File 'lib/google/apis/compute_v1/classes.rb', line 17229

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17234
17235
17236
# File 'lib/google/apis/compute_v1/classes.rb', line 17234

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17244
17245
17246
# File 'lib/google/apis/compute_v1/classes.rb', line 17244

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17249
17250
17251
# File 'lib/google/apis/compute_v1/classes.rb', line 17249

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HttpHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17254
17255
17256
# File 'lib/google/apis/compute_v1/classes.rb', line 17254

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17261
17262
17263
17264
17265
17266
17267
17268
# File 'lib/google/apis/compute_v1/classes.rb', line 17261

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end