Class: Google::Apis::ComputeV1::HttpHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HttpHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HttpHealthCheck>
A list of HttpHealthCheck resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHealthCheckList
constructor
A new instance of HttpHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHealthCheckList
Returns a new instance of HttpHealthCheckList.
10976 10977 10978 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10976 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10945 10946 10947 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10945 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HttpHealthCheck>
A list of HttpHealthCheck resources.
Corresponds to the JSON property items
10950 10951 10952 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10950 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
10955 10956 10957 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10955 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10964 10965 10966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10964 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10969 10970 10971 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10969 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10974 10975 10976 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10974 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10981 10982 10983 10984 10985 10986 10987 10988 |
# File 'lib/google/apis/compute_v1/classes.rb', line 10981 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |