Class: Google::Apis::ComputeV1::HttpQueryParameterMatch
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpQueryParameterMatch
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
HttpRouteRuleMatch criteria for a request's query parameter.
Instance Attribute Summary collapse
-
#exact_match ⇒ String
The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch.
-
#name ⇒ String
The name of the query parameter to match.
-
#present_match ⇒ Boolean
(also: #present_match?)
Specifies that the queryParameterMatch matches if the request contains the query parameter, irrespective of whether the parameter has a value or not.
-
#regex_match ⇒ String
The queryParameterMatch matches if the value of the parameter matches the regular expression specified byregexMatch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpQueryParameterMatch
constructor
A new instance of HttpQueryParameterMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpQueryParameterMatch
Returns a new instance of HttpQueryParameterMatch.
20003 20004 20005 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exact_match ⇒ String
The queryParameterMatch matches if the value of the
parameter exactly matches the contents of exactMatch.
Only one of presentMatch, exactMatch, orregexMatch must be set.
Corresponds to the JSON property exactMatch
19975 19976 19977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19975 def exact_match @exact_match end |
#name ⇒ String
The name of the query parameter to match. The query parameter must exist in
the request, in the absence of which the request match fails.
Corresponds to the JSON property name
19981 19982 19983 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19981 def name @name end |
#present_match ⇒ Boolean Also known as: present_match?
Specifies that the queryParameterMatch matches if the
request contains the query parameter, irrespective of whether the
parameter has a value or not.
Only one of presentMatch, exactMatch, orregexMatch must be set.
Corresponds to the JSON property presentMatch
19989 19990 19991 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19989 def present_match @present_match end |
#regex_match ⇒ String
The queryParameterMatch matches if the value of the
parameter matches the regular expression specified byregexMatch. For
more information about regular expression syntax, see Syntax.
Only one of presentMatch, exactMatch, orregexMatch must be set.
Regular expressions can only be used when the loadBalancingScheme is
set to INTERNAL_SELF_MANAGED, EXTERNAL_MANAGED
(regional scope) or INTERNAL_MANAGED.
Corresponds to the JSON property regexMatch
20001 20002 20003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20001 def regex_match @regex_match end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20008 20009 20010 20011 20012 20013 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20008 def update!(**args) @exact_match = args[:exact_match] if args.key?(:exact_match) @name = args[:name] if args.key?(:name) @present_match = args[:present_match] if args.key?(:present_match) @regex_match = args[:regex_match] if args.key?(:regex_match) end |