Class: Google::Apis::ComputeV1::HttpRouteAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpRouteAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#cors_policy ⇒ Google::Apis::ComputeV1::CorsPolicy
The specification for allowing client-side cross-origin requests.
-
#fault_injection_policy ⇒ Google::Apis::ComputeV1::HttpFaultInjection
The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure.
-
#max_stream_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_mirror_policy ⇒ Google::Apis::ComputeV1::RequestMirrorPolicy
A policy that specifies how requests intended for the route's backends are shadowed to a separate mirrored backend service.
-
#retry_policy ⇒ Google::Apis::ComputeV1::HttpRetryPolicy
The retry policy associates with HttpRouteRule Corresponds to the JSON property
retryPolicy. -
#timeout ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#url_rewrite ⇒ Google::Apis::ComputeV1::UrlRewrite
The spec for modifying the path before sending the request to the matched backend service.
-
#weighted_backend_services ⇒ Array<Google::Apis::ComputeV1::WeightedBackendService>
A list of weighted backend services to send traffic to when a route match occurs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteAction
constructor
A new instance of HttpRouteAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteAction
Returns a new instance of HttpRouteAction.
11297 11298 11299 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cors_policy ⇒ Google::Apis::ComputeV1::CorsPolicy
The specification for allowing client-side cross-origin requests. For more
information about the W3C recommendation for cross-origin resource sharing (
CORS), see Fetch API Living Standard.
Corresponds to the JSON property corsPolicy
11238 11239 11240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11238 def cors_policy @cors_policy end |
#fault_injection_policy ⇒ Google::Apis::ComputeV1::HttpFaultInjection
The specification for fault injection introduced into traffic to test the
resiliency of clients to backend service failure. As part of fault injection,
when clients send requests to a backend service, delays can be introduced by
the load balancer on a percentage of requests before sending those request to
the backend service. Similarly requests from clients can be aborted by the
load balancer for a percentage of requests.
Corresponds to the JSON property faultInjectionPolicy
11248 11249 11250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11248 def fault_injection_policy @fault_injection_policy end |
#max_stream_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of
seconds and fractions of seconds at nanosecond resolution. It is independent
of any calendar and concepts like "day" or "month". Range is approximately 10,
000 years.
Corresponds to the JSON property maxStreamDuration
11256 11257 11258 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11256 def max_stream_duration @max_stream_duration end |
#request_mirror_policy ⇒ Google::Apis::ComputeV1::RequestMirrorPolicy
A policy that specifies how requests intended for the route's backends are
shadowed to a separate mirrored backend service. The load balancer doesn't
wait for responses from the shadow service. Before sending traffic to the
shadow service, the host or authority header is suffixed with -shadow.
Corresponds to the JSON property requestMirrorPolicy
11264 11265 11266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11264 def request_mirror_policy @request_mirror_policy end |
#retry_policy ⇒ Google::Apis::ComputeV1::HttpRetryPolicy
The retry policy associates with HttpRouteRule
Corresponds to the JSON property retryPolicy
11269 11270 11271 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11269 def retry_policy @retry_policy end |
#timeout ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of
seconds and fractions of seconds at nanosecond resolution. It is independent
of any calendar and concepts like "day" or "month". Range is approximately 10,
000 years.
Corresponds to the JSON property timeout
11277 11278 11279 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11277 def timeout @timeout end |
#url_rewrite ⇒ Google::Apis::ComputeV1::UrlRewrite
The spec for modifying the path before sending the request to the matched
backend service.
Corresponds to the JSON property urlRewrite
11283 11284 11285 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11283 def url_rewrite @url_rewrite end |
#weighted_backend_services ⇒ Array<Google::Apis::ComputeV1::WeightedBackendService>
A list of weighted backend services to send traffic to when a route match
occurs. The weights determine the fraction of traffic that flows to their
corresponding backend service. If all traffic needs to go to a single backend
service, there must be one weightedBackendService with weight set to a non-
zero number. After a backend service is identified and before forwarding the
request to the backend service, advanced routing actions such as URL rewrites
and header transformations are applied depending on additional settings
specified in this HttpRouteAction.
Corresponds to the JSON property weightedBackendServices
11295 11296 11297 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11295 def weighted_backend_services @weighted_backend_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11302 11303 11304 11305 11306 11307 11308 11309 11310 11311 |
# File 'lib/google/apis/compute_v1/classes.rb', line 11302 def update!(**args) @cors_policy = args[:cors_policy] if args.key?(:cors_policy) @fault_injection_policy = args[:fault_injection_policy] if args.key?(:fault_injection_policy) @max_stream_duration = args[:max_stream_duration] if args.key?(:max_stream_duration) @request_mirror_policy = args[:request_mirror_policy] if args.key?(:request_mirror_policy) @retry_policy = args[:retry_policy] if args.key?(:retry_policy) @timeout = args[:timeout] if args.key?(:timeout) @url_rewrite = args[:url_rewrite] if args.key?(:url_rewrite) @weighted_backend_services = args[:weighted_backend_services] if args.key?(:weighted_backend_services) end |