Class: Google::Apis::ComputeV1::HttpRouteRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpRouteRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The HttpRouteRule setting specifies how to match an HTTP request and the corresponding routing action that load balancing proxies perform.
Instance Attribute Summary collapse
-
#custom_error_response_policy ⇒ Google::Apis::ComputeV1::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.
-
#description ⇒ String
The short description conveying the intent of this routeRule.
-
#header_action ⇒ Google::Apis::ComputeV1::HttpHeaderAction
The request and response header transformations that take effect before the request is passed along to the selected backendService.
-
#match_rules ⇒ Array<Google::Apis::ComputeV1::HttpRouteRuleMatch>
The list of criteria for matching attributes of a request to thisrouteRule.
-
#priority ⇒ Fixnum
For routeRules within a given pathMatcher, priority determines the order in which a load balancer interpretsrouteRules.
-
#route_action ⇒ Google::Apis::ComputeV1::HttpRouteAction
In response to a matching matchRule, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend.
-
#service ⇒ String
The full or partial URL of the backend service resource to which traffic is directed if this rule is matched.
-
#url_redirect ⇒ Google::Apis::ComputeV1::HttpRedirectAction
Specifies settings for an HTTP redirect.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteRule
constructor
A new instance of HttpRouteRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteRule
Returns a new instance of HttpRouteRule.
17102 17103 17104 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_error_response_policy ⇒ Google::Apis::ComputeV1::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the
backend service or backend bucket responds with an error.
Corresponds to the JSON property customErrorResponsePolicy
17033 17034 17035 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17033 def custom_error_response_policy @custom_error_response_policy end |
#description ⇒ String
The short description conveying the intent of this routeRule.
The description can have a maximum length of 1024 characters.
Corresponds to the JSON property description
17039 17040 17041 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17039 def description @description end |
#header_action ⇒ Google::Apis::ComputeV1::HttpHeaderAction
The request and response header transformations that take effect before
the request is passed along to the selected backendService.
Corresponds to the JSON property headerAction
17045 17046 17047 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17045 def header_action @header_action end |
#match_rules ⇒ Array<Google::Apis::ComputeV1::HttpRouteRuleMatch>
The list of criteria for matching attributes of a request to thisrouteRule.
This list has OR semantics: the request matches
this routeRule when any of thematchRules are satisfied. However predicates
within
a given matchRule have AND semantics. All predicates
within a matchRule must match for the request to
match the rule.
Corresponds to the JSON property matchRules
17056 17057 17058 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17056 def match_rules @match_rules end |
#priority ⇒ Fixnum
For routeRules within a given pathMatcher,
priority determines the order in which a load balancer interpretsrouteRules.
RouteRules are evaluated in order
of priority, from the lowest to highest number. The priority of a
rule decreases as its number increases (1, 2, 3, N+1). The first rule
that matches the request is applied.
You cannot configure two or more routeRules with the same priority.
Priority for each rule must be set to a number from 0 to 2147483647
inclusive.
Priority numbers can have gaps, which enable you to add or remove rules
in the future without affecting the rest of the rules. For example, 1, 2,
3, 4, 5, 9, 12, 16 is a valid series of priority numbers to which you
could add rules numbered from 6 to 8, 10 to 11, and 13 to 15 in the future
without any impact on existing rules.
Corresponds to the JSON property priority
17074 17075 17076 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17074 def priority @priority end |
#route_action ⇒ Google::Apis::ComputeV1::HttpRouteAction
In response to a matching matchRule, the load balancer
performs advanced routing actions, such as URL rewrites and header
transformations, before forwarding the request to the selected backend.
Only one of urlRedirect, service orrouteAction.weightedBackendService can be
set.
URL maps for classic Application Load Balancers only support
the urlRewrite action within a route rule'srouteAction.
Corresponds to the JSON property routeAction
17085 17086 17087 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17085 def route_action @route_action end |
#service ⇒ String
The full or partial URL of the backend service resource to which traffic
is directed if this rule is matched. If routeAction is
also specified, advanced routing actions, such as URL rewrites,
take effect before sending the request to the backend.
Only one of urlRedirect, service orrouteAction.weightedBackendService can be
set.
Corresponds to the JSON property service
17095 17096 17097 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17095 def service @service end |
#url_redirect ⇒ Google::Apis::ComputeV1::HttpRedirectAction
Specifies settings for an HTTP redirect.
Corresponds to the JSON property urlRedirect
17100 17101 17102 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17100 def url_redirect @url_redirect end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17107 17108 17109 17110 17111 17112 17113 17114 17115 17116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 17107 def update!(**args) @custom_error_response_policy = args[:custom_error_response_policy] if args.key?(:custom_error_response_policy) @description = args[:description] if args.key?(:description) @header_action = args[:header_action] if args.key?(:header_action) @match_rules = args[:match_rules] if args.key?(:match_rules) @priority = args[:priority] if args.key?(:priority) @route_action = args[:route_action] if args.key?(:route_action) @service = args[:service] if args.key?(:service) @url_redirect = args[:url_redirect] if args.key?(:url_redirect) end |