Class: Google::Apis::ComputeV1::HttpRouteRuleMatch

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

HttpRouteRuleMatch specifies a set of criteria for matching requests to an HttpRouteRule. All specified criteria must be satisfied for a match to occur.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteRuleMatch

Returns a new instance of HttpRouteRuleMatch.



17841
17842
17843
# File 'lib/google/apis/compute_v1/classes.rb', line 17841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_path_matchString

For satisfying the matchRule condition, the path of the request must exactly match the value specified infullPathMatch after removing any query parameters and anchor that may be part of the original URL. fullPathMatch must be from 1 to 1024 characters. Only one of prefixMatch, fullPathMatch,regexMatch or path_template_match must be specified. Corresponds to the JSON property fullPathMatch

Returns:

  • (String)


17745
17746
17747
# File 'lib/google/apis/compute_v1/classes.rb', line 17745

def full_path_match
  @full_path_match
end

#header_matchesArray<Google::Apis::ComputeV1::HttpHeaderMatch>

Specifies a list of header match criteria, all of which must match corresponding headers in the request. Corresponds to the JSON property headerMatches



17751
17752
17753
# File 'lib/google/apis/compute_v1/classes.rb', line 17751

def header_matches
  @header_matches
end

#ignore_caseBoolean Also known as: ignore_case?

Specifies that prefixMatch and fullPathMatch matches are case sensitive. The default value is false. ignoreCase must not be used with regexMatch. Not supported when the URL map is bound to a target gRPC proxy. Corresponds to the JSON property ignoreCase

Returns:

  • (Boolean)


17760
17761
17762
# File 'lib/google/apis/compute_v1/classes.rb', line 17760

def ignore_case
  @ignore_case
end

#metadata_filtersArray<Google::Apis::ComputeV1::MetadataFilter>

Opaque filter criteria used by the load balancer to restrict routing configuration to a limited set of xDS compliant clients. In their xDS requests to the load balancer, xDS clients present node metadata. When there is a match, the relevant routing configuration is made available to those proxies. For each metadataFilter in this list, if itsfilterMatchCriteria is set to MATCH_ANY, at least one of thefilterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. If multiple metadata filters are specified, all of them need to be satisfied in order to be considered a match. metadataFilters specified here is applied after those specified in ForwardingRule that refers to theUrlMap this HttpRouteRuleMatch belongs to. metadataFilters only applies to load balancers that haveloadBalancingScheme set toINTERNAL_SELF_MANAGED. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property metadataFilters



17786
17787
17788
# File 'lib/google/apis/compute_v1/classes.rb', line 17786

def 
  @metadata_filters
end

#path_template_matchString

If specified, this field defines a path template pattern that must match the :path header after the query string is removed. A path template pattern can include variables and wildcards. Variables are enclosed in curly braces, for examplevariable_name. Wildcards include * that matches a single path segment, and ** that matches zero or more path segments. The pattern must follow these rules:

  • The value must be between 1 and 1024 characters.
  • The pattern must start with a leading slash ("/").
  • No more than 5 operators (variables or wildcards) may appear in the pattern. Precisely one ofprefixMatch, fullPathMatch,regexMatch, or pathTemplateMatch must be set. Corresponds to the JSON property pathTemplateMatch

Returns:

  • (String)


17805
17806
17807
# File 'lib/google/apis/compute_v1/classes.rb', line 17805

def path_template_match
  @path_template_match
end

#prefix_matchString

For satisfying the matchRule condition, the request's path must begin with the specified prefixMatch.prefixMatch must begin with a /. The value must be from 1 to 1024 characters. The * character inside a prefix match is treated as a literal character, not as a wildcard. Only one of prefixMatch, fullPathMatch,regexMatch or path_template_match can be used within a matchRule. Corresponds to the JSON property prefixMatch

Returns:

  • (String)


17817
17818
17819
# File 'lib/google/apis/compute_v1/classes.rb', line 17817

def prefix_match
  @prefix_match
end

#query_parameter_matchesArray<Google::Apis::ComputeV1::HttpQueryParameterMatch>

Specifies a list of query parameter match criteria, all of which must match corresponding query parameters in the request. Not supported when the URL map is bound to a target gRPC proxy. Corresponds to the JSON property queryParameterMatches



17824
17825
17826
# File 'lib/google/apis/compute_v1/classes.rb', line 17824

def query_parameter_matches
  @query_parameter_matches
end

#regex_matchString

For satisfying the matchRule condition, the path of the request must satisfy the regular expression specified inregexMatch after removing any query parameters and anchor supplied with the original URL. For more information about regular expression syntax, see Syntax. Only one of prefixMatch, fullPathMatch,regexMatch or path_template_match must be specified. Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED, EXTERNAL_MANAGED (regional scope) or INTERNAL_MANAGED. Corresponds to the JSON property regexMatch

Returns:

  • (String)


17839
17840
17841
# File 'lib/google/apis/compute_v1/classes.rb', line 17839

def regex_match
  @regex_match
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17846
17847
17848
17849
17850
17851
17852
17853
17854
17855
# File 'lib/google/apis/compute_v1/classes.rb', line 17846

def update!(**args)
  @full_path_match = args[:full_path_match] if args.key?(:full_path_match)
  @header_matches = args[:header_matches] if args.key?(:header_matches)
  @ignore_case = args[:ignore_case] if args.key?(:ignore_case)
  @metadata_filters = args[:metadata_filters] if args.key?(:metadata_filters)
  @path_template_match = args[:path_template_match] if args.key?(:path_template_match)
  @prefix_match = args[:prefix_match] if args.key?(:prefix_match)
  @query_parameter_matches = args[:query_parameter_matches] if args.key?(:query_parameter_matches)
  @regex_match = args[:regex_match] if args.key?(:regex_match)
end