Class: Google::Apis::ComputeV1::HttpsHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a legacy HTTPS Health Check resource. Legacy HTTPS health checks have been deprecated. If you are using a target pool-based network load balancer, you must use a legacy HTTP (not HTTPS) health check. For all other load balancers, including backend service-based network load balancers, and for managed instance group auto-healing, you must use modern (non-legacy) health checks. For more information, see Health checks overview .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheck

Returns a new instance of HttpsHealthCheck.



9602
9603
9604
# File 'lib/google/apis/compute_v1/classes.rb', line 9602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_interval_secFixnum

How often (in seconds) to send a health check. The default value is 5 seconds. Corresponds to the JSON property checkIntervalSec

Returns:

  • (Fixnum)


11499
11500
11501
# File 'lib/google/apis/compute_v1/classes.rb', line 11499

def check_interval_sec
  @check_interval_sec
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


11504
11505
11506
# File 'lib/google/apis/compute_v1/classes.rb', line 11504

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


11510
11511
11512
# File 'lib/google/apis/compute_v1/classes.rb', line 11510

def description
  @description
end

#healthy_thresholdFixnum

A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2. Corresponds to the JSON property healthyThreshold

Returns:

  • (Fixnum)


11516
11517
11518
# File 'lib/google/apis/compute_v1/classes.rb', line 11516

def healthy_threshold
  @healthy_threshold
end

#hostString

The value of the host header in the HTTPS health check request. If left empty ( default value), the public IP on behalf of which this health check is performed will be used. Corresponds to the JSON property host

Returns:

  • (String)


9559
9560
9561
# File 'lib/google/apis/compute_v1/classes.rb', line 9559

def host
  @host
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


11529
11530
11531
# File 'lib/google/apis/compute_v1/classes.rb', line 11529

def id
  @id
end

#kindString

Type of the resource. Corresponds to the JSON property kind

Returns:

  • (String)


11534
11535
11536
# File 'lib/google/apis/compute_v1/classes.rb', line 11534

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


11544
11545
11546
# File 'lib/google/apis/compute_v1/classes.rb', line 11544

def name
  @name
end

#portFixnum

The TCP port number for the HTTPS health check request. The default value is 443. Corresponds to the JSON property port

Returns:

  • (Fixnum)


9565
9566
9567
# File 'lib/google/apis/compute_v1/classes.rb', line 9565

def port
  @port
end

#port_nameString

Port name as defined in InstanceGroup#NamedPort#name. If both port and port_name are defined, port takes precedence. Corresponds to the JSON property portName

Returns:

  • (String)


9571
9572
9573
# File 'lib/google/apis/compute_v1/classes.rb', line 9571

def port_name
  @port_name
end

#port_specificationString

Specifies how port is selected for health checking, can be one of following values: USE_FIXED_PORT: The port number in port is used for health checking. USE_NAMED_PORT: The portName is used for health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each network endpoint is used for health checking. For other backends, the port or named port specified in the Backend Service is used for health checking. If not specified, HTTPS health check follows behavior specified in port and portName fields. Corresponds to the JSON property portSpecification

Returns:

  • (String)


9582
9583
9584
# File 'lib/google/apis/compute_v1/classes.rb', line 9582

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


9588
9589
9590
# File 'lib/google/apis/compute_v1/classes.rb', line 9588

def proxy_header
  @proxy_header
end

#request_pathString

The request path of the HTTPS health check request. The default value is "/". Corresponds to the JSON property requestPath

Returns:

  • (String)


9593
9594
9595
# File 'lib/google/apis/compute_v1/classes.rb', line 9593

def request_path
  @request_path
end

#responseString

The string to match anywhere in the first 1024 bytes of the response body. If left empty (the default value), the status code determines health. The response data can only be ASCII. Corresponds to the JSON property response

Returns:

  • (String)


9600
9601
9602
# File 'lib/google/apis/compute_v1/classes.rb', line 9600

def response
  @response
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11560
11561
11562
# File 'lib/google/apis/compute_v1/classes.rb', line 11560

def self_link
  @self_link
end

#timeout_secFixnum

How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have a greater value than checkIntervalSec. Corresponds to the JSON property timeoutSec

Returns:

  • (Fixnum)


11567
11568
11569
# File 'lib/google/apis/compute_v1/classes.rb', line 11567

def timeout_sec
  @timeout_sec
end

#unhealthy_thresholdFixnum

A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2. Corresponds to the JSON property unhealthyThreshold

Returns:

  • (Fixnum)


11573
11574
11575
# File 'lib/google/apis/compute_v1/classes.rb', line 11573

def unhealthy_threshold
  @unhealthy_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9607
9608
9609
9610
9611
9612
9613
9614
9615
# File 'lib/google/apis/compute_v1/classes.rb', line 9607

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request_path = args[:request_path] if args.key?(:request_path)
  @response = args[:response] if args.key?(:response)
end