Class: Google::Apis::ComputeV1::HttpsHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpsHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of HttpsHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpsHealthCheckList
constructor
A new instance of HttpsHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpsHealthCheckList
Returns a new instance of HttpsHealthCheckList.
21159 21160 21161 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21127 21128 21129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21127 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::HttpsHealthCheck>
A list of HttpsHealthCheck resources.
Corresponds to the JSON property items
21132 21133 21134 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21132 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
21137 21138 21139 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21137 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21147 21148 21149 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21147 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21152 21153 21154 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21152 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::HttpsHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21157 21158 21159 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21157 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21164 21165 21166 21167 21168 21169 21170 21171 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21164 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |