Class: Google::Apis::ComputeV1::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



20807
20808
20809
# File 'lib/google/apis/compute_v1/classes.rb', line 20807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20775
20776
20777
# File 'lib/google/apis/compute_v1/classes.rb', line 20775

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



20780
20781
20782
# File 'lib/google/apis/compute_v1/classes.rb', line 20780

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


20785
20786
20787
# File 'lib/google/apis/compute_v1/classes.rb', line 20785

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20795
20796
20797
# File 'lib/google/apis/compute_v1/classes.rb', line 20795

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20800
20801
20802
# File 'lib/google/apis/compute_v1/classes.rb', line 20800

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20805
20806
20807
# File 'lib/google/apis/compute_v1/classes.rb', line 20805

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20812
20813
20814
20815
20816
20817
20818
20819
# File 'lib/google/apis/compute_v1/classes.rb', line 20812

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end