Class: Google::Apis::ComputeV1::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



18013
18014
18015
# File 'lib/google/apis/compute_v1/classes.rb', line 18013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17981
17982
17983
# File 'lib/google/apis/compute_v1/classes.rb', line 17981

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



17986
17987
17988
# File 'lib/google/apis/compute_v1/classes.rb', line 17986

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17991
17992
17993
# File 'lib/google/apis/compute_v1/classes.rb', line 17991

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18001
18002
18003
# File 'lib/google/apis/compute_v1/classes.rb', line 18001

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18006
18007
18008
# File 'lib/google/apis/compute_v1/classes.rb', line 18006

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18011
18012
18013
# File 'lib/google/apis/compute_v1/classes.rb', line 18011

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18018
18019
18020
18021
18022
18023
18024
18025
# File 'lib/google/apis/compute_v1/classes.rb', line 18018

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end