Class: Google::Apis::ComputeV1::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



11635
11636
11637
# File 'lib/google/apis/compute_v1/classes.rb', line 11635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11604
11605
11606
# File 'lib/google/apis/compute_v1/classes.rb', line 11604

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



11609
11610
11611
# File 'lib/google/apis/compute_v1/classes.rb', line 11609

def items
  @items
end

#kindString

Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


11614
11615
11616
# File 'lib/google/apis/compute_v1/classes.rb', line 11614

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11623
11624
11625
# File 'lib/google/apis/compute_v1/classes.rb', line 11623

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11628
11629
11630
# File 'lib/google/apis/compute_v1/classes.rb', line 11628

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11633
11634
11635
# File 'lib/google/apis/compute_v1/classes.rb', line 11633

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11640
11641
11642
11643
11644
11645
11646
11647
# File 'lib/google/apis/compute_v1/classes.rb', line 11640

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end