Class: Google::Apis::ComputeV1::Image

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an Image resource. You can use images to create boot disks for your VM instances. For more information, read Images.

Defined Under Namespace

Classes: RawDisk

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Image

Returns a new instance of Image.



20498
20499
20500
# File 'lib/google/apis/compute_v1/classes.rb', line 20498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The architecture of the image. Valid values are ARM64 or X86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


20224
20225
20226
# File 'lib/google/apis/compute_v1/classes.rb', line 20224

def architecture
  @architecture
end

#archive_size_bytesFixnum

Size of the image tar.gz archive stored in Google Cloud Storage (in bytes). Corresponds to the JSON property archiveSizeBytes

Returns:

  • (Fixnum)


20230
20231
20232
# File 'lib/google/apis/compute_v1/classes.rb', line 20230

def archive_size_bytes
  @archive_size_bytes
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


20236
20237
20238
# File 'lib/google/apis/compute_v1/classes.rb', line 20236

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeV1::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



20241
20242
20243
# File 'lib/google/apis/compute_v1/classes.rb', line 20241

def deprecated
  @deprecated
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


20247
20248
20249
# File 'lib/google/apis/compute_v1/classes.rb', line 20247

def description
  @description
end

#disk_size_gbFixnum

Size of the image when restored onto a persistent disk (in GB). Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


20252
20253
20254
# File 'lib/google/apis/compute_v1/classes.rb', line 20252

def disk_size_gb
  @disk_size_gb
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Output only. Whether this image is created from a confidential compute mode disk. [Output Only]: This field is not set by user, but from source disk. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


20259
20260
20261
# File 'lib/google/apis/compute_v1/classes.rb', line 20259

def enable_confidential_compute
  @enable_confidential_compute
end

#familyString

The name of the image family to which this image belongs. The image family name can be from a publicly managed image family provided by Compute Engine, or from a custom image family you create. For example,centos- stream-9 is a publicly available image family. For more information, see Image family best practices. When creating disks, you can specify an image family instead of a specific image name. The image family always returns its latest image that is not deprecated. The name of the image family must comply with RFC1035. Corresponds to the JSON property family

Returns:

  • (String)


20273
20274
20275
# File 'lib/google/apis/compute_v1/classes.rb', line 20273

def family
  @family
end

#guest_os_featuresArray<Google::Apis::ComputeV1::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. To see a list of available options, see theguestOSfeatures[].type parameter. Corresponds to the JSON property guestOsFeatures



20280
20281
20282
# File 'lib/google/apis/compute_v1/classes.rb', line 20280

def guest_os_features
  @guest_os_features
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


20287
20288
20289
# File 'lib/google/apis/compute_v1/classes.rb', line 20287

def id
  @id
end

#image_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Encrypts the image using acustomer-supplied encryption key. After you encrypt an image with a customer-supplied key, you must provide the same key if you use the image later (e.g. to create a disk from the image). Customer-supplied encryption keys do not protect access to metadata of the disk. If you do not provide an encryption key when creating the image, then the disk will be encrypted using an automatically generated key and you do not need to provide a key to use the image later. Corresponds to the JSON property imageEncryptionKey



20301
20302
20303
# File 'lib/google/apis/compute_v1/classes.rb', line 20301

def image_encryption_key
  @image_encryption_key
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#image for images. Corresponds to the JSON property kind

Returns:

  • (String)


20307
20308
20309
# File 'lib/google/apis/compute_v1/classes.rb', line 20307

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this image, which is essentially a hash of the labels used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an image. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


20320
20321
20322
# File 'lib/google/apis/compute_v1/classes.rb', line 20320

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this image. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


20326
20327
20328
# File 'lib/google/apis/compute_v1/classes.rb', line 20326

def labels
  @labels
end

#license_codesArray<Fixnum>

Integer license codes indicating which licenses are attached to this image. Corresponds to the JSON property licenseCodes

Returns:

  • (Array<Fixnum>)


20331
20332
20333
# File 'lib/google/apis/compute_v1/classes.rb', line 20331

def license_codes
  @license_codes
end

#licensesArray<String>

Any applicable license URI. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


20336
20337
20338
# File 'lib/google/apis/compute_v1/classes.rb', line 20336

def licenses
  @licenses
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


20347
20348
20349
# File 'lib/google/apis/compute_v1/classes.rb', line 20347

def name
  @name
end

#paramsGoogle::Apis::ComputeV1::ImageParams

Additional image params. Corresponds to the JSON property params



20352
20353
20354
# File 'lib/google/apis/compute_v1/classes.rb', line 20352

def params
  @params
end

#raw_diskGoogle::Apis::ComputeV1::Image::RawDisk

The parameters of the raw disk image. Corresponds to the JSON property rawDisk



20357
20358
20359
# File 'lib/google/apis/compute_v1/classes.rb', line 20357

def raw_disk
  @raw_disk
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


20362
20363
20364
# File 'lib/google/apis/compute_v1/classes.rb', line 20362

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


20368
20369
20370
# File 'lib/google/apis/compute_v1/classes.rb', line 20368

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20374
20375
20376
# File 'lib/google/apis/compute_v1/classes.rb', line 20374

def self_link
  @self_link
end

#shielded_instance_initial_stateGoogle::Apis::ComputeV1::InitialStateConfig

Initial State for shielded instance, these are public keys which are safe to store in public Corresponds to the JSON property shieldedInstanceInitialState



20380
20381
20382
# File 'lib/google/apis/compute_v1/classes.rb', line 20380

def shielded_instance_initial_state
  @shielded_instance_initial_state
end

#source_diskString

URL of the source disk used to create this image. For example, the following are valid values:

  • https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
  • projects/project/zones/zone/disks/disk
  • zones/zone/disks/disk In order to create an image, you must provide the full or partial URL of one of the following:

  • The rawDisk.source URL

  • The sourceDisk URL

  • The sourceImage URL

  • The sourceSnapshot URL Corresponds to the JSON property sourceDisk

Returns:

  • (String)


20398
20399
20400
# File 'lib/google/apis/compute_v1/classes.rb', line 20398

def source_disk
  @source_disk
end

#source_disk_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceDiskEncryptionKey



20405
20406
20407
# File 'lib/google/apis/compute_v1/classes.rb', line 20405

def source_disk_encryption_key
  @source_disk_encryption_key
end

#source_disk_idString

Output only. [Output Only] The ID value of the disk used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given disk name. Corresponds to the JSON property sourceDiskId

Returns:

  • (String)


20413
20414
20415
# File 'lib/google/apis/compute_v1/classes.rb', line 20413

def source_disk_id
  @source_disk_id
end

#source_imageString

URL of the source image used to create this image. The following are valid formats for the URL:

  • https://www.googleapis.com/compute/v1/projects/project_id/global/ images/image_name
  • projects/project_id/global/images/image_name In order to create an image, you must provide the full or partial URL of one of the following:

  • The rawDisk.source URL

  • The sourceDisk URL

  • The sourceImage URL

  • The sourceSnapshot URL Corresponds to the JSON property sourceImage

Returns:

  • (String)


20430
20431
20432
# File 'lib/google/apis/compute_v1/classes.rb', line 20430

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceImageEncryptionKey



20436
20437
20438
# File 'lib/google/apis/compute_v1/classes.rb', line 20436

def source_image_encryption_key
  @source_image_encryption_key
end

#source_image_idString

Output only. [Output Only] The ID value of the image used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given image name. Corresponds to the JSON property sourceImageId

Returns:

  • (String)


20444
20445
20446
# File 'lib/google/apis/compute_v1/classes.rb', line 20444

def source_image_id
  @source_image_id
end

#source_snapshotString

URL of the source snapshot used to create this image. The following are valid formats for the URL:

  • https://www.googleapis.com/compute/v1/projects/project_id/global/ snapshots/snapshot_name
  • projects/project_id/global/snapshots/snapshot_name In order to create an image, you must provide the full or partial URL of one of the following:

  • The rawDisk.source URL

  • The sourceDisk URL

  • The sourceImage URL

  • The sourceSnapshot URL Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


20461
20462
20463
# File 'lib/google/apis/compute_v1/classes.rb', line 20461

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The customer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceSnapshotEncryptionKey



20467
20468
20469
# File 'lib/google/apis/compute_v1/classes.rb', line 20467

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

#source_snapshot_idString

Output only. [Output Only] The ID value of the snapshot used to create this image. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given snapshot name. Corresponds to the JSON property sourceSnapshotId

Returns:

  • (String)


20475
20476
20477
# File 'lib/google/apis/compute_v1/classes.rb', line 20475

def source_snapshot_id
  @source_snapshot_id
end

#source_typeString

The type of the image used to create this disk. The default and only valid value is RAW. Corresponds to the JSON property sourceType

Returns:

  • (String)


20481
20482
20483
# File 'lib/google/apis/compute_v1/classes.rb', line 20481

def source_type
  @source_type
end

#statusString

Output only. [Output Only] The status of the image. An image can be used to create other resources, such as instances, only after the image has been successfully created and the status is set to READY. Possible values are FAILED, PENDING, orREADY. Corresponds to the JSON property status

Returns:

  • (String)


20490
20491
20492
# File 'lib/google/apis/compute_v1/classes.rb', line 20490

def status
  @status
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the image (regional or multi-regional). Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


20496
20497
20498
# File 'lib/google/apis/compute_v1/classes.rb', line 20496

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20503
20504
20505
20506
20507
20508
20509
20510
20511
20512
20513
20514
20515
20516
20517
20518
20519
20520
20521
20522
20523
20524
20525
20526
20527
20528
20529
20530
20531
20532
20533
20534
20535
20536
20537
20538
20539
# File 'lib/google/apis/compute_v1/classes.rb', line 20503

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @archive_size_bytes = args[:archive_size_bytes] if args.key?(:archive_size_bytes)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @family = args[:family] if args.key?(:family)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @id = args[:id] if args.key?(:id)
  @image_encryption_key = args[:image_encryption_key] if args.key?(:image_encryption_key)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @license_codes = args[:license_codes] if args.key?(:license_codes)
  @licenses = args[:licenses] if args.key?(:licenses)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @raw_disk = args[:raw_disk] if args.key?(:raw_disk)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @shielded_instance_initial_state = args[:shielded_instance_initial_state] if args.key?(:shielded_instance_initial_state)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key)
  @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_image_id = args[:source_image_id] if args.key?(:source_image_id)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
  @source_snapshot_id = args[:source_snapshot_id] if args.key?(:source_snapshot_id)
  @source_type = args[:source_type] if args.key?(:source_type)
  @status = args[:status] if args.key?(:status)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end