Class: Google::Apis::ComputeV1::Image
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Image
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents an Image resource. You can use images to create boot disks for your VM instances. For more information, read Images.
Defined Under Namespace
Classes: RawDisk
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture of the image.
-
#archive_size_bytes ⇒ Fixnum
Size of the image tar.gz archive stored in Google Cloud Storage (in bytes).
-
#creation_timestamp ⇒ String
Output only.
-
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ Fixnum
Size of the image when restored onto a persistent disk (in GB).
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Output only.
-
#family ⇒ String
The name of the image family to which this image belongs.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeV1::GuestOsFeature>
A list of features to enable on the guest operating system.
-
#id ⇒ Fixnum
Output only.
-
#image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Encrypts the image using acustomer-supplied encryption key.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this image, which is essentially a hash of the labels used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this image.
-
#license_codes ⇒ Array<Fixnum>
Integer license codes indicating which licenses are attached to this image.
-
#licenses ⇒ Array<String>
Any applicable license URI.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#params ⇒ Google::Apis::ComputeV1::ImageParams
Additional image params.
-
#raw_disk ⇒ Google::Apis::ComputeV1::Image::RawDisk
The parameters of the raw disk image.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#shielded_instance_initial_state ⇒ Google::Apis::ComputeV1::InitialStateConfig
Initial State for shielded instance, these are public keys which are safe to store in public Corresponds to the JSON property
shieldedInstanceInitialState. -
#source_disk ⇒ String
URL of the source disk used to create this image.
-
#source_disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source disk.
-
#source_disk_id ⇒ String
Output only.
-
#source_image ⇒ String
URL of the source image used to create this image.
-
#source_image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The customer-supplied encryption key of the source image.
-
#source_image_id ⇒ String
Output only.
-
#source_snapshot ⇒ String
URL of the source snapshot used to create this image.
-
#source_snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The customer-supplied encryption key of the source snapshot.
-
#source_snapshot_id ⇒ String
Output only.
-
#source_type ⇒ String
The type of the image used to create this disk.
-
#status ⇒ String
Output only.
-
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the image (regional or multi-regional).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Image
constructor
A new instance of Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Image
Returns a new instance of Image.
18382 18383 18384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
The architecture of the image. Valid values are
ARM64 or X86_64.
Corresponds to the JSON property architecture
18108 18109 18110 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18108 def architecture @architecture end |
#archive_size_bytes ⇒ Fixnum
Size of the image tar.gz archive stored in Google Cloud
Storage (in bytes).
Corresponds to the JSON property archiveSizeBytes
18114 18115 18116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18114 def archive_size_bytes @archive_size_bytes end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
18120 18121 18122 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18120 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
18125 18126 18127 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18125 def deprecated @deprecated end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
18131 18132 18133 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18131 def description @description end |
#disk_size_gb ⇒ Fixnum
Size of the image when restored onto a persistent disk (in GB).
Corresponds to the JSON property diskSizeGb
18136 18137 18138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18136 def disk_size_gb @disk_size_gb end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Output only. Whether this image is created from a confidential compute mode
disk.
[Output Only]: This field is not set by user, but from source disk.
Corresponds to the JSON property enableConfidentialCompute
18143 18144 18145 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18143 def enable_confidential_compute @enable_confidential_compute end |
#family ⇒ String
The name of the image family to which this image belongs. The image
family name can be from a publicly managed image family provided by
Compute Engine, or from a custom image family you create. For example,centos-
stream-9 is a publicly available image family.
For more information, see Image
family best practices.
When creating disks, you can specify an image family instead of a specific
image name. The image family always returns its latest image that is not
deprecated. The name of the image family must comply with RFC1035.
Corresponds to the JSON property family
18157 18158 18159 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18157 def family @family end |
#guest_os_features ⇒ Array<Google::Apis::ComputeV1::GuestOsFeature>
A list of features to enable on the guest operating system. Applicable
only for bootable images. To see a list of available options, see
theguestOSfeatures[].type parameter.
Corresponds to the JSON property guestOsFeatures
18164 18165 18166 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18164 def guest_os_features @guest_os_features end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
18171 18172 18173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18171 def id @id end |
#image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Encrypts the image using acustomer-supplied
encryption key.
After you encrypt an image with a customer-supplied key, you must provide
the same key if you use the image later (e.g. to create a disk from
the image).
Customer-supplied encryption keys do not protect access to metadata
of the disk.
If you do not provide an encryption key when creating the image, then the
disk will be encrypted using an automatically generated key and you do not
need to provide a key to use the image later.
Corresponds to the JSON property imageEncryptionKey
18185 18186 18187 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18185 def image_encryption_key @image_encryption_key end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#image for
images.
Corresponds to the JSON property kind
18191 18192 18193 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18191 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this image, which is
essentially a hash of the labels used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an image.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
18204 18205 18206 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18204 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this image. These can be later modified by
the setLabels method.
Corresponds to the JSON property labels
18210 18211 18212 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18210 def labels @labels end |
#license_codes ⇒ Array<Fixnum>
Integer license codes indicating which licenses are attached to this image.
Corresponds to the JSON property licenseCodes
18215 18216 18217 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18215 def license_codes @license_codes end |
#licenses ⇒ Array<String>
Any applicable license URI.
Corresponds to the JSON property licenses
18220 18221 18222 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18220 def licenses @licenses end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
18231 18232 18233 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18231 def name @name end |
#params ⇒ Google::Apis::ComputeV1::ImageParams
Additional image params.
Corresponds to the JSON property params
18236 18237 18238 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18236 def params @params end |
#raw_disk ⇒ Google::Apis::ComputeV1::Image::RawDisk
The parameters of the raw disk image.
Corresponds to the JSON property rawDisk
18241 18242 18243 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18241 def raw_disk @raw_disk end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
18246 18247 18248 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18246 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
18252 18253 18254 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18252 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
18258 18259 18260 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18258 def self_link @self_link end |
#shielded_instance_initial_state ⇒ Google::Apis::ComputeV1::InitialStateConfig
Initial State for shielded instance,
these are public keys which are safe to store in public
Corresponds to the JSON property shieldedInstanceInitialState
18264 18265 18266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18264 def shielded_instance_initial_state @shielded_instance_initial_state end |
#source_disk ⇒ String
URL of the source disk used to create this image. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
- projects/project/zones/zone/disks/disk
zones/zone/disks/disk In order to create an image, you must provide the full or partial URL of one of the following:
The rawDisk.source URL
The sourceDisk URL
The sourceImage URL
The sourceSnapshot URL Corresponds to the JSON property
sourceDisk
18282 18283 18284 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18282 def source_disk @source_disk end |
#source_disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Thecustomer-supplied
encryption key of the source disk. Required if the source disk is
protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceDiskEncryptionKey
18289 18290 18291 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18289 def source_disk_encryption_key @source_disk_encryption_key end |
#source_disk_id ⇒ String
Output only. [Output Only]
The ID value of the disk used to create this image. This value may be used
to determine whether the image was taken from the current or a previous
instance of a given disk name.
Corresponds to the JSON property sourceDiskId
18297 18298 18299 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18297 def source_disk_id @source_disk_id end |
#source_image ⇒ String
URL of the source image used to create this image. The following are valid formats for the URL:
- https://www.googleapis.com/compute/v1/projects/project_id/global/ images/image_name
projects/project_id/global/images/image_name In order to create an image, you must provide the full or partial URL of one of the following:
The rawDisk.source URL
The sourceDisk URL
The sourceImage URL
The sourceSnapshot URL Corresponds to the JSON property
sourceImage
18314 18315 18316 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18314 def source_image @source_image end |
#source_image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The customer-supplied encryption key of the source image. Required if the
source image is protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceImageEncryptionKey
18320 18321 18322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18320 def source_image_encryption_key @source_image_encryption_key end |
#source_image_id ⇒ String
Output only. [Output Only]
The ID value of the image used to create this image. This value may be used
to determine whether the image was taken from the current or a previous
instance of a given image name.
Corresponds to the JSON property sourceImageId
18328 18329 18330 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18328 def source_image_id @source_image_id end |
#source_snapshot ⇒ String
URL of the source snapshot used to create this image. The following are valid formats for the URL:
- https://www.googleapis.com/compute/v1/projects/project_id/global/ snapshots/snapshot_name
projects/project_id/global/snapshots/snapshot_name In order to create an image, you must provide the full or partial URL of one of the following:
The rawDisk.source URL
The sourceDisk URL
The sourceImage URL
The sourceSnapshot URL Corresponds to the JSON property
sourceSnapshot
18345 18346 18347 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18345 def source_snapshot @source_snapshot end |
#source_snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The customer-supplied encryption key of the source snapshot. Required if
the source snapshot is protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceSnapshotEncryptionKey
18351 18352 18353 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18351 def source_snapshot_encryption_key @source_snapshot_encryption_key end |
#source_snapshot_id ⇒ String
Output only. [Output Only]
The ID value of the snapshot used to create this image. This value may be
used to determine whether the snapshot was taken from the current or a
previous instance of a given snapshot name.
Corresponds to the JSON property sourceSnapshotId
18359 18360 18361 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18359 def source_snapshot_id @source_snapshot_id end |
#source_type ⇒ String
The type of the image used to create this disk. The
default and only valid value is RAW.
Corresponds to the JSON property sourceType
18365 18366 18367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18365 def source_type @source_type end |
#status ⇒ String
Output only. [Output Only] The status of the image. An image can be used to
create other
resources, such as instances, only after the image has been successfully
created and the status is set to READY. Possible
values are FAILED, PENDING, orREADY.
Corresponds to the JSON property status
18374 18375 18376 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18374 def status @status end |
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the image (regional or
multi-regional).
Corresponds to the JSON property storageLocations
18380 18381 18382 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18380 def storage_locations @storage_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18387 18388 18389 18390 18391 18392 18393 18394 18395 18396 18397 18398 18399 18400 18401 18402 18403 18404 18405 18406 18407 18408 18409 18410 18411 18412 18413 18414 18415 18416 18417 18418 18419 18420 18421 18422 18423 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18387 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @archive_size_bytes = args[:archive_size_bytes] if args.key?(:archive_size_bytes) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) @family = args[:family] if args.key?(:family) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @id = args[:id] if args.key?(:id) @image_encryption_key = args[:image_encryption_key] if args.key?(:image_encryption_key) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @license_codes = args[:license_codes] if args.key?(:license_codes) @licenses = args[:licenses] if args.key?(:licenses) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @raw_disk = args[:raw_disk] if args.key?(:raw_disk) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @shielded_instance_initial_state = args[:shielded_instance_initial_state] if args.key?(:shielded_instance_initial_state) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @source_image = args[:source_image] if args.key?(:source_image) @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key) @source_image_id = args[:source_image_id] if args.key?(:source_image_id) @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot) @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key) @source_snapshot_id = args[:source_snapshot_id] if args.key?(:source_snapshot_id) @source_type = args[:source_type] if args.key?(:source_type) @status = args[:status] if args.key?(:status) @storage_locations = args[:storage_locations] if args.key?(:storage_locations) end |