Class: Google::Apis::ComputeV1::Image

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an Image resource. You can use images to create boot disks for your VM instances. For more information, read Images.

Defined Under Namespace

Classes: RawDisk

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Image

Returns a new instance of Image.



11931
11932
11933
# File 'lib/google/apis/compute_v1/classes.rb', line 11931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_size_bytesFixnum

Size of the image tar.gz archive stored in Google Cloud Storage (in bytes). Corresponds to the JSON property archiveSizeBytes

Returns:

  • (Fixnum)


11722
11723
11724
# File 'lib/google/apis/compute_v1/classes.rb', line 11722

def archive_size_bytes
  @archive_size_bytes
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


11727
11728
11729
# File 'lib/google/apis/compute_v1/classes.rb', line 11727

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeV1::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



11732
11733
11734
# File 'lib/google/apis/compute_v1/classes.rb', line 11732

def deprecated
  @deprecated
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


11738
11739
11740
# File 'lib/google/apis/compute_v1/classes.rb', line 11738

def description
  @description
end

#disk_size_gbFixnum

Size of the image when restored onto a persistent disk (in GB). Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


11743
11744
11745
# File 'lib/google/apis/compute_v1/classes.rb', line 11743

def disk_size_gb
  @disk_size_gb
end

#familyString

The name of the image family to which this image belongs. You can create disks by specifying an image family instead of a specific image name. The image family always returns its latest image that is not deprecated. The name of the image family must comply with RFC1035. Corresponds to the JSON property family

Returns:

  • (String)


11751
11752
11753
# File 'lib/google/apis/compute_v1/classes.rb', line 11751

def family
  @family
end

#guest_os_featuresArray<Google::Apis::ComputeV1::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. To see a list of available options, see the guestOSfeatures[].type parameter. Corresponds to the JSON property guestOsFeatures



11758
11759
11760
# File 'lib/google/apis/compute_v1/classes.rb', line 11758

def guest_os_features
  @guest_os_features
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


11764
11765
11766
# File 'lib/google/apis/compute_v1/classes.rb', line 11764

def id
  @id
end

#image_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Encrypts the image using a customer-supplied encryption key. After you encrypt an image with a customer-supplied key, you must provide the same key if you use the image later (e.g. to create a disk from the image). Customer-supplied encryption keys do not protect access to metadata of the disk. If you do not provide an encryption key when creating the image, then the disk will be encrypted using an automatically generated key and you do not need to provide a key to use the image later. Corresponds to the JSON property imageEncryptionKey



11775
11776
11777
# File 'lib/google/apis/compute_v1/classes.rb', line 11775

def image_encryption_key
  @image_encryption_key
end

#kindString

[Output Only] Type of the resource. Always compute#image for images. Corresponds to the JSON property kind

Returns:

  • (String)


11780
11781
11782
# File 'lib/google/apis/compute_v1/classes.rb', line 11780

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this image, which is essentially a hash of the labels used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an image. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


11792
11793
11794
# File 'lib/google/apis/compute_v1/classes.rb', line 11792

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this image. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11798
11799
11800
# File 'lib/google/apis/compute_v1/classes.rb', line 11798

def labels
  @labels
end

#license_codesArray<Fixnum>

Integer license codes indicating which licenses are attached to this image. Corresponds to the JSON property licenseCodes

Returns:

  • (Array<Fixnum>)


11803
11804
11805
# File 'lib/google/apis/compute_v1/classes.rb', line 11803

def license_codes
  @license_codes
end

#licensesArray<String>

Any applicable license URI. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


11808
11809
11810
# File 'lib/google/apis/compute_v1/classes.rb', line 11808

def licenses
  @licenses
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


11818
11819
11820
# File 'lib/google/apis/compute_v1/classes.rb', line 11818

def name
  @name
end

#raw_diskGoogle::Apis::ComputeV1::Image::RawDisk

The parameters of the raw disk image. Corresponds to the JSON property rawDisk



11823
11824
11825
# File 'lib/google/apis/compute_v1/classes.rb', line 11823

def raw_disk
  @raw_disk
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

[Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


11828
11829
11830
# File 'lib/google/apis/compute_v1/classes.rb', line 11828

def satisfies_pzs
  @satisfies_pzs
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11834
11835
11836
# File 'lib/google/apis/compute_v1/classes.rb', line 11834

def self_link
  @self_link
end

#shielded_instance_initial_stateGoogle::Apis::ComputeV1::InitialStateConfig

Initial State for shielded instance, these are public keys which are safe to store in public Corresponds to the JSON property shieldedInstanceInitialState



11840
11841
11842
# File 'lib/google/apis/compute_v1/classes.rb', line 11840

def shielded_instance_initial_state
  @shielded_instance_initial_state
end

#source_diskString

URL of the source disk used to create this image. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/ zones/zone /disks/disk - projects/project/zones/zone/disks/disk - zones/zone/ disks/disk In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL Corresponds to the JSON property sourceDisk

Returns:

  • (String)


11850
11851
11852
# File 'lib/google/apis/compute_v1/classes.rb', line 11850

def source_disk
  @source_disk
end

#source_disk_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceDiskEncryptionKey



11856
11857
11858
# File 'lib/google/apis/compute_v1/classes.rb', line 11856

def source_disk_encryption_key
  @source_disk_encryption_key
end

#source_disk_idString

[Output Only] The ID value of the disk used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given disk name. Corresponds to the JSON property sourceDiskId

Returns:

  • (String)


11863
11864
11865
# File 'lib/google/apis/compute_v1/classes.rb', line 11863

def source_disk_id
  @source_disk_id
end

#source_imageString

URL of the source image used to create this image. The following are valid formats for the URL: - https://www.googleapis.com/compute/v1/projects/ project_id/global/ images/image_name - projects/project_id/global/images/ image_name In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL Corresponds to the JSON property sourceImage

Returns:

  • (String)


11873
11874
11875
# File 'lib/google/apis/compute_v1/classes.rb', line 11873

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The customer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceImageEncryptionKey



11879
11880
11881
# File 'lib/google/apis/compute_v1/classes.rb', line 11879

def source_image_encryption_key
  @source_image_encryption_key
end

#source_image_idString

[Output Only] The ID value of the image used to create this image. This value may be used to determine whether the image was taken from the current or a previous instance of a given image name. Corresponds to the JSON property sourceImageId

Returns:

  • (String)


11886
11887
11888
# File 'lib/google/apis/compute_v1/classes.rb', line 11886

def source_image_id
  @source_image_id
end

#source_snapshotString

URL of the source snapshot used to create this image. The following are valid formats for the URL: - https://www.googleapis.com/compute/v1/projects/ project_id/global/ snapshots/snapshot_name - projects/project_id/global/ snapshots/snapshot_name In order to create an image, you must provide the full or partial URL of one of the following: - The rawDisk.source URL - The sourceDisk URL - The sourceImage URL - The sourceSnapshot URL Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


11896
11897
11898
# File 'lib/google/apis/compute_v1/classes.rb', line 11896

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The customer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceSnapshotEncryptionKey



11902
11903
11904
# File 'lib/google/apis/compute_v1/classes.rb', line 11902

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

#source_snapshot_idString

[Output Only] The ID value of the snapshot used to create this image. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given snapshot name. Corresponds to the JSON property sourceSnapshotId

Returns:

  • (String)


11909
11910
11911
# File 'lib/google/apis/compute_v1/classes.rb', line 11909

def source_snapshot_id
  @source_snapshot_id
end

#source_typeString

The type of the image used to create this disk. The default and only value is RAW Corresponds to the JSON property sourceType

Returns:

  • (String)


11915
11916
11917
# File 'lib/google/apis/compute_v1/classes.rb', line 11915

def source_type
  @source_type
end

#statusString

[Output Only] The status of the image. An image can be used to create other resources, such as instances, only after the image has been successfully created and the status is set to READY. Possible values are FAILED, PENDING, or READY. Corresponds to the JSON property status

Returns:

  • (String)


11923
11924
11925
# File 'lib/google/apis/compute_v1/classes.rb', line 11923

def status
  @status
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the image (regional or multi-regional) . Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


11929
11930
11931
# File 'lib/google/apis/compute_v1/classes.rb', line 11929

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11936
11937
11938
11939
11940
11941
11942
11943
11944
11945
11946
11947
11948
11949
11950
11951
11952
11953
11954
11955
11956
11957
11958
11959
11960
11961
11962
11963
11964
11965
11966
11967
11968
# File 'lib/google/apis/compute_v1/classes.rb', line 11936

def update!(**args)
  @archive_size_bytes = args[:archive_size_bytes] if args.key?(:archive_size_bytes)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @family = args[:family] if args.key?(:family)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @id = args[:id] if args.key?(:id)
  @image_encryption_key = args[:image_encryption_key] if args.key?(:image_encryption_key)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @license_codes = args[:license_codes] if args.key?(:license_codes)
  @licenses = args[:licenses] if args.key?(:licenses)
  @name = args[:name] if args.key?(:name)
  @raw_disk = args[:raw_disk] if args.key?(:raw_disk)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @shielded_instance_initial_state = args[:shielded_instance_initial_state] if args.key?(:shielded_instance_initial_state)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key)
  @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_image_id = args[:source_image_id] if args.key?(:source_image_id)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
  @source_snapshot_id = args[:source_snapshot_id] if args.key?(:source_snapshot_id)
  @source_type = args[:source_type] if args.key?(:source_type)
  @status = args[:status] if args.key?(:status)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end