Class: Google::Apis::ComputeV1::Image::RawDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The parameters of the raw disk image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RawDisk

Returns a new instance of RawDisk.



21258
21259
21260
# File 'lib/google/apis/compute_v1/classes.rb', line 21258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_typeString

The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created. Corresponds to the JSON property containerType

Returns:

  • (String)


21228
21229
21230
# File 'lib/google/apis/compute_v1/classes.rb', line 21228

def container_type
  @container_type
end

#sha1_checksumString

[Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created. Corresponds to the JSON property sha1Checksum

Returns:

  • (String)


21235
21236
21237
# File 'lib/google/apis/compute_v1/classes.rb', line 21235

def sha1_checksum
  @sha1_checksum
end

#sourceString

The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:

Returns:

  • (String)


21256
21257
21258
# File 'lib/google/apis/compute_v1/classes.rb', line 21256

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21263
21264
21265
21266
21267
# File 'lib/google/apis/compute_v1/classes.rb', line 21263

def update!(**args)
  @container_type = args[:container_type] if args.key?(:container_type)
  @sha1_checksum = args[:sha1_checksum] if args.key?(:sha1_checksum)
  @source = args[:source] if args.key?(:source)
end