Class: Google::Apis::ComputeV1::Image::RawDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The parameters of the raw disk image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RawDisk

Returns a new instance of RawDisk.



18460
18461
18462
# File 'lib/google/apis/compute_v1/classes.rb', line 18460

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_typeString

The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created. Corresponds to the JSON property containerType

Returns:

  • (String)


18434
18435
18436
# File 'lib/google/apis/compute_v1/classes.rb', line 18434

def container_type
  @container_type
end

#sha1_checksumString

[Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created. Corresponds to the JSON property sha1Checksum

Returns:

  • (String)


18441
18442
18443
# File 'lib/google/apis/compute_v1/classes.rb', line 18441

def sha1_checksum
  @sha1_checksum
end

#sourceString

The full Google Cloud Storage URL where the raw disk image archive is stored. The following are valid formats for the URL:

Returns:

  • (String)


18458
18459
18460
# File 'lib/google/apis/compute_v1/classes.rb', line 18458

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18465
18466
18467
18468
18469
# File 'lib/google/apis/compute_v1/classes.rb', line 18465

def update!(**args)
  @container_type = args[:container_type] if args.key?(:container_type)
  @sha1_checksum = args[:sha1_checksum] if args.key?(:sha1_checksum)
  @source = args[:source] if args.key?(:source)
end