Class: Google::Apis::ComputeV1::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



21683
21684
21685
# File 'lib/google/apis/compute_v1/classes.rb', line 21683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21651
21652
21653
# File 'lib/google/apis/compute_v1/classes.rb', line 21651

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Image>

A list of Image resources. Corresponds to the JSON property items

Returns:



21656
21657
21658
# File 'lib/google/apis/compute_v1/classes.rb', line 21656

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21661
21662
21663
# File 'lib/google/apis/compute_v1/classes.rb', line 21661

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21671
21672
21673
# File 'lib/google/apis/compute_v1/classes.rb', line 21671

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21676
21677
21678
# File 'lib/google/apis/compute_v1/classes.rb', line 21676

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21681
21682
21683
# File 'lib/google/apis/compute_v1/classes.rb', line 21681

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21688
21689
21690
21691
21692
21693
21694
21695
# File 'lib/google/apis/compute_v1/classes.rb', line 21688

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end