Class: Google::Apis::ComputeV1::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Image>
A list of Image resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageList
Returns a new instance of ImageList.
21168 21169 21170 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21136 21137 21138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21136 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Image>
A list of Image resources.
Corresponds to the JSON property items
21141 21142 21143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21141 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
21146 21147 21148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21146 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21156 21157 21158 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21156 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21161 21162 21163 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21161 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21166 21167 21168 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21166 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21173 21174 21175 21176 21177 21178 21179 21180 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21173 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |