Class: Google::Apis::ComputeV1::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



21160
21161
21162
# File 'lib/google/apis/compute_v1/classes.rb', line 21160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21128
21129
21130
# File 'lib/google/apis/compute_v1/classes.rb', line 21128

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Image>

A list of Image resources. Corresponds to the JSON property items

Returns:



21133
21134
21135
# File 'lib/google/apis/compute_v1/classes.rb', line 21133

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21138
21139
21140
# File 'lib/google/apis/compute_v1/classes.rb', line 21138

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21148
21149
21150
# File 'lib/google/apis/compute_v1/classes.rb', line 21148

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21153
21154
21155
# File 'lib/google/apis/compute_v1/classes.rb', line 21153

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21158
21159
21160
# File 'lib/google/apis/compute_v1/classes.rb', line 21158

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21165
21166
21167
21168
21169
21170
21171
21172
# File 'lib/google/apis/compute_v1/classes.rb', line 21165

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end