Class: Google::Apis::ComputeV1::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



18533
18534
18535
# File 'lib/google/apis/compute_v1/classes.rb', line 18533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18501
18502
18503
# File 'lib/google/apis/compute_v1/classes.rb', line 18501

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Image>

A list of Image resources. Corresponds to the JSON property items

Returns:



18506
18507
18508
# File 'lib/google/apis/compute_v1/classes.rb', line 18506

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18511
18512
18513
# File 'lib/google/apis/compute_v1/classes.rb', line 18511

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18521
18522
18523
# File 'lib/google/apis/compute_v1/classes.rb', line 18521

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18526
18527
18528
# File 'lib/google/apis/compute_v1/classes.rb', line 18526

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18531
18532
18533
# File 'lib/google/apis/compute_v1/classes.rb', line 18531

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18538
18539
18540
18541
18542
18543
18544
18545
# File 'lib/google/apis/compute_v1/classes.rb', line 18538

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end