Class: Google::Apis::ComputeV1::ImageParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ImageParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Additional image params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageParams
constructor
A new instance of ImageParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageParams
Returns a new instance of ImageParams.
20754 20755 20756 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20754 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the image. Tag keys and
values have
the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/456` or in namespaced
format such asorg_id|project_id/tag_key_short_nameand
tag_value_short_name`. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON propertyresourceManagerTags`
20752 20753 20754 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20752 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20759 20760 20761 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20759 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |