Class: Google::Apis::ComputeV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, readVirtual Machine Instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



18399
18400
18401
# File 'lib/google/apis/compute_v1/classes.rb', line 18399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeV1::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



18085
18086
18087
# File 'lib/google/apis/compute_v1/classes.rb', line 18085

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Allows this instance to send and receive packets with non-matching destination or source IPs. This is required if you plan to use this instance to forward routes. For more information, seeEnabling IP Forwarding. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


18092
18093
18094
# File 'lib/google/apis/compute_v1/classes.rb', line 18092

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeV1::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



18098
18099
18100
# File 'lib/google/apis/compute_v1/classes.rb', line 18098

def confidential_instance_config
  @confidential_instance_config
end

#cpu_platformString

Output only. [Output Only] The CPU platform used by this instance. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


18103
18104
18105
# File 'lib/google/apis/compute_v1/classes.rb', line 18103

def cpu_platform
  @cpu_platform
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


18108
18109
18110
# File 'lib/google/apis/compute_v1/classes.rb', line 18108

def creation_timestamp
  @creation_timestamp
end

#deletion_protectionBoolean Also known as: deletion_protection?

Whether the resource should be protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


18113
18114
18115
# File 'lib/google/apis/compute_v1/classes.rb', line 18113

def deletion_protection
  @deletion_protection
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


18120
18121
18122
# File 'lib/google/apis/compute_v1/classes.rb', line 18120

def description
  @description
end

#disksArray<Google::Apis::ComputeV1::AttachedDisk>

Array of disks associated with this instance. Persistent disks must be created before you can assign them. Corresponds to the JSON property disks



18126
18127
18128
# File 'lib/google/apis/compute_v1/classes.rb', line 18126

def disks
  @disks
end

#display_deviceGoogle::Apis::ComputeV1::DisplayDevice

A set of Display Device options Corresponds to the JSON property displayDevice



18131
18132
18133
# File 'lib/google/apis/compute_v1/classes.rb', line 18131

def display_device
  @display_device
end

#fingerprintString

Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance. You must always provide an up-to-date fingerprint hash in order to update the instance. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


18143
18144
18145
# File 'lib/google/apis/compute_v1/classes.rb', line 18143

def fingerprint
  @fingerprint
end

#guest_acceleratorsArray<Google::Apis::ComputeV1::AcceleratorConfig>

A list of the type and count of accelerator cards attached to the instance. Corresponds to the JSON property guestAccelerators



18148
18149
18150
# File 'lib/google/apis/compute_v1/classes.rb', line 18148

def guest_accelerators
  @guest_accelerators
end

#hostnameString

Specifies the hostname of the instance. The specified hostname must be RFC1035 compliant. If hostname is not specified, the default hostname is [INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and [INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS. Corresponds to the JSON property hostname

Returns:

  • (String)


18156
18157
18158
# File 'lib/google/apis/compute_v1/classes.rb', line 18156

def hostname
  @hostname
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


18163
18164
18165
# File 'lib/google/apis/compute_v1/classes.rb', line 18163

def id
  @id
end

#instance_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Encrypts suspended data for an instance with acustomer-managed encryption key. If you are creating a new instance, this field will encrypt the local SSD and in-memory contents of the instance during the suspend operation. If you do not provide an encryption key when creating the instance, then the local SSD and in-memory contents will be encrypted using an automatically generated key during the suspend operation. Corresponds to the JSON property instanceEncryptionKey



18174
18175
18176
# File 'lib/google/apis/compute_v1/classes.rb', line 18174

def instance_encryption_key
  @instance_encryption_key
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


18180
18181
18182
# File 'lib/google/apis/compute_v1/classes.rb', line 18180

def key_revocation_action_type
  @key_revocation_action_type
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#instance for instances. Corresponds to the JSON property kind

Returns:

  • (String)


18186
18187
18188
# File 'lib/google/apis/compute_v1/classes.rb', line 18186

def kind
  @kind
end

#label_fingerprintString

A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


18198
18199
18200
# File 'lib/google/apis/compute_v1/classes.rb', line 18198

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this instance. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


18204
18205
18206
# File 'lib/google/apis/compute_v1/classes.rb', line 18204

def labels
  @labels
end

#last_start_timestampString

Output only. [Output Only] Last start timestamp inRFC3339 text format. Corresponds to the JSON property lastStartTimestamp

Returns:

  • (String)


18209
18210
18211
# File 'lib/google/apis/compute_v1/classes.rb', line 18209

def last_start_timestamp
  @last_start_timestamp
end

#last_stop_timestampString

Output only. [Output Only] Last stop timestamp inRFC3339 text format. Corresponds to the JSON property lastStopTimestamp

Returns:

  • (String)


18214
18215
18216
# File 'lib/google/apis/compute_v1/classes.rb', line 18214

def last_stop_timestamp
  @last_stop_timestamp
end

#last_suspended_timestampString

Output only. [Output Only] Last suspended timestamp inRFC3339 text format. Corresponds to the JSON property lastSuspendedTimestamp

Returns:

  • (String)


18219
18220
18221
# File 'lib/google/apis/compute_v1/classes.rb', line 18219

def last_suspended_timestamp
  @last_suspended_timestamp
end

#machine_typeString

Full or partial URL of the machine type resource to use for this instance, in the format:zones/zone/machineTypes/machine-type. This is provided by the client when the instance is created. For example, the following is a valid partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-standard-1 To create acustom machine type, provide a URL to a machine type in the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the total memory for this instance. Memory must be a multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB): zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/machineTypes/custom-4-5120 For a full list of restrictions, read theSpecifications for custom machine types. Corresponds to the JSON property machineType

Returns:

  • (String)


18240
18241
18242
# File 'lib/google/apis/compute_v1/classes.rb', line 18240

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



18245
18246
18247
# File 'lib/google/apis/compute_v1/classes.rb', line 18245

def 
  @metadata
end

#min_cpu_platformString

Specifies aminimum CPU platform for the VM instance. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge". Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


18254
18255
18256
# File 'lib/google/apis/compute_v1/classes.rb', line 18254

def min_cpu_platform
  @min_cpu_platform
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


18266
18267
18268
# File 'lib/google/apis/compute_v1/classes.rb', line 18266

def name
  @name
end

#network_interfacesArray<Google::Apis::ComputeV1::NetworkInterface>

An array of network configurations for this instance. These specify how interfaces are configured to interact with other network services, such as connecting to the internet. Multiple interfaces are supported per instance. Corresponds to the JSON property networkInterfaces



18274
18275
18276
# File 'lib/google/apis/compute_v1/classes.rb', line 18274

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeV1::NetworkPerformanceConfig

Corresponds to the JSON property networkPerformanceConfig



18279
18280
18281
# File 'lib/google/apis/compute_v1/classes.rb', line 18279

def network_performance_config
  @network_performance_config
end

#paramsGoogle::Apis::ComputeV1::InstanceParams

Additional instance params. Corresponds to the JSON property params



18284
18285
18286
# File 'lib/google/apis/compute_v1/classes.rb', line 18284

def params
  @params
end

#private_ipv6_google_accessString

The private IPv6 google access type for the VM. If not specified, use INHERIT_FROM_SUBNETWORK as default. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


18290
18291
18292
# File 'lib/google/apis/compute_v1/classes.rb', line 18290

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeV1::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



18295
18296
18297
# File 'lib/google/apis/compute_v1/classes.rb', line 18295

def reservation_affinity
  @reservation_affinity
end

#resource_policiesArray<String>

Resource policies applied to this instance. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


18300
18301
18302
# File 'lib/google/apis/compute_v1/classes.rb', line 18300

def resource_policies
  @resource_policies
end

#resource_statusGoogle::Apis::ComputeV1::ResourceStatus

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls. Corresponds to the JSON property resourceStatus



18307
18308
18309
# File 'lib/google/apis/compute_v1/classes.rb', line 18307

def resource_status
  @resource_status
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


18312
18313
18314
# File 'lib/google/apis/compute_v1/classes.rb', line 18312

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


18318
18319
18320
# File 'lib/google/apis/compute_v1/classes.rb', line 18318

def satisfies_pzs
  @satisfies_pzs
end

#schedulingGoogle::Apis::ComputeV1::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



18324
18325
18326
# File 'lib/google/apis/compute_v1/classes.rb', line 18324

def scheduling
  @scheduling
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18329
18330
18331
# File 'lib/google/apis/compute_v1/classes.rb', line 18329

def self_link
  @self_link
end

#service_accountsArray<Google::Apis::ComputeV1::ServiceAccount>

A list of service accounts, with their specified scopes, authorized for this instance. Only one service account per VM instance is supported. Service accounts generate access tokens that can be accessed through the metadata server and used to authenticate applications on the instance. SeeService Accounts for more information. Corresponds to the JSON property serviceAccounts



18339
18340
18341
# File 'lib/google/apis/compute_v1/classes.rb', line 18339

def service_accounts
  @service_accounts
end

#shielded_instance_configGoogle::Apis::ComputeV1::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



18344
18345
18346
# File 'lib/google/apis/compute_v1/classes.rb', line 18344

def shielded_instance_config
  @shielded_instance_config
end

#shielded_instance_integrity_policyGoogle::Apis::ComputeV1::ShieldedInstanceIntegrityPolicy

The policy describes the baseline against which Instance boot integrity is measured. Corresponds to the JSON property shieldedInstanceIntegrityPolicy



18350
18351
18352
# File 'lib/google/apis/compute_v1/classes.rb', line 18350

def shielded_instance_integrity_policy
  @shielded_instance_integrity_policy
end

#source_machine_imageString

Source machine image Corresponds to the JSON property sourceMachineImage

Returns:

  • (String)


18355
18356
18357
# File 'lib/google/apis/compute_v1/classes.rb', line 18355

def source_machine_image
  @source_machine_image
end

#source_machine_image_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Source machine image encryption key when creating an instance from a machine image. Corresponds to the JSON property sourceMachineImageEncryptionKey



18361
18362
18363
# File 'lib/google/apis/compute_v1/classes.rb', line 18361

def source_machine_image_encryption_key
  @source_machine_image_encryption_key
end

#start_restrictedBoolean Also known as: start_restricted?

Output only. [Output Only] Whether a VM has been restricted for start because Compute Engine has detected suspicious activity. Corresponds to the JSON property startRestricted

Returns:

  • (Boolean)


18368
18369
18370
# File 'lib/google/apis/compute_v1/classes.rb', line 18368

def start_restricted
  @start_restricted
end

#statusString

Output only. [Output Only] The status of the instance. One of the following values: PROVISIONING, STAGING,RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING, andTERMINATED. For more information about the status of the instance, see Instance life cycle. Corresponds to the JSON property status

Returns:

  • (String)


18379
18380
18381
# File 'lib/google/apis/compute_v1/classes.rb', line 18379

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


18385
18386
18387
# File 'lib/google/apis/compute_v1/classes.rb', line 18385

def status_message
  @status_message
end

#tagsGoogle::Apis::ComputeV1::Tags

A set of instance tags. Corresponds to the JSON property tags



18390
18391
18392
# File 'lib/google/apis/compute_v1/classes.rb', line 18390

def tags
  @tags
end

#zoneString

Output only. [Output Only] URL of the zone where the instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


18397
18398
18399
# File 'lib/google/apis/compute_v1/classes.rb', line 18397

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
18432
18433
18434
18435
18436
18437
18438
18439
18440
18441
18442
18443
18444
18445
18446
18447
18448
18449
18450
18451
# File 'lib/google/apis/compute_v1/classes.rb', line 18404

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @display_device = args[:display_device] if args.key?(:display_device)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @hostname = args[:hostname] if args.key?(:hostname)
  @id = args[:id] if args.key?(:id)
  @instance_encryption_key = args[:instance_encryption_key] if args.key?(:instance_encryption_key)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @last_start_timestamp = args[:last_start_timestamp] if args.key?(:last_start_timestamp)
  @last_stop_timestamp = args[:last_stop_timestamp] if args.key?(:last_stop_timestamp)
  @last_suspended_timestamp = args[:last_suspended_timestamp] if args.key?(:last_suspended_timestamp)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @name = args[:name] if args.key?(:name)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @params = args[:params] if args.key?(:params)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @shielded_instance_integrity_policy = args[:shielded_instance_integrity_policy] if args.key?(:shielded_instance_integrity_policy)
  @source_machine_image = args[:source_machine_image] if args.key?(:source_machine_image)
  @source_machine_image_encryption_key = args[:source_machine_image_encryption_key] if args.key?(:source_machine_image_encryption_key)
  @start_restricted = args[:start_restricted] if args.key?(:start_restricted)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @tags = args[:tags] if args.key?(:tags)
  @zone = args[:zone] if args.key?(:zone)
end