Class: Google::Apis::ComputeV1::Instance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Instance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, read Virtual Machine Instances.
Instance Attribute Summary collapse
-
#advanced_machine_features ⇒ Google::Apis::ComputeV1::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
-
#can_ip_forward ⇒ Boolean
(also: #can_ip_forward?)
Allows this instance to send and receive packets with non-matching destination or source IPs.
-
#confidential_instance_config ⇒ Google::Apis::ComputeV1::ConfidentialInstanceConfig
A set of Confidential Instance options.
-
#cpu_platform ⇒ String
[Output Only] The CPU platform used by this instance.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#deletion_protection ⇒ Boolean
(also: #deletion_protection?)
Whether the resource should be protected against deletion.
-
#description ⇒ String
An optional description of this resource.
-
#disks ⇒ Array<Google::Apis::ComputeV1::AttachedDisk>
Array of disks associated with this instance.
-
#display_device ⇒ Google::Apis::ComputeV1::DisplayDevice
A set of Display Device options Corresponds to the JSON property
displayDevice. -
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking.
-
#guest_accelerators ⇒ Array<Google::Apis::ComputeV1::AcceleratorConfig>
A list of the type and count of accelerator cards attached to the instance.
-
#hostname ⇒ String
Specifies the hostname of the instance.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#label_fingerprint ⇒ String
A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this instance.
-
#last_start_timestamp ⇒ String
[Output Only] Last start timestamp in RFC3339 text format.
-
#last_stop_timestamp ⇒ String
[Output Only] Last stop timestamp in RFC3339 text format.
-
#last_suspended_timestamp ⇒ String
[Output Only] Last suspended timestamp in RFC3339 text format.
-
#machine_type ⇒ String
Full or partial URL of the machine type resource to use for this instance, in the format: zones/zone/machineTypes/machine-type.
-
#metadata ⇒ Google::Apis::ComputeV1::Metadata
A metadata key/value entry.
-
#min_cpu_platform ⇒ String
Specifies a minimum CPU platform for the VM instance.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#network_interfaces ⇒ Array<Google::Apis::ComputeV1::NetworkInterface>
An array of network configurations for this instance.
-
#network_performance_config ⇒ Google::Apis::ComputeV1::NetworkPerformanceConfig
Corresponds to the JSON property
networkPerformanceConfig. -
#params ⇒ Google::Apis::ComputeV1::InstanceParams
Additional instance params.
-
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for the VM.
-
#reservation_affinity ⇒ Google::Apis::ComputeV1::ReservationAffinity
Specifies the reservations that this instance can consume from.
-
#resource_policies ⇒ Array<String>
Resource policies applied to this instance.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
[Output Only] Reserved for future use.
-
#scheduling ⇒ Google::Apis::ComputeV1::Scheduling
Sets the scheduling options for an Instance.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#service_accounts ⇒ Array<Google::Apis::ComputeV1::ServiceAccount>
A list of service accounts, with their specified scopes, authorized for this instance.
-
#shielded_instance_config ⇒ Google::Apis::ComputeV1::ShieldedInstanceConfig
A set of Shielded Instance options.
-
#shielded_instance_integrity_policy ⇒ Google::Apis::ComputeV1::ShieldedInstanceIntegrityPolicy
The policy describes the baseline against which Instance boot integrity is measured.
-
#source_machine_image ⇒ String
Source machine image Corresponds to the JSON property
sourceMachineImage. -
#source_machine_image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Source machine image encryption key when creating an instance from a machine image.
-
#start_restricted ⇒ Boolean
(also: #start_restricted?)
[Output Only] Whether a VM has been restricted for start because Compute Engine has detected suspicious activity.
-
#status ⇒ String
[Output Only] The status of the instance.
-
#status_message ⇒ String
[Output Only] An optional, human-readable explanation of the status.
-
#tags ⇒ Google::Apis::ComputeV1::Tags
A set of instance tags.
-
#zone ⇒ String
[Output Only] URL of the zone where the instance resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
12463 12464 12465 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_machine_features ⇒ Google::Apis::ComputeV1::AdvancedMachineFeatures
Specifies options for controlling advanced machine features. Options that
would traditionally be configured in a BIOS belong here. Features that require
operating system support may have corresponding entries in the GuestOsFeatures
of an Image (e.g., whether or not the OS in the Image supports nested
virtualization being enabled or disabled).
Corresponds to the JSON property advancedMachineFeatures
12198 12199 12200 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12198 def advanced_machine_features @advanced_machine_features end |
#can_ip_forward ⇒ Boolean Also known as: can_ip_forward?
Allows this instance to send and receive packets with non-matching destination
or source IPs. This is required if you plan to use this instance to forward
routes. For more information, see Enabling IP Forwarding .
Corresponds to the JSON property canIpForward
12205 12206 12207 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12205 def can_ip_forward @can_ip_forward end |
#confidential_instance_config ⇒ Google::Apis::ComputeV1::ConfidentialInstanceConfig
A set of Confidential Instance options.
Corresponds to the JSON property confidentialInstanceConfig
12211 12212 12213 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12211 def confidential_instance_config @confidential_instance_config end |
#cpu_platform ⇒ String
[Output Only] The CPU platform used by this instance.
Corresponds to the JSON property cpuPlatform
12216 12217 12218 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12216 def cpu_platform @cpu_platform end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
12221 12222 12223 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12221 def @creation_timestamp end |
#deletion_protection ⇒ Boolean Also known as: deletion_protection?
Whether the resource should be protected against deletion.
Corresponds to the JSON property deletionProtection
12226 12227 12228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12226 def deletion_protection @deletion_protection end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
12233 12234 12235 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12233 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeV1::AttachedDisk>
Array of disks associated with this instance. Persistent disks must be created
before you can assign them.
Corresponds to the JSON property disks
12239 12240 12241 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12239 def disks @disks end |
#display_device ⇒ Google::Apis::ComputeV1::DisplayDevice
A set of Display Device options
Corresponds to the JSON property displayDevice
12244 12245 12246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12244 def display_device @display_device end |
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of the
instance's contents and used for optimistic locking. The fingerprint is
initially generated by Compute Engine and changes after every request to
modify or update the instance. You must always provide an up-to-date
fingerprint hash in order to update the instance. To see the latest
fingerprint, make get() request to the instance.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
12255 12256 12257 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12255 def fingerprint @fingerprint end |
#guest_accelerators ⇒ Array<Google::Apis::ComputeV1::AcceleratorConfig>
A list of the type and count of accelerator cards attached to the instance.
Corresponds to the JSON property guestAccelerators
12260 12261 12262 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12260 def guest_accelerators @guest_accelerators end |
#hostname ⇒ String
Specifies the hostname of the instance. The specified hostname must be RFC1035
compliant. If hostname is not specified, the default hostname is [
INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and [
INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS.
Corresponds to the JSON property hostname
12268 12269 12270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12268 def hostname @hostname end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
12274 12275 12276 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12274 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#instance for instances.
Corresponds to the JSON property kind
12279 12280 12281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12279 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for this request, which is essentially a hash of the label's
contents and used for optimistic locking. The fingerprint is initially
generated by Compute Engine and changes after every request to modify or
update labels. You must always provide an up-to-date fingerprint hash in order
to update or change labels. To see the latest fingerprint, make get() request
to the instance.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
12290 12291 12292 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12290 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this instance. These can be later modified by the setLabels
method.
Corresponds to the JSON property labels
12296 12297 12298 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12296 def labels @labels end |
#last_start_timestamp ⇒ String
[Output Only] Last start timestamp in RFC3339 text format.
Corresponds to the JSON property lastStartTimestamp
12301 12302 12303 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12301 def @last_start_timestamp end |
#last_stop_timestamp ⇒ String
[Output Only] Last stop timestamp in RFC3339 text format.
Corresponds to the JSON property lastStopTimestamp
12306 12307 12308 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12306 def @last_stop_timestamp end |
#last_suspended_timestamp ⇒ String
[Output Only] Last suspended timestamp in RFC3339 text format.
Corresponds to the JSON property lastSuspendedTimestamp
12311 12312 12313 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12311 def @last_suspended_timestamp end |
#machine_type ⇒ String
Full or partial URL of the machine type resource to use for this instance, in
the format: zones/zone/machineTypes/machine-type. This is provided by the
client when the instance is created. For example, the following is a valid
partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-
standard-1 To create a custom machine type, provide a URL to a machine type in
the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ...
24, etc), and MEMORY is the total memory for this instance. Memory must be a
multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB):
zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/
machineTypes/custom-4-5120 For a full list of restrictions, read the
Specifications for custom machine types.
Corresponds to the JSON property machineType
12326 12327 12328 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12326 def machine_type @machine_type end |
#metadata ⇒ Google::Apis::ComputeV1::Metadata
A metadata key/value entry.
Corresponds to the JSON property metadata
12331 12332 12333 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12331 def @metadata end |
#min_cpu_platform ⇒ String
Specifies a minimum CPU platform for the VM instance. Applicable values are
the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell"
or minCpuPlatform: "Intel Sandy Bridge".
Corresponds to the JSON property minCpuPlatform
12338 12339 12340 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12338 def min_cpu_platform @min_cpu_platform end |
#name ⇒ String
The name of the resource, provided by the client when initially creating the
resource. The resource name must be 1-63 characters long, and comply with
RFC1035. Specifically, the name must be 1-63 characters long and match the
regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be a
dash, lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
12349 12350 12351 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12349 def name @name end |
#network_interfaces ⇒ Array<Google::Apis::ComputeV1::NetworkInterface>
An array of network configurations for this instance. These specify how
interfaces are configured to interact with other network services, such as
connecting to the internet. Multiple interfaces are supported per instance.
Corresponds to the JSON property networkInterfaces
12356 12357 12358 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12356 def network_interfaces @network_interfaces end |
#network_performance_config ⇒ Google::Apis::ComputeV1::NetworkPerformanceConfig
Corresponds to the JSON property networkPerformanceConfig
12361 12362 12363 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12361 def network_performance_config @network_performance_config end |
#params ⇒ Google::Apis::ComputeV1::InstanceParams
Additional instance params.
Corresponds to the JSON property params
12366 12367 12368 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12366 def params @params end |
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for the VM. If not specified, use
INHERIT_FROM_SUBNETWORK as default.
Corresponds to the JSON property privateIpv6GoogleAccess
12372 12373 12374 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12372 def private_ipv6_google_access @private_ipv6_google_access end |
#reservation_affinity ⇒ Google::Apis::ComputeV1::ReservationAffinity
Specifies the reservations that this instance can consume from.
Corresponds to the JSON property reservationAffinity
12377 12378 12379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12377 def reservation_affinity @reservation_affinity end |
#resource_policies ⇒ Array<String>
Resource policies applied to this instance.
Corresponds to the JSON property resourcePolicies
12382 12383 12384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12382 def resource_policies @resource_policies end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
[Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
12387 12388 12389 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12387 def satisfies_pzs @satisfies_pzs end |
#scheduling ⇒ Google::Apis::ComputeV1::Scheduling
Sets the scheduling options for an Instance. NextID: 21
Corresponds to the JSON property scheduling
12393 12394 12395 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12393 def scheduling @scheduling end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12398 12399 12400 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12398 def self_link @self_link end |
#service_accounts ⇒ Array<Google::Apis::ComputeV1::ServiceAccount>
A list of service accounts, with their specified scopes, authorized for this
instance. Only one service account per VM instance is supported. Service
accounts generate access tokens that can be accessed through the metadata
server and used to authenticate applications on the instance. See Service
Accounts for more information.
Corresponds to the JSON property serviceAccounts
12407 12408 12409 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12407 def service_accounts @service_accounts end |
#shielded_instance_config ⇒ Google::Apis::ComputeV1::ShieldedInstanceConfig
A set of Shielded Instance options.
Corresponds to the JSON property shieldedInstanceConfig
12412 12413 12414 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12412 def shielded_instance_config @shielded_instance_config end |
#shielded_instance_integrity_policy ⇒ Google::Apis::ComputeV1::ShieldedInstanceIntegrityPolicy
The policy describes the baseline against which Instance boot integrity is
measured.
Corresponds to the JSON property shieldedInstanceIntegrityPolicy
12418 12419 12420 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12418 def shielded_instance_integrity_policy @shielded_instance_integrity_policy end |
#source_machine_image ⇒ String
Source machine image
Corresponds to the JSON property sourceMachineImage
12423 12424 12425 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12423 def source_machine_image @source_machine_image end |
#source_machine_image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Source machine image encryption key when creating an instance from a machine
image.
Corresponds to the JSON property sourceMachineImageEncryptionKey
12429 12430 12431 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12429 def source_machine_image_encryption_key @source_machine_image_encryption_key end |
#start_restricted ⇒ Boolean Also known as: start_restricted?
[Output Only] Whether a VM has been restricted for start because Compute
Engine has detected suspicious activity.
Corresponds to the JSON property startRestricted
12435 12436 12437 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12435 def start_restricted @start_restricted end |
#status ⇒ String
[Output Only] The status of the instance. One of the following values:
PROVISIONING, STAGING, RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING,
and TERMINATED. For more information about the status of the instance, see
Instance life cycle.
Corresponds to the JSON property status
12444 12445 12446 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12444 def status @status end |
#status_message ⇒ String
[Output Only] An optional, human-readable explanation of the status.
Corresponds to the JSON property statusMessage
12449 12450 12451 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12449 def @status_message end |
#tags ⇒ Google::Apis::ComputeV1::Tags
A set of instance tags.
Corresponds to the JSON property tags
12454 12455 12456 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12454 def @tags end |
#zone ⇒ String
[Output Only] URL of the zone where the instance resides. You must specify
this field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property zone
12461 12462 12463 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12461 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12468 12469 12470 12471 12472 12473 12474 12475 12476 12477 12478 12479 12480 12481 12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 12492 12493 12494 12495 12496 12497 12498 12499 12500 12501 12502 12503 12504 12505 12506 12507 12508 12509 12510 12511 |
# File 'lib/google/apis/compute_v1/classes.rb', line 12468 def update!(**args) @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features) @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward) @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config) @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @display_device = args[:display_device] if args.key?(:display_device) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) @hostname = args[:hostname] if args.key?(:hostname) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @last_start_timestamp = args[:last_start_timestamp] if args.key?(:last_start_timestamp) @last_stop_timestamp = args[:last_stop_timestamp] if args.key?(:last_stop_timestamp) @last_suspended_timestamp = args[:last_suspended_timestamp] if args.key?(:last_suspended_timestamp) @machine_type = args[:machine_type] if args.key?(:machine_type) @metadata = args[:metadata] if args.key?(:metadata) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @name = args[:name] if args.key?(:name) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config) @params = args[:params] if args.key?(:params) @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scheduling = args[:scheduling] if args.key?(:scheduling) @self_link = args[:self_link] if args.key?(:self_link) @service_accounts = args[:service_accounts] if args.key?(:service_accounts) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) @shielded_instance_integrity_policy = args[:shielded_instance_integrity_policy] if args.key?(:shielded_instance_integrity_policy) @source_machine_image = args[:source_machine_image] if args.key?(:source_machine_image) @source_machine_image_encryption_key = args[:source_machine_image_encryption_key] if args.key?(:source_machine_image_encryption_key) @start_restricted = args[:start_restricted] if args.key?(:start_restricted) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @tags = args[:tags] if args.key?(:tags) @zone = args[:zone] if args.key?(:zone) end |