Class: Google::Apis::ComputeV1::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
22274 22275 22276 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22235 22236 22237 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22235 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
22240 22241 22242 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22240 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
22247 22248 22249 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22247 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22257 22258 22259 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22257 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22262 22263 22264 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22262 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
22267 22268 22269 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22267 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22272 22273 22274 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22272 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22279 22280 22281 22282 22283 22284 22285 22286 22287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22279 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |