Class: Google::Apis::ComputeV1::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
21922 21923 21924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21922 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21883 21884 21885 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21883 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
21888 21889 21890 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21888 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
21895 21896 21897 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21895 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21905 21906 21907 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21905 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21910 21911 21912 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21910 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
21915 21916 21917 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21915 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21920 21921 21922 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21920 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21927 21928 21929 21930 21931 21932 21933 21934 21935 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21927 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |