Class: Google::Apis::ComputeV1::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



21903
21904
21905
# File 'lib/google/apis/compute_v1/classes.rb', line 21903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21864
21865
21866
# File 'lib/google/apis/compute_v1/classes.rb', line 21864

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



21869
21870
21871
# File 'lib/google/apis/compute_v1/classes.rb', line 21869

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


21876
21877
21878
# File 'lib/google/apis/compute_v1/classes.rb', line 21876

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21886
21887
21888
# File 'lib/google/apis/compute_v1/classes.rb', line 21886

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21891
21892
21893
# File 'lib/google/apis/compute_v1/classes.rb', line 21891

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21896
21897
21898
# File 'lib/google/apis/compute_v1/classes.rb', line 21896

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21901
21902
21903
# File 'lib/google/apis/compute_v1/classes.rb', line 21901

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21908
21909
21910
21911
21912
21913
21914
21915
21916
# File 'lib/google/apis/compute_v1/classes.rb', line 21908

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end