Class: Google::Apis::ComputeV1::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
21744 21745 21746 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21744 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21705 21706 21707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21705 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
21710 21711 21712 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21710 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
21717 21718 21719 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21717 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21727 21728 21729 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21727 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21732 21733 21734 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21732 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
21737 21738 21739 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21737 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21742 21743 21744 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21742 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21749 21750 21751 21752 21753 21754 21755 21756 21757 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21749 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |