Class: Google::Apis::ComputeV1::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



18500
18501
18502
# File 'lib/google/apis/compute_v1/classes.rb', line 18500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18461
18462
18463
# File 'lib/google/apis/compute_v1/classes.rb', line 18461

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



18466
18467
18468
# File 'lib/google/apis/compute_v1/classes.rb', line 18466

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


18473
18474
18475
# File 'lib/google/apis/compute_v1/classes.rb', line 18473

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18483
18484
18485
# File 'lib/google/apis/compute_v1/classes.rb', line 18483

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18488
18489
18490
# File 'lib/google/apis/compute_v1/classes.rb', line 18488

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18493
18494
18495
# File 'lib/google/apis/compute_v1/classes.rb', line 18493

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18498
18499
18500
# File 'lib/google/apis/compute_v1/classes.rb', line 18498

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18505
18506
18507
18508
18509
18510
18511
18512
18513
# File 'lib/google/apis/compute_v1/classes.rb', line 18505

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end