Class: Google::Apis::ComputeV1::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



12558
12559
12560
# File 'lib/google/apis/compute_v1/classes.rb', line 12558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12521
12522
12523
# File 'lib/google/apis/compute_v1/classes.rb', line 12521

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



12526
12527
12528
# File 'lib/google/apis/compute_v1/classes.rb', line 12526

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


12532
12533
12534
# File 'lib/google/apis/compute_v1/classes.rb', line 12532

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12541
12542
12543
# File 'lib/google/apis/compute_v1/classes.rb', line 12541

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12546
12547
12548
# File 'lib/google/apis/compute_v1/classes.rb', line 12546

def self_link
  @self_link
end

#unreachablesArray<String>

[Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


12551
12552
12553
# File 'lib/google/apis/compute_v1/classes.rb', line 12551

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12556
12557
12558
# File 'lib/google/apis/compute_v1/classes.rb', line 12556

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12563
12564
12565
12566
12567
12568
12569
12570
12571
# File 'lib/google/apis/compute_v1/classes.rb', line 12563

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end