Class: Google::Apis::ComputeV1::InstanceConsumptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceConsumptionInfo

Returns a new instance of InstanceConsumptionInfo.



18637
18638
18639
# File 'lib/google/apis/compute_v1/classes.rb', line 18637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#guest_cpusFixnum

Output only. The number of virtual CPUs that are available to the instance. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


18618
18619
18620
# File 'lib/google/apis/compute_v1/classes.rb', line 18618

def guest_cpus
  @guest_cpus
end

#local_ssd_gbFixnum

Output only. The amount of local SSD storage available to the instance, defined in GiB. Corresponds to the JSON property localSsdGb

Returns:

  • (Fixnum)


18624
18625
18626
# File 'lib/google/apis/compute_v1/classes.rb', line 18624

def local_ssd_gb
  @local_ssd_gb
end

#memory_mbFixnum

Output only. The amount of physical memory available to the instance, defined in MiB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


18630
18631
18632
# File 'lib/google/apis/compute_v1/classes.rb', line 18630

def memory_mb
  @memory_mb
end

#min_node_cpusFixnum

Output only. The minimal guaranteed number of virtual CPUs that are reserved. Corresponds to the JSON property minNodeCpus

Returns:

  • (Fixnum)


18635
18636
18637
# File 'lib/google/apis/compute_v1/classes.rb', line 18635

def min_node_cpus
  @min_node_cpus
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18642
18643
18644
18645
18646
18647
# File 'lib/google/apis/compute_v1/classes.rb', line 18642

def update!(**args)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus)
end