Class: Google::Apis::ComputeV1::InstanceFlexibilityPolicyInstanceSelection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceFlexibilityPolicyInstanceSelection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specification of machine type to use. Every position inside this message is an alternative. The count specified in the shape flexibility must not exceed the number of entries in per_instance_properties or the capacity of the name_pattern, if used.
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeV1::AttachedDisk>
Disks to be attached to the instances created from in this selection.
-
#machine_types ⇒ Array<String>
Alternative machine types to use for instances that are created from these properties.
-
#rank ⇒ Fixnum
Rank when prioritizing the shape flexibilities.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceFlexibilityPolicyInstanceSelection
constructor
A new instance of InstanceFlexibilityPolicyInstanceSelection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceFlexibilityPolicyInstanceSelection
Returns a new instance of InstanceFlexibilityPolicyInstanceSelection.
22482 22483 22484 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeV1::AttachedDisk>
Disks to be attached to the instances created from in this selection.
They override the disks specified in the instance properties.
Corresponds to the JSON property disks
22465 22466 22467 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22465 def disks @disks end |
#machine_types ⇒ Array<String>
Alternative machine types to use for instances that are created from
these properties. This field only accepts a machine type names, for
example n2-standard-4 and not URLs or partial URLs.
Corresponds to the JSON property machineTypes
22472 22473 22474 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22472 def machine_types @machine_types end |
#rank ⇒ Fixnum
Rank when prioritizing the shape flexibilities.
The instance selections with rank are considered
first, in the ascending order of the rank.
If not set, defaults to 0.
Corresponds to the JSON property rank
22480 22481 22482 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22480 def rank @rank end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22487 22488 22489 22490 22491 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22487 def update!(**args) @disks = args[:disks] if args.key?(:disks) @machine_types = args[:machine_types] if args.key?(:machine_types) @rank = args[:rank] if args.key?(:rank) end |