Class: Google::Apis::ComputeV1::InstanceFlexibilityPolicyInstanceSelection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specification of machine type to use. Every position inside this message is an alternative. The count specified in the shape flexibility must not exceed the number of entries in per_instance_properties or the capacity of the name_pattern, if used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceFlexibilityPolicyInstanceSelection

Returns a new instance of InstanceFlexibilityPolicyInstanceSelection.



22111
22112
22113
# File 'lib/google/apis/compute_v1/classes.rb', line 22111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksArray<Google::Apis::ComputeV1::AttachedDisk>

Disks to be attached to the instances created from in this selection. They override the disks specified in the instance properties. Corresponds to the JSON property disks



22094
22095
22096
# File 'lib/google/apis/compute_v1/classes.rb', line 22094

def disks
  @disks
end

#machine_typesArray<String>

Alternative machine types to use for instances that are created from these properties. This field only accepts a machine type names, for example n2-standard-4 and not URLs or partial URLs. Corresponds to the JSON property machineTypes

Returns:

  • (Array<String>)


22101
22102
22103
# File 'lib/google/apis/compute_v1/classes.rb', line 22101

def machine_types
  @machine_types
end

#rankFixnum

Rank when prioritizing the shape flexibilities. The instance selections with rank are considered first, in the ascending order of the rank. If not set, defaults to 0. Corresponds to the JSON property rank

Returns:

  • (Fixnum)


22109
22110
22111
# File 'lib/google/apis/compute_v1/classes.rb', line 22109

def rank
  @rank
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22116
22117
22118
22119
22120
# File 'lib/google/apis/compute_v1/classes.rb', line 22116

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @machine_types = args[:machine_types] if args.key?(:machine_types)
  @rank = args[:rank] if args.key?(:rank)
end