Class: Google::Apis::ComputeV1::InstanceFlexibilityPolicyInstanceSelection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specification of machine type to use. Every position inside this message is an alternative. The count specified in the shape flexibility must not exceed the number of entries in per_instance_properties or the capacity of the name_pattern, if used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceFlexibilityPolicyInstanceSelection

Returns a new instance of InstanceFlexibilityPolicyInstanceSelection.



21445
21446
21447
# File 'lib/google/apis/compute_v1/classes.rb', line 21445

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksArray<Google::Apis::ComputeV1::AttachedDisk>

Disks to be attached to the instances created from in this selection. They override the disks specified in the instance properties. Corresponds to the JSON property disks



21428
21429
21430
# File 'lib/google/apis/compute_v1/classes.rb', line 21428

def disks
  @disks
end

#machine_typesArray<String>

Alternative machine types to use for instances that are created from these properties. This field only accepts a machine type names, for example n2-standard-4 and not URLs or partial URLs. Corresponds to the JSON property machineTypes

Returns:

  • (Array<String>)


21435
21436
21437
# File 'lib/google/apis/compute_v1/classes.rb', line 21435

def machine_types
  @machine_types
end

#rankFixnum

Rank when prioritizing the shape flexibilities. The instance selections with rank are considered first, in the ascending order of the rank. If not set, defaults to 0. Corresponds to the JSON property rank

Returns:

  • (Fixnum)


21443
21444
21445
# File 'lib/google/apis/compute_v1/classes.rb', line 21443

def rank
  @rank
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21450
21451
21452
21453
21454
# File 'lib/google/apis/compute_v1/classes.rb', line 21450

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @machine_types = args[:machine_types] if args.key?(:machine_types)
  @rank = args[:rank] if args.key?(:rank)
end