Class: Google::Apis::ComputeV1::InstanceGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an Instance Group resource. Instance Groups can be used to configure a target for load balancing. Instance groups can either be managed or unmanaged. To create managed instance groups, use the instanceGroupManager or regionInstanceGroupManager resource instead. Use zonal unmanaged instance groups if you need to apply load balancing to groups of heterogeneous instances or if you need to manage the instances yourself. You cannot create regional unmanaged instance groups. For more information, read Instance groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroup

Returns a new instance of InstanceGroup.



12733
12734
12735
# File 'lib/google/apis/compute_v1/classes.rb', line 12733

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] The creation timestamp for this instance group in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


12652
12653
12654
# File 'lib/google/apis/compute_v1/classes.rb', line 12652

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


12658
12659
12660
# File 'lib/google/apis/compute_v1/classes.rb', line 12658

def description
  @description
end

#fingerprintString

[Output Only] The fingerprint of the named ports. The system uses this fingerprint to detect conflicts when multiple users change the named ports concurrently. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


12666
12667
12668
# File 'lib/google/apis/compute_v1/classes.rb', line 12666

def fingerprint
  @fingerprint
end

#idFixnum

[Output Only] A unique identifier for this instance group, generated by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12672
12673
12674
# File 'lib/google/apis/compute_v1/classes.rb', line 12672

def id
  @id
end

#kindString

[Output Only] The resource type, which is always compute#instanceGroup for instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


12678
12679
12680
# File 'lib/google/apis/compute_v1/classes.rb', line 12678

def kind
  @kind
end

#nameString

The name of the instance group. The name must be 1-63 characters long, and comply with RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


12684
12685
12686
# File 'lib/google/apis/compute_v1/classes.rb', line 12684

def name
  @name
end

#named_portsArray<Google::Apis::ComputeV1::NamedPort>

Assigns a name to a port number. For example: name: "http", port: 80 This allows the system to reference ports by the assigned name instead of a port number. Named ports can also contain multiple ports. For example: [name: " app1", port: 8080, name: "app1", port: 8081, name: "app2", port: 8082] Named ports apply to all instances in this instance group. Corresponds to the JSON property namedPorts



12693
12694
12695
# File 'lib/google/apis/compute_v1/classes.rb', line 12693

def named_ports
  @named_ports
end

#networkString

[Output Only] The URL of the network to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0). Corresponds to the JSON property network

Returns:

  • (String)


12701
12702
12703
# File 'lib/google/apis/compute_v1/classes.rb', line 12701

def network
  @network
end

#regionString

[Output Only] The URL of the region where the instance group is located (for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


12707
12708
12709
# File 'lib/google/apis/compute_v1/classes.rb', line 12707

def region
  @region
end

[Output Only] The URL for this instance group. The server generates this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


12712
12713
12714
# File 'lib/google/apis/compute_v1/classes.rb', line 12712

def self_link
  @self_link
end

#sizeFixnum

[Output Only] The total number of instances in the instance group. Corresponds to the JSON property size

Returns:

  • (Fixnum)


12717
12718
12719
# File 'lib/google/apis/compute_v1/classes.rb', line 12717

def size
  @size
end

#subnetworkString

[Output Only] The URL of the subnetwork to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0). Corresponds to the JSON property subnetwork

Returns:

  • (String)


12725
12726
12727
# File 'lib/google/apis/compute_v1/classes.rb', line 12725

def subnetwork
  @subnetwork
end

#zoneString

[Output Only] The URL of the zone where the instance group is located (for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


12731
12732
12733
# File 'lib/google/apis/compute_v1/classes.rb', line 12731

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12738
12739
12740
12741
12742
12743
12744
12745
12746
12747
12748
12749
12750
12751
12752
# File 'lib/google/apis/compute_v1/classes.rb', line 12738

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @network = args[:network] if args.key?(:network)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @size = args[:size] if args.key?(:size)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @zone = args[:zone] if args.key?(:zone)
end