Class: Google::Apis::ComputeV1::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



22320
22321
22322
# File 'lib/google/apis/compute_v1/classes.rb', line 22320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22280
22281
22282
# File 'lib/google/apis/compute_v1/classes.rb', line 22280

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



22285
22286
22287
# File 'lib/google/apis/compute_v1/classes.rb', line 22285

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


22292
22293
22294
# File 'lib/google/apis/compute_v1/classes.rb', line 22292

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22303
22304
22305
# File 'lib/google/apis/compute_v1/classes.rb', line 22303

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22308
22309
22310
# File 'lib/google/apis/compute_v1/classes.rb', line 22308

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22313
22314
22315
# File 'lib/google/apis/compute_v1/classes.rb', line 22313

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



22318
22319
22320
# File 'lib/google/apis/compute_v1/classes.rb', line 22318

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22325
22326
22327
22328
22329
22330
22331
22332
22333
# File 'lib/google/apis/compute_v1/classes.rb', line 22325

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end