Class: Google::Apis::ComputeV1::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



22150
22151
22152
# File 'lib/google/apis/compute_v1/classes.rb', line 22150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22110
22111
22112
# File 'lib/google/apis/compute_v1/classes.rb', line 22110

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



22115
22116
22117
# File 'lib/google/apis/compute_v1/classes.rb', line 22115

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


22122
22123
22124
# File 'lib/google/apis/compute_v1/classes.rb', line 22122

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22133
22134
22135
# File 'lib/google/apis/compute_v1/classes.rb', line 22133

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22138
22139
22140
# File 'lib/google/apis/compute_v1/classes.rb', line 22138

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22143
22144
22145
# File 'lib/google/apis/compute_v1/classes.rb', line 22143

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



22148
22149
22150
# File 'lib/google/apis/compute_v1/classes.rb', line 22148

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22155
22156
22157
22158
22159
22160
22161
22162
22163
# File 'lib/google/apis/compute_v1/classes.rb', line 22155

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end