Class: Google::Apis::ComputeV1::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



21635
21636
21637
# File 'lib/google/apis/compute_v1/classes.rb', line 21635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21595
21596
21597
# File 'lib/google/apis/compute_v1/classes.rb', line 21595

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



21600
21601
21602
# File 'lib/google/apis/compute_v1/classes.rb', line 21600

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


21607
21608
21609
# File 'lib/google/apis/compute_v1/classes.rb', line 21607

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21618
21619
21620
# File 'lib/google/apis/compute_v1/classes.rb', line 21618

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21623
21624
21625
# File 'lib/google/apis/compute_v1/classes.rb', line 21623

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21628
21629
21630
# File 'lib/google/apis/compute_v1/classes.rb', line 21628

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



21633
21634
21635
# File 'lib/google/apis/compute_v1/classes.rb', line 21633

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21640
21641
21642
21643
21644
21645
21646
21647
21648
# File 'lib/google/apis/compute_v1/classes.rb', line 21640

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end