Class: Google::Apis::ComputeV1::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



19515
19516
19517
# File 'lib/google/apis/compute_v1/classes.rb', line 19515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19475
19476
19477
# File 'lib/google/apis/compute_v1/classes.rb', line 19475

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



19480
19481
19482
# File 'lib/google/apis/compute_v1/classes.rb', line 19480

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


19487
19488
19489
# File 'lib/google/apis/compute_v1/classes.rb', line 19487

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19498
19499
19500
# File 'lib/google/apis/compute_v1/classes.rb', line 19498

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19503
19504
19505
# File 'lib/google/apis/compute_v1/classes.rb', line 19503

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


19508
19509
19510
# File 'lib/google/apis/compute_v1/classes.rb', line 19508

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



19513
19514
19515
# File 'lib/google/apis/compute_v1/classes.rb', line 19513

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19520
19521
19522
19523
19524
19525
19526
19527
19528
# File 'lib/google/apis/compute_v1/classes.rb', line 19520

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end