Class: Google::Apis::ComputeV1::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



12799
12800
12801
# File 'lib/google/apis/compute_v1/classes.rb', line 12799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12762
12763
12764
# File 'lib/google/apis/compute_v1/classes.rb', line 12762

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



12767
12768
12769
# File 'lib/google/apis/compute_v1/classes.rb', line 12767

def items
  @items
end

#kindString

[Output Only] The resource type, which is always compute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


12773
12774
12775
# File 'lib/google/apis/compute_v1/classes.rb', line 12773

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12782
12783
12784
# File 'lib/google/apis/compute_v1/classes.rb', line 12782

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12787
12788
12789
# File 'lib/google/apis/compute_v1/classes.rb', line 12787

def self_link
  @self_link
end

#unreachablesArray<String>

[Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


12792
12793
12794
# File 'lib/google/apis/compute_v1/classes.rb', line 12792

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12797
12798
12799
# File 'lib/google/apis/compute_v1/classes.rb', line 12797

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12804
12805
12806
12807
12808
12809
12810
12811
12812
# File 'lib/google/apis/compute_v1/classes.rb', line 12804

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end