Class: Google::Apis::ComputeV1::InstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupList

Returns a new instance of InstanceGroupList.



19643
19644
19645
# File 'lib/google/apis/compute_v1/classes.rb', line 19643

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19609
19610
19611
# File 'lib/google/apis/compute_v1/classes.rb', line 19609

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



19614
19615
19616
# File 'lib/google/apis/compute_v1/classes.rb', line 19614

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupList for instance group lists. Corresponds to the JSON property kind

Returns:

  • (String)


19620
19621
19622
# File 'lib/google/apis/compute_v1/classes.rb', line 19620

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19631
19632
19633
# File 'lib/google/apis/compute_v1/classes.rb', line 19631

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19636
19637
19638
# File 'lib/google/apis/compute_v1/classes.rb', line 19636

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



19641
19642
19643
# File 'lib/google/apis/compute_v1/classes.rb', line 19641

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19648
19649
19650
19651
19652
19653
19654
19655
# File 'lib/google/apis/compute_v1/classes.rb', line 19648

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end