Class: Google::Apis::ComputeV1::InstanceGroupManager

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use theregionInstanceGroupManagers resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManager

Returns a new instance of InstanceGroupManager.



22598
22599
22600
# File 'lib/google/apis/compute_v1/classes.rb', line 22598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeV1::InstanceGroupManagerAllInstancesConfig

Specifies configuration that overrides the instance template configuration for the group. Corresponds to the JSON property allInstancesConfig



22369
22370
22371
# File 'lib/google/apis/compute_v1/classes.rb', line 22369

def all_instances_config
  @all_instances_config
end

#auto_healing_policiesArray<Google::Apis::ComputeV1::InstanceGroupManagerAutoHealingPolicy>

The autohealing policy for this managed instance group. You can specify only one value. Corresponds to the JSON property autoHealingPolicies



22375
22376
22377
# File 'lib/google/apis/compute_v1/classes.rb', line 22375

def auto_healing_policies
  @auto_healing_policies
end

#base_instance_nameString

The base instance name is a prefix that you want to attach to the names of all VMs in a MIG. The maximum character length is 58 and the name must comply with RFC1035 format. When a VM is created in the group, the MIG appends a hyphen and a random four-character string to the base instance name. If you want the MIG to assign sequential numbers instead of a random string, then end the base instance name with a hyphen followed by one or more hash symbols. The hash symbols indicate the number of digits. For example, a base instance name of "vm-###" results in "vm-001" as a VM name. a-z Corresponds to the JSON property baseInstanceName

Returns:

  • (String)


22390
22391
22392
# File 'lib/google/apis/compute_v1/classes.rb', line 22390

def base_instance_name
  @base_instance_name
end

#creation_timestampString

Output only. The creation timestamp for this managed instance group inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


22396
22397
22398
# File 'lib/google/apis/compute_v1/classes.rb', line 22396

def creation_timestamp
  @creation_timestamp
end

#current_actionsGoogle::Apis::ComputeV1::InstanceGroupManagerActionsSummary

Output only. The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions. Corresponds to the JSON property currentActions



22403
22404
22405
# File 'lib/google/apis/compute_v1/classes.rb', line 22403

def current_actions
  @current_actions
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


22408
22409
22410
# File 'lib/google/apis/compute_v1/classes.rb', line 22408

def description
  @description
end

#distribution_policyGoogle::Apis::ComputeV1::DistributionPolicy

Policy specifying the intended distribution of managed instances across zones in a regional managed instance group. Corresponds to the JSON property distributionPolicy



22414
22415
22416
# File 'lib/google/apis/compute_v1/classes.rb', line 22414

def distribution_policy
  @distribution_policy
end

#fingerprintString

Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


22425
22426
22427
# File 'lib/google/apis/compute_v1/classes.rb', line 22425

def fingerprint
  @fingerprint
end

#idFixnum

Output only. A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


22431
22432
22433
# File 'lib/google/apis/compute_v1/classes.rb', line 22431

def id
  @id
end

#instance_flexibility_policyGoogle::Apis::ComputeV1::InstanceGroupManagerInstanceFlexibilityPolicy

Instance flexibility allowing MIG to create VMs from multiple types of machines. Instance flexibility configuration on MIG overrides instance template configuration. Corresponds to the JSON property instanceFlexibilityPolicy



22439
22440
22441
# File 'lib/google/apis/compute_v1/classes.rb', line 22439

def instance_flexibility_policy
  @instance_flexibility_policy
end

#instance_groupString

Output only. The URL of the Instance Group resource. Corresponds to the JSON property instanceGroup

Returns:

  • (String)


22444
22445
22446
# File 'lib/google/apis/compute_v1/classes.rb', line 22444

def instance_group
  @instance_group
end

#instance_lifecycle_policyGoogle::Apis::ComputeV1::InstanceGroupManagerInstanceLifecyclePolicy

The repair policy for this managed instance group. Corresponds to the JSON property instanceLifecyclePolicy



22449
22450
22451
# File 'lib/google/apis/compute_v1/classes.rb', line 22449

def instance_lifecycle_policy
  @instance_lifecycle_policy
end

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


22458
22459
22460
# File 'lib/google/apis/compute_v1/classes.rb', line 22458

def instance_template
  @instance_template
end

#kindString

Output only. The resource type, which is alwayscompute#instanceGroupManager for managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


22464
22465
22466
# File 'lib/google/apis/compute_v1/classes.rb', line 22464

def kind
  @kind
end

#list_managed_instances_resultsString

Pagination behavior of the listManagedInstances API method for this managed instance group. Corresponds to the JSON property listManagedInstancesResults

Returns:

  • (String)


22470
22471
22472
# File 'lib/google/apis/compute_v1/classes.rb', line 22470

def list_managed_instances_results
  @list_managed_instances_results
end

#nameString

The name of the managed instance group. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


22476
22477
22478
# File 'lib/google/apis/compute_v1/classes.rb', line 22476

def name
  @name
end

#named_portsArray<Google::Apis::ComputeV1::NamedPort>

[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager. Corresponds to the JSON property namedPorts



22482
22483
22484
# File 'lib/google/apis/compute_v1/classes.rb', line 22482

def named_ports
  @named_ports
end

#regionString

Output only. [Output Only] The URL of theregion where the managed instance group resides (for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


22488
22489
22490
# File 'lib/google/apis/compute_v1/classes.rb', line 22488

def region
  @region
end

#resource_policiesGoogle::Apis::ComputeV1::InstanceGroupManagerResourcePolicies

Resource policies for this managed instance group. Corresponds to the JSON property resourcePolicies



22493
22494
22495
# File 'lib/google/apis/compute_v1/classes.rb', line 22493

def resource_policies
  @resource_policies
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


22498
22499
22500
# File 'lib/google/apis/compute_v1/classes.rb', line 22498

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


22504
22505
22506
# File 'lib/google/apis/compute_v1/classes.rb', line 22504

def satisfies_pzs
  @satisfies_pzs
end

Output only. The URL for this managed instance group. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


22511
22512
22513
# File 'lib/google/apis/compute_v1/classes.rb', line 22511

def self_link
  @self_link
end

#standby_policyGoogle::Apis::ComputeV1::InstanceGroupManagerStandbyPolicy

Standby policy for stopped and suspended instances. Corresponds to the JSON property standbyPolicy



22516
22517
22518
# File 'lib/google/apis/compute_v1/classes.rb', line 22516

def standby_policy
  @standby_policy
end

#stateful_policyGoogle::Apis::ComputeV1::StatefulPolicy

Stateful configuration for this Instanced Group Manager Corresponds to the JSON property statefulPolicy



22521
22522
22523
# File 'lib/google/apis/compute_v1/classes.rb', line 22521

def stateful_policy
  @stateful_policy
end

#statusGoogle::Apis::ComputeV1::InstanceGroupManagerStatus

Output only. The status of this managed instance group. Corresponds to the JSON property status



22526
22527
22528
# File 'lib/google/apis/compute_v1/classes.rb', line 22526

def status
  @status
end

#target_poolsArray<String>

The URLs for all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


22533
22534
22535
# File 'lib/google/apis/compute_v1/classes.rb', line 22533

def target_pools
  @target_pools
end

#target_sizeFixnum

The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number. Corresponds to the JSON property targetSize

Returns:

  • (Fixnum)


22541
22542
22543
# File 'lib/google/apis/compute_v1/classes.rb', line 22541

def target_size
  @target_size
end

#target_size_policyGoogle::Apis::ComputeV1::InstanceGroupManagerTargetSizePolicy

The policy that specifies how the MIG creates its VMs to achieve the target size. Corresponds to the JSON property targetSizePolicy



22547
22548
22549
# File 'lib/google/apis/compute_v1/classes.rb', line 22547

def target_size_policy
  @target_size_policy
end

#target_stopped_sizeFixnum

The target number of stopped instances for this managed instance group. This number changes when you:

  • Stop instance using the stopInstances method or start instances using the startInstances method.
  • Manually change the targetStoppedSize using the update method. Corresponds to the JSON property targetStoppedSize

Returns:

  • (Fixnum)


22559
22560
22561
# File 'lib/google/apis/compute_v1/classes.rb', line 22559

def target_stopped_size
  @target_stopped_size
end

#target_suspended_sizeFixnum

The target number of suspended instances for this managed instance group. This number changes when you:

  • Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
  • Manually change the targetSuspendedSize using the update method. Corresponds to the JSON property targetSuspendedSize

Returns:

  • (Fixnum)


22571
22572
22573
# File 'lib/google/apis/compute_v1/classes.rb', line 22571

def target_suspended_size
  @target_suspended_size
end

#update_policyGoogle::Apis::ComputeV1::InstanceGroupManagerUpdatePolicy

The update policy for this managed instance group. Corresponds to the JSON property updatePolicy



22576
22577
22578
# File 'lib/google/apis/compute_v1/classes.rb', line 22576

def update_policy
  @update_policy
end

#versionsArray<Google::Apis::ComputeV1::InstanceGroupManagerVersion>

Specifies the instance templates used by this managed instance group to create instances. Each version is defined by an instanceTemplate and aname. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about therelationships between these fields. Exactly one version must leave thetargetSize field unset. That version will be applied to all remaining instances. For more information, read aboutcanary updates. Corresponds to the JSON property versions



22590
22591
22592
# File 'lib/google/apis/compute_v1/classes.rb', line 22590

def versions
  @versions
end

#zoneString

Output only. The URL of azone where the managed instance group is located (for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


22596
22597
22598
# File 'lib/google/apis/compute_v1/classes.rb', line 22596

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22603
22604
22605
22606
22607
22608
22609
22610
22611
22612
22613
22614
22615
22616
22617
22618
22619
22620
22621
22622
22623
22624
22625
22626
22627
22628
22629
22630
22631
22632
22633
22634
22635
22636
22637
# File 'lib/google/apis/compute_v1/classes.rb', line 22603

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies)
  @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_actions = args[:current_actions] if args.key?(:current_actions)
  @description = args[:description] if args.key?(:description)
  @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @instance_lifecycle_policy = args[:instance_lifecycle_policy] if args.key?(:instance_lifecycle_policy)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @kind = args[:kind] if args.key?(:kind)
  @list_managed_instances_results = args[:list_managed_instances_results] if args.key?(:list_managed_instances_results)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @region = args[:region] if args.key?(:region)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @standby_policy = args[:standby_policy] if args.key?(:standby_policy)
  @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy)
  @status = args[:status] if args.key?(:status)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @target_size = args[:target_size] if args.key?(:target_size)
  @target_size_policy = args[:target_size_policy] if args.key?(:target_size_policy)
  @target_stopped_size = args[:target_stopped_size] if args.key?(:target_stopped_size)
  @target_suspended_size = args[:target_suspended_size] if args.key?(:target_suspended_size)
  @update_policy = args[:update_policy] if args.key?(:update_policy)
  @versions = args[:versions] if args.key?(:versions)
  @zone = args[:zone] if args.key?(:zone)
end