Class: Google::Apis::ComputeV1::InstanceGroupManager

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use theregionInstanceGroupManagers resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManager

Returns a new instance of InstanceGroupManager.



19282
19283
19284
# File 'lib/google/apis/compute_v1/classes.rb', line 19282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeV1::InstanceGroupManagerAllInstancesConfig

Specifies configuration that overrides the instance template configuration for the group. Corresponds to the JSON property allInstancesConfig



19055
19056
19057
# File 'lib/google/apis/compute_v1/classes.rb', line 19055

def all_instances_config
  @all_instances_config
end

#auto_healing_policiesArray<Google::Apis::ComputeV1::InstanceGroupManagerAutoHealingPolicy>

The autohealing policy for this managed instance group. You can specify only one value. Corresponds to the JSON property autoHealingPolicies



19061
19062
19063
# File 'lib/google/apis/compute_v1/classes.rb', line 19061

def auto_healing_policies
  @auto_healing_policies
end

#base_instance_nameString

The base instance name is a prefix that you want to attach to the names of all VMs in a MIG. The maximum character length is 58 and the name must comply with RFC1035 format. When a VM is created in the group, the MIG appends a hyphen and a random four-character string to the base instance name. If you want the MIG to assign sequential numbers instead of a random string, then end the base instance name with a hyphen followed by one or more hash symbols. The hash symbols indicate the number of digits. For example, a base instance name of "vm-###" results in "vm-001" as a VM name. a-z Corresponds to the JSON property baseInstanceName

Returns:

  • (String)


19076
19077
19078
# File 'lib/google/apis/compute_v1/classes.rb', line 19076

def base_instance_name
  @base_instance_name
end

#creation_timestampString

Output only. [Output Only] The creation timestamp for this managed instance group inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


19083
19084
19085
# File 'lib/google/apis/compute_v1/classes.rb', line 19083

def creation_timestamp
  @creation_timestamp
end

#current_actionsGoogle::Apis::ComputeV1::InstanceGroupManagerActionsSummary

Output only. [Output Only] The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions. Corresponds to the JSON property currentActions



19091
19092
19093
# File 'lib/google/apis/compute_v1/classes.rb', line 19091

def current_actions
  @current_actions
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


19096
19097
19098
# File 'lib/google/apis/compute_v1/classes.rb', line 19096

def description
  @description
end

#distribution_policyGoogle::Apis::ComputeV1::DistributionPolicy

Policy specifying the intended distribution of managed instances across zones in a regional managed instance group. Corresponds to the JSON property distributionPolicy



19102
19103
19104
# File 'lib/google/apis/compute_v1/classes.rb', line 19102

def distribution_policy
  @distribution_policy
end

#fingerprintString

Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


19113
19114
19115
# File 'lib/google/apis/compute_v1/classes.rb', line 19113

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


19120
19121
19122
# File 'lib/google/apis/compute_v1/classes.rb', line 19120

def id
  @id
end

#instance_flexibility_policyGoogle::Apis::ComputeV1::InstanceGroupManagerInstanceFlexibilityPolicy

Instance flexibility allowing MIG to create VMs from multiple types of machines. Instance flexibility configuration on MIG overrides instance template configuration. Corresponds to the JSON property instanceFlexibilityPolicy



19128
19129
19130
# File 'lib/google/apis/compute_v1/classes.rb', line 19128

def instance_flexibility_policy
  @instance_flexibility_policy
end

#instance_groupString

Output only. [Output Only] The URL of the Instance Group resource. Corresponds to the JSON property instanceGroup

Returns:

  • (String)


19133
19134
19135
# File 'lib/google/apis/compute_v1/classes.rb', line 19133

def instance_group
  @instance_group
end

#instance_lifecycle_policyGoogle::Apis::ComputeV1::InstanceGroupManagerInstanceLifecyclePolicy

The repair policy for this managed instance group. Corresponds to the JSON property instanceLifecyclePolicy



19138
19139
19140
# File 'lib/google/apis/compute_v1/classes.rb', line 19138

def instance_lifecycle_policy
  @instance_lifecycle_policy
end

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


19147
19148
19149
# File 'lib/google/apis/compute_v1/classes.rb', line 19147

def instance_template
  @instance_template
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupManager for managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


19153
19154
19155
# File 'lib/google/apis/compute_v1/classes.rb', line 19153

def kind
  @kind
end

#list_managed_instances_resultsString

Pagination behavior of the listManagedInstances API method for this managed instance group. Corresponds to the JSON property listManagedInstancesResults

Returns:

  • (String)


19159
19160
19161
# File 'lib/google/apis/compute_v1/classes.rb', line 19159

def list_managed_instances_results
  @list_managed_instances_results
end

#nameString

The name of the managed instance group. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


19165
19166
19167
# File 'lib/google/apis/compute_v1/classes.rb', line 19165

def name
  @name
end

#named_portsArray<Google::Apis::ComputeV1::NamedPort>

[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager. Corresponds to the JSON property namedPorts



19171
19172
19173
# File 'lib/google/apis/compute_v1/classes.rb', line 19171

def named_ports
  @named_ports
end

#regionString

Output only. [Output Only] The URL of theregion where the managed instance group resides (for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


19177
19178
19179
# File 'lib/google/apis/compute_v1/classes.rb', line 19177

def region
  @region
end

#resource_policiesGoogle::Apis::ComputeV1::InstanceGroupManagerResourcePolicies

Resource policies for this managed instance group. Corresponds to the JSON property resourcePolicies



19182
19183
19184
# File 'lib/google/apis/compute_v1/classes.rb', line 19182

def resource_policies
  @resource_policies
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


19187
19188
19189
# File 'lib/google/apis/compute_v1/classes.rb', line 19187

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


19193
19194
19195
# File 'lib/google/apis/compute_v1/classes.rb', line 19193

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] The URL for this managed instance group. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


19201
19202
19203
# File 'lib/google/apis/compute_v1/classes.rb', line 19201

def self_link
  @self_link
end

#standby_policyGoogle::Apis::ComputeV1::InstanceGroupManagerStandbyPolicy

Standby policy for stopped and suspended instances. Corresponds to the JSON property standbyPolicy



19206
19207
19208
# File 'lib/google/apis/compute_v1/classes.rb', line 19206

def standby_policy
  @standby_policy
end

#stateful_policyGoogle::Apis::ComputeV1::StatefulPolicy

Stateful configuration for this Instanced Group Manager Corresponds to the JSON property statefulPolicy



19211
19212
19213
# File 'lib/google/apis/compute_v1/classes.rb', line 19211

def stateful_policy
  @stateful_policy
end

#statusGoogle::Apis::ComputeV1::InstanceGroupManagerStatus

Output only. [Output Only] The status of this managed instance group. Corresponds to the JSON property status



19216
19217
19218
# File 'lib/google/apis/compute_v1/classes.rb', line 19216

def status
  @status
end

#target_poolsArray<String>

The URLs for all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


19223
19224
19225
# File 'lib/google/apis/compute_v1/classes.rb', line 19223

def target_pools
  @target_pools
end

#target_sizeFixnum

The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number. Corresponds to the JSON property targetSize

Returns:

  • (Fixnum)


19231
19232
19233
# File 'lib/google/apis/compute_v1/classes.rb', line 19231

def target_size
  @target_size
end

#target_stopped_sizeFixnum

The target number of stopped instances for this managed instance group. This number changes when you:

  • Stop instance using the stopInstances method or start instances using the startInstances method.
  • Manually change the targetStoppedSize using the update method. Corresponds to the JSON property targetStoppedSize

Returns:

  • (Fixnum)


19243
19244
19245
# File 'lib/google/apis/compute_v1/classes.rb', line 19243

def target_stopped_size
  @target_stopped_size
end

#target_suspended_sizeFixnum

The target number of suspended instances for this managed instance group. This number changes when you:

  • Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
  • Manually change the targetSuspendedSize using the update method. Corresponds to the JSON property targetSuspendedSize

Returns:

  • (Fixnum)


19255
19256
19257
# File 'lib/google/apis/compute_v1/classes.rb', line 19255

def target_suspended_size
  @target_suspended_size
end

#update_policyGoogle::Apis::ComputeV1::InstanceGroupManagerUpdatePolicy

The update policy for this managed instance group. Corresponds to the JSON property updatePolicy



19260
19261
19262
# File 'lib/google/apis/compute_v1/classes.rb', line 19260

def update_policy
  @update_policy
end

#versionsArray<Google::Apis::ComputeV1::InstanceGroupManagerVersion>

Specifies the instance templates used by this managed instance group to create instances. Each version is defined by an instanceTemplate and aname. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about therelationships between these fields. Exactly one version must leave thetargetSize field unset. That version will be applied to all remaining instances. For more information, read aboutcanary updates. Corresponds to the JSON property versions



19274
19275
19276
# File 'lib/google/apis/compute_v1/classes.rb', line 19274

def versions
  @versions
end

#zoneString

Output only. [Output Only] The URL of azone where the managed instance group is located (for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


19280
19281
19282
# File 'lib/google/apis/compute_v1/classes.rb', line 19280

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19287
19288
19289
19290
19291
19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
19317
19318
19319
19320
# File 'lib/google/apis/compute_v1/classes.rb', line 19287

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies)
  @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_actions = args[:current_actions] if args.key?(:current_actions)
  @description = args[:description] if args.key?(:description)
  @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @instance_lifecycle_policy = args[:instance_lifecycle_policy] if args.key?(:instance_lifecycle_policy)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @kind = args[:kind] if args.key?(:kind)
  @list_managed_instances_results = args[:list_managed_instances_results] if args.key?(:list_managed_instances_results)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @region = args[:region] if args.key?(:region)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @standby_policy = args[:standby_policy] if args.key?(:standby_policy)
  @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy)
  @status = args[:status] if args.key?(:status)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @target_size = args[:target_size] if args.key?(:target_size)
  @target_stopped_size = args[:target_stopped_size] if args.key?(:target_stopped_size)
  @target_suspended_size = args[:target_suspended_size] if args.key?(:target_suspended_size)
  @update_policy = args[:update_policy] if args.key?(:update_policy)
  @versions = args[:versions] if args.key?(:versions)
  @zone = args[:zone] if args.key?(:zone)
end