Class: Google::Apis::ComputeV1::InstanceGroupManager

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, read Instance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use the regionInstanceGroupManagers resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManager

Returns a new instance of InstanceGroupManager.



13148
13149
13150
# File 'lib/google/apis/compute_v1/classes.rb', line 13148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_healing_policiesArray<Google::Apis::ComputeV1::InstanceGroupManagerAutoHealingPolicy>

The autohealing policy for this managed instance group. You can specify only one value. Corresponds to the JSON property autoHealingPolicies



13009
13010
13011
# File 'lib/google/apis/compute_v1/classes.rb', line 13009

def auto_healing_policies
  @auto_healing_policies
end

#base_instance_nameString

The base instance name to use for instances in this group. The value must be 1- 58 characters long. Instances are named by appending a hyphen and a random four-character string to the base instance name. The base instance name must comply with RFC1035. Corresponds to the JSON property baseInstanceName

Returns:

  • (String)


13017
13018
13019
# File 'lib/google/apis/compute_v1/classes.rb', line 13017

def base_instance_name
  @base_instance_name
end

#creation_timestampString

[Output Only] The creation timestamp for this managed instance group in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


13023
13024
13025
# File 'lib/google/apis/compute_v1/classes.rb', line 13023

def creation_timestamp
  @creation_timestamp
end

#current_actionsGoogle::Apis::ComputeV1::InstanceGroupManagerActionsSummary

[Output Only] The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions. Corresponds to the JSON property currentActions



13029
13030
13031
# File 'lib/google/apis/compute_v1/classes.rb', line 13029

def current_actions
  @current_actions
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


13034
13035
13036
# File 'lib/google/apis/compute_v1/classes.rb', line 13034

def description
  @description
end

#distribution_policyGoogle::Apis::ComputeV1::DistributionPolicy

Policy specifying the intended distribution of managed instances across zones in a regional managed instance group. Corresponds to the JSON property distributionPolicy



13040
13041
13042
# File 'lib/google/apis/compute_v1/classes.rb', line 13040

def distribution_policy
  @distribution_policy
end

#fingerprintString

Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


13050
13051
13052
# File 'lib/google/apis/compute_v1/classes.rb', line 13050

def fingerprint
  @fingerprint
end

#idFixnum

[Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13056
13057
13058
# File 'lib/google/apis/compute_v1/classes.rb', line 13056

def id
  @id
end

#instance_groupString

[Output Only] The URL of the Instance Group resource. Corresponds to the JSON property instanceGroup

Returns:

  • (String)


13061
13062
13063
# File 'lib/google/apis/compute_v1/classes.rb', line 13061

def instance_group
  @instance_group
end

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


13070
13071
13072
# File 'lib/google/apis/compute_v1/classes.rb', line 13070

def instance_template
  @instance_template
end

#kindString

[Output Only] The resource type, which is always compute#instanceGroupManager for managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


13076
13077
13078
# File 'lib/google/apis/compute_v1/classes.rb', line 13076

def kind
  @kind
end

#nameString

The name of the managed instance group. The name must be 1-63 characters long, and comply with RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


13082
13083
13084
# File 'lib/google/apis/compute_v1/classes.rb', line 13082

def name
  @name
end

#named_portsArray<Google::Apis::ComputeV1::NamedPort>

Named ports configured for the Instance Groups complementary to this Instance Group Manager. Corresponds to the JSON property namedPorts



13088
13089
13090
# File 'lib/google/apis/compute_v1/classes.rb', line 13088

def named_ports
  @named_ports
end

#regionString

[Output Only] The URL of the region where the managed instance group resides ( for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


13094
13095
13096
# File 'lib/google/apis/compute_v1/classes.rb', line 13094

def region
  @region
end

[Output Only] The URL for this managed instance group. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


13100
13101
13102
# File 'lib/google/apis/compute_v1/classes.rb', line 13100

def self_link
  @self_link
end

#stateful_policyGoogle::Apis::ComputeV1::StatefulPolicy

Stateful configuration for this Instanced Group Manager Corresponds to the JSON property statefulPolicy



13105
13106
13107
# File 'lib/google/apis/compute_v1/classes.rb', line 13105

def stateful_policy
  @stateful_policy
end

#statusGoogle::Apis::ComputeV1::InstanceGroupManagerStatus

[Output Only] The status of this managed instance group. Corresponds to the JSON property status



13110
13111
13112
# File 'lib/google/apis/compute_v1/classes.rb', line 13110

def status
  @status
end

#target_poolsArray<String>

The URLs for all TargetPool resources to which instances in the instanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


13117
13118
13119
# File 'lib/google/apis/compute_v1/classes.rb', line 13117

def target_pools
  @target_pools
end

#target_sizeFixnum

The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number. Corresponds to the JSON property targetSize

Returns:

  • (Fixnum)


13124
13125
13126
# File 'lib/google/apis/compute_v1/classes.rb', line 13124

def target_size
  @target_size
end

#update_policyGoogle::Apis::ComputeV1::InstanceGroupManagerUpdatePolicy

The update policy for this managed instance group. Corresponds to the JSON property updatePolicy



13129
13130
13131
# File 'lib/google/apis/compute_v1/classes.rb', line 13129

def update_policy
  @update_policy
end

#versionsArray<Google::Apis::ComputeV1::InstanceGroupManagerVersion>

Specifies the instance templates used by this managed instance group to create instances. Each version is defined by an instanceTemplate and a name. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about the relationships between these fields. Exactly one version must leave the targetSize field unset. That version will be applied to all remaining instances. For more information, read about canary updates. Corresponds to the JSON property versions



13140
13141
13142
# File 'lib/google/apis/compute_v1/classes.rb', line 13140

def versions
  @versions
end

#zoneString

[Output Only] The URL of a zone where the managed instance group is located ( for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


13146
13147
13148
# File 'lib/google/apis/compute_v1/classes.rb', line 13146

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13153
13154
13155
13156
13157
13158
13159
13160
13161
13162
13163
13164
13165
13166
13167
13168
13169
13170
13171
13172
13173
13174
13175
13176
# File 'lib/google/apis/compute_v1/classes.rb', line 13153

def update!(**args)
  @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies)
  @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_actions = args[:current_actions] if args.key?(:current_actions)
  @description = args[:description] if args.key?(:description)
  @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy)
  @status = args[:status] if args.key?(:status)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @target_size = args[:target_size] if args.key?(:target_size)
  @update_policy = args[:update_policy] if args.key?(:update_policy)
  @versions = args[:versions] if args.key?(:versions)
  @zone = args[:zone] if args.key?(:zone)
end