Class: Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#abandoning ⇒ Fixnum
Output only.
-
#creating ⇒ Fixnum
Output only.
-
#creating_without_retries ⇒ Fixnum
Output only.
-
#deleting ⇒ Fixnum
Output only.
-
#none ⇒ Fixnum
Output only.
-
#recreating ⇒ Fixnum
Output only.
-
#refreshing ⇒ Fixnum
Output only.
-
#restarting ⇒ Fixnum
Output only.
-
#resuming ⇒ Fixnum
Output only.
-
#starting ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#verifying ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
constructor
A new instance of InstanceGroupManagerActionsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
Returns a new instance of InstanceGroupManagerActionsSummary.
23265 23266 23267 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abandoning ⇒ Fixnum
Output only. The total number of instances in the managed instance group
that are scheduled to be abandoned. Abandoning an instance removes it
from the managed instance group without deleting it.
Corresponds to the JSON property abandoning
23179 23180 23181 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23179 def abandoning @abandoning end |
#creating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be created or are currently being created. If the group
fails to create any of these instances, it tries again until it creates
the instance successfully.
If you have disabled creation retries, this field will not be populated;
instead, the creatingWithoutRetries field will be populated.
Corresponds to the JSON property creating
23189 23190 23191 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23189 def creating @creating end |
#creating_without_retries ⇒ Fixnum
Output only. The number of instances that the managed instance group
will attempt to create. The group attempts to create each instance
only once. If the group fails to create any of these instances, it
decreases the group's targetSize value accordingly.
Corresponds to the JSON property creatingWithoutRetries
23197 23198 23199 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23197 def creating_without_retries @creating_without_retries end |
#deleting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be deleted or are currently being deleted.
Corresponds to the JSON property deleting
23203 23204 23205 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23203 def deleting @deleting end |
#none ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are running and have no scheduled actions.
Corresponds to the JSON property none
23209 23210 23211 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23209 def none @none end |
#recreating ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be recreated or are currently being being recreated.
Recreating an instance deletes the existing root persistent disk
and creates a new disk from the image that is defined in the
instance template.
Corresponds to the JSON property recreating
23218 23219 23220 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23218 def recreating @recreating end |
#refreshing ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being reconfigured with properties that do not require a restart
or a recreate action. For example, setting or removing target
pools for the instance.
Corresponds to the JSON property refreshing
23226 23227 23228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23226 def refreshing @refreshing end |
#restarting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restarting
23232 23233 23234 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23232 def restarting @restarting end |
#resuming ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be resumed or are currently being resumed.
Corresponds to the JSON property resuming
23238 23239 23240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23238 def resuming @resuming end |
#starting ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be started or are currently being started.
Corresponds to the JSON property starting
23244 23245 23246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23244 def starting @starting end |
#stopping ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be stopped or are currently being stopped.
Corresponds to the JSON property stopping
23250 23251 23252 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23250 def stopping @stopping end |
#suspending ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are scheduled to be suspended or are currently being suspended.
Corresponds to the JSON property suspending
23256 23257 23258 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23256 def suspending @suspending end |
#verifying ⇒ Fixnum
Output only. The number of instances in the managed instance group that
are being verified. See the managedInstances[].currentAction
property in the listManagedInstances method documentation.
Corresponds to the JSON property verifying
23263 23264 23265 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23263 def @verifying end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23270 23271 23272 23273 23274 23275 23276 23277 23278 23279 23280 23281 23282 23283 23284 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23270 def update!(**args) @abandoning = args[:abandoning] if args.key?(:abandoning) @creating = args[:creating] if args.key?(:creating) @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries) @deleting = args[:deleting] if args.key?(:deleting) @none = args[:none] if args.key?(:none) @recreating = args[:recreating] if args.key?(:recreating) @refreshing = args[:refreshing] if args.key?(:refreshing) @restarting = args[:restarting] if args.key?(:restarting) @resuming = args[:resuming] if args.key?(:resuming) @starting = args[:starting] if args.key?(:starting) @stopping = args[:stopping] if args.key?(:stopping) @suspending = args[:suspending] if args.key?(:suspending) @verifying = args[:verifying] if args.key?(:verifying) end |