Class: Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



22913
22914
22915
# File 'lib/google/apis/compute_v1/classes.rb', line 22913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

Output only. The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


22827
22828
22829
# File 'lib/google/apis/compute_v1/classes.rb', line 22827

def abandoning
  @abandoning
end

#creatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


22837
22838
22839
# File 'lib/google/apis/compute_v1/classes.rb', line 22837

def creating
  @creating
end

#creating_without_retriesFixnum

Output only. The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


22845
22846
22847
# File 'lib/google/apis/compute_v1/classes.rb', line 22845

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


22851
22852
22853
# File 'lib/google/apis/compute_v1/classes.rb', line 22851

def deleting
  @deleting
end

#noneFixnum

Output only. The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


22857
22858
22859
# File 'lib/google/apis/compute_v1/classes.rb', line 22857

def none
  @none
end

#recreatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


22866
22867
22868
# File 'lib/google/apis/compute_v1/classes.rb', line 22866

def recreating
  @recreating
end

#refreshingFixnum

Output only. The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


22874
22875
22876
# File 'lib/google/apis/compute_v1/classes.rb', line 22874

def refreshing
  @refreshing
end

#restartingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


22880
22881
22882
# File 'lib/google/apis/compute_v1/classes.rb', line 22880

def restarting
  @restarting
end

#resumingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


22886
22887
22888
# File 'lib/google/apis/compute_v1/classes.rb', line 22886

def resuming
  @resuming
end

#startingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


22892
22893
22894
# File 'lib/google/apis/compute_v1/classes.rb', line 22892

def starting
  @starting
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


22898
22899
22900
# File 'lib/google/apis/compute_v1/classes.rb', line 22898

def stopping
  @stopping
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


22904
22905
22906
# File 'lib/google/apis/compute_v1/classes.rb', line 22904

def suspending
  @suspending
end

#verifyingFixnum

Output only. The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


22911
22912
22913
# File 'lib/google/apis/compute_v1/classes.rb', line 22911

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22918
22919
22920
22921
22922
22923
22924
22925
22926
22927
22928
22929
22930
22931
22932
# File 'lib/google/apis/compute_v1/classes.rb', line 22918

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @creating = args[:creating] if args.key?(:creating)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end