Class: Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



22735
22736
22737
# File 'lib/google/apis/compute_v1/classes.rb', line 22735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

Output only. The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


22649
22650
22651
# File 'lib/google/apis/compute_v1/classes.rb', line 22649

def abandoning
  @abandoning
end

#creatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


22659
22660
22661
# File 'lib/google/apis/compute_v1/classes.rb', line 22659

def creating
  @creating
end

#creating_without_retriesFixnum

Output only. The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


22667
22668
22669
# File 'lib/google/apis/compute_v1/classes.rb', line 22667

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


22673
22674
22675
# File 'lib/google/apis/compute_v1/classes.rb', line 22673

def deleting
  @deleting
end

#noneFixnum

Output only. The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


22679
22680
22681
# File 'lib/google/apis/compute_v1/classes.rb', line 22679

def none
  @none
end

#recreatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


22688
22689
22690
# File 'lib/google/apis/compute_v1/classes.rb', line 22688

def recreating
  @recreating
end

#refreshingFixnum

Output only. The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


22696
22697
22698
# File 'lib/google/apis/compute_v1/classes.rb', line 22696

def refreshing
  @refreshing
end

#restartingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


22702
22703
22704
# File 'lib/google/apis/compute_v1/classes.rb', line 22702

def restarting
  @restarting
end

#resumingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


22708
22709
22710
# File 'lib/google/apis/compute_v1/classes.rb', line 22708

def resuming
  @resuming
end

#startingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


22714
22715
22716
# File 'lib/google/apis/compute_v1/classes.rb', line 22714

def starting
  @starting
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


22720
22721
22722
# File 'lib/google/apis/compute_v1/classes.rb', line 22720

def stopping
  @stopping
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


22726
22727
22728
# File 'lib/google/apis/compute_v1/classes.rb', line 22726

def suspending
  @suspending
end

#verifyingFixnum

Output only. The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


22733
22734
22735
# File 'lib/google/apis/compute_v1/classes.rb', line 22733

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22740
22741
22742
22743
22744
22745
22746
22747
22748
22749
22750
22751
22752
22753
22754
# File 'lib/google/apis/compute_v1/classes.rb', line 22740

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @creating = args[:creating] if args.key?(:creating)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end