Class: Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



22228
22229
22230
# File 'lib/google/apis/compute_v1/classes.rb', line 22228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

Output only. The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


22142
22143
22144
# File 'lib/google/apis/compute_v1/classes.rb', line 22142

def abandoning
  @abandoning
end

#creatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


22152
22153
22154
# File 'lib/google/apis/compute_v1/classes.rb', line 22152

def creating
  @creating
end

#creating_without_retriesFixnum

Output only. The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


22160
22161
22162
# File 'lib/google/apis/compute_v1/classes.rb', line 22160

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


22166
22167
22168
# File 'lib/google/apis/compute_v1/classes.rb', line 22166

def deleting
  @deleting
end

#noneFixnum

Output only. The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


22172
22173
22174
# File 'lib/google/apis/compute_v1/classes.rb', line 22172

def none
  @none
end

#recreatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


22181
22182
22183
# File 'lib/google/apis/compute_v1/classes.rb', line 22181

def recreating
  @recreating
end

#refreshingFixnum

Output only. The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


22189
22190
22191
# File 'lib/google/apis/compute_v1/classes.rb', line 22189

def refreshing
  @refreshing
end

#restartingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


22195
22196
22197
# File 'lib/google/apis/compute_v1/classes.rb', line 22195

def restarting
  @restarting
end

#resumingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


22201
22202
22203
# File 'lib/google/apis/compute_v1/classes.rb', line 22201

def resuming
  @resuming
end

#startingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


22207
22208
22209
# File 'lib/google/apis/compute_v1/classes.rb', line 22207

def starting
  @starting
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


22213
22214
22215
# File 'lib/google/apis/compute_v1/classes.rb', line 22213

def stopping
  @stopping
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


22219
22220
22221
# File 'lib/google/apis/compute_v1/classes.rb', line 22219

def suspending
  @suspending
end

#verifyingFixnum

Output only. The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


22226
22227
22228
# File 'lib/google/apis/compute_v1/classes.rb', line 22226

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22233
22234
22235
22236
22237
22238
22239
22240
22241
22242
22243
22244
22245
22246
22247
# File 'lib/google/apis/compute_v1/classes.rb', line 22233

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @creating = args[:creating] if args.key?(:creating)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end