Class: Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#abandoning ⇒ Fixnum
Output only.
-
#creating ⇒ Fixnum
Output only.
-
#creating_without_retries ⇒ Fixnum
Output only.
-
#deleting ⇒ Fixnum
Output only.
-
#none ⇒ Fixnum
Output only.
-
#recreating ⇒ Fixnum
Output only.
-
#refreshing ⇒ Fixnum
Output only.
-
#restarting ⇒ Fixnum
Output only.
-
#resuming ⇒ Fixnum
Output only.
-
#starting ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#verifying ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
constructor
A new instance of InstanceGroupManagerActionsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
Returns a new instance of InstanceGroupManagerActionsSummary.
20118 20119 20120 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abandoning ⇒ Fixnum
Output only. [Output Only] The total number of instances in the managed
instance group
that are scheduled to be abandoned. Abandoning an instance removes it
from the managed instance group without deleting it.
Corresponds to the JSON property abandoning
20020 20021 20022 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20020 def abandoning @abandoning end |
#creating ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be created or are currently being created. If the group
fails to create any of these instances, it tries again until it creates
the instance successfully.
If you have disabled creation retries, this field will not be populated;
instead, the creatingWithoutRetries field will be populated.
Corresponds to the JSON property creating
20031 20032 20033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20031 def creating @creating end |
#creating_without_retries ⇒ Fixnum
Output only. [Output Only] The number of instances that the managed instance
group
will attempt to create. The group attempts to create each instance
only once. If the group fails to create any of these instances, it
decreases the group's targetSize value accordingly.
Corresponds to the JSON property creatingWithoutRetries
20040 20041 20042 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20040 def creating_without_retries @creating_without_retries end |
#deleting ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be deleted or are currently being deleted.
Corresponds to the JSON property deleting
20047 20048 20049 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20047 def deleting @deleting end |
#none ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are running and have no scheduled actions.
Corresponds to the JSON property none
20054 20055 20056 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20054 def none @none end |
#recreating ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be recreated or are currently being being recreated.
Recreating an instance deletes the existing root persistent disk
and creates a new disk from the image that is defined in the
instance template.
Corresponds to the JSON property recreating
20064 20065 20066 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20064 def recreating @recreating end |
#refreshing ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are being reconfigured with properties that do not require a restart
or a recreate action. For example, setting or removing target
pools for the instance.
Corresponds to the JSON property refreshing
20073 20074 20075 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20073 def refreshing @refreshing end |
#restarting ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restarting
20080 20081 20082 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20080 def restarting @restarting end |
#resuming ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be resumed or are currently being resumed.
Corresponds to the JSON property resuming
20087 20088 20089 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20087 def resuming @resuming end |
#starting ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be started or are currently being started.
Corresponds to the JSON property starting
20094 20095 20096 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20094 def starting @starting end |
#stopping ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be stopped or are currently being stopped.
Corresponds to the JSON property stopping
20101 20102 20103 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20101 def stopping @stopping end |
#suspending ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be suspended or are currently being suspended.
Corresponds to the JSON property suspending
20108 20109 20110 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20108 def suspending @suspending end |
#verifying ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are being verified. See the managedInstances[].currentAction
property in the listManagedInstances method documentation.
Corresponds to the JSON property verifying
20116 20117 20118 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20116 def @verifying end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20123 20124 20125 20126 20127 20128 20129 20130 20131 20132 20133 20134 20135 20136 20137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20123 def update!(**args) @abandoning = args[:abandoning] if args.key?(:abandoning) @creating = args[:creating] if args.key?(:creating) @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries) @deleting = args[:deleting] if args.key?(:deleting) @none = args[:none] if args.key?(:none) @recreating = args[:recreating] if args.key?(:recreating) @refreshing = args[:refreshing] if args.key?(:refreshing) @restarting = args[:restarting] if args.key?(:restarting) @resuming = args[:resuming] if args.key?(:resuming) @starting = args[:starting] if args.key?(:starting) @stopping = args[:stopping] if args.key?(:stopping) @suspending = args[:suspending] if args.key?(:suspending) @verifying = args[:verifying] if args.key?(:verifying) end |