Class: Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



19431
19432
19433
# File 'lib/google/apis/compute_v1/classes.rb', line 19431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

Output only. [Output Only] The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


19333
19334
19335
# File 'lib/google/apis/compute_v1/classes.rb', line 19333

def abandoning
  @abandoning
end

#creatingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


19344
19345
19346
# File 'lib/google/apis/compute_v1/classes.rb', line 19344

def creating
  @creating
end

#creating_without_retriesFixnum

Output only. [Output Only] The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


19353
19354
19355
# File 'lib/google/apis/compute_v1/classes.rb', line 19353

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


19360
19361
19362
# File 'lib/google/apis/compute_v1/classes.rb', line 19360

def deleting
  @deleting
end

#noneFixnum

Output only. [Output Only] The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


19367
19368
19369
# File 'lib/google/apis/compute_v1/classes.rb', line 19367

def none
  @none
end

#recreatingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


19377
19378
19379
# File 'lib/google/apis/compute_v1/classes.rb', line 19377

def recreating
  @recreating
end

#refreshingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


19386
19387
19388
# File 'lib/google/apis/compute_v1/classes.rb', line 19386

def refreshing
  @refreshing
end

#restartingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


19393
19394
19395
# File 'lib/google/apis/compute_v1/classes.rb', line 19393

def restarting
  @restarting
end

#resumingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


19400
19401
19402
# File 'lib/google/apis/compute_v1/classes.rb', line 19400

def resuming
  @resuming
end

#startingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


19407
19408
19409
# File 'lib/google/apis/compute_v1/classes.rb', line 19407

def starting
  @starting
end

#stoppingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


19414
19415
19416
# File 'lib/google/apis/compute_v1/classes.rb', line 19414

def stopping
  @stopping
end

#suspendingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


19421
19422
19423
# File 'lib/google/apis/compute_v1/classes.rb', line 19421

def suspending
  @suspending
end

#verifyingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


19429
19430
19431
# File 'lib/google/apis/compute_v1/classes.rb', line 19429

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19436
19437
19438
19439
19440
19441
19442
19443
19444
19445
19446
19447
19448
19449
19450
# File 'lib/google/apis/compute_v1/classes.rb', line 19436

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @creating = args[:creating] if args.key?(:creating)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end