Class: Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



13271
13272
13273
# File 'lib/google/apis/compute_v1/classes.rb', line 13271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

[Output Only] The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


13188
13189
13190
# File 'lib/google/apis/compute_v1/classes.rb', line 13188

def abandoning
  @abandoning
end

#creatingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


13197
13198
13199
# File 'lib/google/apis/compute_v1/classes.rb', line 13197

def creating
  @creating
end

#creating_without_retriesFixnum

[Output Only] The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


13205
13206
13207
# File 'lib/google/apis/compute_v1/classes.rb', line 13205

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


13211
13212
13213
# File 'lib/google/apis/compute_v1/classes.rb', line 13211

def deleting
  @deleting
end

#noneFixnum

[Output Only] The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


13217
13218
13219
# File 'lib/google/apis/compute_v1/classes.rb', line 13217

def none
  @none
end

#recreatingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


13225
13226
13227
# File 'lib/google/apis/compute_v1/classes.rb', line 13225

def recreating
  @recreating
end

#refreshingFixnum

[Output Only] The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


13232
13233
13234
# File 'lib/google/apis/compute_v1/classes.rb', line 13232

def refreshing
  @refreshing
end

#restartingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


13238
13239
13240
# File 'lib/google/apis/compute_v1/classes.rb', line 13238

def restarting
  @restarting
end

#resumingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


13244
13245
13246
# File 'lib/google/apis/compute_v1/classes.rb', line 13244

def resuming
  @resuming
end

#startingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


13250
13251
13252
# File 'lib/google/apis/compute_v1/classes.rb', line 13250

def starting
  @starting
end

#stoppingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


13256
13257
13258
# File 'lib/google/apis/compute_v1/classes.rb', line 13256

def stopping
  @stopping
end

#suspendingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


13262
13263
13264
# File 'lib/google/apis/compute_v1/classes.rb', line 13262

def suspending
  @suspending
end

#verifyingFixnum

[Output Only] The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


13269
13270
13271
# File 'lib/google/apis/compute_v1/classes.rb', line 13269

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13276
13277
13278
13279
13280
13281
13282
13283
13284
13285
13286
13287
13288
13289
13290
# File 'lib/google/apis/compute_v1/classes.rb', line 13276

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @creating = args[:creating] if args.key?(:creating)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end