Class: Google::Apis::ComputeV1::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



23333
23334
23335
# File 'lib/google/apis/compute_v1/classes.rb', line 23333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23294
23295
23296
# File 'lib/google/apis/compute_v1/classes.rb', line 23294

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



23299
23300
23301
# File 'lib/google/apis/compute_v1/classes.rb', line 23299

def items
  @items
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


23306
23307
23308
# File 'lib/google/apis/compute_v1/classes.rb', line 23306

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23316
23317
23318
# File 'lib/google/apis/compute_v1/classes.rb', line 23316

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23321
23322
23323
# File 'lib/google/apis/compute_v1/classes.rb', line 23321

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23326
23327
23328
# File 'lib/google/apis/compute_v1/classes.rb', line 23326

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagerAggregatedList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



23331
23332
23333
# File 'lib/google/apis/compute_v1/classes.rb', line 23331

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23338
23339
23340
23341
23342
23343
23344
23345
23346
# File 'lib/google/apis/compute_v1/classes.rb', line 23338

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end