Class: Google::Apis::ComputeV1::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



22803
22804
22805
# File 'lib/google/apis/compute_v1/classes.rb', line 22803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22764
22765
22766
# File 'lib/google/apis/compute_v1/classes.rb', line 22764

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



22769
22770
22771
# File 'lib/google/apis/compute_v1/classes.rb', line 22769

def items
  @items
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


22776
22777
22778
# File 'lib/google/apis/compute_v1/classes.rb', line 22776

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22786
22787
22788
# File 'lib/google/apis/compute_v1/classes.rb', line 22786

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22791
22792
22793
# File 'lib/google/apis/compute_v1/classes.rb', line 22791

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22796
22797
22798
# File 'lib/google/apis/compute_v1/classes.rb', line 22796

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagerAggregatedList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



22801
22802
22803
# File 'lib/google/apis/compute_v1/classes.rb', line 22801

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22808
22809
22810
22811
22812
22813
22814
22815
22816
# File 'lib/google/apis/compute_v1/classes.rb', line 22808

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end