Class: Google::Apis::ComputeV1::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



20188
20189
20190
# File 'lib/google/apis/compute_v1/classes.rb', line 20188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20148
20149
20150
# File 'lib/google/apis/compute_v1/classes.rb', line 20148

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



20153
20154
20155
# File 'lib/google/apis/compute_v1/classes.rb', line 20153

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


20160
20161
20162
# File 'lib/google/apis/compute_v1/classes.rb', line 20160

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20171
20172
20173
# File 'lib/google/apis/compute_v1/classes.rb', line 20171

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20176
20177
20178
# File 'lib/google/apis/compute_v1/classes.rb', line 20176

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20181
20182
20183
# File 'lib/google/apis/compute_v1/classes.rb', line 20181

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagerAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



20186
20187
20188
# File 'lib/google/apis/compute_v1/classes.rb', line 20186

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20193
20194
20195
20196
20197
20198
20199
20200
20201
# File 'lib/google/apis/compute_v1/classes.rb', line 20193

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end