Class: Google::Apis::ComputeV1::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#machine_types ⇒ Array<String>
Full machine-type names, e.g.
-
#rank ⇒ Fixnum
Preference of this instance selection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
constructor
A new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.
22986 22987 22988 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22986 def initialize(**args) update!(**args) end |
Instance Attribute Details
#machine_types ⇒ Array<String>
Full machine-type names, e.g. "n1-standard-16".
Corresponds to the JSON property machineTypes
22975 22976 22977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22975 def machine_types @machine_types end |
#rank ⇒ Fixnum
Preference of this instance selection. Lower number means higher
preference. MIG will first try to create a VM based on the machine-type
with lowest rank and fallback to next rank based on availability.
Machine types and instance selections with the same rank have the same
preference.
Corresponds to the JSON property rank
22984 22985 22986 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22984 def rank @rank end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22991 22992 22993 22994 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22991 def update!(**args) @machine_types = args[:machine_types] if args.key?(:machine_types) @rank = args[:rank] if args.key?(:rank) end |