Class: Google::Apis::ComputeV1::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.



22978
22979
22980
# File 'lib/google/apis/compute_v1/classes.rb', line 22978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#machine_typesArray<String>

Full machine-type names, e.g. "n1-standard-16". Corresponds to the JSON property machineTypes

Returns:

  • (Array<String>)


22967
22968
22969
# File 'lib/google/apis/compute_v1/classes.rb', line 22967

def machine_types
  @machine_types
end

#rankFixnum

Preference of this instance selection. Lower number means higher preference. MIG will first try to create a VM based on the machine-type with lowest rank and fallback to next rank based on availability. Machine types and instance selections with the same rank have the same preference. Corresponds to the JSON property rank

Returns:

  • (Fixnum)


22976
22977
22978
# File 'lib/google/apis/compute_v1/classes.rb', line 22976

def rank
  @rank
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22983
22984
22985
22986
# File 'lib/google/apis/compute_v1/classes.rb', line 22983

def update!(**args)
  @machine_types = args[:machine_types] if args.key?(:machine_types)
  @rank = args[:rank] if args.key?(:rank)
end