Class: Google::Apis::ComputeV1::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.



22473
22474
22475
# File 'lib/google/apis/compute_v1/classes.rb', line 22473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#machine_typesArray<String>

Full machine-type names, e.g. "n1-standard-16". Corresponds to the JSON property machineTypes

Returns:

  • (Array<String>)


22462
22463
22464
# File 'lib/google/apis/compute_v1/classes.rb', line 22462

def machine_types
  @machine_types
end

#rankFixnum

Preference of this instance selection. Lower number means higher preference. MIG will first try to create a VM based on the machine-type with lowest rank and fallback to next rank based on availability. Machine types and instance selections with the same rank have the same preference. Corresponds to the JSON property rank

Returns:

  • (Fixnum)


22471
22472
22473
# File 'lib/google/apis/compute_v1/classes.rb', line 22471

def rank
  @rank
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22478
22479
22480
22481
# File 'lib/google/apis/compute_v1/classes.rb', line 22478

def update!(**args)
  @machine_types = args[:machine_types] if args.key?(:machine_types)
  @rank = args[:rank] if args.key?(:rank)
end