Class: Google::Apis::ComputeV1::InstanceGroupManagerInstanceLifecyclePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerInstanceLifecyclePolicy

Returns a new instance of InstanceGroupManagerInstanceLifecyclePolicy.



20421
20422
20423
# File 'lib/google/apis/compute_v1/classes.rb', line 20421

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_action_on_failureString

The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are

  • REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG.
  • DO_NOTHING: MIG does not repair a failed or an unhealthy VM. Corresponds to the JSON property defaultActionOnFailure

Returns:

  • (String)


20390
20391
20392
# File 'lib/google/apis/compute_v1/classes.rb', line 20390

def default_action_on_failure
  @default_action_on_failure
end

#force_update_on_repairString

A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:

  • NO (default): If configuration updates are available, they are not forcefully applied during repair. Instead, configuration updates are applied according to the group's update policy.

  • YES: If configuration updates are available, they are applied during repair. Corresponds to the JSON property forceUpdateOnRepair

Returns:

  • (String)


20404
20405
20406
# File 'lib/google/apis/compute_v1/classes.rb', line 20404

def force_update_on_repair
  @force_update_on_repair
end

#on_failed_health_checkString

The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:

  • DEFAULT_ACTION (default): MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  • REPAIR: MIG automatically repairs an unhealthy VM by recreating it.
  • DO_NOTHING: MIG doesn't repair an unhealthy VM. For more information, see About repairing VMs in a MIG. Corresponds to the JSON property onFailedHealthCheck

Returns:

  • (String)


20419
20420
20421
# File 'lib/google/apis/compute_v1/classes.rb', line 20419

def on_failed_health_check
  @on_failed_health_check
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20426
20427
20428
20429
20430
# File 'lib/google/apis/compute_v1/classes.rb', line 20426

def update!(**args)
  @default_action_on_failure = args[:default_action_on_failure] if args.key?(:default_action_on_failure)
  @force_update_on_repair = args[:force_update_on_repair] if args.key?(:force_update_on_repair)
  @on_failed_health_check = args[:on_failed_health_check] if args.key?(:on_failed_health_check)
end