Class: Google::Apis::ComputeV1::InstanceGroupManagerInstanceLifecyclePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerInstanceLifecyclePolicy

Returns a new instance of InstanceGroupManagerInstanceLifecyclePolicy.



19719
19720
19721
# File 'lib/google/apis/compute_v1/classes.rb', line 19719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_action_on_failureString

The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are

  • REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG.
  • DO_NOTHING: MIG does not repair a failed or an unhealthy VM. Corresponds to the JSON property defaultActionOnFailure

Returns:

  • (String)


19703
19704
19705
# File 'lib/google/apis/compute_v1/classes.rb', line 19703

def default_action_on_failure
  @default_action_on_failure
end

#force_update_on_repairString

A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:

  • NO (default): If configuration updates are available, they are not forcefully applied during repair. Instead, configuration updates are applied according to the group's update policy.

  • YES: If configuration updates are available, they are applied during repair. Corresponds to the JSON property forceUpdateOnRepair

Returns:

  • (String)


19717
19718
19719
# File 'lib/google/apis/compute_v1/classes.rb', line 19717

def force_update_on_repair
  @force_update_on_repair
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19724
19725
19726
19727
# File 'lib/google/apis/compute_v1/classes.rb', line 19724

def update!(**args)
  @default_action_on_failure = args[:default_action_on_failure] if args.key?(:default_action_on_failure)
  @force_update_on_repair = args[:force_update_on_repair] if args.key?(:force_update_on_repair)
end