Class: Google::Apis::ComputeV1::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



23279
23280
23281
# File 'lib/google/apis/compute_v1/classes.rb', line 23279

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23245
23246
23247
# File 'lib/google/apis/compute_v1/classes.rb', line 23245

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



23250
23251
23252
# File 'lib/google/apis/compute_v1/classes.rb', line 23250

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


23257
23258
23259
# File 'lib/google/apis/compute_v1/classes.rb', line 23257

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23267
23268
23269
# File 'lib/google/apis/compute_v1/classes.rb', line 23267

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23272
23273
23274
# File 'lib/google/apis/compute_v1/classes.rb', line 23272

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



23277
23278
23279
# File 'lib/google/apis/compute_v1/classes.rb', line 23277

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23284
23285
23286
23287
23288
23289
23290
23291
# File 'lib/google/apis/compute_v1/classes.rb', line 23284

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end