Class: Google::Apis::ComputeV1::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



19772
19773
19774
# File 'lib/google/apis/compute_v1/classes.rb', line 19772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19738
19739
19740
# File 'lib/google/apis/compute_v1/classes.rb', line 19738

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



19743
19744
19745
# File 'lib/google/apis/compute_v1/classes.rb', line 19743

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


19749
19750
19751
# File 'lib/google/apis/compute_v1/classes.rb', line 19749

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19760
19761
19762
# File 'lib/google/apis/compute_v1/classes.rb', line 19760

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19765
19766
19767
# File 'lib/google/apis/compute_v1/classes.rb', line 19765

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagerList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



19770
19771
19772
# File 'lib/google/apis/compute_v1/classes.rb', line 19770

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19777
19778
19779
19780
19781
19782
19783
19784
# File 'lib/google/apis/compute_v1/classes.rb', line 19777

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end