Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequest

Returns a new instance of InstanceGroupManagerResizeRequest.



23261
23262
23263
# File 'lib/google/apis/compute_v1/classes.rb', line 23261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. The creation timestamp for this resize request inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


23186
23187
23188
# File 'lib/google/apis/compute_v1/classes.rb', line 23186

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


23191
23192
23193
# File 'lib/google/apis/compute_v1/classes.rb', line 23191

def description
  @description
end

#idFixnum

Output only. A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


23198
23199
23200
# File 'lib/google/apis/compute_v1/classes.rb', line 23198

def id
  @id
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerResizeRequest for resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


23204
23205
23206
# File 'lib/google/apis/compute_v1/classes.rb', line 23204

def kind
  @kind
end

#nameString

The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


23210
23211
23212
# File 'lib/google/apis/compute_v1/classes.rb', line 23210

def name
  @name
end

#regionString

Output only. The URL of a region where the resize request is located. Populated only for regional resize requests. Corresponds to the JSON property region

Returns:

  • (String)


23217
23218
23219
# File 'lib/google/apis/compute_v1/classes.rb', line 23217

def region
  @region
end

#requested_run_durationGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property requestedRunDuration



23225
23226
23227
# File 'lib/google/apis/compute_v1/classes.rb', line 23225

def requested_run_duration
  @requested_run_duration
end

#resize_byFixnum

The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'. Corresponds to the JSON property resizeBy

Returns:

  • (Fixnum)


23232
23233
23234
# File 'lib/google/apis/compute_v1/classes.rb', line 23232

def resize_by
  @resize_by
end

Output only. The URL for this resize request. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


23237
23238
23239
# File 'lib/google/apis/compute_v1/classes.rb', line 23237

def self_link
  @self_link
end

Output only. Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


23242
23243
23244
# File 'lib/google/apis/compute_v1/classes.rb', line 23242

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. Current state of the request. Corresponds to the JSON property state

Returns:

  • (String)


23247
23248
23249
# File 'lib/google/apis/compute_v1/classes.rb', line 23247

def state
  @state
end

#statusGoogle::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus

Output only. Status of the request. Corresponds to the JSON property status



23252
23253
23254
# File 'lib/google/apis/compute_v1/classes.rb', line 23252

def status
  @status
end

#zoneString

Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests. Corresponds to the JSON property zone

Returns:

  • (String)


23259
23260
23261
# File 'lib/google/apis/compute_v1/classes.rb', line 23259

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23266
23267
23268
23269
23270
23271
23272
23273
23274
23275
23276
23277
23278
23279
23280
# File 'lib/google/apis/compute_v1/classes.rb', line 23266

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration)
  @resize_by = args[:resize_by] if args.key?(:resize_by)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end