Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequest

Returns a new instance of InstanceGroupManagerResizeRequest.



20644
20645
20646
# File 'lib/google/apis/compute_v1/classes.rb', line 20644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] The creation timestamp for this resize request inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


20573
20574
20575
# File 'lib/google/apis/compute_v1/classes.rb', line 20573

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


20578
20579
20580
# File 'lib/google/apis/compute_v1/classes.rb', line 20578

def description
  @description
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


20585
20586
20587
# File 'lib/google/apis/compute_v1/classes.rb', line 20585

def id
  @id
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupManagerResizeRequest for resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


20592
20593
20594
# File 'lib/google/apis/compute_v1/classes.rb', line 20592

def kind
  @kind
end

#nameString

The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


20598
20599
20600
# File 'lib/google/apis/compute_v1/classes.rb', line 20598

def name
  @name
end

#requested_run_durationGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property requestedRunDuration



20606
20607
20608
# File 'lib/google/apis/compute_v1/classes.rb', line 20606

def requested_run_duration
  @requested_run_duration
end

#resize_byFixnum

The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'. Corresponds to the JSON property resizeBy

Returns:

  • (Fixnum)


20613
20614
20615
# File 'lib/google/apis/compute_v1/classes.rb', line 20613

def resize_by
  @resize_by
end

Output only. [Output Only] The URL for this resize request. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


20619
20620
20621
# File 'lib/google/apis/compute_v1/classes.rb', line 20619

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


20625
20626
20627
# File 'lib/google/apis/compute_v1/classes.rb', line 20625

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. [Output only] Current state of the request. Corresponds to the JSON property state

Returns:

  • (String)


20630
20631
20632
# File 'lib/google/apis/compute_v1/classes.rb', line 20630

def state
  @state
end

#statusGoogle::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus

Output only. [Output only] Status of the request. Corresponds to the JSON property status



20635
20636
20637
# File 'lib/google/apis/compute_v1/classes.rb', line 20635

def status
  @status
end

#zoneString

Output only. [Output Only] The URL of azone where the resize request is located. Populated only for zonal resize requests. Corresponds to the JSON property zone

Returns:

  • (String)


20642
20643
20644
# File 'lib/google/apis/compute_v1/classes.rb', line 20642

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
# File 'lib/google/apis/compute_v1/classes.rb', line 20649

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration)
  @resize_by = args[:resize_by] if args.key?(:resize_by)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end