Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of this resize request.
-
#requested_run_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
constructor
A new instance of InstanceGroupManagerResizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
Returns a new instance of InstanceGroupManagerResizeRequest.
19941 19942 19943 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this resize request
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
19870 19871 19872 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19870 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
19875 19876 19877 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19875 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
19882 19883 19884 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19882 def id @id end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceGroupManagerResizeRequest for
resize requests.
Corresponds to the JSON property kind
19889 19890 19891 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19889 def kind @kind end |
#name ⇒ String
The name of this resize request. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
19895 19896 19897 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19895 def name @name end |
#requested_run_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property requestedRunDuration
19903 19904 19905 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19903 def requested_run_duration @requested_run_duration end |
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request. The group's
target size will be increased by this number. This field cannot be used
together with 'instances'.
Corresponds to the JSON property resizeBy
19910 19911 19912 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19910 def resize_by @resize_by end |
#self_link ⇒ String
Output only. [Output Only] The URL for this resize request. The server defines
this URL.
Corresponds to the JSON property selfLink
19916 19917 19918 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19916 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
19922 19923 19924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19922 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. [Output only] Current state of the request.
Corresponds to the JSON property state
19927 19928 19929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19927 def state @state end |
#status ⇒ Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus
Output only. [Output only] Status of the request.
Corresponds to the JSON property status
19932 19933 19934 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19932 def status @status end |
#zone ⇒ String
Output only. [Output Only] The URL of azone
where the resize request is located. Populated only for zonal resize
requests.
Corresponds to the JSON property zone
19939 19940 19941 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19939 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19946 19947 19948 19949 19950 19951 19952 19953 19954 19955 19956 19957 19958 19959 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19946 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration) @resize_by = args[:resize_by] if args.key?(:resize_by) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |