Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestStatus

Returns a new instance of InstanceGroupManagerResizeRequestStatus.



23499
23500
23501
# File 'lib/google/apis/compute_v1/classes.rb', line 23499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus::Error

Output only. Fatal errors encountered during the queueing or provisioning phases of the ResizeRequest that caused the transition to the FAILED state. Contrary to the last_attempt errors, this field is final and errors are never removed from here, as the ResizeRequest is not going to retry. Corresponds to the JSON property error



23484
23485
23486
# File 'lib/google/apis/compute_v1/classes.rb', line 23484

def error
  @error
end

#last_attemptGoogle::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatusLastAttempt

Output only. Information about the last attempt to fulfill the request. The value is temporary since the ResizeRequest can retry, as long as it's still active and the last attempt value can either be cleared or replaced with a different error. Since ResizeRequest retries infrequently, the value may be stale and no longer show an active problem. The value is cleared when ResizeRequest transitions to the final state (becomes inactive). If the final state is FAILED the error describing it will be stored in the "error" field only. Corresponds to the JSON property lastAttempt



23497
23498
23499
# File 'lib/google/apis/compute_v1/classes.rb', line 23497

def last_attempt
  @last_attempt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23504
23505
23506
23507
# File 'lib/google/apis/compute_v1/classes.rb', line 23504

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @last_attempt = args[:last_attempt] if args.key?(:last_attempt)
end