Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Output only. [Output only] Fatal errors encountered during the queueing or provisioning phases of the ResizeRequest that caused the transition to the FAILED state. Contrary to the last_attempt errors, this field is final and errors are never removed from here, as the ResizeRequest is not going to retry.

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



20012
20013
20014
# File 'lib/google/apis/compute_v1/classes.rb', line 20012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestStatus::Error::Error>

[Output Only] The array of errors encountered while processing this operation. Corresponds to the JSON property errors



20010
20011
20012
# File 'lib/google/apis/compute_v1/classes.rb', line 20010

def errors
  @errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20017
20018
20019
# File 'lib/google/apis/compute_v1/classes.rb', line 20017

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
end