Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] A list of resize requests.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest>
A list of resize request resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
constructor
A new instance of InstanceGroupManagerResizeRequestsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.
24199 24200 24201 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
24165 24166 24167 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24165 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest>
A list of resize request resources.
Corresponds to the JSON property items
24170 24171 24172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24170 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#
instanceGroupManagerResizeRequestList for
a list of resize requests.
Corresponds to the JSON property kind
24177 24178 24179 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24177 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for list
requests.
If the number of results is larger than maxResults, use thenextPageToken as a
value for the query parameterpageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
24187 24188 24189 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24187 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
24192 24193 24194 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24192 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
24197 24198 24199 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24197 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24204 24205 24206 24207 24208 24209 24210 24211 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24204 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |