Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



23847
23848
23849
# File 'lib/google/apis/compute_v1/classes.rb', line 23847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23813
23814
23815
# File 'lib/google/apis/compute_v1/classes.rb', line 23813

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



23818
23819
23820
# File 'lib/google/apis/compute_v1/classes.rb', line 23818

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


23825
23826
23827
# File 'lib/google/apis/compute_v1/classes.rb', line 23825

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use thenextPageToken as a value for the query parameterpageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23835
23836
23837
# File 'lib/google/apis/compute_v1/classes.rb', line 23835

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23840
23841
23842
# File 'lib/google/apis/compute_v1/classes.rb', line 23840

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



23845
23846
23847
# File 'lib/google/apis/compute_v1/classes.rb', line 23845

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23852
23853
23854
23855
23856
23857
23858
23859
# File 'lib/google/apis/compute_v1/classes.rb', line 23852

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end