Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] A list of resize requests.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest>
A list of resize request resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
constructor
A new instance of InstanceGroupManagerResizeRequestsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.
23843 23844 23845 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23809 23810 23811 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23809 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest>
A list of resize request resources.
Corresponds to the JSON property items
23814 23815 23816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23814 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#
instanceGroupManagerResizeRequestList for
a list of resize requests.
Corresponds to the JSON property kind
23821 23822 23823 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23821 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for list
requests.
If the number of results is larger than maxResults, use thenextPageToken as a
value for the query parameterpageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23831 23832 23833 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23831 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23836 23837 23838 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23836 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
23841 23842 23843 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23841 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23848 23849 23850 23851 23852 23853 23854 23855 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23848 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |