Class: Google::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



23815
23816
23817
# File 'lib/google/apis/compute_v1/classes.rb', line 23815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23781
23782
23783
# File 'lib/google/apis/compute_v1/classes.rb', line 23781

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



23786
23787
23788
# File 'lib/google/apis/compute_v1/classes.rb', line 23786

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


23793
23794
23795
# File 'lib/google/apis/compute_v1/classes.rb', line 23793

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use thenextPageToken as a value for the query parameterpageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23803
23804
23805
# File 'lib/google/apis/compute_v1/classes.rb', line 23803

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23808
23809
23810
# File 'lib/google/apis/compute_v1/classes.rb', line 23808

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



23813
23814
23815
# File 'lib/google/apis/compute_v1/classes.rb', line 23813

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23820
23821
23822
23823
23824
23825
23826
23827
# File 'lib/google/apis/compute_v1/classes.rb', line 23820

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end