Class: Google::Apis::ComputeV1::InstanceGroupManagerStandbyPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStandbyPolicy

Returns a new instance of InstanceGroupManagerStandbyPolicy.



20439
20440
20441
# File 'lib/google/apis/compute_v1/classes.rb', line 20439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#initial_delay_secFixnum

Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created. The initial delay gives the initialization script the time to prepare your VM for a quick scale out. The value of initial delay must be between 0 and 3600 seconds. The default value is 0. Corresponds to the JSON property initialDelaySec

Returns:

  • (Fixnum)


20431
20432
20433
# File 'lib/google/apis/compute_v1/classes.rb', line 20431

def initial_delay_sec
  @initial_delay_sec
end

#modeString

Defines how a MIG resumes or starts VMs from a standby pool when the group scales out. The default mode is MANUAL. Corresponds to the JSON property mode

Returns:

  • (String)


20437
20438
20439
# File 'lib/google/apis/compute_v1/classes.rb', line 20437

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20444
20445
20446
20447
# File 'lib/google/apis/compute_v1/classes.rb', line 20444

def update!(**args)
  @initial_delay_sec = args[:initial_delay_sec] if args.key?(:initial_delay_sec)
  @mode = args[:mode] if args.key?(:mode)
end