Class: Google::Apis::ComputeV1::InstanceGroupManagerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatus

Returns a new instance of InstanceGroupManagerStatus.



24048
24049
24050
# File 'lib/google/apis/compute_v1/classes.rb', line 24048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeV1::InstanceGroupManagerStatusAllInstancesConfig

Output only. Status of all-instances configuration on the group. Corresponds to the JSON property allInstancesConfig



23997
23998
23999
# File 'lib/google/apis/compute_v1/classes.rb', line 23997

def all_instances_config
  @all_instances_config
end

#applied_accelerator_topologiesArray<Google::Apis::ComputeV1::InstanceGroupManagerStatusAcceleratorTopology>

Output only. The accelerator topology applied to this MIG. Currently only one accelerator topology is supported. Corresponds to the JSON property appliedAcceleratorTopologies



24003
24004
24005
# File 'lib/google/apis/compute_v1/classes.rb', line 24003

def applied_accelerator_topologies
  @applied_accelerator_topologies
end

#autoscalerString

Output only. The URL of theAutoscaler that targets this instance group manager. Corresponds to the JSON property autoscaler

Returns:

  • (String)


24009
24010
24011
# File 'lib/google/apis/compute_v1/classes.rb', line 24009

def autoscaler
  @autoscaler
end

#bulk_instance_operationGoogle::Apis::ComputeV1::InstanceGroupManagerStatusBulkInstanceOperation

Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK. Corresponds to the JSON property bulkInstanceOperation



24015
24016
24017
# File 'lib/google/apis/compute_v1/classes.rb', line 24015

def bulk_instance_operation
  @bulk_instance_operation
end

#current_instance_statusesGoogle::Apis::ComputeV1::InstanceGroupManagerStatusInstanceStatusSummary

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs. Corresponds to the JSON property currentInstanceStatuses



24023
24024
24025
# File 'lib/google/apis/compute_v1/classes.rb', line 24023

def current_instance_statuses
  @current_instance_statuses
end

#is_stableBoolean Also known as: is_stable?

Output only. A bit indicating whether the managed instance group is in a stable state. A stable state means that: none of the instances in the managed instance group is currently undergoing any type of change (for example, creation, restart, or deletion); no future changes are scheduled for instances in the managed instance group; and the managed instance group itself is not being modified. Corresponds to the JSON property isStable

Returns:

  • (Boolean)


24033
24034
24035
# File 'lib/google/apis/compute_v1/classes.rb', line 24033

def is_stable
  @is_stable
end

#statefulGoogle::Apis::ComputeV1::InstanceGroupManagerStatusStateful

Output only. Stateful status of the given Instance Group Manager. Corresponds to the JSON property stateful



24039
24040
24041
# File 'lib/google/apis/compute_v1/classes.rb', line 24039

def stateful
  @stateful
end

#version_targetGoogle::Apis::ComputeV1::InstanceGroupManagerStatusVersionTarget

Output only. A status of consistency of Instances' versions with their target version specified by version field on Instance Group Manager. Corresponds to the JSON property versionTarget



24046
24047
24048
# File 'lib/google/apis/compute_v1/classes.rb', line 24046

def version_target
  @version_target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24053
24054
24055
24056
24057
24058
24059
24060
24061
24062
# File 'lib/google/apis/compute_v1/classes.rb', line 24053

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @applied_accelerator_topologies = args[:applied_accelerator_topologies] if args.key?(:applied_accelerator_topologies)
  @autoscaler = args[:autoscaler] if args.key?(:autoscaler)
  @bulk_instance_operation = args[:bulk_instance_operation] if args.key?(:bulk_instance_operation)
  @current_instance_statuses = args[:current_instance_statuses] if args.key?(:current_instance_statuses)
  @is_stable = args[:is_stable] if args.key?(:is_stable)
  @stateful = args[:stateful] if args.key?(:stateful)
  @version_target = args[:version_target] if args.key?(:version_target)
end