Class: Google::Apis::ComputeV1::InstanceGroupManagerStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusAllInstancesConfig
Output only.
-
#applied_accelerator_topologies ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManagerStatusAcceleratorTopology>
Output only.
-
#autoscaler ⇒ String
Output only.
-
#bulk_instance_operation ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusBulkInstanceOperation
Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK.
-
#current_instance_statuses ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusInstanceStatusSummary
The list of instance statuses and the number of instances in this managed instance group that have the status.
-
#is_stable ⇒ Boolean
(also: #is_stable?)
Output only.
-
#stateful ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusStateful
Output only.
-
#version_target ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusVersionTarget
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatus
constructor
A new instance of InstanceGroupManagerStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatus
Returns a new instance of InstanceGroupManagerStatus.
23325 23326 23327 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusAllInstancesConfig
Output only. Status of all-instances configuration on the group.
Corresponds to the JSON property allInstancesConfig
23274 23275 23276 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23274 def all_instances_config @all_instances_config end |
#applied_accelerator_topologies ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManagerStatusAcceleratorTopology>
Output only. The accelerator topology applied to this MIG.
Currently only one accelerator topology is supported.
Corresponds to the JSON property appliedAcceleratorTopologies
23280 23281 23282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23280 def applied_accelerator_topologies @applied_accelerator_topologies end |
#autoscaler ⇒ String
Output only. The URL of theAutoscaler
that targets this instance group manager.
Corresponds to the JSON property autoscaler
23286 23287 23288 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23286 def autoscaler @autoscaler end |
#bulk_instance_operation ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusBulkInstanceOperation
Bulk instance operation is the creation of VMs in a MIG when the
targetSizePolicy.mode is set to BULK.
Corresponds to the JSON property bulkInstanceOperation
23292 23293 23294 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23292 def bulk_instance_operation @bulk_instance_operation end |
#current_instance_statuses ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusInstanceStatusSummary
The list of instance statuses and the number of instances in this managed
instance group that have the status. For more information about how to
interpret each status check the instance lifecycle documentation.
Currently only shown for TPU MIGs.
Corresponds to the JSON property currentInstanceStatuses
23300 23301 23302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23300 def current_instance_statuses @current_instance_statuses end |
#is_stable ⇒ Boolean Also known as: is_stable?
Output only. A bit indicating whether the managed instance group is in a
stable state. A stable state means that: none of the instances in the
managed instance group is currently undergoing any type of change (for
example, creation, restart, or deletion); no future changes are scheduled
for instances in the managed instance group; and the managed instance
group itself is not being modified.
Corresponds to the JSON property isStable
23310 23311 23312 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23310 def is_stable @is_stable end |
#stateful ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusStateful
Output only. Stateful status of the given Instance Group Manager.
Corresponds to the JSON property stateful
23316 23317 23318 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23316 def stateful @stateful end |
#version_target ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusVersionTarget
Output only. A status of consistency of Instances' versions with their
target version specified by version field on Instance Group
Manager.
Corresponds to the JSON property versionTarget
23323 23324 23325 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23323 def version_target @version_target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23330 23331 23332 23333 23334 23335 23336 23337 23338 23339 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23330 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @applied_accelerator_topologies = args[:applied_accelerator_topologies] if args.key?(:applied_accelerator_topologies) @autoscaler = args[:autoscaler] if args.key?(:autoscaler) @bulk_instance_operation = args[:bulk_instance_operation] if args.key?(:bulk_instance_operation) @current_instance_statuses = args[:current_instance_statuses] if args.key?(:current_instance_statuses) @is_stable = args[:is_stable] if args.key?(:is_stable) @stateful = args[:stateful] if args.key?(:stateful) @version_target = args[:version_target] if args.key?(:version_target) end |