Class: Google::Apis::ComputeV1::InstanceGroupManagerStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusAllInstancesConfig
Output only.
-
#autoscaler ⇒ String
Output only.
-
#is_stable ⇒ Boolean
(also: #is_stable?)
Output only.
-
#stateful ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusStateful
Output only.
-
#version_target ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusVersionTarget
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatus
constructor
A new instance of InstanceGroupManagerStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatus
Returns a new instance of InstanceGroupManagerStatus.
20490 20491 20492 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusAllInstancesConfig
Output only. [Output only] Status of all-instances configuration on the group.
Corresponds to the JSON property allInstancesConfig
20457 20458 20459 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20457 def all_instances_config @all_instances_config end |
#autoscaler ⇒ String
Output only. [Output Only] The URL of theAutoscaler
that targets this instance group manager.
Corresponds to the JSON property autoscaler
20463 20464 20465 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20463 def autoscaler @autoscaler end |
#is_stable ⇒ Boolean Also known as: is_stable?
Output only. [Output Only] A bit indicating whether the managed instance group
is in a
stable state. A stable state means that: none of the instances in the
managed instance group is currently undergoing any type of change (for
example, creation, restart, or deletion); no future changes are scheduled
for instances in the managed instance group; and the managed instance
group itself is not being modified.
Corresponds to the JSON property isStable
20474 20475 20476 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20474 def is_stable @is_stable end |
#stateful ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusStateful
Output only. [Output Only] Stateful status of the given Instance Group Manager.
Corresponds to the JSON property stateful
20480 20481 20482 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20480 def stateful @stateful end |
#version_target ⇒ Google::Apis::ComputeV1::InstanceGroupManagerStatusVersionTarget
Output only. [Output Only] A status of consistency of Instances' versions with
their
target version specified by version field on Instance Group
Manager.
Corresponds to the JSON property versionTarget
20488 20489 20490 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20488 def version_target @version_target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20495 20496 20497 20498 20499 20500 20501 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20495 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @autoscaler = args[:autoscaler] if args.key?(:autoscaler) @is_stable = args[:is_stable] if args.key?(:is_stable) @stateful = args[:stateful] if args.key?(:stateful) @version_target = args[:version_target] if args.key?(:version_target) end |