Class: Google::Apis::ComputeV1::InstanceGroupManagerStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusAcceleratorTopology

Returns a new instance of InstanceGroupManagerStatusAcceleratorTopology.



24055
24056
24057
# File 'lib/google/apis/compute_v1/classes.rb', line 24055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


24042
24043
24044
# File 'lib/google/apis/compute_v1/classes.rb', line 24042

def accelerator_topology
  @accelerator_topology
end

#stateString

Output only. The state of the accelerator topology. Corresponds to the JSON property state

Returns:

  • (String)


24047
24048
24049
# File 'lib/google/apis/compute_v1/classes.rb', line 24047

def state
  @state
end

#state_detailsGoogle::Apis::ComputeV1::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails

Output only. The result of the latest accelerator topology state check. Corresponds to the JSON property stateDetails



24053
24054
24055
# File 'lib/google/apis/compute_v1/classes.rb', line 24053

def state_details
  @state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24060
24061
24062
24063
24064
# File 'lib/google/apis/compute_v1/classes.rb', line 24060

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
end