Class: Google::Apis::ComputeV1::InstanceGroupManagerStatusVersionTarget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusVersionTarget

Returns a new instance of InstanceGroupManagerStatusVersionTarget.



21304
21305
21306
# File 'lib/google/apis/compute_v1/classes.rb', line 21304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_reachedBoolean Also known as: is_reached?

Output only. [Output Only] A bit indicating whether version target has been reached in this managed instance group, i.e. all instances are in their target version. Instances' target version are specified byversion field on Instance Group Manager. Corresponds to the JSON property isReached

Returns:

  • (Boolean)


21301
21302
21303
# File 'lib/google/apis/compute_v1/classes.rb', line 21301

def is_reached
  @is_reached
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21309
21310
21311
# File 'lib/google/apis/compute_v1/classes.rb', line 21309

def update!(**args)
  @is_reached = args[:is_reached] if args.key?(:is_reached)
end