Class: Google::Apis::ComputeV1::InstanceGroupManagerStatusVersionTarget
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerStatusVersionTarget
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#is_reached ⇒ Boolean
(also: #is_reached?)
[Output Only] A bit indicating whether version target has been reached in this managed instance group, i.e.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatusVersionTarget
constructor
A new instance of InstanceGroupManagerStatusVersionTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatusVersionTarget
Returns a new instance of InstanceGroupManagerStatusVersionTarget.
13676 13677 13678 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13676 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_reached ⇒ Boolean Also known as: is_reached?
[Output Only] A bit indicating whether version target has been reached in this
managed instance group, i.e. all instances are in their target version.
Instances' target version are specified by version field on Instance Group
Manager.
Corresponds to the JSON property isReached
13673 13674 13675 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13673 def is_reached @is_reached end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13681 13682 13683 |
# File 'lib/google/apis/compute_v1/classes.rb', line 13681 def update!(**args) @is_reached = args[:is_reached] if args.key?(:is_reached) end |