Class: Google::Apis::ComputeV1::InstanceGroupManagersListManagedInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagersListManagedInstancesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#managed_instances ⇒ Array<Google::Apis::ComputeV1::ManagedInstance>
Output only.
-
#next_page_token ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersListManagedInstancesResponse
constructor
A new instance of InstanceGroupManagersListManagedInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersListManagedInstancesResponse
Returns a new instance of InstanceGroupManagersListManagedInstancesResponse.
24784 24785 24786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#managed_instances ⇒ Array<Google::Apis::ComputeV1::ManagedInstance>
Output only. [Output Only] The list of instances in the managed instance group.
Corresponds to the JSON property managedInstances
24771 24772 24773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24771 def managed_instances @managed_instances end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
24782 24783 24784 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24782 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24789 24790 24791 24792 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24789 def update!(**args) @managed_instances = args[:managed_instances] if args.key?(:managed_instances) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |