Class: Google::Apis::ComputeV1::InstanceGroupManagersListPerInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersListPerInstanceConfigsResp

Returns a new instance of InstanceGroupManagersListPerInstanceConfigsResp.



14021
14022
14023
# File 'lib/google/apis/compute_v1/classes.rb', line 14021

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeV1::PerInstanceConfig>

[Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



14005
14006
14007
# File 'lib/google/apis/compute_v1/classes.rb', line 14005

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14014
14015
14016
# File 'lib/google/apis/compute_v1/classes.rb', line 14014

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagersListPerInstanceConfigsResp::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14019
14020
14021
# File 'lib/google/apis/compute_v1/classes.rb', line 14019

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14026
14027
14028
14029
14030
# File 'lib/google/apis/compute_v1/classes.rb', line 14026

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end