Class: Google::Apis::ComputeV1::InstanceGroupManagersScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersScopedList

Returns a new instance of InstanceGroupManagersScopedList.



21848
21849
21850
# File 'lib/google/apis/compute_v1/classes.rb', line 21848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_group_managersArray<Google::Apis::ComputeV1::InstanceGroupManager>

Output only. [Output Only] The list of managed instance groups that are contained in the specified project and zone. Corresponds to the JSON property instanceGroupManagers



21839
21840
21841
# File 'lib/google/apis/compute_v1/classes.rb', line 21839

def instance_group_managers
  @instance_group_managers
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagersScopedList::Warning

Output only. [Output Only] The warning that replaces the list of managed instance groups when the list is empty. Corresponds to the JSON property warning



21846
21847
21848
# File 'lib/google/apis/compute_v1/classes.rb', line 21846

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21853
21854
21855
21856
# File 'lib/google/apis/compute_v1/classes.rb', line 21853

def update!(**args)
  @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers)
  @warning = args[:warning] if args.key?(:warning)
end