Class: Google::Apis::ComputeV1::InstanceGroupManagersScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersScopedList

Returns a new instance of InstanceGroupManagersScopedList.



21145
21146
21147
# File 'lib/google/apis/compute_v1/classes.rb', line 21145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_group_managersArray<Google::Apis::ComputeV1::InstanceGroupManager>

Output only. [Output Only] The list of managed instance groups that are contained in the specified project and zone. Corresponds to the JSON property instanceGroupManagers



21136
21137
21138
# File 'lib/google/apis/compute_v1/classes.rb', line 21136

def instance_group_managers
  @instance_group_managers
end

#warningGoogle::Apis::ComputeV1::InstanceGroupManagersScopedList::Warning

Output only. [Output Only] The warning that replaces the list of managed instance groups when the list is empty. Corresponds to the JSON property warning



21143
21144
21145
# File 'lib/google/apis/compute_v1/classes.rb', line 21143

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21150
21151
21152
21153
# File 'lib/google/apis/compute_v1/classes.rb', line 21150

def update!(**args)
  @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers)
  @warning = args[:warning] if args.key?(:warning)
end