Class: Google::Apis::ComputeV1::InstanceGroupManagersSetInstanceTemplateRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersSetInstanceTemplateRequest

Returns a new instance of InstanceGroupManagersSetInstanceTemplateRequest.



25293
25294
25295
# File 'lib/google/apis/compute_v1/classes.rb', line 25293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


25291
25292
25293
# File 'lib/google/apis/compute_v1/classes.rb', line 25291

def instance_template
  @instance_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25298
25299
25300
# File 'lib/google/apis/compute_v1/classes.rb', line 25298

def update!(**args)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
end