Class: Google::Apis::ComputeV1::InstanceGroupManagersSetInstanceTemplateRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagersSetInstanceTemplateRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#instance_template ⇒ String
The URL of the instance template that is specified for this managed instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersSetInstanceTemplateRequest
constructor
A new instance of InstanceGroupManagersSetInstanceTemplateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersSetInstanceTemplateRequest
Returns a new instance of InstanceGroupManagersSetInstanceTemplateRequest.
21944 21945 21946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21944 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_template ⇒ String
The URL of the instance template that is specified for this managed
instance group. The group uses this template to create all new instances
in the managed instance group. The templates for existing instances in the
group do not change unless you run recreateInstances,
runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE.
Corresponds to the JSON property instanceTemplate
21942 21943 21944 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21942 def instance_template @instance_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21949 21950 21951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21949 def update!(**args) @instance_template = args[:instance_template] if args.key?(:instance_template) end |