Class: Google::Apis::ComputeV1::InstanceGroupManagersSetTargetPoolsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagersSetTargetPoolsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
The fingerprint of the target pools information.
-
#target_pools ⇒ Array<String>
The list of target pool URLs that instances in this managed instance group belong to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersSetTargetPoolsRequest
constructor
A new instance of InstanceGroupManagersSetTargetPoolsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersSetTargetPoolsRequest
Returns a new instance of InstanceGroupManagersSetTargetPoolsRequest.
25110 25111 25112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
The fingerprint of the target pools information. Use this optional
property to prevent conflicts when multiple users change the target pools
settings concurrently. Obtain the fingerprint with theinstanceGroupManagers.
get
method. Then, include the fingerprint in your request to ensure that you
do not overwrite changes that were applied from another
concurrent request.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
25100 25101 25102 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25100 def fingerprint @fingerprint end |
#target_pools ⇒ Array<String>
The list of target pool URLs that instances in this managed instance group
belong to. The managed instance group applies these target pools to all
of the instances in the group. Existing instances and new instances in the
group all receive these target pool settings.
Corresponds to the JSON property targetPools
25108 25109 25110 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25108 def target_pools @target_pools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25115 25116 25117 25118 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25115 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @target_pools = args[:target_pools] if args.key?(:target_pools) end |