Class: Google::Apis::ComputeV1::InstanceGroupManagersSuspendInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagersSuspendInstancesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#force_suspend ⇒ Boolean
(also: #force_suspend?)
If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them.
-
#instances ⇒ Array<String>
The URLs of one or more instances to suspend.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersSuspendInstancesRequest
constructor
A new instance of InstanceGroupManagersSuspendInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersSuspendInstancesRequest
Returns a new instance of InstanceGroupManagersSuspendInstancesRequest.
24676 24677 24678 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24676 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force_suspend ⇒ Boolean Also known as: force_suspend?
If this flag is set to true, the Instance Group Manager will proceed to
suspend the instances, skipping initialization on them.
Corresponds to the JSON property forceSuspend
24667 24668 24669 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24667 def force_suspend @force_suspend end |
#instances ⇒ Array<String>
The URLs of one or more instances to suspend. This can be a full URL or
a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
Corresponds to the JSON property instances
24674 24675 24676 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24674 def instances @instances end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24681 24682 24683 24684 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24681 def update!(**args) @force_suspend = args[:force_suspend] if args.key?(:force_suspend) @instances = args[:instances] if args.key?(:instances) end |