Class: Google::Apis::ComputeV1::InstanceGroupManagersSuspendInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersSuspendInstancesRequest

Returns a new instance of InstanceGroupManagersSuspendInstancesRequest.



21351
21352
21353
# File 'lib/google/apis/compute_v1/classes.rb', line 21351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#force_suspendBoolean Also known as: force_suspend?

If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them. Corresponds to the JSON property forceSuspend

Returns:

  • (Boolean)


21342
21343
21344
# File 'lib/google/apis/compute_v1/classes.rb', line 21342

def force_suspend
  @force_suspend
end

#instancesArray<String>

The URLs of one or more instances to suspend. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME]. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


21349
21350
21351
# File 'lib/google/apis/compute_v1/classes.rb', line 21349

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21356
21357
21358
21359
# File 'lib/google/apis/compute_v1/classes.rb', line 21356

def update!(**args)
  @force_suspend = args[:force_suspend] if args.key?(:force_suspend)
  @instances = args[:instances] if args.key?(:instances)
end