Class: Google::Apis::ComputeV1::InstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstances

Returns a new instance of InstanceGroupsListInstances.



25460
25461
25462
# File 'lib/google/apis/compute_v1/classes.rb', line 25460

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25425
25426
25427
# File 'lib/google/apis/compute_v1/classes.rb', line 25425

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



25430
25431
25432
# File 'lib/google/apis/compute_v1/classes.rb', line 25430

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupsListInstances for the list of instances in the specified instance group. Corresponds to the JSON property kind

Returns:

  • (String)


25437
25438
25439
# File 'lib/google/apis/compute_v1/classes.rb', line 25437

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25448
25449
25450
# File 'lib/google/apis/compute_v1/classes.rb', line 25448

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25453
25454
25455
# File 'lib/google/apis/compute_v1/classes.rb', line 25453

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



25458
25459
25460
# File 'lib/google/apis/compute_v1/classes.rb', line 25458

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25465
25466
25467
25468
25469
25470
25471
25472
# File 'lib/google/apis/compute_v1/classes.rb', line 25465

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end