Class: Google::Apis::ComputeV1::InstanceGroupsListInstances
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupsListInstances
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceWithNamedPorts>
A list of InstanceWithNamedPorts resources.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute# instanceGroupsListInstances for the list of instances in the specified instance group.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceGroupsListInstances::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsListInstances
constructor
A new instance of InstanceGroupsListInstances.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupsListInstances
Returns a new instance of InstanceGroupsListInstances.
14364 14365 14366 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
14331 14332 14333 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14331 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceWithNamedPorts>
A list of InstanceWithNamedPorts resources.
Corresponds to the JSON property items
14336 14337 14338 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14336 def items @items end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#
instanceGroupsListInstances for the list of instances in the specified
instance group.
Corresponds to the JSON property kind
14343 14344 14345 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14343 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
14352 14353 14354 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14352 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
14357 14358 14359 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14357 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceGroupsListInstances::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
14362 14363 14364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14362 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14369 14370 14371 14372 14373 14374 14375 14376 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14369 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |