Class: Google::Apis::ComputeV1::InstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstancesRequest

Returns a new instance of InstanceGroupsListInstancesRequest.



25944
25945
25946
# File 'lib/google/apis/compute_v1/classes.rb', line 25944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_stateString

A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Corresponds to the JSON property instanceState

Returns:

  • (String)


25942
25943
25944
# File 'lib/google/apis/compute_v1/classes.rb', line 25942

def instance_state
  @instance_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25949
25950
25951
# File 'lib/google/apis/compute_v1/classes.rb', line 25949

def update!(**args)
  @instance_state = args[:instance_state] if args.key?(:instance_state)
end