Class: Google::Apis::ComputeV1::InstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstancesRequest

Returns a new instance of InstanceGroupsListInstancesRequest.



25375
25376
25377
# File 'lib/google/apis/compute_v1/classes.rb', line 25375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_stateString

A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Corresponds to the JSON property instanceState

Returns:

  • (String)


25373
25374
25375
# File 'lib/google/apis/compute_v1/classes.rb', line 25373

def instance_state
  @instance_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25380
25381
25382
# File 'lib/google/apis/compute_v1/classes.rb', line 25380

def update!(**args)
  @instance_state = args[:instance_state] if args.key?(:instance_state)
end