Class: Google::Apis::ComputeV1::InstanceGroupsListInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupsListInstancesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#instance_state ⇒ String
A filter for the state of the instances in the instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsListInstancesRequest
constructor
A new instance of InstanceGroupsListInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupsListInstancesRequest
Returns a new instance of InstanceGroupsListInstancesRequest.
24865 24866 24867 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24865 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_state ⇒ String
A filter for the state of the instances in the instance group. Valid
options are ALL or RUNNING. If you do not specify
this parameter the list includes all instances regardless of their state.
Corresponds to the JSON property instanceState
24863 24864 24865 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24863 def instance_state @instance_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24870 24871 24872 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24870 def update!(**args) @instance_state = args[:instance_state] if args.key?(:instance_state) end |