Class: Google::Apis::ComputeV1::InstanceGroupsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsScopedList

Returns a new instance of InstanceGroupsScopedList.



21585
21586
21587
# File 'lib/google/apis/compute_v1/classes.rb', line 21585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_groupsArray<Google::Apis::ComputeV1::InstanceGroup>

Output only. [Output Only] The list ofinstance groups that are contained in this scope. Corresponds to the JSON property instanceGroups



21577
21578
21579
# File 'lib/google/apis/compute_v1/classes.rb', line 21577

def instance_groups
  @instance_groups
end

#warningGoogle::Apis::ComputeV1::InstanceGroupsScopedList::Warning

Output only. [Output Only] An informational warning that replaces the list of instance groups when the list is empty. Corresponds to the JSON property warning



21583
21584
21585
# File 'lib/google/apis/compute_v1/classes.rb', line 21583

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21590
21591
21592
21593
# File 'lib/google/apis/compute_v1/classes.rb', line 21590

def update!(**args)
  @instance_groups = args[:instance_groups] if args.key?(:instance_groups)
  @warning = args[:warning] if args.key?(:warning)
end