Class: Google::Apis::ComputeV1::InstanceGroupsSetNamedPortsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupsSetNamedPortsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeV1::NamedPort>
The list of named ports to set for this instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest
constructor
A new instance of InstanceGroupsSetNamedPortsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest
Returns a new instance of InstanceGroupsSetNamedPortsRequest.
25524 25525 25526 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25524 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
Use this optional property to prevent conflicts when multiple users change
the named ports settings concurrently. Obtain the fingerprint with
theinstanceGroups.get
method. Then, include the fingerprint in your request to ensure that you
do not overwrite changes that were applied from another concurrent request.
A request with an incorrect fingerprint will fail with error412
conditionNotMet.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
25517 25518 25519 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25517 def fingerprint @fingerprint end |
#named_ports ⇒ Array<Google::Apis::ComputeV1::NamedPort>
The list of named ports to set for this instance group.
Corresponds to the JSON property namedPorts
25522 25523 25524 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25522 def named_ports @named_ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25529 25530 25531 25532 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25529 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @named_ports = args[:named_ports] if args.key?(:named_ports) end |