Class: Google::Apis::ComputeV1::InstanceGroupsSetNamedPortsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupsSetNamedPortsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeV1::NamedPort>
The list of named ports to set for this instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest
constructor
A new instance of InstanceGroupsSetNamedPortsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest
Returns a new instance of InstanceGroupsSetNamedPortsRequest.
14595 14596 14597 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group. Use
this optional property to prevent conflicts when multiple users change the
named ports settings concurrently. Obtain the fingerprint with the
instanceGroups.get method. Then, include the fingerprint in your request to
ensure that you do not overwrite changes that were applied from another
concurrent request. A request with an incorrect fingerprint will fail with
error 412 conditionNotMet.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
14588 14589 14590 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14588 def fingerprint @fingerprint end |
#named_ports ⇒ Array<Google::Apis::ComputeV1::NamedPort>
The list of named ports to set for this instance group.
Corresponds to the JSON property namedPorts
14593 14594 14595 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14593 def named_ports @named_ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14600 14601 14602 14603 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14600 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @named_ports = args[:named_ports] if args.key?(:named_ports) end |