Class: Google::Apis::ComputeV1::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of instances.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Instance>
A list of Instance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
26144 26145 26146 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
26111 26112 26113 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26111 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Instance>
A list of Instance resources.
Corresponds to the JSON property items
26116 26117 26118 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26116 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#instanceList
for lists of Instance resources.
Corresponds to the JSON property kind
26122 26123 26124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26122 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26132 26133 26134 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26132 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
26137 26138 26139 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26137 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26142 26143 26144 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26142 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26149 26150 26151 26152 26153 26154 26155 26156 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26149 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |