Class: Google::Apis::ComputeV1::InstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of instances.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceList

Returns a new instance of InstanceList.



25784
25785
25786
# File 'lib/google/apis/compute_v1/classes.rb', line 25784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25751
25752
25753
# File 'lib/google/apis/compute_v1/classes.rb', line 25751

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Instance>

A list of Instance resources. Corresponds to the JSON property items



25756
25757
25758
# File 'lib/google/apis/compute_v1/classes.rb', line 25756

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#instanceList for lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


25762
25763
25764
# File 'lib/google/apis/compute_v1/classes.rb', line 25762

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25772
25773
25774
# File 'lib/google/apis/compute_v1/classes.rb', line 25772

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25777
25778
25779
# File 'lib/google/apis/compute_v1/classes.rb', line 25777

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25782
25783
25784
# File 'lib/google/apis/compute_v1/classes.rb', line 25782

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25789
25790
25791
25792
25793
25794
25795
25796
# File 'lib/google/apis/compute_v1/classes.rb', line 25789

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end