Class: Google::Apis::ComputeV1::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of instances.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Instance>
A list of Instance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
25757 25758 25759 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25724 25725 25726 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25724 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Instance>
A list of Instance resources.
Corresponds to the JSON property items
25729 25730 25731 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25729 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#instanceList
for lists of Instance resources.
Corresponds to the JSON property kind
25735 25736 25737 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25735 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25745 25746 25747 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25745 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25750 25751 25752 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25750 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
25755 25756 25757 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25755 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25762 25763 25764 25765 25766 25767 25768 25769 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25762 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |