Class: Google::Apis::ComputeV1::InstanceListReferrers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceListReferrers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of instance referrers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Reference>
A list of Reference resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceListReferrers
constructor
A new instance of InstanceListReferrers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceListReferrers
Returns a new instance of InstanceListReferrers.
26269 26270 26271 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26269 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
26236 26237 26238 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26236 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Reference>
A list of Reference resources.
Corresponds to the JSON property items
26241 26242 26243 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26241 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceListReferrers for lists of Instance referrers.
Corresponds to the JSON property kind
26247 26248 26249 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26247 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26257 26258 26259 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26257 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
26262 26263 26264 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26262 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26267 26268 26269 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26267 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26274 26275 26276 26277 26278 26279 26280 26281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26274 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |