Class: Google::Apis::ComputeV1::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



25917
25918
25919
# File 'lib/google/apis/compute_v1/classes.rb', line 25917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25884
25885
25886
# File 'lib/google/apis/compute_v1/classes.rb', line 25884

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Reference>

A list of Reference resources. Corresponds to the JSON property items



25889
25890
25891
# File 'lib/google/apis/compute_v1/classes.rb', line 25889

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


25895
25896
25897
# File 'lib/google/apis/compute_v1/classes.rb', line 25895

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25905
25906
25907
# File 'lib/google/apis/compute_v1/classes.rb', line 25905

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25910
25911
25912
# File 'lib/google/apis/compute_v1/classes.rb', line 25910

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25915
25916
25917
# File 'lib/google/apis/compute_v1/classes.rb', line 25915

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25922
25923
25924
25925
25926
25927
25928
25929
# File 'lib/google/apis/compute_v1/classes.rb', line 25922

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end