Class: Google::Apis::ComputeV1::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



25692
25693
25694
# File 'lib/google/apis/compute_v1/classes.rb', line 25692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25659
25660
25661
# File 'lib/google/apis/compute_v1/classes.rb', line 25659

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Reference>

A list of Reference resources. Corresponds to the JSON property items



25664
25665
25666
# File 'lib/google/apis/compute_v1/classes.rb', line 25664

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


25670
25671
25672
# File 'lib/google/apis/compute_v1/classes.rb', line 25670

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25680
25681
25682
# File 'lib/google/apis/compute_v1/classes.rb', line 25680

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25685
25686
25687
# File 'lib/google/apis/compute_v1/classes.rb', line 25685

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25690
25691
25692
# File 'lib/google/apis/compute_v1/classes.rb', line 25690

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25697
25698
25699
25700
25701
25702
25703
25704
# File 'lib/google/apis/compute_v1/classes.rb', line 25697

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end