Class: Google::Apis::ComputeV1::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



25190
25191
25192
# File 'lib/google/apis/compute_v1/classes.rb', line 25190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25157
25158
25159
# File 'lib/google/apis/compute_v1/classes.rb', line 25157

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Reference>

A list of Reference resources. Corresponds to the JSON property items



25162
25163
25164
# File 'lib/google/apis/compute_v1/classes.rb', line 25162

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


25168
25169
25170
# File 'lib/google/apis/compute_v1/classes.rb', line 25168

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25178
25179
25180
# File 'lib/google/apis/compute_v1/classes.rb', line 25178

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25183
25184
25185
# File 'lib/google/apis/compute_v1/classes.rb', line 25183

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25188
25189
25190
# File 'lib/google/apis/compute_v1/classes.rb', line 25188

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25195
25196
25197
25198
25199
25200
25201
25202
# File 'lib/google/apis/compute_v1/classes.rb', line 25195

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end