Class: Google::Apis::ComputeV1::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



22568
22569
22570
# File 'lib/google/apis/compute_v1/classes.rb', line 22568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22535
22536
22537
# File 'lib/google/apis/compute_v1/classes.rb', line 22535

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Reference>

A list of Reference resources. Corresponds to the JSON property items



22540
22541
22542
# File 'lib/google/apis/compute_v1/classes.rb', line 22540

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


22546
22547
22548
# File 'lib/google/apis/compute_v1/classes.rb', line 22546

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22556
22557
22558
# File 'lib/google/apis/compute_v1/classes.rb', line 22556

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22561
22562
22563
# File 'lib/google/apis/compute_v1/classes.rb', line 22561

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22566
22567
22568
# File 'lib/google/apis/compute_v1/classes.rb', line 22566

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22573
22574
22575
22576
22577
22578
22579
22580
# File 'lib/google/apis/compute_v1/classes.rb', line 22573

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end