Class: Google::Apis::ComputeV1::InstanceListReferrers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceListReferrers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of instance referrers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Reference>
A list of Reference resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceListReferrers
constructor
A new instance of InstanceListReferrers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceListReferrers
Returns a new instance of InstanceListReferrers.
21865 21866 21867 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21865 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21832 21833 21834 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21832 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Reference>
A list of Reference resources.
Corresponds to the JSON property items
21837 21838 21839 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21837 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceListReferrers for lists of Instance referrers.
Corresponds to the JSON property kind
21843 21844 21845 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21843 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21853 21854 21855 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21853 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21858 21859 21860 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21858 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21863 21864 21865 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21863 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21870 21871 21872 21873 21874 21875 21876 21877 |
# File 'lib/google/apis/compute_v1/classes.rb', line 21870 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |