Class: Google::Apis::ComputeV1::InstanceListReferrers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceListReferrers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of instance referrers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Reference>
A list of Reference resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceListReferrers
constructor
A new instance of InstanceListReferrers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceListReferrers
Returns a new instance of InstanceListReferrers.
14763 14764 14765 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
14731 14732 14733 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14731 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Reference>
A list of Reference resources.
Corresponds to the JSON property items
14736 14737 14738 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14736 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#instanceListReferrers for lists
of Instance referrers.
Corresponds to the JSON property kind
14742 14743 14744 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14742 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
14751 14752 14753 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14751 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
14756 14757 14758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14756 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
14761 14762 14763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14761 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14768 14769 14770 14771 14772 14773 14774 14775 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14768 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |