Class: Google::Apis::ComputeV1::InstanceManagedByIgmError

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmError

Returns a new instance of InstanceManagedByIgmError.



25989
25990
25991
# File 'lib/google/apis/compute_v1/classes.rb', line 25989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeV1::InstanceManagedByIgmErrorManagedInstanceError

Output only. Contents of the error. Corresponds to the JSON property error



25974
25975
25976
# File 'lib/google/apis/compute_v1/classes.rb', line 25974

def error
  @error
end

#instance_action_detailsGoogle::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails

Output only. Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional. Corresponds to the JSON property instanceActionDetails



25981
25982
25983
# File 'lib/google/apis/compute_v1/classes.rb', line 25981

def instance_action_details
  @instance_action_details
end

#timestampString

Output only. The time that this error occurred. This value is in RFC3339 text format. Corresponds to the JSON property timestamp

Returns:

  • (String)


25987
25988
25989
# File 'lib/google/apis/compute_v1/classes.rb', line 25987

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25994
25995
25996
25997
25998
# File 'lib/google/apis/compute_v1/classes.rb', line 25994

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @instance_action_details = args[:instance_action_details] if args.key?(:instance_action_details)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end