Class: Google::Apis::ComputeV1::InstanceManagedByIgmError

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmError

Returns a new instance of InstanceManagedByIgmError.



25800
25801
25802
# File 'lib/google/apis/compute_v1/classes.rb', line 25800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeV1::InstanceManagedByIgmErrorManagedInstanceError

Output only. [Output Only] Contents of the error. Corresponds to the JSON property error



25784
25785
25786
# File 'lib/google/apis/compute_v1/classes.rb', line 25784

def error
  @error
end

#instance_action_detailsGoogle::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails

Output only. [Output Only] Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional. Corresponds to the JSON property instanceActionDetails



25792
25793
25794
# File 'lib/google/apis/compute_v1/classes.rb', line 25792

def instance_action_details
  @instance_action_details
end

#timestampString

Output only. [Output Only] The time that this error occurred. This value is in RFC3339 text format. Corresponds to the JSON property timestamp

Returns:

  • (String)


25798
25799
25800
# File 'lib/google/apis/compute_v1/classes.rb', line 25798

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25805
25806
25807
25808
25809
# File 'lib/google/apis/compute_v1/classes.rb', line 25805

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @instance_action_details = args[:instance_action_details] if args.key?(:instance_action_details)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end