Class: Google::Apis::ComputeV1::InstanceManagedByIgmError

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmError

Returns a new instance of InstanceManagedByIgmError.



21973
21974
21975
# File 'lib/google/apis/compute_v1/classes.rb', line 21973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeV1::InstanceManagedByIgmErrorManagedInstanceError

Output only. [Output Only] Contents of the error. Corresponds to the JSON property error



21957
21958
21959
# File 'lib/google/apis/compute_v1/classes.rb', line 21957

def error
  @error
end

#instance_action_detailsGoogle::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails

Output only. [Output Only] Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional. Corresponds to the JSON property instanceActionDetails



21965
21966
21967
# File 'lib/google/apis/compute_v1/classes.rb', line 21965

def instance_action_details
  @instance_action_details
end

#timestampString

Output only. [Output Only] The time that this error occurred. This value is in RFC3339 text format. Corresponds to the JSON property timestamp

Returns:

  • (String)


21971
21972
21973
# File 'lib/google/apis/compute_v1/classes.rb', line 21971

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21978
21979
21980
21981
21982
# File 'lib/google/apis/compute_v1/classes.rb', line 21978

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @instance_action_details = args[:instance_action_details] if args.key?(:instance_action_details)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end