Class: Google::Apis::ComputeV1::InstanceManagedByIgmError
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceManagedByIgmError
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeV1::InstanceManagedByIgmErrorManagedInstanceError
[Output Only] Contents of the error.
-
#instance_action_details ⇒ Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails
[Output Only] Details of the instance action that triggered this error.
-
#timestamp ⇒ String
[Output Only] The time that this error occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmError
constructor
A new instance of InstanceManagedByIgmError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmError
Returns a new instance of InstanceManagedByIgmError.
14864 14865 14866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeV1::InstanceManagedByIgmErrorManagedInstanceError
[Output Only] Contents of the error.
Corresponds to the JSON property error
14849 14850 14851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14849 def error @error end |
#instance_action_details ⇒ Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails
[Output Only] Details of the instance action that triggered this error. May be
null, if the error was not caused by an action on an instance. This field is
optional.
Corresponds to the JSON property instanceActionDetails
14856 14857 14858 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14856 def instance_action_details @instance_action_details end |
#timestamp ⇒ String
[Output Only] The time that this error occurred. This value is in RFC3339 text
format.
Corresponds to the JSON property timestamp
14862 14863 14864 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14862 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14869 14870 14871 14872 14873 |
# File 'lib/google/apis/compute_v1/classes.rb', line 14869 def update!(**args) @error = args[:error] if args.key?(:error) @instance_action_details = args[:instance_action_details] if args.key?(:instance_action_details) @timestamp = args[:timestamp] if args.key?(:timestamp) end |