Class: Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#instance ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeV1::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
constructor
A new instance of InstanceManagedByIgmErrorInstanceActionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.
26054 26055 26056 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. Action that managed instance group was executing on the instance
when the
error occurred. Possible values:
Corresponds to the JSON property action
26037 26038 26039 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26037 def action @action end |
#instance ⇒ String
Output only. The URL of the instance. The URL can be set even if the instance
has not
yet been created.
Corresponds to the JSON property instance
26044 26045 26046 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26044 def instance @instance end |
#version ⇒ Google::Apis::ComputeV1::ManagedInstanceVersion
Output only. Version this instance was created from, or was being
created from, but the creation failed. Corresponds to one of the versions
that were set on the Instance Group Manager resource at the time this
instance was being created.
Corresponds to the JSON property version
26052 26053 26054 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26052 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26059 26060 26061 26062 26063 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26059 def update!(**args) @action = args[:action] if args.key?(:action) @instance = args[:instance] if args.key?(:instance) @version = args[:version] if args.key?(:version) end |