Class: Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails

Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.



26026
26027
26028
# File 'lib/google/apis/compute_v1/classes.rb', line 26026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. Action that managed instance group was executing on the instance when the error occurred. Possible values: Corresponds to the JSON property action

Returns:

  • (String)


26009
26010
26011
# File 'lib/google/apis/compute_v1/classes.rb', line 26009

def action
  @action
end

#instanceString

Output only. The URL of the instance. The URL can be set even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


26016
26017
26018
# File 'lib/google/apis/compute_v1/classes.rb', line 26016

def instance
  @instance
end

#versionGoogle::Apis::ComputeV1::ManagedInstanceVersion

Output only. Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created. Corresponds to the JSON property version



26024
26025
26026
# File 'lib/google/apis/compute_v1/classes.rb', line 26024

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26031
26032
26033
26034
26035
# File 'lib/google/apis/compute_v1/classes.rb', line 26031

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @instance = args[:instance] if args.key?(:instance)
  @version = args[:version] if args.key?(:version)
end