Class: Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails

Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.



26027
26028
26029
# File 'lib/google/apis/compute_v1/classes.rb', line 26027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. Action that managed instance group was executing on the instance when the error occurred. Possible values: Corresponds to the JSON property action

Returns:

  • (String)


26010
26011
26012
# File 'lib/google/apis/compute_v1/classes.rb', line 26010

def action
  @action
end

#instanceString

Output only. The URL of the instance. The URL can be set even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


26017
26018
26019
# File 'lib/google/apis/compute_v1/classes.rb', line 26017

def instance
  @instance
end

#versionGoogle::Apis::ComputeV1::ManagedInstanceVersion

Output only. Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created. Corresponds to the JSON property version



26025
26026
26027
# File 'lib/google/apis/compute_v1/classes.rb', line 26025

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26032
26033
26034
26035
26036
# File 'lib/google/apis/compute_v1/classes.rb', line 26032

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @instance = args[:instance] if args.key?(:instance)
  @version = args[:version] if args.key?(:version)
end