Class: Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails

Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.



25335
25336
25337
# File 'lib/google/apis/compute_v1/classes.rb', line 25335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. [Output Only] Action that managed instance group was executing on the instance when the error occurred. Possible values: Corresponds to the JSON property action

Returns:

  • (String)


25318
25319
25320
# File 'lib/google/apis/compute_v1/classes.rb', line 25318

def action
  @action
end

#instanceString

Output only. [Output Only] The URL of the instance. The URL can be set even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


25324
25325
25326
# File 'lib/google/apis/compute_v1/classes.rb', line 25324

def instance
  @instance
end

#versionGoogle::Apis::ComputeV1::ManagedInstanceVersion

Output only. [Output Only] Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created. Corresponds to the JSON property version



25333
25334
25335
# File 'lib/google/apis/compute_v1/classes.rb', line 25333

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25340
25341
25342
25343
25344
# File 'lib/google/apis/compute_v1/classes.rb', line 25340

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @instance = args[:instance] if args.key?(:instance)
  @version = args[:version] if args.key?(:version)
end