Class: Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#instance ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeV1::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
constructor
A new instance of InstanceManagedByIgmErrorInstanceActionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.
22713 22714 22715 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22713 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. [Output Only] Action that managed instance group was executing on
the instance when the error occurred. Possible values:
Corresponds to the JSON property action
22696 22697 22698 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22696 def action @action end |
#instance ⇒ String
Output only. [Output Only] The URL of the instance.
The URL can be set even if the instance has not yet been created.
Corresponds to the JSON property instance
22702 22703 22704 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22702 def instance @instance end |
#version ⇒ Google::Apis::ComputeV1::ManagedInstanceVersion
Output only. [Output Only] Version this instance was created from, or was
being
created from, but the creation failed. Corresponds to one of the versions
that were set on the Instance Group Manager resource at the time this
instance was being created.
Corresponds to the JSON property version
22711 22712 22713 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22711 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22718 22719 22720 22721 22722 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22718 def update!(**args) @action = args[:action] if args.key?(:action) @instance = args[:instance] if args.key?(:instance) @version = args[:version] if args.key?(:version) end |