Class: Google::Apis::ComputeV1::InstanceManagedByIgmErrorInstanceActionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails

Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.



14900
14901
14902
# File 'lib/google/apis/compute_v1/classes.rb', line 14900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

[Output Only] Action that managed instance group was executing on the instance when the error occurred. Possible values: Corresponds to the JSON property action

Returns:

  • (String)


14884
14885
14886
# File 'lib/google/apis/compute_v1/classes.rb', line 14884

def action
  @action
end

#instanceString

[Output Only] The URL of the instance. The URL can be set even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


14890
14891
14892
# File 'lib/google/apis/compute_v1/classes.rb', line 14890

def instance
  @instance
end

#versionGoogle::Apis::ComputeV1::ManagedInstanceVersion

[Output Only] Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created. Corresponds to the JSON property version



14898
14899
14900
# File 'lib/google/apis/compute_v1/classes.rb', line 14898

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14905
14906
14907
14908
14909
# File 'lib/google/apis/compute_v1/classes.rb', line 14905

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @instance = args[:instance] if args.key?(:instance)
  @version = args[:version] if args.key?(:version)
end