Class: Google::Apis::ComputeV1::InstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceProperties

Returns a new instance of InstanceProperties.



26322
26323
26324
# File 'lib/google/apis/compute_v1/classes.rb', line 26322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeV1::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



26174
26175
26176
# File 'lib/google/apis/compute_v1/classes.rb', line 26174

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


26185
26186
26187
# File 'lib/google/apis/compute_v1/classes.rb', line 26185

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeV1::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



26191
26192
26193
# File 'lib/google/apis/compute_v1/classes.rb', line 26191

def confidential_instance_config
  @confidential_instance_config
end

#descriptionString

An optional text description for the instances that are created from these properties. Corresponds to the JSON property description

Returns:

  • (String)


26197
26198
26199
# File 'lib/google/apis/compute_v1/classes.rb', line 26197

def description
  @description
end

#disksArray<Google::Apis::ComputeV1::AttachedDisk>

An array of disks that are associated with the instances that are created from these properties. Corresponds to the JSON property disks



26203
26204
26205
# File 'lib/google/apis/compute_v1/classes.rb', line 26203

def disks
  @disks
end

#guest_acceleratorsArray<Google::Apis::ComputeV1::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from these properties. Corresponds to the JSON property guestAccelerators



26209
26210
26211
# File 'lib/google/apis/compute_v1/classes.rb', line 26209

def guest_accelerators
  @guest_accelerators
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


26215
26216
26217
# File 'lib/google/apis/compute_v1/classes.rb', line 26215

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from these properties. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


26220
26221
26222
# File 'lib/google/apis/compute_v1/classes.rb', line 26220

def labels
  @labels
end

#local_ssd_encryption_modeString

Specifies which method should be used for encrypting the Local SSDs attached to the VM. Corresponds to the JSON property localSsdEncryptionMode

Returns:

  • (String)


26226
26227
26228
# File 'lib/google/apis/compute_v1/classes.rb', line 26226

def local_ssd_encryption_mode
  @local_ssd_encryption_mode
end

#machine_typeString

The machine type to use for instances that are created from these properties. This field only accepts a machine type name, for example n2-standard-4. If you use the machine type full or partial URL, for example projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4, the request will result in an INTERNAL_ERROR. Corresponds to the JSON property machineType

Returns:

  • (String)


26236
26237
26238
# File 'lib/google/apis/compute_v1/classes.rb', line 26236

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



26241
26242
26243
# File 'lib/google/apis/compute_v1/classes.rb', line 26241

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such asminCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


26251
26252
26253
# File 'lib/google/apis/compute_v1/classes.rb', line 26251

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeV1::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



26256
26257
26258
# File 'lib/google/apis/compute_v1/classes.rb', line 26256

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeV1::NetworkPerformanceConfig

Note that for MachineImage, this is not supported yet. Corresponds to the JSON property networkPerformanceConfig



26261
26262
26263
# File 'lib/google/apis/compute_v1/classes.rb', line 26261

def network_performance_config
  @network_performance_config
end

#private_ipv6_google_accessString

The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


26268
26269
26270
# File 'lib/google/apis/compute_v1/classes.rb', line 26268

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeV1::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



26273
26274
26275
# File 'lib/google/apis/compute_v1/classes.rb', line 26273

def reservation_affinity
  @reservation_affinity
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


26285
26286
26287
# File 'lib/google/apis/compute_v1/classes.rb', line 26285

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


26292
26293
26294
# File 'lib/google/apis/compute_v1/classes.rb', line 26292

def resource_policies
  @resource_policies
end

#schedulingGoogle::Apis::ComputeV1::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



26297
26298
26299
# File 'lib/google/apis/compute_v1/classes.rb', line 26297

def scheduling
  @scheduling
end

#service_accountsArray<Google::Apis::ComputeV1::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



26305
26306
26307
# File 'lib/google/apis/compute_v1/classes.rb', line 26305

def service_accounts
  @service_accounts
end

#shielded_instance_configGoogle::Apis::ComputeV1::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



26310
26311
26312
# File 'lib/google/apis/compute_v1/classes.rb', line 26310

def shielded_instance_config
  @shielded_instance_config
end

#tagsGoogle::Apis::ComputeV1::Tags

A set of instance tags. Corresponds to the JSON property tags



26315
26316
26317
# File 'lib/google/apis/compute_v1/classes.rb', line 26315

def tags
  @tags
end

#workload_identity_configGoogle::Apis::ComputeV1::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



26320
26321
26322
# File 'lib/google/apis/compute_v1/classes.rb', line 26320

def workload_identity_config
  @workload_identity_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26327
26328
26329
26330
26331
26332
26333
26334
26335
26336
26337
26338
26339
26340
26341
26342
26343
26344
26345
26346
26347
26348
26349
26350
26351
# File 'lib/google/apis/compute_v1/classes.rb', line 26327

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @local_ssd_encryption_mode = args[:local_ssd_encryption_mode] if args.key?(:local_ssd_encryption_mode)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @tags = args[:tags] if args.key?(:tags)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
end