Class: Google::Apis::ComputeV1::InstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceProperties

Returns a new instance of InstanceProperties.



26099
26100
26101
# File 'lib/google/apis/compute_v1/classes.rb', line 26099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeV1::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



25957
25958
25959
# File 'lib/google/apis/compute_v1/classes.rb', line 25957

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


25968
25969
25970
# File 'lib/google/apis/compute_v1/classes.rb', line 25968

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeV1::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



25974
25975
25976
# File 'lib/google/apis/compute_v1/classes.rb', line 25974

def confidential_instance_config
  @confidential_instance_config
end

#descriptionString

An optional text description for the instances that are created from these properties. Corresponds to the JSON property description

Returns:

  • (String)


25980
25981
25982
# File 'lib/google/apis/compute_v1/classes.rb', line 25980

def description
  @description
end

#disksArray<Google::Apis::ComputeV1::AttachedDisk>

An array of disks that are associated with the instances that are created from these properties. Corresponds to the JSON property disks



25986
25987
25988
# File 'lib/google/apis/compute_v1/classes.rb', line 25986

def disks
  @disks
end

#guest_acceleratorsArray<Google::Apis::ComputeV1::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from these properties. Corresponds to the JSON property guestAccelerators



25992
25993
25994
# File 'lib/google/apis/compute_v1/classes.rb', line 25992

def guest_accelerators
  @guest_accelerators
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


25998
25999
26000
# File 'lib/google/apis/compute_v1/classes.rb', line 25998

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from these properties. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


26003
26004
26005
# File 'lib/google/apis/compute_v1/classes.rb', line 26003

def labels
  @labels
end

#machine_typeString

The machine type to use for instances that are created from these properties. This field only accepts a machine type name, for example n2-standard-4. If you use the machine type full or partial URL, for example projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4, the request will result in an INTERNAL_ERROR. Corresponds to the JSON property machineType

Returns:

  • (String)


26013
26014
26015
# File 'lib/google/apis/compute_v1/classes.rb', line 26013

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



26018
26019
26020
# File 'lib/google/apis/compute_v1/classes.rb', line 26018

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such asminCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


26028
26029
26030
# File 'lib/google/apis/compute_v1/classes.rb', line 26028

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeV1::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



26033
26034
26035
# File 'lib/google/apis/compute_v1/classes.rb', line 26033

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeV1::NetworkPerformanceConfig

Note that for MachineImage, this is not supported yet. Corresponds to the JSON property networkPerformanceConfig



26038
26039
26040
# File 'lib/google/apis/compute_v1/classes.rb', line 26038

def network_performance_config
  @network_performance_config
end

#private_ipv6_google_accessString

The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


26045
26046
26047
# File 'lib/google/apis/compute_v1/classes.rb', line 26045

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeV1::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



26050
26051
26052
# File 'lib/google/apis/compute_v1/classes.rb', line 26050

def reservation_affinity
  @reservation_affinity
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


26062
26063
26064
# File 'lib/google/apis/compute_v1/classes.rb', line 26062

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


26069
26070
26071
# File 'lib/google/apis/compute_v1/classes.rb', line 26069

def resource_policies
  @resource_policies
end

#schedulingGoogle::Apis::ComputeV1::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



26074
26075
26076
# File 'lib/google/apis/compute_v1/classes.rb', line 26074

def scheduling
  @scheduling
end

#service_accountsArray<Google::Apis::ComputeV1::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



26082
26083
26084
# File 'lib/google/apis/compute_v1/classes.rb', line 26082

def service_accounts
  @service_accounts
end

#shielded_instance_configGoogle::Apis::ComputeV1::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



26087
26088
26089
# File 'lib/google/apis/compute_v1/classes.rb', line 26087

def shielded_instance_config
  @shielded_instance_config
end

#tagsGoogle::Apis::ComputeV1::Tags

A set of instance tags. Corresponds to the JSON property tags



26092
26093
26094
# File 'lib/google/apis/compute_v1/classes.rb', line 26092

def tags
  @tags
end

#workload_identity_configGoogle::Apis::ComputeV1::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



26097
26098
26099
# File 'lib/google/apis/compute_v1/classes.rb', line 26097

def workload_identity_config
  @workload_identity_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26104
26105
26106
26107
26108
26109
26110
26111
26112
26113
26114
26115
26116
26117
26118
26119
26120
26121
26122
26123
26124
26125
26126
26127
# File 'lib/google/apis/compute_v1/classes.rb', line 26104

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @tags = args[:tags] if args.key?(:tags)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
end