Class: Google::Apis::ComputeV1::InstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceProperties

Returns a new instance of InstanceProperties.



25595
25596
25597
# File 'lib/google/apis/compute_v1/classes.rb', line 25595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeV1::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



25455
25456
25457
# File 'lib/google/apis/compute_v1/classes.rb', line 25455

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


25466
25467
25468
# File 'lib/google/apis/compute_v1/classes.rb', line 25466

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeV1::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



25472
25473
25474
# File 'lib/google/apis/compute_v1/classes.rb', line 25472

def confidential_instance_config
  @confidential_instance_config
end

#descriptionString

An optional text description for the instances that are created from these properties. Corresponds to the JSON property description

Returns:

  • (String)


25478
25479
25480
# File 'lib/google/apis/compute_v1/classes.rb', line 25478

def description
  @description
end

#disksArray<Google::Apis::ComputeV1::AttachedDisk>

An array of disks that are associated with the instances that are created from these properties. Corresponds to the JSON property disks



25484
25485
25486
# File 'lib/google/apis/compute_v1/classes.rb', line 25484

def disks
  @disks
end

#guest_acceleratorsArray<Google::Apis::ComputeV1::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from these properties. Corresponds to the JSON property guestAccelerators



25490
25491
25492
# File 'lib/google/apis/compute_v1/classes.rb', line 25490

def guest_accelerators
  @guest_accelerators
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


25496
25497
25498
# File 'lib/google/apis/compute_v1/classes.rb', line 25496

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from these properties. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


25501
25502
25503
# File 'lib/google/apis/compute_v1/classes.rb', line 25501

def labels
  @labels
end

#machine_typeString

The machine type to use for instances that are created from these properties. This field only accepts a machine type name, for example n2-standard-4. If you use the machine type full or partial URL, for example projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4, the request will result in an INTERNAL_ERROR. Corresponds to the JSON property machineType

Returns:

  • (String)


25511
25512
25513
# File 'lib/google/apis/compute_v1/classes.rb', line 25511

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



25516
25517
25518
# File 'lib/google/apis/compute_v1/classes.rb', line 25516

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such asminCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


25526
25527
25528
# File 'lib/google/apis/compute_v1/classes.rb', line 25526

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeV1::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



25531
25532
25533
# File 'lib/google/apis/compute_v1/classes.rb', line 25531

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeV1::NetworkPerformanceConfig

Note that for MachineImage, this is not supported yet. Corresponds to the JSON property networkPerformanceConfig



25536
25537
25538
# File 'lib/google/apis/compute_v1/classes.rb', line 25536

def network_performance_config
  @network_performance_config
end

#private_ipv6_google_accessString

The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


25543
25544
25545
# File 'lib/google/apis/compute_v1/classes.rb', line 25543

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeV1::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



25548
25549
25550
# File 'lib/google/apis/compute_v1/classes.rb', line 25548

def reservation_affinity
  @reservation_affinity
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys must be in the format tagKeys/tag_key_id`, and values are in the formattagValues/456. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON propertyresourceManagerTags`

Returns:

  • (Hash<String,String>)


25558
25559
25560
# File 'lib/google/apis/compute_v1/classes.rb', line 25558

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


25565
25566
25567
# File 'lib/google/apis/compute_v1/classes.rb', line 25565

def resource_policies
  @resource_policies
end

#schedulingGoogle::Apis::ComputeV1::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



25570
25571
25572
# File 'lib/google/apis/compute_v1/classes.rb', line 25570

def scheduling
  @scheduling
end

#service_accountsArray<Google::Apis::ComputeV1::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



25578
25579
25580
# File 'lib/google/apis/compute_v1/classes.rb', line 25578

def service_accounts
  @service_accounts
end

#shielded_instance_configGoogle::Apis::ComputeV1::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



25583
25584
25585
# File 'lib/google/apis/compute_v1/classes.rb', line 25583

def shielded_instance_config
  @shielded_instance_config
end

#tagsGoogle::Apis::ComputeV1::Tags

A set of instance tags. Corresponds to the JSON property tags



25588
25589
25590
# File 'lib/google/apis/compute_v1/classes.rb', line 25588

def tags
  @tags
end

#workload_identity_configGoogle::Apis::ComputeV1::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



25593
25594
25595
# File 'lib/google/apis/compute_v1/classes.rb', line 25593

def workload_identity_config
  @workload_identity_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25600
25601
25602
25603
25604
25605
25606
25607
25608
25609
25610
25611
25612
25613
25614
25615
25616
25617
25618
25619
25620
25621
25622
25623
# File 'lib/google/apis/compute_v1/classes.rb', line 25600

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @tags = args[:tags] if args.key?(:tags)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
end