Class: Google::Apis::ComputeV1::InstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceProperties

Returns a new instance of InstanceProperties.



22263
22264
22265
# File 'lib/google/apis/compute_v1/classes.rb', line 22263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeV1::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



22129
22130
22131
# File 'lib/google/apis/compute_v1/classes.rb', line 22129

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


22140
22141
22142
# File 'lib/google/apis/compute_v1/classes.rb', line 22140

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeV1::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



22146
22147
22148
# File 'lib/google/apis/compute_v1/classes.rb', line 22146

def confidential_instance_config
  @confidential_instance_config
end

#descriptionString

An optional text description for the instances that are created from these properties. Corresponds to the JSON property description

Returns:

  • (String)


22152
22153
22154
# File 'lib/google/apis/compute_v1/classes.rb', line 22152

def description
  @description
end

#disksArray<Google::Apis::ComputeV1::AttachedDisk>

An array of disks that are associated with the instances that are created from these properties. Corresponds to the JSON property disks



22158
22159
22160
# File 'lib/google/apis/compute_v1/classes.rb', line 22158

def disks
  @disks
end

#guest_acceleratorsArray<Google::Apis::ComputeV1::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from these properties. Corresponds to the JSON property guestAccelerators



22164
22165
22166
# File 'lib/google/apis/compute_v1/classes.rb', line 22164

def guest_accelerators
  @guest_accelerators
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


22170
22171
22172
# File 'lib/google/apis/compute_v1/classes.rb', line 22170

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from these properties. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


22175
22176
22177
# File 'lib/google/apis/compute_v1/classes.rb', line 22175

def labels
  @labels
end

#machine_typeString

The machine type to use for instances that are created from these properties. This field only accepts a machine type name, for example n2-standard-4. If you use the machine type full or partial URL, for example projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4, the request will result in an INTERNAL_ERROR. Corresponds to the JSON property machineType

Returns:

  • (String)


22185
22186
22187
# File 'lib/google/apis/compute_v1/classes.rb', line 22185

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



22190
22191
22192
# File 'lib/google/apis/compute_v1/classes.rb', line 22190

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such asminCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


22200
22201
22202
# File 'lib/google/apis/compute_v1/classes.rb', line 22200

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeV1::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



22205
22206
22207
# File 'lib/google/apis/compute_v1/classes.rb', line 22205

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeV1::NetworkPerformanceConfig

Note that for MachineImage, this is not supported yet. Corresponds to the JSON property networkPerformanceConfig



22210
22211
22212
# File 'lib/google/apis/compute_v1/classes.rb', line 22210

def network_performance_config
  @network_performance_config
end

#private_ipv6_google_accessString

The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


22217
22218
22219
# File 'lib/google/apis/compute_v1/classes.rb', line 22217

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeV1::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



22222
22223
22224
# File 'lib/google/apis/compute_v1/classes.rb', line 22222

def reservation_affinity
  @reservation_affinity
end

#resource_manager_tagsHash<String,String>

Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys must be in the format tagKeys/tag_key_id`, and values are in the formattagValues/456. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON propertyresourceManagerTags`

Returns:

  • (Hash<String,String>)


22231
22232
22233
# File 'lib/google/apis/compute_v1/classes.rb', line 22231

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


22238
22239
22240
# File 'lib/google/apis/compute_v1/classes.rb', line 22238

def resource_policies
  @resource_policies
end

#schedulingGoogle::Apis::ComputeV1::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



22243
22244
22245
# File 'lib/google/apis/compute_v1/classes.rb', line 22243

def scheduling
  @scheduling
end

#service_accountsArray<Google::Apis::ComputeV1::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



22251
22252
22253
# File 'lib/google/apis/compute_v1/classes.rb', line 22251

def service_accounts
  @service_accounts
end

#shielded_instance_configGoogle::Apis::ComputeV1::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



22256
22257
22258
# File 'lib/google/apis/compute_v1/classes.rb', line 22256

def shielded_instance_config
  @shielded_instance_config
end

#tagsGoogle::Apis::ComputeV1::Tags

A set of instance tags. Corresponds to the JSON property tags



22261
22262
22263
# File 'lib/google/apis/compute_v1/classes.rb', line 22261

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22268
22269
22270
22271
22272
22273
22274
22275
22276
22277
22278
22279
22280
22281
22282
22283
22284
22285
22286
22287
22288
22289
22290
# File 'lib/google/apis/compute_v1/classes.rb', line 22268

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @tags = args[:tags] if args.key?(:tags)
end