Class: Google::Apis::ComputeV1::InstanceProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#advanced_machine_features ⇒ Google::Apis::ComputeV1::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
-
#can_ip_forward ⇒ Boolean
(also: #can_ip_forward?)
Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own.
-
#confidential_instance_config ⇒ Google::Apis::ComputeV1::ConfidentialInstanceConfig
A set of Confidential Instance options.
-
#description ⇒ String
An optional text description for the instances that are created from these properties.
-
#disks ⇒ Array<Google::Apis::ComputeV1::AttachedDisk>
An array of disks that are associated with the instances that are created from these properties.
-
#guest_accelerators ⇒ Array<Google::Apis::ComputeV1::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances created from these properties.
-
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from these properties.
-
#machine_type ⇒ String
The machine type to use for instances that are created from these properties.
-
#metadata ⇒ Google::Apis::ComputeV1::Metadata
A metadata key/value entry.
-
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances.
-
#network_interfaces ⇒ Array<Google::Apis::ComputeV1::NetworkInterface>
An array of network access configurations for this interface.
-
#network_performance_config ⇒ Google::Apis::ComputeV1::NetworkPerformanceConfig
Note that for MachineImage, this is not supported yet.
-
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for VMs.
-
#reservation_affinity ⇒ Google::Apis::ComputeV1::ReservationAffinity
Specifies the reservations that this instance can consume from.
-
#resource_manager_tags ⇒ Hash<String,String>
Resource manager tags to be bound to the instance.
-
#resource_policies ⇒ Array<String>
Resource policies (names, not URLs) applied to instances created from these properties.
-
#scheduling ⇒ Google::Apis::ComputeV1::Scheduling
Sets the scheduling options for an Instance.
-
#service_accounts ⇒ Array<Google::Apis::ComputeV1::ServiceAccount>
A list of service accounts with specified scopes.
-
#shielded_instance_config ⇒ Google::Apis::ComputeV1::ShieldedInstanceConfig
A set of Shielded Instance options.
-
#tags ⇒ Google::Apis::ComputeV1::Tags
A set of instance tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceProperties
constructor
A new instance of InstanceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceProperties
Returns a new instance of InstanceProperties.
15120 15121 15122 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_machine_features ⇒ Google::Apis::ComputeV1::AdvancedMachineFeatures
Specifies options for controlling advanced machine features. Options that
would traditionally be configured in a BIOS belong here. Features that require
operating system support may have corresponding entries in the GuestOsFeatures
of an Image (e.g., whether or not the OS in the Image supports nested
virtualization being enabled or disabled).
Corresponds to the JSON property advancedMachineFeatures
15001 15002 15003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15001 def advanced_machine_features @advanced_machine_features end |
#can_ip_forward ⇒ Boolean Also known as: can_ip_forward?
Enables instances created based on these properties to send packets with
source IP addresses other than their own and receive packets with destination
IP addresses other than their own. If these instances will be used as an IP
gateway or it will be set as the next-hop in a Route resource, specify true.
If unsure, leave this set to false. See the Enable IP forwarding documentation
for more information.
Corresponds to the JSON property canIpForward
15011 15012 15013 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15011 def can_ip_forward @can_ip_forward end |
#confidential_instance_config ⇒ Google::Apis::ComputeV1::ConfidentialInstanceConfig
A set of Confidential Instance options.
Corresponds to the JSON property confidentialInstanceConfig
15017 15018 15019 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15017 def confidential_instance_config @confidential_instance_config end |
#description ⇒ String
An optional text description for the instances that are created from these
properties.
Corresponds to the JSON property description
15023 15024 15025 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15023 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeV1::AttachedDisk>
An array of disks that are associated with the instances that are created from
these properties.
Corresponds to the JSON property disks
15029 15030 15031 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15029 def disks @disks end |
#guest_accelerators ⇒ Array<Google::Apis::ComputeV1::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances created
from these properties.
Corresponds to the JSON property guestAccelerators
15035 15036 15037 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15035 def guest_accelerators @guest_accelerators end |
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from these properties.
Corresponds to the JSON property labels
15040 15041 15042 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15040 def labels @labels end |
#machine_type ⇒ String
The machine type to use for instances that are created from these properties.
Corresponds to the JSON property machineType
15045 15046 15047 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15045 def machine_type @machine_type end |
#metadata ⇒ Google::Apis::ComputeV1::Metadata
A metadata key/value entry.
Corresponds to the JSON property metadata
15050 15051 15052 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15050 def @metadata end |
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances. The instance may be scheduled on
the specified or newer cpu/platform. Applicable values are the friendly names
of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "
Intel Sandy Bridge". For more information, read Specifying a Minimum CPU
Platform.
Corresponds to the JSON property minCpuPlatform
15059 15060 15061 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15059 def min_cpu_platform @min_cpu_platform end |
#network_interfaces ⇒ Array<Google::Apis::ComputeV1::NetworkInterface>
An array of network access configurations for this interface.
Corresponds to the JSON property networkInterfaces
15064 15065 15066 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15064 def network_interfaces @network_interfaces end |
#network_performance_config ⇒ Google::Apis::ComputeV1::NetworkPerformanceConfig
Note that for MachineImage, this is not supported yet.
Corresponds to the JSON property networkPerformanceConfig
15069 15070 15071 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15069 def network_performance_config @network_performance_config end |
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for VMs. If not specified, use
INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not
supported yet.
Corresponds to the JSON property privateIpv6GoogleAccess
15076 15077 15078 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15076 def private_ipv6_google_access @private_ipv6_google_access end |
#reservation_affinity ⇒ Google::Apis::ComputeV1::ReservationAffinity
Specifies the reservations that this instance can consume from.
Corresponds to the JSON property reservationAffinity
15081 15082 15083 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15081 def reservation_affinity @reservation_affinity end |
#resource_manager_tags ⇒ Hash<String,String>
Resource manager tags to be bound to the instance. Tag keys and values have
the same definition as resource manager tags. Keys must be in the format
tagKeys/tag_key_id`, and values are in the formattagValues/456. The field
is ignored (both PUT & PATCH) when empty.
Corresponds to the JSON propertyresourceManagerTags`
15089 15090 15091 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15089 def @resource_manager_tags end |
#resource_policies ⇒ Array<String>
Resource policies (names, not URLs) applied to instances created from these
properties. Note that for MachineImage, this is not supported yet.
Corresponds to the JSON property resourcePolicies
15095 15096 15097 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15095 def resource_policies @resource_policies end |
#scheduling ⇒ Google::Apis::ComputeV1::Scheduling
Sets the scheduling options for an Instance. NextID: 21
Corresponds to the JSON property scheduling
15100 15101 15102 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15100 def scheduling @scheduling end |
#service_accounts ⇒ Array<Google::Apis::ComputeV1::ServiceAccount>
A list of service accounts with specified scopes. Access tokens for these
service accounts are available to the instances that are created from these
properties. Use metadata queries to obtain the access tokens for these
instances.
Corresponds to the JSON property serviceAccounts
15108 15109 15110 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15108 def service_accounts @service_accounts end |
#shielded_instance_config ⇒ Google::Apis::ComputeV1::ShieldedInstanceConfig
A set of Shielded Instance options.
Corresponds to the JSON property shieldedInstanceConfig
15113 15114 15115 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15113 def shielded_instance_config @shielded_instance_config end |
#tags ⇒ Google::Apis::ComputeV1::Tags
A set of instance tags.
Corresponds to the JSON property tags
15118 15119 15120 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15118 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15125 15126 15127 15128 15129 15130 15131 15132 15133 15134 15135 15136 15137 15138 15139 15140 15141 15142 15143 15144 15145 15146 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15125 def update!(**args) @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features) @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward) @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) @labels = args[:labels] if args.key?(:labels) @machine_type = args[:machine_type] if args.key?(:machine_type) @metadata = args[:metadata] if args.key?(:metadata) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config) @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @scheduling = args[:scheduling] if args.key?(:scheduling) @service_accounts = args[:service_accounts] if args.key?(:service_accounts) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) @tags = args[:tags] if args.key?(:tags) end |