Class: Google::Apis::ComputeV1::InstanceTemplate
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceTemplate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents an Instance Template resource. Google Compute Engine has two Instance Template resources:
- Global
- Regional You can reuse a global instance template in different regions whereas you can use a regional instance template in a specified region only. If you want to reduce cross-region dependency or achieve data residency, use a regional instance template. To create VMs, managed instance groups, and reservations, you can use either global or regional instance templates. For more information, readInstance Templates.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#properties ⇒ Google::Apis::ComputeV1::InstanceProperties
The instance properties for this instance template.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#source_instance ⇒ String
The source instance used to create the template.
-
#source_instance_params ⇒ Google::Apis::ComputeV1::SourceInstanceParams
A specification of the parameters to use when creating the instance template from a source instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplate
constructor
A new instance of InstanceTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplate
Returns a new instance of InstanceTemplate.
23218 23219 23220 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this instance template
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
23149 23150 23151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23149 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
23155 23156 23157 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23155 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this instance template. The
server
defines this identifier.
Corresponds to the JSON property id
23162 23163 23164 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23162 def id @id end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceTemplate for instance templates.
Corresponds to the JSON property kind
23168 23169 23170 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23168 def kind @kind end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
23179 23180 23181 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23179 def name @name end |
#properties ⇒ Google::Apis::ComputeV1::InstanceProperties
The instance properties for this instance template.
Corresponds to the JSON property properties
23184 23185 23186 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23184 def properties @properties end |
#region ⇒ String
Output only. [Output Only] URL of the region where the instance template
resides. Only
applicable for regional resources.
Corresponds to the JSON property region
23191 23192 23193 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23191 def region @region end |
#self_link ⇒ String
Output only. [Output Only] The URL for this instance template. The server
defines this
URL.
Corresponds to the JSON property selfLink
23198 23199 23200 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23198 def self_link @self_link end |
#source_instance ⇒ String
The source instance used to create the template. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ instances/instance
- projects/project/zones/zone/instances/instance
Corresponds to the JSON property
sourceInstance
23210 23211 23212 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23210 def source_instance @source_instance end |
#source_instance_params ⇒ Google::Apis::ComputeV1::SourceInstanceParams
A specification of the parameters to use when creating the instance template
from a source instance.
Corresponds to the JSON property sourceInstanceParams
23216 23217 23218 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23216 def source_instance_params @source_instance_params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23223 23224 23225 23226 23227 23228 23229 23230 23231 23232 23233 23234 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23223 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @properties = args[:properties] if args.key?(:properties) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @source_instance = args[:source_instance] if args.key?(:source_instance) @source_instance_params = args[:source_instance_params] if args.key?(:source_instance_params) end |