Class: Google::Apis::ComputeV1::InstanceTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of InstanceTemplatesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateAggregatedList
constructor
A new instance of InstanceTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplateAggregatedList
Returns a new instance of InstanceTemplateAggregatedList.
26998 26999 27000 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
26966 26967 26968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26966 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
Corresponds to the JSON property items
26971 26972 26973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26971 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
26976 26977 26978 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26976 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26986 26987 26988 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26986 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
26991 26992 26993 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26991 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26996 26997 26998 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26996 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27003 27004 27005 27006 27007 27008 27009 27010 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27003 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |