Class: Google::Apis::ComputeV1::InstanceTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstanceTemplatesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateAggregatedList

Returns a new instance of InstanceTemplateAggregatedList.



26591
26592
26593
# File 'lib/google/apis/compute_v1/classes.rb', line 26591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26559
26560
26561
# File 'lib/google/apis/compute_v1/classes.rb', line 26559

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceTemplatesScopedList>

A list of InstanceTemplatesScopedList resources. Corresponds to the JSON property items



26564
26565
26566
# File 'lib/google/apis/compute_v1/classes.rb', line 26564

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


26569
26570
26571
# File 'lib/google/apis/compute_v1/classes.rb', line 26569

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26579
26580
26581
# File 'lib/google/apis/compute_v1/classes.rb', line 26579

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26584
26585
26586
# File 'lib/google/apis/compute_v1/classes.rb', line 26584

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



26589
26590
26591
# File 'lib/google/apis/compute_v1/classes.rb', line 26589

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26596
26597
26598
26599
26600
26601
26602
26603
# File 'lib/google/apis/compute_v1/classes.rb', line 26596

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end