Class: Google::Apis::ComputeV1::InstanceTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstanceTemplatesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateAggregatedList

Returns a new instance of InstanceTemplateAggregatedList.



26402
26403
26404
# File 'lib/google/apis/compute_v1/classes.rb', line 26402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26370
26371
26372
# File 'lib/google/apis/compute_v1/classes.rb', line 26370

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceTemplatesScopedList>

A list of InstanceTemplatesScopedList resources. Corresponds to the JSON property items



26375
26376
26377
# File 'lib/google/apis/compute_v1/classes.rb', line 26375

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


26380
26381
26382
# File 'lib/google/apis/compute_v1/classes.rb', line 26380

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26390
26391
26392
# File 'lib/google/apis/compute_v1/classes.rb', line 26390

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26395
26396
26397
# File 'lib/google/apis/compute_v1/classes.rb', line 26395

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



26400
26401
26402
# File 'lib/google/apis/compute_v1/classes.rb', line 26400

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26407
26408
26409
26410
26411
26412
26413
26414
# File 'lib/google/apis/compute_v1/classes.rb', line 26407

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end