Class: Google::Apis::ComputeV1::InstanceTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstanceTemplatesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateAggregatedList

Returns a new instance of InstanceTemplateAggregatedList.



22565
22566
22567
# File 'lib/google/apis/compute_v1/classes.rb', line 22565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22533
22534
22535
# File 'lib/google/apis/compute_v1/classes.rb', line 22533

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceTemplatesScopedList>

A list of InstanceTemplatesScopedList resources. Corresponds to the JSON property items



22538
22539
22540
# File 'lib/google/apis/compute_v1/classes.rb', line 22538

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22543
22544
22545
# File 'lib/google/apis/compute_v1/classes.rb', line 22543

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22553
22554
22555
# File 'lib/google/apis/compute_v1/classes.rb', line 22553

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22558
22559
22560
# File 'lib/google/apis/compute_v1/classes.rb', line 22558

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22563
22564
22565
# File 'lib/google/apis/compute_v1/classes.rb', line 22563

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22570
22571
22572
22573
22574
22575
22576
22577
# File 'lib/google/apis/compute_v1/classes.rb', line 22570

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end