Class: Google::Apis::ComputeV1::InstanceTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of instance templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceTemplate>
A list of InstanceTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateList
constructor
A new instance of InstanceTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplateList
Returns a new instance of InstanceTemplateList.
26024 26025 26026 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25990 25991 25992 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25990 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceTemplate>
A list of InstanceTemplate resources.
Corresponds to the JSON property items
25995 25996 25997 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25995 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceTemplatesListResponse for instance template
lists.
Corresponds to the JSON property kind
26002 26003 26004 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26002 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26012 26013 26014 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26012 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
26017 26018 26019 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26017 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26022 26023 26024 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26022 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26029 26030 26031 26032 26033 26034 26035 26036 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26029 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |