Class: Google::Apis::ComputeV1::InstanceTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of instance templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceTemplate>
A list of InstanceTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstanceTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateList
constructor
A new instance of InstanceTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplateList
Returns a new instance of InstanceTemplateList.
23402 23403 23404 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23402 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23368 23369 23370 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23368 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceTemplate>
A list of InstanceTemplate resources.
Corresponds to the JSON property items
23373 23374 23375 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23373 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceTemplatesListResponse for instance template
lists.
Corresponds to the JSON property kind
23380 23381 23382 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23380 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23390 23391 23392 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23390 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23395 23396 23397 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23395 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstanceTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
23400 23401 23402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23400 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23407 23408 23409 23410 23411 23412 23413 23414 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23407 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |