Class: Google::Apis::ComputeV1::InstanceTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of instance templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateList

Returns a new instance of InstanceTemplateList.



22691
22692
22693
# File 'lib/google/apis/compute_v1/classes.rb', line 22691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22657
22658
22659
# File 'lib/google/apis/compute_v1/classes.rb', line 22657

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceTemplate>

A list of InstanceTemplate resources. Corresponds to the JSON property items



22662
22663
22664
# File 'lib/google/apis/compute_v1/classes.rb', line 22662

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceTemplatesListResponse for instance template lists. Corresponds to the JSON property kind

Returns:

  • (String)


22669
22670
22671
# File 'lib/google/apis/compute_v1/classes.rb', line 22669

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22679
22680
22681
# File 'lib/google/apis/compute_v1/classes.rb', line 22679

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22684
22685
22686
# File 'lib/google/apis/compute_v1/classes.rb', line 22684

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstanceTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22689
22690
22691
# File 'lib/google/apis/compute_v1/classes.rb', line 22689

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22696
22697
22698
22699
22700
22701
22702
22703
# File 'lib/google/apis/compute_v1/classes.rb', line 22696

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end