Class: Google::Apis::ComputeV1::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Returns a new instance of InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.



27078
27079
27080
# File 'lib/google/apis/compute_v1/classes.rb', line 27078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy. Corresponds to the JSON property displayName

Returns:

  • (String)


27039
27040
27041
# File 'lib/google/apis/compute_v1/classes.rb', line 27039

def display_name
  @display_name
end

#nameString

Output only. [Output Only] The name of the firewall policy. Corresponds to the JSON property name

Returns:

  • (String)


27044
27045
27046
# File 'lib/google/apis/compute_v1/classes.rb', line 27044

def name
  @name
end

#packet_mirroring_rulesArray<Google::Apis::ComputeV1::FirewallPolicyRule>

Output only. [Output Only] The packet mirroring rules that apply to the instance. Corresponds to the JSON property packetMirroringRules



27050
27051
27052
# File 'lib/google/apis/compute_v1/classes.rb', line 27050

def packet_mirroring_rules
  @packet_mirroring_rules
end

#priorityFixnum

Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


27057
27058
27059
# File 'lib/google/apis/compute_v1/classes.rb', line 27057

def priority
  @priority
end

#rulesArray<Google::Apis::ComputeV1::FirewallPolicyRule>

[Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules. Corresponds to the JSON property rules



27064
27065
27066
# File 'lib/google/apis/compute_v1/classes.rb', line 27064

def rules
  @rules
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy. Corresponds to the JSON property shortName

Returns:

  • (String)


27069
27070
27071
# File 'lib/google/apis/compute_v1/classes.rb', line 27069

def short_name
  @short_name
end

#typeString

Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Corresponds to the JSON property type

Returns:

  • (String)


27076
27077
27078
# File 'lib/google/apis/compute_v1/classes.rb', line 27076

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27083
27084
27085
27086
27087
27088
27089
27090
27091
# File 'lib/google/apis/compute_v1/classes.rb', line 27083

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules)
  @priority = args[:priority] if args.key?(:priority)
  @rules = args[:rules] if args.key?(:rules)
  @short_name = args[:short_name] if args.key?(:short_name)
  @type = args[:type] if args.key?(:type)
end