Class: Google::Apis::ComputeV1::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Returns a new instance of InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.



26854
26855
26856
# File 'lib/google/apis/compute_v1/classes.rb', line 26854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy. Corresponds to the JSON property displayName

Returns:

  • (String)


26815
26816
26817
# File 'lib/google/apis/compute_v1/classes.rb', line 26815

def display_name
  @display_name
end

#nameString

Output only. [Output Only] The name of the firewall policy. Corresponds to the JSON property name

Returns:

  • (String)


26820
26821
26822
# File 'lib/google/apis/compute_v1/classes.rb', line 26820

def name
  @name
end

#packet_mirroring_rulesArray<Google::Apis::ComputeV1::FirewallPolicyRule>

Output only. [Output Only] The packet mirroring rules that apply to the instance. Corresponds to the JSON property packetMirroringRules



26826
26827
26828
# File 'lib/google/apis/compute_v1/classes.rb', line 26826

def packet_mirroring_rules
  @packet_mirroring_rules
end

#priorityFixnum

Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


26833
26834
26835
# File 'lib/google/apis/compute_v1/classes.rb', line 26833

def priority
  @priority
end

#rulesArray<Google::Apis::ComputeV1::FirewallPolicyRule>

[Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules. Corresponds to the JSON property rules



26840
26841
26842
# File 'lib/google/apis/compute_v1/classes.rb', line 26840

def rules
  @rules
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy. Corresponds to the JSON property shortName

Returns:

  • (String)


26845
26846
26847
# File 'lib/google/apis/compute_v1/classes.rb', line 26845

def short_name
  @short_name
end

#typeString

Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Corresponds to the JSON property type

Returns:

  • (String)


26852
26853
26854
# File 'lib/google/apis/compute_v1/classes.rb', line 26852

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26859
26860
26861
26862
26863
26864
26865
26866
26867
# File 'lib/google/apis/compute_v1/classes.rb', line 26859

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules)
  @priority = args[:priority] if args.key?(:priority)
  @rules = args[:rules] if args.key?(:rules)
  @short_name = args[:short_name] if args.key?(:short_name)
  @type = args[:type] if args.key?(:type)
end