Class: Google::Apis::ComputeV1::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Returns a new instance of InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.



26350
26351
26352
# File 'lib/google/apis/compute_v1/classes.rb', line 26350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy. Corresponds to the JSON property displayName

Returns:

  • (String)


26311
26312
26313
# File 'lib/google/apis/compute_v1/classes.rb', line 26311

def display_name
  @display_name
end

#nameString

Output only. [Output Only] The name of the firewall policy. Corresponds to the JSON property name

Returns:

  • (String)


26316
26317
26318
# File 'lib/google/apis/compute_v1/classes.rb', line 26316

def name
  @name
end

#packet_mirroring_rulesArray<Google::Apis::ComputeV1::FirewallPolicyRule>

Output only. [Output Only] The packet mirroring rules that apply to the instance. Corresponds to the JSON property packetMirroringRules



26322
26323
26324
# File 'lib/google/apis/compute_v1/classes.rb', line 26322

def packet_mirroring_rules
  @packet_mirroring_rules
end

#priorityFixnum

Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


26329
26330
26331
# File 'lib/google/apis/compute_v1/classes.rb', line 26329

def priority
  @priority
end

#rulesArray<Google::Apis::ComputeV1::FirewallPolicyRule>

[Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules. Corresponds to the JSON property rules



26336
26337
26338
# File 'lib/google/apis/compute_v1/classes.rb', line 26336

def rules
  @rules
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy. Corresponds to the JSON property shortName

Returns:

  • (String)


26341
26342
26343
# File 'lib/google/apis/compute_v1/classes.rb', line 26341

def short_name
  @short_name
end

#typeString

Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Corresponds to the JSON property type

Returns:

  • (String)


26348
26349
26350
# File 'lib/google/apis/compute_v1/classes.rb', line 26348

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26355
26356
26357
26358
26359
26360
26361
26362
26363
# File 'lib/google/apis/compute_v1/classes.rb', line 26355

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules)
  @priority = args[:priority] if args.key?(:priority)
  @rules = args[:rules] if args.key?(:rules)
  @short_name = args[:short_name] if args.key?(:short_name)
  @type = args[:type] if args.key?(:type)
end