Class: Google::Apis::ComputeV1::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Returns a new instance of InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.



23728
23729
23730
# File 'lib/google/apis/compute_v1/classes.rb', line 23728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy. Corresponds to the JSON property displayName

Returns:

  • (String)


23689
23690
23691
# File 'lib/google/apis/compute_v1/classes.rb', line 23689

def display_name
  @display_name
end

#nameString

Output only. [Output Only] The name of the firewall policy. Corresponds to the JSON property name

Returns:

  • (String)


23694
23695
23696
# File 'lib/google/apis/compute_v1/classes.rb', line 23694

def name
  @name
end

#packet_mirroring_rulesArray<Google::Apis::ComputeV1::FirewallPolicyRule>

Output only. [Output Only] The packet mirroring rules that apply to the instance. Corresponds to the JSON property packetMirroringRules



23700
23701
23702
# File 'lib/google/apis/compute_v1/classes.rb', line 23700

def packet_mirroring_rules
  @packet_mirroring_rules
end

#priorityFixnum

Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


23707
23708
23709
# File 'lib/google/apis/compute_v1/classes.rb', line 23707

def priority
  @priority
end

#rulesArray<Google::Apis::ComputeV1::FirewallPolicyRule>

[Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules. Corresponds to the JSON property rules



23714
23715
23716
# File 'lib/google/apis/compute_v1/classes.rb', line 23714

def rules
  @rules
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy. Corresponds to the JSON property shortName

Returns:

  • (String)


23719
23720
23721
# File 'lib/google/apis/compute_v1/classes.rb', line 23719

def short_name
  @short_name
end

#typeString

Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Corresponds to the JSON property type

Returns:

  • (String)


23726
23727
23728
# File 'lib/google/apis/compute_v1/classes.rb', line 23726

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23733
23734
23735
23736
23737
23738
23739
23740
23741
# File 'lib/google/apis/compute_v1/classes.rb', line 23733

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules)
  @priority = args[:priority] if args.key?(:priority)
  @rules = args[:rules] if args.key?(:rules)
  @short_name = args[:short_name] if args.key?(:short_name)
  @type = args[:type] if args.key?(:type)
end