Class: Google::Apis::ComputeV1::InstancesSetNameRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesSetNameRequest

Returns a new instance of InstancesSetNameRequest.



23301
23302
23303
# File 'lib/google/apis/compute_v1/classes.rb', line 23301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_nameString

The current name of this resource, used to prevent conflicts. Provide the latest name when making a request to change name. Corresponds to the JSON property currentName

Returns:

  • (String)


23294
23295
23296
# File 'lib/google/apis/compute_v1/classes.rb', line 23294

def current_name
  @current_name
end

#nameString

The name to be applied to the instance. Needs to be RFC 1035 compliant. Corresponds to the JSON property name

Returns:

  • (String)


23299
23300
23301
# File 'lib/google/apis/compute_v1/classes.rb', line 23299

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23306
23307
23308
23309
# File 'lib/google/apis/compute_v1/classes.rb', line 23306

def update!(**args)
  @current_name = args[:current_name] if args.key?(:current_name)
  @name = args[:name] if args.key?(:name)
end