Class: Google::Apis::ComputeV1::InstancesSetSecurityPolicyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstancesSetSecurityPolicyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#network_interfaces ⇒ Array<String>
The network interfaces that the security policy will be applied to.
-
#security_policy ⇒ String
A full or partial URL to a security policy to add to this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesSetSecurityPolicyRequest
constructor
A new instance of InstancesSetSecurityPolicyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesSetSecurityPolicyRequest
Returns a new instance of InstancesSetSecurityPolicyRequest.
27399 27400 27401 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#network_interfaces ⇒ Array<String>
The network interfaces that the security policy will be applied to. Network
interfaces use the nicN naming format. You can only set a
security policy for network interfaces with an access config.
Corresponds to the JSON property networkInterfaces
27390 27391 27392 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27390 def network_interfaces @network_interfaces end |
#security_policy ⇒ String
A full or partial URL to a security policy to add to this instance.
If this field is set to an empty string it will remove the associated
security policy.
Corresponds to the JSON property securityPolicy
27397 27398 27399 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27397 def security_policy @security_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27404 27405 27406 27407 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27404 def update!(**args) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @security_policy = args[:security_policy] if args.key?(:security_policy) end |