Class: Google::Apis::ComputeV1::InstantSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstantSnapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a InstantSnapshot resource. You can use instant snapshots to create disk rollback points quickly..
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ Fixnum
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this InstantSnapshot, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this InstantSnapshot.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#params ⇒ Google::Apis::ComputeV1::InstantSnapshotParams
Additional instant snapshot params.
-
#region ⇒ String
Output only.
-
#resource_status ⇒ Google::Apis::ComputeV1::InstantSnapshotResourceStatus
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_disk ⇒ String
URL of the source disk used to create this instant snapshot.
-
#source_disk_id ⇒ String
Output only.
-
#source_instant_snapshot_group ⇒ String
Output only.
-
#source_instant_snapshot_group_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshot
constructor
A new instance of InstantSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshot
Returns a new instance of InstantSnapshot.
27993 27994 27995 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27993 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the instant snapshot. Valid
values are
ARM64 or X86_64.
Corresponds to the JSON property architecture
27822 27823 27824 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27822 def architecture @architecture end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
27828 27829 27830 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27828 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
27834 27835 27836 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27834 def description @description end |
#disk_size_gb ⇒ Fixnum
Output only. [Output Only] Size of the source disk, specified in GB.
Corresponds to the JSON property diskSizeGb
27839 27840 27841 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27839 def disk_size_gb @disk_size_gb end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
27846 27847 27848 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27846 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#instantSnapshot
for InstantSnapshot resources.
Corresponds to the JSON property kind
27852 27853 27854 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27852 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this InstantSnapshot, which
is essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a InstantSnapshot.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
27865 27866 27867 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27865 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this InstantSnapshot. These can be later modified by
the setLabels method.
Label values may be empty.
Corresponds to the JSON property labels
27872 27873 27874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27872 def labels @labels end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
27883 27884 27885 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27883 def name @name end |
#params ⇒ Google::Apis::ComputeV1::InstantSnapshotParams
Additional instant snapshot params.
Corresponds to the JSON property params
27888 27889 27890 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27888 def params @params end |
#region ⇒ String
Output only. [Output Only] URL of the region where the instant snapshot
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
27896 27897 27898 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27896 def region @region end |
#resource_status ⇒ Google::Apis::ComputeV1::InstantSnapshotResourceStatus
Output only. [Output Only] Status information for the instant snapshot
resource.
Corresponds to the JSON property resourceStatus
27902 27903 27904 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27902 def resource_status @resource_status end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
27907 27908 27909 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27907 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
27913 27914 27915 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27913 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
27919 27920 27921 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27919 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
27924 27925 27926 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27924 def self_link_with_id @self_link_with_id end |
#source_disk ⇒ String
URL of the source disk used to create this instant snapshot. Note that the source disk must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ disks/disk
- projects/project/zones/zone/disks/disk
- projects/project/regions/region/disks/disk
- zones/zone/disks/disk
-
regions/region/disks/disk
Corresponds to the JSON property sourceDisk
27953 27954 27955 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27953 def source_disk @source_disk end |
#source_disk_id ⇒ String
Output only. [Output Only] The ID value of the disk used to create this
InstantSnapshot.
This value may be used to determine whether the InstantSnapshot
was taken from the current or a previous instance of a given disk name.
Corresponds to the JSON property sourceDiskId
27961 27962 27963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27961 def source_disk_id @source_disk_id end |
#source_instant_snapshot_group ⇒ String
Output only. [Output Only] URL of the source instant snapshot this instant
snapshot is
part of. Note that the source instant snapshot group must be in the same
zone/region as the instant snapshot to be created. This can be a full or
valid partial URL.
Corresponds to the JSON property sourceInstantSnapshotGroup
27970 27971 27972 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27970 def source_instant_snapshot_group @source_instant_snapshot_group end |
#source_instant_snapshot_group_id ⇒ String
Output only. [Output Only] The ID value of the source instant snapshot group
this
InstantSnapshot is part of. This value may be used to determine whether the
InstantSnapshot was created as part of an InstantSnapshotGroup creation.
Corresponds to the JSON property sourceInstantSnapshotGroupId
27978 27979 27980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27978 def source_instant_snapshot_group_id @source_instant_snapshot_group_id end |
#status ⇒ String
Output only. [Output Only] The status of the instantSnapshot. This can
beCREATING, DELETING, FAILED, orREADY.
Corresponds to the JSON property status
27984 27985 27986 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27984 def status @status end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the instant snapshot resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
27991 27992 27993 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27991 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27998 27999 28000 28001 28002 28003 28004 28005 28006 28007 28008 28009 28010 28011 28012 28013 28014 28015 28016 28017 28018 28019 28020 28021 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27998 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group) @source_instant_snapshot_group_id = args[:source_instant_snapshot_group_id] if args.key?(:source_instant_snapshot_group_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |