Class: Google::Apis::ComputeV1::InstantSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstantSnapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a InstantSnapshot resource. You can use instant snapshots to create disk rollback points quickly..
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ Fixnum
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this InstantSnapshot, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this InstantSnapshot.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#params ⇒ Google::Apis::ComputeV1::InstantSnapshotParams
Additional instant snapshot params.
-
#region ⇒ String
Output only.
-
#resource_status ⇒ Google::Apis::ComputeV1::InstantSnapshotResourceStatus
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_disk ⇒ String
URL of the source disk used to create this instant snapshot.
-
#source_disk_id ⇒ String
Output only.
-
#source_instant_snapshot_group ⇒ String
Output only.
-
#source_instant_snapshot_group_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshot
constructor
A new instance of InstantSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshot
Returns a new instance of InstantSnapshot.
27417 27418 27419 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the instant snapshot. Valid
values are
ARM64 or X86_64.
Corresponds to the JSON property architecture
27246 27247 27248 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27246 def architecture @architecture end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
27252 27253 27254 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27252 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
27258 27259 27260 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27258 def description @description end |
#disk_size_gb ⇒ Fixnum
Output only. [Output Only] Size of the source disk, specified in GB.
Corresponds to the JSON property diskSizeGb
27263 27264 27265 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27263 def disk_size_gb @disk_size_gb end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
27270 27271 27272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27270 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#instantSnapshot
for InstantSnapshot resources.
Corresponds to the JSON property kind
27276 27277 27278 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27276 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this InstantSnapshot, which
is essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a InstantSnapshot.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
27289 27290 27291 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27289 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this InstantSnapshot. These can be later modified by
the setLabels method.
Label values may be empty.
Corresponds to the JSON property labels
27296 27297 27298 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27296 def labels @labels end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
27307 27308 27309 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27307 def name @name end |
#params ⇒ Google::Apis::ComputeV1::InstantSnapshotParams
Additional instant snapshot params.
Corresponds to the JSON property params
27312 27313 27314 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27312 def params @params end |
#region ⇒ String
Output only. [Output Only] URL of the region where the instant snapshot
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
27320 27321 27322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27320 def region @region end |
#resource_status ⇒ Google::Apis::ComputeV1::InstantSnapshotResourceStatus
Output only. [Output Only] Status information for the instant snapshot
resource.
Corresponds to the JSON property resourceStatus
27326 27327 27328 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27326 def resource_status @resource_status end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
27331 27332 27333 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27331 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
27337 27338 27339 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27337 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
27343 27344 27345 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27343 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
27348 27349 27350 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27348 def self_link_with_id @self_link_with_id end |
#source_disk ⇒ String
URL of the source disk used to create this instant snapshot. Note that the source disk must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ disks/disk
- projects/project/zones/zone/disks/disk
- projects/project/regions/region/disks/disk
- zones/zone/disks/disk
-
regions/region/disks/disk
Corresponds to the JSON property sourceDisk
27377 27378 27379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27377 def source_disk @source_disk end |
#source_disk_id ⇒ String
Output only. [Output Only] The ID value of the disk used to create this
InstantSnapshot.
This value may be used to determine whether the InstantSnapshot
was taken from the current or a previous instance of a given disk name.
Corresponds to the JSON property sourceDiskId
27385 27386 27387 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27385 def source_disk_id @source_disk_id end |
#source_instant_snapshot_group ⇒ String
Output only. [Output Only] URL of the source instant snapshot this instant
snapshot is
part of. Note that the source instant snapshot group must be in the same
zone/region as the instant snapshot to be created. This can be a full or
valid partial URL.
Corresponds to the JSON property sourceInstantSnapshotGroup
27394 27395 27396 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27394 def source_instant_snapshot_group @source_instant_snapshot_group end |
#source_instant_snapshot_group_id ⇒ String
Output only. [Output Only] The ID value of the source instant snapshot group
this
InstantSnapshot is part of. This value may be used to determine whether the
InstantSnapshot was created as part of an InstantSnapshotGroup creation.
Corresponds to the JSON property sourceInstantSnapshotGroupId
27402 27403 27404 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27402 def source_instant_snapshot_group_id @source_instant_snapshot_group_id end |
#status ⇒ String
Output only. [Output Only] The status of the instantSnapshot. This can
beCREATING, DELETING, FAILED, orREADY.
Corresponds to the JSON property status
27408 27409 27410 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27408 def status @status end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the instant snapshot resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
27415 27416 27417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27415 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27422 27423 27424 27425 27426 27427 27428 27429 27430 27431 27432 27433 27434 27435 27436 27437 27438 27439 27440 27441 27442 27443 27444 27445 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27422 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group) @source_instant_snapshot_group_id = args[:source_instant_snapshot_group_id] if args.key?(:source_instant_snapshot_group_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |