Class: Google::Apis::ComputeV1::InstantSnapshotGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an InstantSnapshotGroup resource. An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotGroup

Returns a new instance of InstantSnapshotGroup.



27154
27155
27156
# File 'lib/google/apis/compute_v1/classes.rb', line 27154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


27078
27079
27080
# File 'lib/google/apis/compute_v1/classes.rb', line 27078

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Optional. An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


27085
27086
27087
# File 'lib/google/apis/compute_v1/classes.rb', line 27085

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27092
27093
27094
# File 'lib/google/apis/compute_v1/classes.rb', line 27092

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instantSnapshotGroup for InstantSnapshotGroup resources. Corresponds to the JSON property kind

Returns:

  • (String)


27099
27100
27101
# File 'lib/google/apis/compute_v1/classes.rb', line 27099

def kind
  @kind
end

#nameString

Identifier. Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


27111
27112
27113
# File 'lib/google/apis/compute_v1/classes.rb', line 27111

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


27119
27120
27121
# File 'lib/google/apis/compute_v1/classes.rb', line 27119

def region
  @region
end

#resource_statusGoogle::Apis::ComputeV1::InstantSnapshotGroupResourceStatus

Corresponds to the JSON property resourceStatus



27124
27125
27126
# File 'lib/google/apis/compute_v1/classes.rb', line 27124

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27129
27130
27131
# File 'lib/google/apis/compute_v1/classes.rb', line 27129

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


27134
27135
27136
# File 'lib/google/apis/compute_v1/classes.rb', line 27134

def self_link_with_id
  @self_link_with_id
end

#source_consistency_groupString

Corresponds to the JSON property sourceConsistencyGroup

Returns:

  • (String)


27139
27140
27141
# File 'lib/google/apis/compute_v1/classes.rb', line 27139

def source_consistency_group
  @source_consistency_group
end

#statusString

Output only. [Output Only] Corresponds to the JSON property status

Returns:

  • (String)


27144
27145
27146
# File 'lib/google/apis/compute_v1/classes.rb', line 27144

def status
  @status
end

#zoneString

Output only. [Output Only] URL of the zone where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


27152
27153
27154
# File 'lib/google/apis/compute_v1/classes.rb', line 27152

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27159
27160
27161
27162
27163
27164
27165
27166
27167
27168
27169
27170
27171
27172
# File 'lib/google/apis/compute_v1/classes.rb', line 27159

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_consistency_group = args[:source_consistency_group] if args.key?(:source_consistency_group)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end