Class: Google::Apis::ComputeV1::InstantSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstantSnapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotList

Returns a new instance of InstantSnapshotList.



28027
28028
28029
# File 'lib/google/apis/compute_v1/classes.rb', line 28027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27995
27996
27997
# File 'lib/google/apis/compute_v1/classes.rb', line 27995

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstantSnapshot>

A list of InstantSnapshot resources. Corresponds to the JSON property items



28000
28001
28002
# File 'lib/google/apis/compute_v1/classes.rb', line 28000

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


28005
28006
28007
# File 'lib/google/apis/compute_v1/classes.rb', line 28005

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28015
28016
28017
# File 'lib/google/apis/compute_v1/classes.rb', line 28015

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28020
28021
28022
# File 'lib/google/apis/compute_v1/classes.rb', line 28020

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstantSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



28025
28026
28027
# File 'lib/google/apis/compute_v1/classes.rb', line 28025

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28032
28033
28034
28035
28036
28037
28038
28039
# File 'lib/google/apis/compute_v1/classes.rb', line 28032

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end