Class: Google::Apis::ComputeV1::InstantSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstantSnapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotList

Returns a new instance of InstantSnapshotList.



28019
28020
28021
# File 'lib/google/apis/compute_v1/classes.rb', line 28019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27987
27988
27989
# File 'lib/google/apis/compute_v1/classes.rb', line 27987

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstantSnapshot>

A list of InstantSnapshot resources. Corresponds to the JSON property items



27992
27993
27994
# File 'lib/google/apis/compute_v1/classes.rb', line 27992

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


27997
27998
27999
# File 'lib/google/apis/compute_v1/classes.rb', line 27997

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28007
28008
28009
# File 'lib/google/apis/compute_v1/classes.rb', line 28007

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28012
28013
28014
# File 'lib/google/apis/compute_v1/classes.rb', line 28012

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InstantSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



28017
28018
28019
# File 'lib/google/apis/compute_v1/classes.rb', line 28017

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28024
28025
28026
28027
28028
28029
28030
28031
# File 'lib/google/apis/compute_v1/classes.rb', line 28024

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end