Class: Google::Apis::ComputeV1::InstantSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstantSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of InstantSnapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshot>
A list of InstantSnapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotList
constructor
A new instance of InstantSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotList
Returns a new instance of InstantSnapshotList.
27803 27804 27805 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
27771 27772 27773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27771 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshot>
A list of InstantSnapshot resources.
Corresponds to the JSON property items
27776 27777 27778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27776 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
27781 27782 27783 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27781 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
27791 27792 27793 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27791 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
27796 27797 27798 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27796 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
27801 27802 27803 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27801 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27808 27809 27810 27811 27812 27813 27814 27815 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27808 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |