Class: Google::Apis::ComputeV1::InstantSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstantSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of InstantSnapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshot>
A list of InstantSnapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotList
constructor
A new instance of InstantSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotList
Returns a new instance of InstantSnapshotList.
27291 27292 27293 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
27259 27260 27261 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27259 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshot>
A list of InstantSnapshot resources.
Corresponds to the JSON property items
27264 27265 27266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27264 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
27269 27270 27271 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27269 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
27279 27280 27281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27279 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
27284 27285 27286 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27284 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
27289 27290 27291 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27289 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27296 27297 27298 27299 27300 27301 27302 27303 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27296 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |