Class: Google::Apis::ComputeV1::InstantSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstantSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of InstantSnapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshot>
A list of InstantSnapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotList
constructor
A new instance of InstantSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotList
Returns a new instance of InstantSnapshotList.
23749 23750 23751 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23717 23718 23719 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23717 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshot>
A list of InstantSnapshot resources.
Corresponds to the JSON property items
23722 23723 23724 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23722 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
23727 23728 23729 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23727 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23737 23738 23739 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23737 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23742 23743 23744 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23742 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
23747 23748 23749 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23747 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23754 23755 23756 23757 23758 23759 23760 23761 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23754 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |