Class: Google::Apis::ComputeV1::Interconnect
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Interconnect
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents an Interconnect resource. An Interconnect resource is a dedicated connection between the GCP network and your on-premises network. For more information, read the Dedicated Interconnect Overview.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Administrative status of the interconnect.
-
#circuit_infos ⇒ Array<Google::Apis::ComputeV1::InterconnectCircuitInfo>
[Output Only] A list of CircuitInfo objects, that describe the individual circuits in this LAG.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#customer_name ⇒ String
Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
-
#description ⇒ String
An optional description of this resource.
-
#expected_outages ⇒ Array<Google::Apis::ComputeV1::InterconnectOutageNotification>
[Output Only] A list of outages expected for this Interconnect.
-
#google_ip_address ⇒ String
[Output Only] IP address configured on the Google side of the Interconnect link.
-
#google_reference_id ⇒ String
[Output Only] Google reference ID to be used when raising support tickets with Google or otherwise to debug backend connectivity issues.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#interconnect_attachments ⇒ Array<String>
[Output Only] A list of the URLs of all InterconnectAttachments configured to use this Interconnect.
-
#interconnect_type ⇒ String
Type of interconnect, which can take one of the following values: - PARTNER: A partner-managed interconnection shared between customers though a partner.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#link_type ⇒ String
Type of link requested, which can take one of the following values: - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics.
-
#location ⇒ String
URL of the InterconnectLocation object that represents where this connection is to be provisioned.
-
#name ⇒ String
Name of the resource.
-
#noc_contact_email ⇒ String
Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect.
-
#operational_status ⇒ String
[Output Only] The current status of this Interconnect's functionality, which can take one of the following values: - OS_ACTIVE: A valid Interconnect, which is turned up and is ready to use.
-
#peer_ip_address ⇒ String
[Output Only] IP address configured on the customer side of the Interconnect link.
-
#provisioned_link_count ⇒ Fixnum
[Output Only] Number of links actually provisioned in this interconnect.
-
#requested_link_count ⇒ Fixnum
Target number of physical links in the link bundle, as requested by the customer.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
[Output Only] Set to true if the resource satisfies the zone separation organization policy constraints and false otherwise.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#state ⇒ String
[Output Only] The current state of Interconnect functionality, which can take one of the following values: - ACTIVE: The Interconnect is valid, turned up and ready to use.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Interconnect
constructor
A new instance of Interconnect.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Interconnect
Returns a new instance of Interconnect.
15926 15927 15928 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Administrative status of the interconnect. When this is set to true, the
Interconnect is functional and can carry traffic. When set to false, no
packets can be carried over the interconnect and no BGP routes are exchanged
over it. By default, the status is set to true.
Corresponds to the JSON property adminEnabled
15771 15772 15773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15771 def admin_enabled @admin_enabled end |
#circuit_infos ⇒ Array<Google::Apis::ComputeV1::InterconnectCircuitInfo>
[Output Only] A list of CircuitInfo objects, that describe the individual
circuits in this LAG.
Corresponds to the JSON property circuitInfos
15778 15779 15780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15778 def circuit_infos @circuit_infos end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
15783 15784 15785 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15783 def @creation_timestamp end |
#customer_name ⇒ String
Customer name, to put in the Letter of Authorization as the party authorized
to request a crossconnect.
Corresponds to the JSON property customerName
15789 15790 15791 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15789 def customer_name @customer_name end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
15795 15796 15797 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15795 def description @description end |
#expected_outages ⇒ Array<Google::Apis::ComputeV1::InterconnectOutageNotification>
[Output Only] A list of outages expected for this Interconnect.
Corresponds to the JSON property expectedOutages
15800 15801 15802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15800 def expected_outages @expected_outages end |
#google_ip_address ⇒ String
[Output Only] IP address configured on the Google side of the Interconnect
link. This can be used only for ping tests.
Corresponds to the JSON property googleIpAddress
15806 15807 15808 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15806 def google_ip_address @google_ip_address end |
#google_reference_id ⇒ String
[Output Only] Google reference ID to be used when raising support tickets with
Google or otherwise to debug backend connectivity issues.
Corresponds to the JSON property googleReferenceId
15812 15813 15814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15812 def google_reference_id @google_reference_id end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
15818 15819 15820 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15818 def id @id end |
#interconnect_attachments ⇒ Array<String>
[Output Only] A list of the URLs of all InterconnectAttachments configured to
use this Interconnect.
Corresponds to the JSON property interconnectAttachments
15824 15825 15826 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15824 def @interconnect_attachments end |
#interconnect_type ⇒ String
Type of interconnect, which can take one of the following values: - PARTNER: A
partner-managed interconnection shared between customers though a partner. -
DEDICATED: A dedicated physical interconnection with the customer. Note that a
value IT_PRIVATE has been deprecated in favor of DEDICATED.
Corresponds to the JSON property interconnectType
15832 15833 15834 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15832 def interconnect_type @interconnect_type end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#interconnect for
interconnects.
Corresponds to the JSON property kind
15838 15839 15840 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15838 def kind @kind end |
#link_type ⇒ String
Type of link requested, which can take one of the following values: -
LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics -
LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. Note that this
field indicates the speed of each of the links in the bundle, not the speed of
the entire bundle.
Corresponds to the JSON property linkType
15847 15848 15849 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15847 def link_type @link_type end |
#location ⇒ String
URL of the InterconnectLocation object that represents where this connection
is to be provisioned.
Corresponds to the JSON property location
15853 15854 15855 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15853 def location @location end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
15863 15864 15865 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15863 def name @name end |
#noc_contact_email ⇒ String
Email address to contact the customer NOC for operations and maintenance
notifications regarding this Interconnect. If specified, this will be used for
notifications in addition to all other forms described, such as Stackdriver
logs alerting and Cloud Notifications.
Corresponds to the JSON property nocContactEmail
15871 15872 15873 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15871 def noc_contact_email @noc_contact_email end |
#operational_status ⇒ String
[Output Only] The current status of this Interconnect's functionality, which
can take one of the following values: - OS_ACTIVE: A valid Interconnect, which
is turned up and is ready to use. Attachments may be provisioned on this
Interconnect. - OS_UNPROVISIONED: An Interconnect that has not completed
turnup. No attachments may be provisioned on this Interconnect. -
OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal maintenance.
No attachments may be provisioned or updated on this Interconnect.
Corresponds to the JSON property operationalStatus
15882 15883 15884 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15882 def operational_status @operational_status end |
#peer_ip_address ⇒ String
[Output Only] IP address configured on the customer side of the Interconnect
link. The customer should configure this IP address during turnup when
prompted by Google NOC. This can be used only for ping tests.
Corresponds to the JSON property peerIpAddress
15889 15890 15891 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15889 def peer_ip_address @peer_ip_address end |
#provisioned_link_count ⇒ Fixnum
[Output Only] Number of links actually provisioned in this interconnect.
Corresponds to the JSON property provisionedLinkCount
15894 15895 15896 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15894 def provisioned_link_count @provisioned_link_count end |
#requested_link_count ⇒ Fixnum
Target number of physical links in the link bundle, as requested by the
customer.
Corresponds to the JSON property requestedLinkCount
15900 15901 15902 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15900 def requested_link_count @requested_link_count end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
[Output Only] Set to true if the resource satisfies the zone separation
organization policy constraints and false otherwise. Defaults to false if the
field is not present.
Corresponds to the JSON property satisfiesPzs
15907 15908 15909 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15907 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
15913 15914 15915 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15913 def self_link @self_link end |
#state ⇒ String
[Output Only] The current state of Interconnect functionality, which can take
one of the following values: - ACTIVE: The Interconnect is valid, turned up
and ready to use. Attachments may be provisioned on this Interconnect. -
UNPROVISIONED: The Interconnect has not completed turnup. No attachments may
be provisioned on this Interconnect. - UNDER_MAINTENANCE: The Interconnect is
undergoing internal maintenance. No attachments may be provisioned or updated
on this Interconnect.
Corresponds to the JSON property state
15924 15925 15926 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15924 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15931 15932 15933 15934 15935 15936 15937 15938 15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 15952 15953 15954 15955 |
# File 'lib/google/apis/compute_v1/classes.rb', line 15931 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @circuit_infos = args[:circuit_infos] if args.key?(:circuit_infos) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @customer_name = args[:customer_name] if args.key?(:customer_name) @description = args[:description] if args.key?(:description) @expected_outages = args[:expected_outages] if args.key?(:expected_outages) @google_ip_address = args[:google_ip_address] if args.key?(:google_ip_address) @google_reference_id = args[:google_reference_id] if args.key?(:google_reference_id) @id = args[:id] if args.key?(:id) @interconnect_attachments = args[:interconnect_attachments] if args.key?(:interconnect_attachments) @interconnect_type = args[:interconnect_type] if args.key?(:interconnect_type) @kind = args[:kind] if args.key?(:kind) @link_type = args[:link_type] if args.key?(:link_type) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @noc_contact_email = args[:noc_contact_email] if args.key?(:noc_contact_email) @operational_status = args[:operational_status] if args.key?(:operational_status) @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address) @provisioned_link_count = args[:provisioned_link_count] if args.key?(:provisioned_link_count) @requested_link_count = args[:requested_link_count] if args.key?(:requested_link_count) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @state = args[:state] if args.key?(:state) end |