Class: Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnect
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnect
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Configuration information for application awareness on this Cloud Interconnect.
Instance Attribute Summary collapse
-
#bandwidth_percentage_policy ⇒ Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy
Corresponds to the JSON property
bandwidthPercentagePolicy. -
#profile_description ⇒ String
Description for the application awareness profile on this Cloud Interconnect.
-
#shape_average_percentages ⇒ Array<Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnectBandwidthPercentage>
Optional field to specify a list of shape average percentages to be applied in conjunction with StrictPriorityPolicy or BandwidthPercentagePolicy.
-
#strict_priority_policy ⇒ Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnectStrictPriorityPolicy
Specify configuration for StrictPriorityPolicy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect
constructor
A new instance of InterconnectApplicationAwareInterconnect.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect
Returns a new instance of InterconnectApplicationAwareInterconnect.
25089 25090 25091 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bandwidth_percentage_policy ⇒ Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy
Corresponds to the JSON property bandwidthPercentagePolicy
25069 25070 25071 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25069 def bandwidth_percentage_policy @bandwidth_percentage_policy end |
#profile_description ⇒ String
Description for the application awareness profile on this Cloud
Interconnect.
Corresponds to the JSON property profileDescription
25075 25076 25077 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25075 def profile_description @profile_description end |
#shape_average_percentages ⇒ Array<Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnectBandwidthPercentage>
Optional field to specify a list of shape average percentages to be
applied in conjunction with StrictPriorityPolicy or
BandwidthPercentagePolicy.
Corresponds to the JSON property shapeAveragePercentages
25082 25083 25084 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25082 def shape_average_percentages @shape_average_percentages end |
#strict_priority_policy ⇒ Google::Apis::ComputeV1::InterconnectApplicationAwareInterconnectStrictPriorityPolicy
Specify configuration for StrictPriorityPolicy.
Corresponds to the JSON property strictPriorityPolicy
25087 25088 25089 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25087 def strict_priority_policy @strict_priority_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25094 25095 25096 25097 25098 25099 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25094 def update!(**args) @bandwidth_percentage_policy = args[:bandwidth_percentage_policy] if args.key?(:bandwidth_percentage_policy) @profile_description = args[:profile_description] if args.key?(:profile_description) @shape_average_percentages = args[:shape_average_percentages] if args.key?(:shape_average_percentages) @strict_priority_policy = args[:strict_priority_policy] if args.key?(:strict_priority_policy) end |