Class: Google::Apis::ComputeV1::InterconnectAttachment
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents an Interconnect Attachment (VLAN) resource. You can use Interconnect attachments (VLANS) to connect your Virtual Private Cloud networks to your on-premises networks through an Interconnect. For more information, read Creating VLAN Attachments.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Determines whether this Attachment will carry packets.
-
#attachment_group ⇒ String
Output only.
-
#bandwidth ⇒ String
Provisioned bandwidth capacity for the interconnect attachment.
-
#candidate_cloud_router_ip_address ⇒ String
Single IPv4 address + prefix length to be configured on the cloud router interface for this interconnect attachment.
-
#candidate_cloud_router_ipv6_address ⇒ String
Single IPv6 address + prefix length to be configured on the cloud router interface for this interconnect attachment.
-
#candidate_customer_router_ip_address ⇒ String
Single IPv4 address + prefix length to be configured on the customer router interface for this interconnect attachment.
-
#candidate_customer_router_ipv6_address ⇒ String
Single IPv6 address + prefix length to be configured on the customer router interface for this interconnect attachment.
-
#candidate_ipv6_subnets ⇒ Array<String>
This field is not available.
-
#candidate_subnets ⇒ Array<String>
Input only.
-
#cloud_router_ip_address ⇒ String
Output only.
-
#cloud_router_ipv6_address ⇒ String
Output only.
-
#cloud_router_ipv6_interface_id ⇒ String
This field is not available.
-
#configuration_constraints ⇒ Google::Apis::ComputeV1::InterconnectAttachmentConfigurationConstraints
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#customer_router_ip_address ⇒ String
Output only.
-
#customer_router_ipv6_address ⇒ String
Output only.
-
#customer_router_ipv6_interface_id ⇒ String
This field is not available.
-
#dataplane_version ⇒ Fixnum
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#edge_availability_domain ⇒ String
Input only.
-
#encryption ⇒ String
Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment).
-
#google_reference_id ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#interconnect ⇒ String
URL of the underlying Interconnect object that this attachment's traffic will traverse through.
-
#ipsec_internal_addresses ⇒ Array<String>
A list of URLs of addresses that have been reserved for the VLAN attachment.
-
#kind ⇒ String
Output only.
-
#l2_forwarding ⇒ Google::Apis::ComputeV1::InterconnectAttachmentL2Forwarding
L2 Interconnect Attachment related configuration.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this InterconnectAttachment, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#mtu ⇒ Fixnum
Maximum Transmission Unit (MTU), in bytes, of packets passing through this interconnect attachment.
-
#name ⇒ String
Name of the resource.
-
#operational_status ⇒ String
Output only.
-
#pairing_key ⇒ String
[Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not present for DEDICATED].
-
#params ⇒ Google::Apis::ComputeV1::InterconnectAttachmentParams
Additional interconnect attachment parameters.
-
#partner_asn ⇒ Fixnum
Optional BGP ASN for the router supplied by a Layer 3 Partner if they configured BGP on behalf of the customer.
-
#partner_metadata ⇒ Google::Apis::ComputeV1::InterconnectAttachmentPartnerMetadata
Informational metadata about Partner attachments from Partners to display to customers.
-
#private_interconnect_info ⇒ Google::Apis::ComputeV1::InterconnectAttachmentPrivateInfo
Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED.
-
#region ⇒ String
Output only.
-
#remote_service ⇒ String
Output only.
-
#router ⇒ String
URL of the Cloud Router to be used for dynamic routing.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#stack_type ⇒ String
The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not.
-
#state ⇒ String
Output only.
-
#subnet_length ⇒ Fixnum
Input only.
-
#type ⇒ String
The type of interconnect attachment this is, which can take one of the following values:.
-
#vlan_tag8021q ⇒ Fixnum
The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4093.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachment
constructor
A new instance of InterconnectAttachment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachment
Returns a new instance of InterconnectAttachment.
29135 29136 29137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Determines whether this Attachment will carry packets.
Not present for PARTNER_PROVIDER.
Corresponds to the JSON property adminEnabled
28701 28702 28703 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28701 def admin_enabled @admin_enabled end |
#attachment_group ⇒ String
Output only. [Output Only] URL of the AttachmentGroup that includes this
Attachment.
Corresponds to the JSON property attachmentGroup
28708 28709 28710 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28708 def @attachment_group end |
#bandwidth ⇒ String
Provisioned bandwidth capacity for the interconnect attachment. For attachments of type DEDICATED, the user can set the bandwidth. For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth. Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the following values:
- BPS_50M: 50 Mbit/s
- BPS_100M: 100 Mbit/s
- BPS_200M: 200 Mbit/s
- BPS_300M: 300 Mbit/s
- BPS_400M: 400 Mbit/s
- BPS_500M: 500 Mbit/s
- BPS_1G: 1 Gbit/s
- BPS_2G: 2 Gbit/s
- BPS_5G: 5 Gbit/s
- BPS_10G: 10 Gbit/s
- BPS_20G: 20 Gbit/s
- BPS_50G: 50 Gbit/s
- BPS_100G: 100 Gbit/s
- BPS_400G: 400 Gbit/s
Corresponds to the JSON property
bandwidth
28733 28734 28735 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28733 def bandwidth @bandwidth end |
#candidate_cloud_router_ip_address ⇒ String
Single IPv4 address + prefix length to be configured on the cloud router interface for this interconnect attachment.
- Both candidate_cloud_router_ip_address and candidate_customer_router_ip_address fields must be set or both must be unset.
- Prefix length of both candidate_cloud_router_ip_address and candidate_customer_router_ip_address must be the same.
- Max prefix length is 31.
Corresponds to the JSON property
candidateCloudRouterIpAddress
28746 28747 28748 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28746 def candidate_cloud_router_ip_address @candidate_cloud_router_ip_address end |
#candidate_cloud_router_ipv6_address ⇒ String
Single IPv6 address + prefix length to be configured on the cloud router interface for this interconnect attachment.
- Both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address fields must be set or both must be unset.
- Prefix length of both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address must be the same.
- Max prefix length is 126.
Corresponds to the JSON property
candidateCloudRouterIpv6Address
28759 28760 28761 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28759 def candidate_cloud_router_ipv6_address @candidate_cloud_router_ipv6_address end |
#candidate_customer_router_ip_address ⇒ String
Single IPv4 address + prefix length to be configured on the customer router
interface for this interconnect attachment.
Corresponds to the JSON property candidateCustomerRouterIpAddress
28765 28766 28767 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28765 def candidate_customer_router_ip_address @candidate_customer_router_ip_address end |
#candidate_customer_router_ipv6_address ⇒ String
Single IPv6 address + prefix length to be configured on the customer router
interface for this interconnect attachment.
Corresponds to the JSON property candidateCustomerRouterIpv6Address
28771 28772 28773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28771 def candidate_customer_router_ipv6_address @candidate_customer_router_ipv6_address end |
#candidate_ipv6_subnets ⇒ Array<String>
This field is not available.
Corresponds to the JSON property candidateIpv6Subnets
28776 28777 28778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28776 def candidate_ipv6_subnets @candidate_ipv6_subnets end |
#candidate_subnets ⇒ Array<String>
Input only. Up to 16 candidate prefixes that can be used to restrict the
allocation
of cloudRouterIpAddress and customerRouterIpAddress for this attachment.
All prefixes must be within link-local address space (169.254.0.0/16) and
must be /29 or shorter (/28, /27, etc). Google will attempt to select an
unused /29 from the supplied candidate prefix(es). The request will fail if
all possible /29s are in use on Google's edge. If not supplied, Google will
randomly select an unused /29 from all of link-local space.
Corresponds to the JSON property candidateSubnets
28788 28789 28790 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28788 def candidate_subnets @candidate_subnets end |
#cloud_router_ip_address ⇒ String
Output only. [Output Only] IPv4 address + prefix length to be configured on
Cloud Router
Interface for this interconnect attachment.
Corresponds to the JSON property cloudRouterIpAddress
28795 28796 28797 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28795 def cloud_router_ip_address @cloud_router_ip_address end |
#cloud_router_ipv6_address ⇒ String
Output only. [Output Only] IPv6 address + prefix length to be configured on
Cloud
Router Interface for this interconnect attachment.
Corresponds to the JSON property cloudRouterIpv6Address
28802 28803 28804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28802 def cloud_router_ipv6_address @cloud_router_ipv6_address end |
#cloud_router_ipv6_interface_id ⇒ String
This field is not available.
Corresponds to the JSON property cloudRouterIpv6InterfaceId
28807 28808 28809 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28807 def cloud_router_ipv6_interface_id @cloud_router_ipv6_interface_id end |
#configuration_constraints ⇒ Google::Apis::ComputeV1::InterconnectAttachmentConfigurationConstraints
Output only. [Output Only] Constraints for this attachment, if any. The
attachment does
not work if these constraints are not met.
Corresponds to the JSON property configurationConstraints
28814 28815 28816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28814 def configuration_constraints @configuration_constraints end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
28820 28821 28822 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28820 def @creation_timestamp end |
#customer_router_ip_address ⇒ String
Output only. [Output Only] IPv4 address + prefix length to be configured on
the customer
router subinterface for this interconnect attachment.
Corresponds to the JSON property customerRouterIpAddress
28827 28828 28829 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28827 def customer_router_ip_address @customer_router_ip_address end |
#customer_router_ipv6_address ⇒ String
Output only. [Output Only] IPv6 address + prefix length to be configured on
the
customer router subinterface for this interconnect attachment.
Corresponds to the JSON property customerRouterIpv6Address
28834 28835 28836 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28834 def customer_router_ipv6_address @customer_router_ipv6_address end |
#customer_router_ipv6_interface_id ⇒ String
This field is not available.
Corresponds to the JSON property customerRouterIpv6InterfaceId
28839 28840 28841 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28839 def customer_router_ipv6_interface_id @customer_router_ipv6_interface_id end |
#dataplane_version ⇒ Fixnum
Output only. [Output Only] Dataplane version for this InterconnectAttachment.
This
field is only present for Dataplane version 2 and higher. Absence of this
field in the API output indicates that the Dataplane is version 1.
Corresponds to the JSON property dataplaneVersion
28847 28848 28849 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28847 def dataplane_version @dataplane_version end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
28852 28853 28854 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28852 def description @description end |
#edge_availability_domain ⇒ String
Input only. Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values:
- AVAILABILITY_DOMAIN_ANY
- AVAILABILITY_DOMAIN_1
- AVAILABILITY_DOMAIN_2
For improved reliability, customers should configure a pair of attachments,
one per availability domain. The selected availability domain will be
provided to the Partner via the pairing key, so that the provisioned
circuit will lie in the specified domain. If not specified, the value will
default to AVAILABILITY_DOMAIN_ANY.
Corresponds to the JSON property
edgeAvailabilityDomain
28868 28869 28870 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28868 def edge_availability_domain @edge_availability_domain end |
#encryption ⇒ String
Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment). Can only be specified at attachment creation for PARTNER or DEDICATED attachments. Possible values are:
- NONE - This is the default value, which means that the VLAN attachment carries unencrypted traffic. VMs are able to send traffic to, or receive traffic from, such a VLAN attachment.
- IPSEC - The VLAN attachment carries only encrypted
traffic that is encrypted by an IPsec device, such as an HA VPN gateway or
third-party IPsec VPN. VMs cannot directly send traffic to, or receive
traffic from, such a VLAN attachment. To use HA VPN over Cloud
Interconnect, the VLAN attachment must be created with this
option.
Corresponds to the JSON property
encryption
28886 28887 28888 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28886 def encryption @encryption end |
#google_reference_id ⇒ String
Output only. [Output Only] Google reference ID, to be used when raising
support tickets
with Google or otherwise to debug backend connectivity issues.
[Deprecated] This field is not used.
Corresponds to the JSON property googleReferenceId
28894 28895 28896 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28894 def google_reference_id @google_reference_id end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
28901 28902 28903 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28901 def id @id end |
#interconnect ⇒ String
URL of the underlying Interconnect object that this attachment's traffic
will traverse through.
Corresponds to the JSON property interconnect
28907 28908 28909 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28907 def interconnect @interconnect end |
#ipsec_internal_addresses ⇒ Array<String>
A list of URLs of addresses that have been reserved for the VLAN
attachment. Used only for the VLAN attachment that has the encryption
option as IPSEC. The addresses must be regional internal IP address ranges.
When creating an HA VPN gateway over the VLAN attachment, if the attachment
is configured to use a regional internal IP address, then the VPN gateway's
IP address is allocated from the IP address range specified here. For
example, if the HA VPN gateway's interface 0 is paired to this VLAN
attachment, then a regional internal IP address for the VPN gateway
interface 0 will be allocated from the IP address specified for this
VLAN attachment.
If this field is not specified when creating the VLAN attachment, then
later on when creating an HA VPN gateway on this VLAN attachment, the HA
VPN gateway's IP address is allocated from the regional external IP address
pool.
Corresponds to the JSON property ipsecInternalAddresses
28925 28926 28927 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28925 def ipsec_internal_addresses @ipsec_internal_addresses end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
interconnectAttachment for interconnect attachments.
Corresponds to the JSON property kind
28931 28932 28933 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28931 def kind @kind end |
#l2_forwarding ⇒ Google::Apis::ComputeV1::InterconnectAttachmentL2Forwarding
L2 Interconnect Attachment related configuration.
Corresponds to the JSON property l2Forwarding
28936 28937 28938 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28936 def l2_forwarding @l2_forwarding end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this InterconnectAttachment,
which is essentially a hash of the labels set used for optimistic locking.
The fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an InterconnectAttachment.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
28949 28950 28951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28949 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
28956 28957 28958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28956 def labels @labels end |
#mtu ⇒ Fixnum
Maximum Transmission Unit (MTU), in bytes, of packets passing through this
interconnect attachment.
Valid values are 1440, 1460, 1500, and 8896. If not specified,
the value will default to 1440.
Corresponds to the JSON property mtu
28964 28965 28966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28964 def mtu @mtu end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
28975 28976 28977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28975 def name @name end |
#operational_status ⇒ String
Output only. [Output Only] The current status of whether or not this interconnect attachment is functional, which can take one of the following values:
- OS_ACTIVE: The attachment has been turned up and is ready to use.
- OS_UNPROVISIONED: The attachment is not ready to use yet,
because turnup is not complete.
Corresponds to the JSON property
operationalStatus
28987 28988 28989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28987 def operational_status @operational_status end |
#pairing_key ⇒ String
[Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not
present for DEDICATED].
The opaque identifier of a PARTNER attachment used to initiate
provisioning with a selected partner.
Of the form "XXXXX/region/domain"
Corresponds to the JSON property pairingKey
28996 28997 28998 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28996 def pairing_key @pairing_key end |
#params ⇒ Google::Apis::ComputeV1::InterconnectAttachmentParams
Additional interconnect attachment parameters.
Corresponds to the JSON property params
29001 29002 29003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29001 def params @params end |
#partner_asn ⇒ Fixnum
Optional BGP ASN for the router supplied by a Layer 3 Partner if they
configured BGP on behalf of the customer.
Output only for PARTNER type, input only for PARTNER_PROVIDER, not
available for DEDICATED.
Corresponds to the JSON property partnerAsn
29009 29010 29011 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29009 def partner_asn @partner_asn end |
#partner_metadata ⇒ Google::Apis::ComputeV1::InterconnectAttachmentPartnerMetadata
Informational metadata about Partner attachments from Partners to display
to customers. These fields are propagated from PARTNER_PROVIDER
attachments to their corresponding PARTNER attachments.
Corresponds to the JSON property partnerMetadata
29016 29017 29018 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29016 def @partner_metadata end |
#private_interconnect_info ⇒ Google::Apis::ComputeV1::InterconnectAttachmentPrivateInfo
Information for an interconnect attachment when this belongs to an
interconnect of type DEDICATED.
Corresponds to the JSON property privateInterconnectInfo
29022 29023 29024 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29022 def private_interconnect_info @private_interconnect_info end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional interconnect
attachment
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
29031 29032 29033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29031 def region @region end |
#remote_service ⇒ String
Output only. [Output Only]
If the attachment is on a Cross-Cloud Interconnect connection, this field
contains the interconnect's remote location service provider. Example
values: "Amazon Web Services" "Microsoft Azure".
The field is set only for attachments on Cross-Cloud Interconnect
connections. Its value is copied from the InterconnectRemoteLocation
remoteService field.
Corresponds to the JSON property remoteService
29042 29043 29044 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29042 def remote_service @remote_service end |
#router ⇒ String
URL of the Cloud Router to be used for dynamic routing. This router must be
in the same region as this InterconnectAttachment. The
InterconnectAttachment will automatically connect the Interconnect to the
network & region within which the Cloud Router is configured.
Corresponds to the JSON property router
29050 29051 29052 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29050 def router @router end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
29055 29056 29057 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29055 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
29061 29062 29063 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29061 def self_link @self_link end |
#stack_type ⇒ String
The stack type for this interconnect attachment to identify whether the
IPv6 feature is enabled or not. If not specified, IPV4_ONLY
will be used.
This field can be both set at interconnect attachments creation and
update interconnect attachment operations.
Corresponds to the JSON property stackType
29070 29071 29072 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29070 def stack_type @stack_type end |
#state ⇒ String
Output only. [Output Only] The current state of this attachment's functionality. Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state can take one of the following values:
- ACTIVE: The attachment has been turned up and is ready to use.
- UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete.
- PENDING_PARTNER: A newly-created PARTNER attachment that has not yet been configured on the Partner side.
- PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it.
- PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is waiting for a customer to activate it.
- DEFUNCT:
The attachment was deleted externally and is no longer functional. This
could be because the associated Interconnect was removed, or because the
other side of a Partner attachment was deleted.
Corresponds to the JSON property
state
29096 29097 29098 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29096 def state @state end |
#subnet_length ⇒ Fixnum
Input only. Length of the IPv4 subnet mask. Allowed values:
- 29 (default)
- 30
The default value is 29, except for Cross-Cloud Interconnect
connections that use an InterconnectRemoteLocation with a
constraints.subnetLengthRange.min equal to 30. For example,
connections that use an Azure remote location fall into this
category. In these cases, the default value is 30, and requesting
29 returns an error.
Where both 29 and 30 are allowed, 29 is preferred, because it gives
Google Cloud Support more debugging visibility.
Corresponds to the JSON property
subnetLength
29114 29115 29116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29114 def subnet_length @subnet_length end |
#type ⇒ String
The type of interconnect attachment this is, which can take one of the following values:
- DEDICATED: an attachment to a Dedicated Interconnect.
- PARTNER: an attachment to a Partner Interconnect, created by the customer.
- PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the partner.
- L2_DEDICATED: a L2 attachment to a Dedicated Interconnect.
Corresponds to the JSON property
type
29127 29128 29129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29127 def type @type end |
#vlan_tag8021q ⇒ Fixnum
The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4093.
Only specified at creation time.
Corresponds to the JSON property vlanTag8021q
29133 29134 29135 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29133 def vlan_tag8021q @vlan_tag8021q end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29140 29141 29142 29143 29144 29145 29146 29147 29148 29149 29150 29151 29152 29153 29154 29155 29156 29157 29158 29159 29160 29161 29162 29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 29187 29188 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29140 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @attachment_group = args[:attachment_group] if args.key?(:attachment_group) @bandwidth = args[:bandwidth] if args.key?(:bandwidth) @candidate_cloud_router_ip_address = args[:candidate_cloud_router_ip_address] if args.key?(:candidate_cloud_router_ip_address) @candidate_cloud_router_ipv6_address = args[:candidate_cloud_router_ipv6_address] if args.key?(:candidate_cloud_router_ipv6_address) @candidate_customer_router_ip_address = args[:candidate_customer_router_ip_address] if args.key?(:candidate_customer_router_ip_address) @candidate_customer_router_ipv6_address = args[:candidate_customer_router_ipv6_address] if args.key?(:candidate_customer_router_ipv6_address) @candidate_ipv6_subnets = args[:candidate_ipv6_subnets] if args.key?(:candidate_ipv6_subnets) @candidate_subnets = args[:candidate_subnets] if args.key?(:candidate_subnets) @cloud_router_ip_address = args[:cloud_router_ip_address] if args.key?(:cloud_router_ip_address) @cloud_router_ipv6_address = args[:cloud_router_ipv6_address] if args.key?(:cloud_router_ipv6_address) @cloud_router_ipv6_interface_id = args[:cloud_router_ipv6_interface_id] if args.key?(:cloud_router_ipv6_interface_id) @configuration_constraints = args[:configuration_constraints] if args.key?(:configuration_constraints) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @customer_router_ip_address = args[:customer_router_ip_address] if args.key?(:customer_router_ip_address) @customer_router_ipv6_address = args[:customer_router_ipv6_address] if args.key?(:customer_router_ipv6_address) @customer_router_ipv6_interface_id = args[:customer_router_ipv6_interface_id] if args.key?(:customer_router_ipv6_interface_id) @dataplane_version = args[:dataplane_version] if args.key?(:dataplane_version) @description = args[:description] if args.key?(:description) @edge_availability_domain = args[:edge_availability_domain] if args.key?(:edge_availability_domain) @encryption = args[:encryption] if args.key?(:encryption) @google_reference_id = args[:google_reference_id] if args.key?(:google_reference_id) @id = args[:id] if args.key?(:id) @interconnect = args[:interconnect] if args.key?(:interconnect) @ipsec_internal_addresses = args[:ipsec_internal_addresses] if args.key?(:ipsec_internal_addresses) @kind = args[:kind] if args.key?(:kind) @l2_forwarding = args[:l2_forwarding] if args.key?(:l2_forwarding) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @mtu = args[:mtu] if args.key?(:mtu) @name = args[:name] if args.key?(:name) @operational_status = args[:operational_status] if args.key?(:operational_status) @pairing_key = args[:pairing_key] if args.key?(:pairing_key) @params = args[:params] if args.key?(:params) @partner_asn = args[:partner_asn] if args.key?(:partner_asn) @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata) @private_interconnect_info = args[:private_interconnect_info] if args.key?(:private_interconnect_info) @region = args[:region] if args.key?(:region) @remote_service = args[:remote_service] if args.key?(:remote_service) @router = args[:router] if args.key?(:router) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @stack_type = args[:stack_type] if args.key?(:stack_type) @state = args[:state] if args.key?(:state) @subnet_length = args[:subnet_length] if args.key?(:subnet_length) @type = args[:type] if args.key?(:type) @vlan_tag8021q = args[:vlan_tag8021q] if args.key?(:vlan_tag8021q) end |