Class: Google::Apis::ComputeV1::InterconnectAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an Interconnect Attachment (VLAN) resource. You can use Interconnect attachments (VLANS) to connect your Virtual Private Cloud networks to your on-premises networks through an Interconnect. For more information, read Creating VLAN Attachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachment

Returns a new instance of InterconnectAttachment.



28937
28938
28939
# File 'lib/google/apis/compute_v1/classes.rb', line 28937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Determines whether this Attachment will carry packets. Not present for PARTNER_PROVIDER. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


28503
28504
28505
# File 'lib/google/apis/compute_v1/classes.rb', line 28503

def admin_enabled
  @admin_enabled
end

#attachment_groupString

Output only. [Output Only] URL of the AttachmentGroup that includes this Attachment. Corresponds to the JSON property attachmentGroup

Returns:

  • (String)


28510
28511
28512
# File 'lib/google/apis/compute_v1/classes.rb', line 28510

def attachment_group
  @attachment_group
end

#bandwidthString

Provisioned bandwidth capacity for the interconnect attachment. For attachments of type DEDICATED, the user can set the bandwidth. For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth. Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the following values:

  • BPS_50M: 50 Mbit/s
  • BPS_100M: 100 Mbit/s
  • BPS_200M: 200 Mbit/s
  • BPS_300M: 300 Mbit/s
  • BPS_400M: 400 Mbit/s
  • BPS_500M: 500 Mbit/s
  • BPS_1G: 1 Gbit/s
  • BPS_2G: 2 Gbit/s
  • BPS_5G: 5 Gbit/s
  • BPS_10G: 10 Gbit/s
  • BPS_20G: 20 Gbit/s
  • BPS_50G: 50 Gbit/s
  • BPS_100G: 100 Gbit/s
  • BPS_400G: 400 Gbit/s Corresponds to the JSON property bandwidth

Returns:

  • (String)


28535
28536
28537
# File 'lib/google/apis/compute_v1/classes.rb', line 28535

def bandwidth
  @bandwidth
end

#candidate_cloud_router_ip_addressString

Single IPv4 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ip_address and candidate_customer_router_ip_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ip_address and candidate_customer_router_ip_address must be the same.
  • Max prefix length is 31. Corresponds to the JSON property candidateCloudRouterIpAddress

Returns:

  • (String)


28548
28549
28550
# File 'lib/google/apis/compute_v1/classes.rb', line 28548

def candidate_cloud_router_ip_address
  @candidate_cloud_router_ip_address
end

#candidate_cloud_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address must be the same.
  • Max prefix length is 126. Corresponds to the JSON property candidateCloudRouterIpv6Address

Returns:

  • (String)


28561
28562
28563
# File 'lib/google/apis/compute_v1/classes.rb', line 28561

def candidate_cloud_router_ipv6_address
  @candidate_cloud_router_ipv6_address
end

#candidate_customer_router_ip_addressString

Single IPv4 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpAddress

Returns:

  • (String)


28567
28568
28569
# File 'lib/google/apis/compute_v1/classes.rb', line 28567

def candidate_customer_router_ip_address
  @candidate_customer_router_ip_address
end

#candidate_customer_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpv6Address

Returns:

  • (String)


28573
28574
28575
# File 'lib/google/apis/compute_v1/classes.rb', line 28573

def candidate_customer_router_ipv6_address
  @candidate_customer_router_ipv6_address
end

#candidate_ipv6_subnetsArray<String>

This field is not available. Corresponds to the JSON property candidateIpv6Subnets

Returns:

  • (Array<String>)


28578
28579
28580
# File 'lib/google/apis/compute_v1/classes.rb', line 28578

def candidate_ipv6_subnets
  @candidate_ipv6_subnets
end

#candidate_subnetsArray<String>

Input only. Up to 16 candidate prefixes that can be used to restrict the allocation of cloudRouterIpAddress and customerRouterIpAddress for this attachment. All prefixes must be within link-local address space (169.254.0.0/16) and must be /29 or shorter (/28, /27, etc). Google will attempt to select an unused /29 from the supplied candidate prefix(es). The request will fail if all possible /29s are in use on Google's edge. If not supplied, Google will randomly select an unused /29 from all of link-local space. Corresponds to the JSON property candidateSubnets

Returns:

  • (Array<String>)


28590
28591
28592
# File 'lib/google/apis/compute_v1/classes.rb', line 28590

def candidate_subnets
  @candidate_subnets
end

#cloud_router_ip_addressString

Output only. [Output Only] IPv4 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment. Corresponds to the JSON property cloudRouterIpAddress

Returns:

  • (String)


28597
28598
28599
# File 'lib/google/apis/compute_v1/classes.rb', line 28597

def cloud_router_ip_address
  @cloud_router_ip_address
end

#cloud_router_ipv6_addressString

Output only. [Output Only] IPv6 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment. Corresponds to the JSON property cloudRouterIpv6Address

Returns:

  • (String)


28604
28605
28606
# File 'lib/google/apis/compute_v1/classes.rb', line 28604

def cloud_router_ipv6_address
  @cloud_router_ipv6_address
end

#cloud_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property cloudRouterIpv6InterfaceId

Returns:

  • (String)


28609
28610
28611
# File 'lib/google/apis/compute_v1/classes.rb', line 28609

def cloud_router_ipv6_interface_id
  @cloud_router_ipv6_interface_id
end

#configuration_constraintsGoogle::Apis::ComputeV1::InterconnectAttachmentConfigurationConstraints

Output only. [Output Only] Constraints for this attachment, if any. The attachment does not work if these constraints are not met. Corresponds to the JSON property configurationConstraints



28616
28617
28618
# File 'lib/google/apis/compute_v1/classes.rb', line 28616

def configuration_constraints
  @configuration_constraints
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


28622
28623
28624
# File 'lib/google/apis/compute_v1/classes.rb', line 28622

def creation_timestamp
  @creation_timestamp
end

#customer_router_ip_addressString

Output only. [Output Only] IPv4 address + prefix length to be configured on the customer router subinterface for this interconnect attachment. Corresponds to the JSON property customerRouterIpAddress

Returns:

  • (String)


28629
28630
28631
# File 'lib/google/apis/compute_v1/classes.rb', line 28629

def customer_router_ip_address
  @customer_router_ip_address
end

#customer_router_ipv6_addressString

Output only. [Output Only] IPv6 address + prefix length to be configured on the customer router subinterface for this interconnect attachment. Corresponds to the JSON property customerRouterIpv6Address

Returns:

  • (String)


28636
28637
28638
# File 'lib/google/apis/compute_v1/classes.rb', line 28636

def customer_router_ipv6_address
  @customer_router_ipv6_address
end

#customer_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property customerRouterIpv6InterfaceId

Returns:

  • (String)


28641
28642
28643
# File 'lib/google/apis/compute_v1/classes.rb', line 28641

def customer_router_ipv6_interface_id
  @customer_router_ipv6_interface_id
end

#dataplane_versionFixnum

Output only. [Output Only] Dataplane version for this InterconnectAttachment. This field is only present for Dataplane version 2 and higher. Absence of this field in the API output indicates that the Dataplane is version 1. Corresponds to the JSON property dataplaneVersion

Returns:

  • (Fixnum)


28649
28650
28651
# File 'lib/google/apis/compute_v1/classes.rb', line 28649

def dataplane_version
  @dataplane_version
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


28654
28655
28656
# File 'lib/google/apis/compute_v1/classes.rb', line 28654

def description
  @description
end

#edge_availability_domainString

Input only. Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values:

  • AVAILABILITY_DOMAIN_ANY
  • AVAILABILITY_DOMAIN_1
  • AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure a pair of attachments, one per availability domain. The selected availability domain will be provided to the Partner via the pairing key, so that the provisioned circuit will lie in the specified domain. If not specified, the value will default to AVAILABILITY_DOMAIN_ANY. Corresponds to the JSON property edgeAvailabilityDomain

Returns:

  • (String)


28670
28671
28672
# File 'lib/google/apis/compute_v1/classes.rb', line 28670

def edge_availability_domain
  @edge_availability_domain
end

#encryptionString

Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment). Can only be specified at attachment creation for PARTNER or DEDICATED attachments. Possible values are:

  • NONE - This is the default value, which means that the VLAN attachment carries unencrypted traffic. VMs are able to send traffic to, or receive traffic from, such a VLAN attachment.
  • IPSEC - The VLAN attachment carries only encrypted traffic that is encrypted by an IPsec device, such as an HA VPN gateway or third-party IPsec VPN. VMs cannot directly send traffic to, or receive traffic from, such a VLAN attachment. To use HA VPN over Cloud Interconnect, the VLAN attachment must be created with this option. Corresponds to the JSON property encryption

Returns:

  • (String)


28688
28689
28690
# File 'lib/google/apis/compute_v1/classes.rb', line 28688

def encryption
  @encryption
end

#google_reference_idString

Output only. [Output Only] Google reference ID, to be used when raising support tickets with Google or otherwise to debug backend connectivity issues. [Deprecated] This field is not used. Corresponds to the JSON property googleReferenceId

Returns:

  • (String)


28696
28697
28698
# File 'lib/google/apis/compute_v1/classes.rb', line 28696

def google_reference_id
  @google_reference_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28703
28704
28705
# File 'lib/google/apis/compute_v1/classes.rb', line 28703

def id
  @id
end

#interconnectString

URL of the underlying Interconnect object that this attachment's traffic will traverse through. Corresponds to the JSON property interconnect

Returns:

  • (String)


28709
28710
28711
# File 'lib/google/apis/compute_v1/classes.rb', line 28709

def interconnect
  @interconnect
end

#ipsec_internal_addressesArray<String>

A list of URLs of addresses that have been reserved for the VLAN attachment. Used only for the VLAN attachment that has the encryption option as IPSEC. The addresses must be regional internal IP address ranges. When creating an HA VPN gateway over the VLAN attachment, if the attachment is configured to use a regional internal IP address, then the VPN gateway's IP address is allocated from the IP address range specified here. For example, if the HA VPN gateway's interface 0 is paired to this VLAN attachment, then a regional internal IP address for the VPN gateway interface 0 will be allocated from the IP address specified for this VLAN attachment. If this field is not specified when creating the VLAN attachment, then later on when creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's IP address is allocated from the regional external IP address pool. Corresponds to the JSON property ipsecInternalAddresses

Returns:

  • (Array<String>)


28727
28728
28729
# File 'lib/google/apis/compute_v1/classes.rb', line 28727

def ipsec_internal_addresses
  @ipsec_internal_addresses
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# interconnectAttachment for interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


28733
28734
28735
# File 'lib/google/apis/compute_v1/classes.rb', line 28733

def kind
  @kind
end

#l2_forwardingGoogle::Apis::ComputeV1::InterconnectAttachmentL2Forwarding

L2 Interconnect Attachment related configuration. Corresponds to the JSON property l2Forwarding



28738
28739
28740
# File 'lib/google/apis/compute_v1/classes.rb', line 28738

def l2_forwarding
  @l2_forwarding
end

#label_fingerprintString

A fingerprint for the labels being applied to this InterconnectAttachment, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InterconnectAttachment. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


28751
28752
28753
# File 'lib/google/apis/compute_v1/classes.rb', line 28751

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


28758
28759
28760
# File 'lib/google/apis/compute_v1/classes.rb', line 28758

def labels
  @labels
end

#mtuFixnum

Maximum Transmission Unit (MTU), in bytes, of packets passing through this interconnect attachment. Valid values are 1440, 1460, 1500, and 8896. If not specified, the value will default to 1440. Corresponds to the JSON property mtu

Returns:

  • (Fixnum)


28766
28767
28768
# File 'lib/google/apis/compute_v1/classes.rb', line 28766

def mtu
  @mtu
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


28777
28778
28779
# File 'lib/google/apis/compute_v1/classes.rb', line 28777

def name
  @name
end

#operational_statusString

Output only. [Output Only] The current status of whether or not this interconnect attachment is functional, which can take one of the following values:

  • OS_ACTIVE: The attachment has been turned up and is ready to use.
  • OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


28789
28790
28791
# File 'lib/google/apis/compute_v1/classes.rb', line 28789

def operational_status
  @operational_status
end

#pairing_keyString

[Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of a PARTNER attachment used to initiate provisioning with a selected partner. Of the form "XXXXX/region/domain" Corresponds to the JSON property pairingKey

Returns:

  • (String)


28798
28799
28800
# File 'lib/google/apis/compute_v1/classes.rb', line 28798

def pairing_key
  @pairing_key
end

#paramsGoogle::Apis::ComputeV1::InterconnectAttachmentParams

Additional interconnect attachment parameters. Corresponds to the JSON property params



28803
28804
28805
# File 'lib/google/apis/compute_v1/classes.rb', line 28803

def params
  @params
end

#partner_asnFixnum

Optional BGP ASN for the router supplied by a Layer 3 Partner if they configured BGP on behalf of the customer. Output only for PARTNER type, input only for PARTNER_PROVIDER, not available for DEDICATED. Corresponds to the JSON property partnerAsn

Returns:

  • (Fixnum)


28811
28812
28813
# File 'lib/google/apis/compute_v1/classes.rb', line 28811

def partner_asn
  @partner_asn
end

#partner_metadataGoogle::Apis::ComputeV1::InterconnectAttachmentPartnerMetadata

Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments. Corresponds to the JSON property partnerMetadata



28818
28819
28820
# File 'lib/google/apis/compute_v1/classes.rb', line 28818

def 
  @partner_metadata
end

#private_interconnect_infoGoogle::Apis::ComputeV1::InterconnectAttachmentPrivateInfo

Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED. Corresponds to the JSON property privateInterconnectInfo



28824
28825
28826
# File 'lib/google/apis/compute_v1/classes.rb', line 28824

def private_interconnect_info
  @private_interconnect_info
end

#regionString

Output only. [Output Only] URL of the region where the regional interconnect attachment resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


28833
28834
28835
# File 'lib/google/apis/compute_v1/classes.rb', line 28833

def region
  @region
end

#remote_serviceString

Output only. [Output Only] If the attachment is on a Cross-Cloud Interconnect connection, this field contains the interconnect's remote location service provider. Example values: "Amazon Web Services" "Microsoft Azure". The field is set only for attachments on Cross-Cloud Interconnect connections. Its value is copied from the InterconnectRemoteLocation remoteService field. Corresponds to the JSON property remoteService

Returns:

  • (String)


28844
28845
28846
# File 'lib/google/apis/compute_v1/classes.rb', line 28844

def remote_service
  @remote_service
end

#routerString

URL of the Cloud Router to be used for dynamic routing. This router must be in the same region as this InterconnectAttachment. The InterconnectAttachment will automatically connect the Interconnect to the network & region within which the Cloud Router is configured. Corresponds to the JSON property router

Returns:

  • (String)


28852
28853
28854
# File 'lib/google/apis/compute_v1/classes.rb', line 28852

def router
  @router
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


28857
28858
28859
# File 'lib/google/apis/compute_v1/classes.rb', line 28857

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28863
28864
28865
# File 'lib/google/apis/compute_v1/classes.rb', line 28863

def self_link
  @self_link
end

#stack_typeString

The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used. This field can be both set at interconnect attachments creation and update interconnect attachment operations. Corresponds to the JSON property stackType

Returns:

  • (String)


28872
28873
28874
# File 'lib/google/apis/compute_v1/classes.rb', line 28872

def stack_type
  @stack_type
end

#stateString

Output only. [Output Only] The current state of this attachment's functionality. Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state can take one of the following values:

  • ACTIVE: The attachment has been turned up and is ready to use.
  • UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete.
  • PENDING_PARTNER: A newly-created PARTNER attachment that has not yet been configured on the Partner side.
  • PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it.
  • PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is waiting for a customer to activate it.
  • DEFUNCT: The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was removed, or because the other side of a Partner attachment was deleted. Corresponds to the JSON property state

Returns:

  • (String)


28898
28899
28900
# File 'lib/google/apis/compute_v1/classes.rb', line 28898

def state
  @state
end

#subnet_lengthFixnum

Input only. Length of the IPv4 subnet mask. Allowed values:

  • 29 (default)
  • 30 The default value is 29, except for Cross-Cloud Interconnect connections that use an InterconnectRemoteLocation with a constraints.subnetLengthRange.min equal to 30. For example, connections that use an Azure remote location fall into this category. In these cases, the default value is 30, and requesting 29 returns an error. Where both 29 and 30 are allowed, 29 is preferred, because it gives Google Cloud Support more debugging visibility. Corresponds to the JSON property subnetLength

Returns:

  • (Fixnum)


28916
28917
28918
# File 'lib/google/apis/compute_v1/classes.rb', line 28916

def subnet_length
  @subnet_length
end

#typeString

The type of interconnect attachment this is, which can take one of the following values:

  • DEDICATED: an attachment to a Dedicated Interconnect.
  • PARTNER: an attachment to a Partner Interconnect, created by the customer.
  • PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the partner.
  • L2_DEDICATED: a L2 attachment to a Dedicated Interconnect. Corresponds to the JSON property type

Returns:

  • (String)


28929
28930
28931
# File 'lib/google/apis/compute_v1/classes.rb', line 28929

def type
  @type
end

#vlan_tag8021qFixnum

The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4093. Only specified at creation time. Corresponds to the JSON property vlanTag8021q

Returns:

  • (Fixnum)


28935
28936
28937
# File 'lib/google/apis/compute_v1/classes.rb', line 28935

def vlan_tag8021q
  @vlan_tag8021q
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
28956
28957
28958
28959
28960
28961
28962
28963
28964
28965
28966
28967
28968
28969
28970
28971
28972
28973
28974
28975
28976
28977
28978
28979
28980
28981
28982
28983
28984
28985
28986
28987
28988
28989
28990
# File 'lib/google/apis/compute_v1/classes.rb', line 28942

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @attachment_group = args[:attachment_group] if args.key?(:attachment_group)
  @bandwidth = args[:bandwidth] if args.key?(:bandwidth)
  @candidate_cloud_router_ip_address = args[:candidate_cloud_router_ip_address] if args.key?(:candidate_cloud_router_ip_address)
  @candidate_cloud_router_ipv6_address = args[:candidate_cloud_router_ipv6_address] if args.key?(:candidate_cloud_router_ipv6_address)
  @candidate_customer_router_ip_address = args[:candidate_customer_router_ip_address] if args.key?(:candidate_customer_router_ip_address)
  @candidate_customer_router_ipv6_address = args[:candidate_customer_router_ipv6_address] if args.key?(:candidate_customer_router_ipv6_address)
  @candidate_ipv6_subnets = args[:candidate_ipv6_subnets] if args.key?(:candidate_ipv6_subnets)
  @candidate_subnets = args[:candidate_subnets] if args.key?(:candidate_subnets)
  @cloud_router_ip_address = args[:cloud_router_ip_address] if args.key?(:cloud_router_ip_address)
  @cloud_router_ipv6_address = args[:cloud_router_ipv6_address] if args.key?(:cloud_router_ipv6_address)
  @cloud_router_ipv6_interface_id = args[:cloud_router_ipv6_interface_id] if args.key?(:cloud_router_ipv6_interface_id)
  @configuration_constraints = args[:configuration_constraints] if args.key?(:configuration_constraints)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @customer_router_ip_address = args[:customer_router_ip_address] if args.key?(:customer_router_ip_address)
  @customer_router_ipv6_address = args[:customer_router_ipv6_address] if args.key?(:customer_router_ipv6_address)
  @customer_router_ipv6_interface_id = args[:customer_router_ipv6_interface_id] if args.key?(:customer_router_ipv6_interface_id)
  @dataplane_version = args[:dataplane_version] if args.key?(:dataplane_version)
  @description = args[:description] if args.key?(:description)
  @edge_availability_domain = args[:edge_availability_domain] if args.key?(:edge_availability_domain)
  @encryption = args[:encryption] if args.key?(:encryption)
  @google_reference_id = args[:google_reference_id] if args.key?(:google_reference_id)
  @id = args[:id] if args.key?(:id)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @ipsec_internal_addresses = args[:ipsec_internal_addresses] if args.key?(:ipsec_internal_addresses)
  @kind = args[:kind] if args.key?(:kind)
  @l2_forwarding = args[:l2_forwarding] if args.key?(:l2_forwarding)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @mtu = args[:mtu] if args.key?(:mtu)
  @name = args[:name] if args.key?(:name)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @pairing_key = args[:pairing_key] if args.key?(:pairing_key)
  @params = args[:params] if args.key?(:params)
  @partner_asn = args[:partner_asn] if args.key?(:partner_asn)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @private_interconnect_info = args[:private_interconnect_info] if args.key?(:private_interconnect_info)
  @region = args[:region] if args.key?(:region)
  @remote_service = args[:remote_service] if args.key?(:remote_service)
  @router = args[:router] if args.key?(:router)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @state = args[:state] if args.key?(:state)
  @subnet_length = args[:subnet_length] if args.key?(:subnet_length)
  @type = args[:type] if args.key?(:type)
  @vlan_tag8021q = args[:vlan_tag8021q] if args.key?(:vlan_tag8021q)
end