Class: Google::Apis::ComputeV1::InterconnectAttachmentGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
An interconnect attachment group resource allows customers to create, analyze, and expand highly available deployments.
Instance Attribute Summary collapse
-
#attachments ⇒ Hash<String,Google::Apis::ComputeV1::InterconnectAttachmentGroupAttachment>
Attachments in the AttachmentGroup.
-
#configured ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
-
#id ⇒ Fixnum
Output only.
-
#intent ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup.
-
#interconnect_group ⇒ String
The URL of an InterconnectGroup that groups these Attachments' Interconnects.
-
#kind ⇒ String
Output only.
-
#logical_structure ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure
[Output Only] An analysis of the logical layout of Attachments in this group.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroup
constructor
A new instance of InterconnectAttachmentGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroup
Returns a new instance of InterconnectAttachmentGroup.
29279 29280 29281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Hash<String,Google::Apis::ComputeV1::InterconnectAttachmentGroupAttachment>
Attachments in the AttachmentGroup. Keys are arbitrary user-specified
strings. Users are encouraged, but not required, to use their preferred
format for resource links as keys.
Note that there are add-members and remove-members methods in gcloud.
The size of this map is limited by an "Attachments per group" quota.
Corresponds to the JSON property attachments
29201 29202 29203 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29201 def @attachments end |
#configured ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property configured
29208 29209 29210 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29208 def configured @configured end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
29214 29215 29216 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29214 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
29220 29221 29222 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29220 def description @description end |
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
If provided when patching a configuration in update mode, the provided
token must match the current token or the update is rejected. This provides
a reliable means of doing read-modify-write (optimistic locking) as
described byAIP 154.
Corresponds to the JSON property etag
29229 29230 29231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29229 def etag @etag end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
29236 29237 29238 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29236 def id @id end |
#intent ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup. This is the only required field
besides the name that must be specified on group creation.
Corresponds to the JSON property intent
29242 29243 29244 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29242 def intent @intent end |
#interconnect_group ⇒ String
The URL of an InterconnectGroup that groups these Attachments'
Interconnects. Customers do not need to set this unless directed by
Google Support.
Corresponds to the JSON property interconnectGroup
29249 29250 29251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29249 def interconnect_group @interconnect_group end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always
compute#interconnectAttachmentGroup.
Corresponds to the JSON property kind
29255 29256 29257 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29255 def kind @kind end |
#logical_structure ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure
[Output Only] An analysis of the logical layout of Attachments in this
group. Every Attachment in the group is shown once in this structure.
Corresponds to the JSON property logicalStructure
29261 29262 29263 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29261 def logical_structure @logical_structure end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
29272 29273 29274 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29272 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
29277 29278 29279 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29277 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29284 29285 29286 29287 29288 29289 29290 29291 29292 29293 29294 29295 29296 29297 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29284 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @configured = args[:configured] if args.key?(:configured) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @intent = args[:intent] if args.key?(:intent) @interconnect_group = args[:interconnect_group] if args.key?(:interconnect_group) @kind = args[:kind] if args.key?(:kind) @logical_structure = args[:logical_structure] if args.key?(:logical_structure) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) end |