Class: Google::Apis::ComputeV1::InterconnectAttachmentGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

An interconnect attachment group resource allows customers to create, analyze, and expand highly available deployments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroup

Returns a new instance of InterconnectAttachmentGroup.



25950
25951
25952
# File 'lib/google/apis/compute_v1/classes.rb', line 25950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsHash<String,Google::Apis::ComputeV1::InterconnectAttachmentGroupAttachment>

Attachments in the AttachmentGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an "Attachments per group" quota. Corresponds to the JSON property attachments



25872
25873
25874
# File 'lib/google/apis/compute_v1/classes.rb', line 25872

def attachments
  @attachments
end

#configuredGoogle::Apis::ComputeV1::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



25879
25880
25881
# File 'lib/google/apis/compute_v1/classes.rb', line 25879

def configured
  @configured
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


25885
25886
25887
# File 'lib/google/apis/compute_v1/classes.rb', line 25885

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


25891
25892
25893
# File 'lib/google/apis/compute_v1/classes.rb', line 25891

def description
  @description
end

#etagString

Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described byAIP 154. Corresponds to the JSON property etag

Returns:

  • (String)


25900
25901
25902
# File 'lib/google/apis/compute_v1/classes.rb', line 25900

def etag
  @etag
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25907
25908
25909
# File 'lib/google/apis/compute_v1/classes.rb', line 25907

def id
  @id
end

#intentGoogle::Apis::ComputeV1::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



25913
25914
25915
# File 'lib/google/apis/compute_v1/classes.rb', line 25913

def intent
  @intent
end

#interconnect_groupString

The URL of an InterconnectGroup that groups these Attachments' Interconnects. Customers do not need to set this unless directed by Google Support. Corresponds to the JSON property interconnectGroup

Returns:

  • (String)


25920
25921
25922
# File 'lib/google/apis/compute_v1/classes.rb', line 25920

def interconnect_group
  @interconnect_group
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#interconnectAttachmentGroup. Corresponds to the JSON property kind

Returns:

  • (String)


25926
25927
25928
# File 'lib/google/apis/compute_v1/classes.rb', line 25926

def kind
  @kind
end

#logical_structureGoogle::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure. Corresponds to the JSON property logicalStructure



25932
25933
25934
# File 'lib/google/apis/compute_v1/classes.rb', line 25932

def logical_structure
  @logical_structure
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


25943
25944
25945
# File 'lib/google/apis/compute_v1/classes.rb', line 25943

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25948
25949
25950
# File 'lib/google/apis/compute_v1/classes.rb', line 25948

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25955
25956
25957
25958
25959
25960
25961
25962
25963
25964
25965
25966
25967
25968
# File 'lib/google/apis/compute_v1/classes.rb', line 25955

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @configured = args[:configured] if args.key?(:configured)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @intent = args[:intent] if args.key?(:intent)
  @interconnect_group = args[:interconnect_group] if args.key?(:interconnect_group)
  @kind = args[:kind] if args.key?(:kind)
  @logical_structure = args[:logical_structure] if args.key?(:logical_structure)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
end