Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySla

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySla

Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySla.



29356
29357
29358
# File 'lib/google/apis/compute_v1/classes.rb', line 29356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_slaString

Corresponds to the JSON property effectiveSla

Returns:

  • (String)


29349
29350
29351
# File 'lib/google/apis/compute_v1/classes.rb', line 29349

def effective_sla
  @effective_sla
end

#intended_sla_blockersArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers>

Corresponds to the JSON property intendedSlaBlockers



29354
29355
29356
# File 'lib/google/apis/compute_v1/classes.rb', line 29354

def intended_sla_blockers
  @intended_sla_blockers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29361
29362
29363
29364
# File 'lib/google/apis/compute_v1/classes.rb', line 29361

def update!(**args)
  @effective_sla = args[:effective_sla] if args.key?(:effective_sla)
  @intended_sla_blockers = args[:intended_sla_blockers] if args.key?(:intended_sla_blockers)
end