Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySla
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySla
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements.
Instance Attribute Summary collapse
-
#effective_sla ⇒ String
Corresponds to the JSON property
effectiveSla. -
#intended_sla_blockers ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers>
Corresponds to the JSON property
intendedSlaBlockers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySla
constructor
A new instance of InterconnectAttachmentGroupConfiguredAvailabilitySla.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySla
Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySla.
25284 25285 25286 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_sla ⇒ String
Corresponds to the JSON property effectiveSla
25277 25278 25279 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25277 def effective_sla @effective_sla end |
#intended_sla_blockers ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers>
Corresponds to the JSON property intendedSlaBlockers
25282 25283 25284 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25282 def intended_sla_blockers @intended_sla_blockers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25289 25290 25291 25292 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25289 def update!(**args) @effective_sla = args[:effective_sla] if args.key?(:effective_sla) @intended_sla_blockers = args[:intended_sla_blockers] if args.key?(:intended_sla_blockers) end |