Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] Reasons why configuration.availabilitySLA.sla differs from intent.availabilitySLA. This list is empty if and only if those are the same.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<String>
Output only.
-
#blocker_type ⇒ String
Corresponds to the JSON property
blockerType. -
#documentation_link ⇒ String
Output only.
-
#explanation ⇒ String
Output only.
-
#metros ⇒ Array<String>
Output only.
-
#regions ⇒ Array<String>
Output only.
-
#zones ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
constructor
A new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers
Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.
29421 29422 29423 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Array<String>
Output only. [Output Only] URLs of any particular Attachments to explain this
blocker in more detail.
Corresponds to the JSON property attachments
29377 29378 29379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29377 def @attachments end |
#blocker_type ⇒ String
Corresponds to the JSON property blockerType
29382 29383 29384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29382 def blocker_type @blocker_type end |
#documentation_link ⇒ String
Output only. [Output Only] The url of Google Cloud public documentation
explaining
this requirement. This is set for every type of requirement.
Corresponds to the JSON property documentationLink
29389 29390 29391 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29389 def documentation_link @documentation_link end |
#explanation ⇒ String
Output only. [Output Only] A human-readable explanation of this requirement
and
why it's not met. This is set for every type of requirement.
Corresponds to the JSON property explanation
29396 29397 29398 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29396 def explanation @explanation end |
#metros ⇒ Array<String>
Output only. [Output Only] Metros used to explain this blocker in more detail.
These are three-letter lowercase strings like "iad". This will be set
for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does
not apply to others.
Corresponds to the JSON property metros
29404 29405 29406 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29404 def metros @metros end |
#regions ⇒ Array<String>
Output only. [Output Only] Regions used to explain this blocker in more
detail. These are region names formatted like "us-central1". This
will be set for some blockers (like INCOMPATIBLE_REGIONS) but does
not apply to others.
Corresponds to the JSON property regions
29412 29413 29414 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29412 def regions @regions end |
#zones ⇒ Array<String>
Output only. [Output Only] Zones used to explain this blocker in more detail.
Format is "zone1" and/or "zone2". This will be set for some blockers
(like MISSING_ZONE) but does not apply to others.
Corresponds to the JSON property zones
29419 29420 29421 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29419 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29426 29427 29428 29429 29430 29431 29432 29433 29434 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29426 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @blocker_type = args[:blocker_type] if args.key?(:blocker_type) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @explanation = args[:explanation] if args.key?(:explanation) @metros = args[:metros] if args.key?(:metros) @regions = args[:regions] if args.key?(:regions) @zones = args[:zones] if args.key?(:zones) end |