Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



29699
29700
29701
# File 'lib/google/apis/compute_v1/classes.rb', line 29699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



29697
29698
29699
# File 'lib/google/apis/compute_v1/classes.rb', line 29697

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29704
29705
29706
# File 'lib/google/apis/compute_v1/classes.rb', line 29704

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end