Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



29665
29666
29667
# File 'lib/google/apis/compute_v1/classes.rb', line 29665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



29663
29664
29665
# File 'lib/google/apis/compute_v1/classes.rb', line 29663

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29670
29671
29672
# File 'lib/google/apis/compute_v1/classes.rb', line 29670

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end