Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



29467
29468
29469
# File 'lib/google/apis/compute_v1/classes.rb', line 29467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



29465
29466
29467
# File 'lib/google/apis/compute_v1/classes.rb', line 29465

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29472
29473
29474
# File 'lib/google/apis/compute_v1/classes.rb', line 29472

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end