Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



28963
28964
28965
# File 'lib/google/apis/compute_v1/classes.rb', line 28963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



28961
28962
28963
# File 'lib/google/apis/compute_v1/classes.rb', line 28961

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28968
28969
28970
# File 'lib/google/apis/compute_v1/classes.rb', line 28968

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end