Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



26138
26139
26140
# File 'lib/google/apis/compute_v1/classes.rb', line 26138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



26136
26137
26138
# File 'lib/google/apis/compute_v1/classes.rb', line 26136

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26143
26144
26145
# File 'lib/google/apis/compute_v1/classes.rb', line 26143

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end