Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructure
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.
Instance Attribute Summary collapse
-
#regions ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegion>
Corresponds to the JSON property
regions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure
constructor
A new instance of InterconnectAttachmentGroupLogicalStructure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure
Returns a new instance of InterconnectAttachmentGroupLogicalStructure.
25395 25396 25397 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#regions ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegion>
Corresponds to the JSON property regions
25393 25394 25395 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25393 def regions @regions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25400 25401 25402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25400 def update!(**args) @regions = args[:regions] if args.key?(:regions) end |