Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetro
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetro
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] The metros of Attachments in this group in this region.
Instance Attribute Summary collapse
-
#facilities ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>
Corresponds to the JSON property
facilities. -
#metro ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro
constructor
A new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro
Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.
29518 29519 29520 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#facilities ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>
Corresponds to the JSON property facilities
29509 29510 29511 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29509 def facilities @facilities end |
#metro ⇒ String
Output only. [Output Only] The name of the metro, as a three-letter lowercase
string like "iad". This is the first component of the location of an
Interconnect.
Corresponds to the JSON property metro
29516 29517 29518 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29516 def metro @metro end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29523 29524 29525 29526 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29523 def update!(**args) @facilities = args[:facilities] if args.key?(:facilities) @metro = args[:metro] if args.key?(:metro) end |