Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetro
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetro
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] The metros of Attachments in this group in this region.
Instance Attribute Summary collapse
-
#facilities ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>
Corresponds to the JSON property
facilities. -
#metro ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro
constructor
A new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro
Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.
25446 25447 25448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#facilities ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>
Corresponds to the JSON property facilities
25437 25438 25439 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25437 def facilities @facilities end |
#metro ⇒ String
Output only. [Output Only] The name of the metro, as a three-letter lowercase
string like "iad". This is the first component of the location of an
Interconnect.
Corresponds to the JSON property metro
25444 25445 25446 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25444 def metro @metro end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25451 25452 25453 25454 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25451 def update!(**args) @facilities = args[:facilities] if args.key?(:facilities) @metro = args[:metro] if args.key?(:metro) end |