Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<String>
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
constructor
A new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
30165 30166 30167 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Array<String>
Output only. [Output Only] URLs of Attachments in the given zone, to the given
region, on Interconnects in the given facility and metro. Every
Attachment in the AG has such an entry.
Corresponds to the JSON property attachments
30158 30159 30160 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30158 def @attachments end |
#zone ⇒ String
Output only. [Output Only] The name of a zone, either "zone1" or "zone2".
Corresponds to the JSON property zone
30163 30164 30165 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30163 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30170 30171 30172 30173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30170 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @zone = args[:zone] if args.key?(:zone) end |