Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<String>
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
constructor
A new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
29771 29772 29773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29771 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Array<String>
Output only. [Output Only] URLs of Attachments in the given zone, to the given
region, on Interconnects in the given facility and metro. Every
Attachment in the AG has such an entry.
Corresponds to the JSON property attachments
29764 29765 29766 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29764 def @attachments end |
#zone ⇒ String
Output only. [Output Only] The name of a zone, either "zone1" or "zone2".
Corresponds to the JSON property zone
29769 29770 29771 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29769 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29776 29777 29778 29779 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29776 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @zone = args[:zone] if args.key?(:zone) end |