Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone

Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.



26244
26245
26246
# File 'lib/google/apis/compute_v1/classes.rb', line 26244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<String>

Output only. [Output Only] URLs of Attachments in the given zone, to the given region, on Interconnects in the given facility and metro. Every Attachment in the AG has such an entry. Corresponds to the JSON property attachments

Returns:

  • (Array<String>)


26237
26238
26239
# File 'lib/google/apis/compute_v1/classes.rb', line 26237

def attachments
  @attachments
end

#zoneString

Output only. [Output Only] The name of a zone, either "zone1" or "zone2". Corresponds to the JSON property zone

Returns:

  • (String)


26242
26243
26244
# File 'lib/google/apis/compute_v1/classes.rb', line 26242

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26249
26250
26251
26252
# File 'lib/google/apis/compute_v1/classes.rb', line 26249

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @zone = args[:zone] if args.key?(:zone)
end