Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



30252
30253
30254
# File 'lib/google/apis/compute_v1/classes.rb', line 30252

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


30208
30209
30210
# File 'lib/google/apis/compute_v1/classes.rb', line 30208

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30213
30214
30215
# File 'lib/google/apis/compute_v1/classes.rb', line 30213

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



30218
30219
30220
# File 'lib/google/apis/compute_v1/classes.rb', line 30218

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


30223
30224
30225
# File 'lib/google/apis/compute_v1/classes.rb', line 30223

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30233
30234
30235
# File 'lib/google/apis/compute_v1/classes.rb', line 30233

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30238
30239
30240
# File 'lib/google/apis/compute_v1/classes.rb', line 30238

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


30245
30246
30247
# File 'lib/google/apis/compute_v1/classes.rb', line 30245

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30250
30251
30252
# File 'lib/google/apis/compute_v1/classes.rb', line 30250

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30257
30258
30259
30260
30261
30262
30263
30264
30265
30266
# File 'lib/google/apis/compute_v1/classes.rb', line 30257

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end