Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



29900
29901
29902
# File 'lib/google/apis/compute_v1/classes.rb', line 29900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


29856
29857
29858
# File 'lib/google/apis/compute_v1/classes.rb', line 29856

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29861
29862
29863
# File 'lib/google/apis/compute_v1/classes.rb', line 29861

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



29866
29867
29868
# File 'lib/google/apis/compute_v1/classes.rb', line 29866

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


29871
29872
29873
# File 'lib/google/apis/compute_v1/classes.rb', line 29871

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29881
29882
29883
# File 'lib/google/apis/compute_v1/classes.rb', line 29881

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29886
29887
29888
# File 'lib/google/apis/compute_v1/classes.rb', line 29886

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


29893
29894
29895
# File 'lib/google/apis/compute_v1/classes.rb', line 29893

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



29898
29899
29900
# File 'lib/google/apis/compute_v1/classes.rb', line 29898

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29905
29906
29907
29908
29909
29910
29911
29912
29913
29914
# File 'lib/google/apis/compute_v1/classes.rb', line 29905

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end