Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



29892
29893
29894
# File 'lib/google/apis/compute_v1/classes.rb', line 29892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


29848
29849
29850
# File 'lib/google/apis/compute_v1/classes.rb', line 29848

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29853
29854
29855
# File 'lib/google/apis/compute_v1/classes.rb', line 29853

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



29858
29859
29860
# File 'lib/google/apis/compute_v1/classes.rb', line 29858

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


29863
29864
29865
# File 'lib/google/apis/compute_v1/classes.rb', line 29863

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29873
29874
29875
# File 'lib/google/apis/compute_v1/classes.rb', line 29873

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29878
29879
29880
# File 'lib/google/apis/compute_v1/classes.rb', line 29878

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


29885
29886
29887
# File 'lib/google/apis/compute_v1/classes.rb', line 29885

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



29890
29891
29892
# File 'lib/google/apis/compute_v1/classes.rb', line 29890

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29897
29898
29899
29900
29901
29902
29903
29904
29905
29906
# File 'lib/google/apis/compute_v1/classes.rb', line 29897

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end