Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



29858
29859
29860
# File 'lib/google/apis/compute_v1/classes.rb', line 29858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


29814
29815
29816
# File 'lib/google/apis/compute_v1/classes.rb', line 29814

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29819
29820
29821
# File 'lib/google/apis/compute_v1/classes.rb', line 29819

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



29824
29825
29826
# File 'lib/google/apis/compute_v1/classes.rb', line 29824

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


29829
29830
29831
# File 'lib/google/apis/compute_v1/classes.rb', line 29829

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29839
29840
29841
# File 'lib/google/apis/compute_v1/classes.rb', line 29839

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29844
29845
29846
# File 'lib/google/apis/compute_v1/classes.rb', line 29844

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


29851
29852
29853
# File 'lib/google/apis/compute_v1/classes.rb', line 29851

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



29856
29857
29858
# File 'lib/google/apis/compute_v1/classes.rb', line 29856

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29863
29864
29865
29866
29867
29868
29869
29870
29871
29872
# File 'lib/google/apis/compute_v1/classes.rb', line 29863

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end