Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



29668
29669
29670
# File 'lib/google/apis/compute_v1/classes.rb', line 29668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


29624
29625
29626
# File 'lib/google/apis/compute_v1/classes.rb', line 29624

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29629
29630
29631
# File 'lib/google/apis/compute_v1/classes.rb', line 29629

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



29634
29635
29636
# File 'lib/google/apis/compute_v1/classes.rb', line 29634

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


29639
29640
29641
# File 'lib/google/apis/compute_v1/classes.rb', line 29639

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29649
29650
29651
# File 'lib/google/apis/compute_v1/classes.rb', line 29649

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29654
29655
29656
# File 'lib/google/apis/compute_v1/classes.rb', line 29654

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


29661
29662
29663
# File 'lib/google/apis/compute_v1/classes.rb', line 29661

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



29666
29667
29668
# File 'lib/google/apis/compute_v1/classes.rb', line 29666

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29673
29674
29675
29676
29677
29678
29679
29680
29681
29682
# File 'lib/google/apis/compute_v1/classes.rb', line 29673

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end