Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



29156
29157
29158
# File 'lib/google/apis/compute_v1/classes.rb', line 29156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


29112
29113
29114
# File 'lib/google/apis/compute_v1/classes.rb', line 29112

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29117
29118
29119
# File 'lib/google/apis/compute_v1/classes.rb', line 29117

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



29122
29123
29124
# File 'lib/google/apis/compute_v1/classes.rb', line 29122

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


29127
29128
29129
# File 'lib/google/apis/compute_v1/classes.rb', line 29127

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29137
29138
29139
# File 'lib/google/apis/compute_v1/classes.rb', line 29137

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29142
29143
29144
# File 'lib/google/apis/compute_v1/classes.rb', line 29142

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


29149
29150
29151
# File 'lib/google/apis/compute_v1/classes.rb', line 29149

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



29154
29155
29156
# File 'lib/google/apis/compute_v1/classes.rb', line 29154

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29161
29162
29163
29164
29165
29166
29167
29168
29169
29170
# File 'lib/google/apis/compute_v1/classes.rb', line 29161

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end