Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



26331
26332
26333
# File 'lib/google/apis/compute_v1/classes.rb', line 26331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


26287
26288
26289
# File 'lib/google/apis/compute_v1/classes.rb', line 26287

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26292
26293
26294
# File 'lib/google/apis/compute_v1/classes.rb', line 26292

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



26297
26298
26299
# File 'lib/google/apis/compute_v1/classes.rb', line 26297

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


26302
26303
26304
# File 'lib/google/apis/compute_v1/classes.rb', line 26302

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26312
26313
26314
# File 'lib/google/apis/compute_v1/classes.rb', line 26312

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26317
26318
26319
# File 'lib/google/apis/compute_v1/classes.rb', line 26317

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


26324
26325
26326
# File 'lib/google/apis/compute_v1/classes.rb', line 26324

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



26329
26330
26331
# File 'lib/google/apis/compute_v1/classes.rb', line 26329

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26336
26337
26338
26339
26340
26341
26342
26343
26344
26345
# File 'lib/google/apis/compute_v1/classes.rb', line 26336

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end