Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



25588
25589
25590
# File 'lib/google/apis/compute_v1/classes.rb', line 25588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


25544
25545
25546
# File 'lib/google/apis/compute_v1/classes.rb', line 25544

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25549
25550
25551
# File 'lib/google/apis/compute_v1/classes.rb', line 25549

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



25554
25555
25556
# File 'lib/google/apis/compute_v1/classes.rb', line 25554

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


25559
25560
25561
# File 'lib/google/apis/compute_v1/classes.rb', line 25559

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25569
25570
25571
# File 'lib/google/apis/compute_v1/classes.rb', line 25569

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25574
25575
25576
# File 'lib/google/apis/compute_v1/classes.rb', line 25574

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


25581
25582
25583
# File 'lib/google/apis/compute_v1/classes.rb', line 25581

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25586
25587
25588
# File 'lib/google/apis/compute_v1/classes.rb', line 25586

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25593
25594
25595
25596
25597
25598
25599
25600
25601
25602
# File 'lib/google/apis/compute_v1/classes.rb', line 25593

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end