Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#attachment_statuses ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
Corresponds to the JSON property
attachmentStatuses. -
#configured ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
-
#group_status ⇒ String
Output only.
-
#intent ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup.
-
#operational ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus
constructor
A new instance of InterconnectAttachmentGroupsOperationalStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus
Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.
30373 30374 30375 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_statuses ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
Corresponds to the JSON property attachmentStatuses
30346 30347 30348 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30346 def @attachment_statuses end |
#configured ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property configured
30353 30354 30355 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30353 def configured @configured end |
#group_status ⇒ String
Output only. Summarizes the status of the group.
Corresponds to the JSON property groupStatus
30358 30359 30360 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30358 def group_status @group_status end |
#intent ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup. This is the only required field
besides the name that must be specified on group creation.
Corresponds to the JSON property intent
30364 30365 30366 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30364 def intent @intent end |
#operational ⇒ Google::Apis::ComputeV1::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property operational
30371 30372 30373 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30371 def operational @operational end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30378 30379 30380 30381 30382 30383 30384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30378 def update!(**args) @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses) @configured = args[:configured] if args.key?(:configured) @group_status = args[:group_status] if args.key?(:group_status) @intent = args[:intent] if args.key?(:intent) @operational = args[:operational] if args.key?(:operational) end |