Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



29781
29782
29783
# File 'lib/google/apis/compute_v1/classes.rb', line 29781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



29754
29755
29756
# File 'lib/google/apis/compute_v1/classes.rb', line 29754

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeV1::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



29761
29762
29763
# File 'lib/google/apis/compute_v1/classes.rb', line 29761

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


29766
29767
29768
# File 'lib/google/apis/compute_v1/classes.rb', line 29766

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeV1::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



29772
29773
29774
# File 'lib/google/apis/compute_v1/classes.rb', line 29772

def intent
  @intent
end

#operationalGoogle::Apis::ComputeV1::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



29779
29780
29781
# File 'lib/google/apis/compute_v1/classes.rb', line 29779

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29786
29787
29788
29789
29790
29791
29792
# File 'lib/google/apis/compute_v1/classes.rb', line 29786

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end