Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



29277
29278
29279
# File 'lib/google/apis/compute_v1/classes.rb', line 29277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



29250
29251
29252
# File 'lib/google/apis/compute_v1/classes.rb', line 29250

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeV1::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



29257
29258
29259
# File 'lib/google/apis/compute_v1/classes.rb', line 29257

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


29262
29263
29264
# File 'lib/google/apis/compute_v1/classes.rb', line 29262

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeV1::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



29268
29269
29270
# File 'lib/google/apis/compute_v1/classes.rb', line 29268

def intent
  @intent
end

#operationalGoogle::Apis::ComputeV1::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



29275
29276
29277
# File 'lib/google/apis/compute_v1/classes.rb', line 29275

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29282
29283
29284
29285
29286
29287
29288
# File 'lib/google/apis/compute_v1/classes.rb', line 29282

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end