Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



25709
25710
25711
# File 'lib/google/apis/compute_v1/classes.rb', line 25709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



25682
25683
25684
# File 'lib/google/apis/compute_v1/classes.rb', line 25682

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeV1::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



25689
25690
25691
# File 'lib/google/apis/compute_v1/classes.rb', line 25689

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


25694
25695
25696
# File 'lib/google/apis/compute_v1/classes.rb', line 25694

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeV1::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



25700
25701
25702
# File 'lib/google/apis/compute_v1/classes.rb', line 25700

def intent
  @intent
end

#operationalGoogle::Apis::ComputeV1::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



25707
25708
25709
# File 'lib/google/apis/compute_v1/classes.rb', line 25707

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25714
25715
25716
25717
25718
25719
25720
# File 'lib/google/apis/compute_v1/classes.rb', line 25714

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end