Class: Google::Apis::ComputeV1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The status of one Attachment in the group. List order is arbitrary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatusAttachmentStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatusAttachmentStatus.



25754
25755
25756
# File 'lib/google/apis/compute_v1/classes.rb', line 25754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Output only. Whether this Attachment is enabled. This becomes false when the customer drains their Attachment. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


25732
25733
25734
# File 'lib/google/apis/compute_v1/classes.rb', line 25732

def admin_enabled
  @admin_enabled
end

#attachmentString

Output only. The URL of the Attachment being described. Corresponds to the JSON property attachment

Returns:

  • (String)


25738
25739
25740
# File 'lib/google/apis/compute_v1/classes.rb', line 25738

def attachment
  @attachment
end

#is_activeString

Output only. Whether this Attachment is participating in the redundant configuration. This will be ACTIVE if and only if the status below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis that generates operational.availabilitySLA. Corresponds to the JSON property isActive

Returns:

  • (String)


25747
25748
25749
# File 'lib/google/apis/compute_v1/classes.rb', line 25747

def is_active
  @is_active
end

#statusString

Output only. Whether this Attachment is active, and if so, whether BGP is up. Corresponds to the JSON property status

Returns:

  • (String)


25752
25753
25754
# File 'lib/google/apis/compute_v1/classes.rb', line 25752

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25759
25760
25761
25762
25763
25764
# File 'lib/google/apis/compute_v1/classes.rb', line 25759

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @attachment = args[:attachment] if args.key?(:attachment)
  @is_active = args[:is_active] if args.key?(:is_active)
  @status = args[:status] if args.key?(:status)
end