Class: Google::Apis::ComputeV1::InterconnectAttachmentL2Forwarding
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentL2Forwarding
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
L2 Interconnect Attachment related configuration.
Instance Attribute Summary collapse
-
#appliance_mappings ⇒ Hash<String,Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingApplianceMapping>
Optional.
-
#default_appliance_ip_address ⇒ String
Optional.
-
#geneve_header ⇒ Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingGeneveHeader
GeneveHeader related configurations.
-
#network ⇒ String
Required.
-
#tunnel_endpoint_ip_address ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentL2Forwarding
constructor
A new instance of InterconnectAttachmentL2Forwarding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentL2Forwarding
Returns a new instance of InterconnectAttachmentL2Forwarding.
30079 30080 30081 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30079 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appliance_mappings ⇒ Hash<String,Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingApplianceMapping>
Optional. A map of VLAN tags to appliances and optional inner mapping
rules. If VLANs are not explicitly mapped to any appliance, the
defaultApplianceIpAddress is used.
Each VLAN tag can be a single number or a range of numbers in the range
of 1 to 4094, e.g., "1" or "4001-4094". Non-empty and non-overlapping
VLAN tag ranges are enforced, and violating operations will be rejected.
The VLAN tags in the Ethernet header must use an ethertype value of
0x88A8 or 0x8100.
Corresponds to the JSON property applianceMappings
30051 30052 30053 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30051 def appliance_mappings @appliance_mappings end |
#default_appliance_ip_address ⇒ String
Optional. A single IPv4 or IPv6 address used as the default destination
IP when there is no VLAN mapping result found.
Unset field (null-value) indicates the unmatched packet should be
dropped.
Corresponds to the JSON property defaultApplianceIpAddress
30059 30060 30061 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30059 def default_appliance_ip_address @default_appliance_ip_address end |
#geneve_header ⇒ Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingGeneveHeader
GeneveHeader related configurations.
Corresponds to the JSON property geneveHeader
30064 30065 30066 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30064 def geneve_header @geneve_header end |
#network ⇒ String
Required. Resource URL of the network to which this attachment belongs.
Corresponds to the JSON property network
30069 30070 30071 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30069 def network @network end |
#tunnel_endpoint_ip_address ⇒ String
Required. A single IPv4 or IPv6 address. This address will be used as the
source IP address for packets sent to the appliances, and must be used as
the destination IP address for packets that should be sent out through
this attachment.
Corresponds to the JSON property tunnelEndpointIpAddress
30077 30078 30079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30077 def tunnel_endpoint_ip_address @tunnel_endpoint_ip_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30084 30085 30086 30087 30088 30089 30090 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30084 def update!(**args) @appliance_mappings = args[:appliance_mappings] if args.key?(:appliance_mappings) @default_appliance_ip_address = args[:default_appliance_ip_address] if args.key?(:default_appliance_ip_address) @geneve_header = args[:geneve_header] if args.key?(:geneve_header) @network = args[:network] if args.key?(:network) @tunnel_endpoint_ip_address = args[:tunnel_endpoint_ip_address] if args.key?(:tunnel_endpoint_ip_address) end |