Class: Google::Apis::ComputeV1::InterconnectAttachmentL2Forwarding

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

L2 Interconnect Attachment related configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentL2Forwarding

Returns a new instance of InterconnectAttachmentL2Forwarding.



29377
29378
29379
# File 'lib/google/apis/compute_v1/classes.rb', line 29377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_mappingsHash<String,Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingApplianceMapping>

Optional. A map of VLAN tags to appliances and optional inner mapping rules. If VLANs are not explicitly mapped to any appliance, the defaultApplianceIpAddress is used. Each VLAN tag can be a single number or a range of numbers in the range of 1 to 4094, e.g., "1" or "4001-4094". Non-empty and non-overlapping VLAN tag ranges are enforced, and violating operations will be rejected. The VLAN tags in the Ethernet header must use an ethertype value of 0x88A8 or 0x8100. Corresponds to the JSON property applianceMappings



29349
29350
29351
# File 'lib/google/apis/compute_v1/classes.rb', line 29349

def appliance_mappings
  @appliance_mappings
end

#default_appliance_ip_addressString

Optional. A single IPv4 or IPv6 address used as the default destination IP when there is no VLAN mapping result found. Unset field (null-value) indicates the unmatched packet should be dropped. Corresponds to the JSON property defaultApplianceIpAddress

Returns:

  • (String)


29357
29358
29359
# File 'lib/google/apis/compute_v1/classes.rb', line 29357

def default_appliance_ip_address
  @default_appliance_ip_address
end

#geneve_headerGoogle::Apis::ComputeV1::InterconnectAttachmentL2ForwardingGeneveHeader

GeneveHeader related configurations. Corresponds to the JSON property geneveHeader



29362
29363
29364
# File 'lib/google/apis/compute_v1/classes.rb', line 29362

def geneve_header
  @geneve_header
end

#networkString

Required. Resource URL of the network to which this attachment belongs. Corresponds to the JSON property network

Returns:

  • (String)


29367
29368
29369
# File 'lib/google/apis/compute_v1/classes.rb', line 29367

def network
  @network
end

#tunnel_endpoint_ip_addressString

Required. A single IPv4 or IPv6 address. This address will be used as the source IP address for packets sent to the appliances, and must be used as the destination IP address for packets that should be sent out through this attachment. Corresponds to the JSON property tunnelEndpointIpAddress

Returns:

  • (String)


29375
29376
29377
# File 'lib/google/apis/compute_v1/classes.rb', line 29375

def tunnel_endpoint_ip_address
  @tunnel_endpoint_ip_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29382
29383
29384
29385
29386
29387
29388
# File 'lib/google/apis/compute_v1/classes.rb', line 29382

def update!(**args)
  @appliance_mappings = args[:appliance_mappings] if args.key?(:appliance_mappings)
  @default_appliance_ip_address = args[:default_appliance_ip_address] if args.key?(:default_appliance_ip_address)
  @geneve_header = args[:geneve_header] if args.key?(:geneve_header)
  @network = args[:network] if args.key?(:network)
  @tunnel_endpoint_ip_address = args[:tunnel_endpoint_ip_address] if args.key?(:tunnel_endpoint_ip_address)
end