Class: Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingApplianceMapping

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Two-level VLAN-to-Appliance mapping rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentL2ForwardingApplianceMapping

Returns a new instance of InterconnectAttachmentL2ForwardingApplianceMapping.



30119
30120
30121
# File 'lib/google/apis/compute_v1/classes.rb', line 30119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_ip_addressString

Optional. A single IPv4 or IPv6 address used as the destination IP address for ingress packets that match on a VLAN tag, but do not match a more specific inner VLAN tag. Unset field (null-value) indicates both VLAN tags are required to be mapped. Otherwise, defaultApplianceIpAddress is used. Corresponds to the JSON property applianceIpAddress

Returns:

  • (String)


30103
30104
30105
# File 'lib/google/apis/compute_v1/classes.rb', line 30103

def appliance_ip_address
  @appliance_ip_address
end

#inner_vlan_to_appliance_mappingsArray<Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping>

Optional. Used to match against the inner VLAN when the packet contains two VLAN tags. A list of mapping rules from inner VLAN tags to IP addresses. If the inner VLAN is not explicitly mapped to an IP address range, the applianceIpAddress is used. Corresponds to the JSON property innerVlanToApplianceMappings



30112
30113
30114
# File 'lib/google/apis/compute_v1/classes.rb', line 30112

def inner_vlan_to_appliance_mappings
  @inner_vlan_to_appliance_mappings
end

#nameString

Optional. The name of this appliance mapping rule. Corresponds to the JSON property name

Returns:

  • (String)


30117
30118
30119
# File 'lib/google/apis/compute_v1/classes.rb', line 30117

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30124
30125
30126
30127
30128
# File 'lib/google/apis/compute_v1/classes.rb', line 30124

def update!(**args)
  @appliance_ip_address = args[:appliance_ip_address] if args.key?(:appliance_ip_address)
  @inner_vlan_to_appliance_mappings = args[:inner_vlan_to_appliance_mappings] if args.key?(:inner_vlan_to_appliance_mappings)
  @name = args[:name] if args.key?(:name)
end