Class: Google::Apis::ComputeV1::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The inner VLAN-to-Appliance mapping.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping

Returns a new instance of InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping.



26626
26627
26628
# File 'lib/google/apis/compute_v1/classes.rb', line 26626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inner_appliance_ip_addressString

Required in this object. A single IPv4 or IPv6 address used as the destination IP address for ingress packets that match on both VLAN tags. Corresponds to the JSON property innerApplianceIpAddress

Returns:

  • (String)


26614
26615
26616
# File 'lib/google/apis/compute_v1/classes.rb', line 26614

def inner_appliance_ip_address
  @inner_appliance_ip_address
end

#inner_vlan_tagsArray<String>

Required in this object. Used to match the inner VLAN tag on the packet. Each entry can be a single number or a range of numbers in the range of 1 to 4094, e.g., ["1", "4001-4094"] is valid. Non-empty and Non-overlapping VLAN tag ranges are enforced, and violating operations will be rejected. The inner VLAN tags must have an ethertype value of 0x8100. Corresponds to the JSON property innerVlanTags

Returns:

  • (Array<String>)


26624
26625
26626
# File 'lib/google/apis/compute_v1/classes.rb', line 26624

def inner_vlan_tags
  @inner_vlan_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26631
26632
26633
26634
# File 'lib/google/apis/compute_v1/classes.rb', line 26631

def update!(**args)
  @inner_appliance_ip_address = args[:inner_appliance_ip_address] if args.key?(:inner_appliance_ip_address)
  @inner_vlan_tags = args[:inner_vlan_tags] if args.key?(:inner_vlan_tags)
end