Class: Google::Apis::ComputeV1::InterconnectAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect attachments.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentList

Returns a new instance of InterconnectAttachmentList.



30620
30621
30622
# File 'lib/google/apis/compute_v1/classes.rb', line 30620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30586
30587
30588
# File 'lib/google/apis/compute_v1/classes.rb', line 30586

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachment>

A list of InterconnectAttachment resources. Corresponds to the JSON property items



30591
30592
30593
# File 'lib/google/apis/compute_v1/classes.rb', line 30591

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectAttachmentList for lists of interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


30598
30599
30600
# File 'lib/google/apis/compute_v1/classes.rb', line 30598

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30608
30609
30610
# File 'lib/google/apis/compute_v1/classes.rb', line 30608

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30613
30614
30615
# File 'lib/google/apis/compute_v1/classes.rb', line 30613

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30618
30619
30620
# File 'lib/google/apis/compute_v1/classes.rb', line 30618

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30625
30626
30627
30628
30629
30630
30631
30632
# File 'lib/google/apis/compute_v1/classes.rb', line 30625

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end