Class: Google::Apis::ComputeV1::InterconnectAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of interconnect attachments.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachment>
A list of InterconnectAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentList
constructor
A new instance of InterconnectAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentList
Returns a new instance of InterconnectAttachmentList.
30260 30261 30262 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30260 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
30226 30227 30228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30226 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachment>
A list of InterconnectAttachment resources.
Corresponds to the JSON property items
30231 30232 30233 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30231 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectAttachmentList for lists of interconnect
attachments.
Corresponds to the JSON property kind
30238 30239 30240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30238 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
30248 30249 30250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30248 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
30253 30254 30255 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30253 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
30258 30259 30260 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30258 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30265 30266 30267 30268 30269 30270 30271 30272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30265 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |