Class: Google::Apis::ComputeV1::InterconnectAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect attachments.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentList

Returns a new instance of InterconnectAttachmentList.



30225
30226
30227
# File 'lib/google/apis/compute_v1/classes.rb', line 30225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30191
30192
30193
# File 'lib/google/apis/compute_v1/classes.rb', line 30191

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachment>

A list of InterconnectAttachment resources. Corresponds to the JSON property items



30196
30197
30198
# File 'lib/google/apis/compute_v1/classes.rb', line 30196

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectAttachmentList for lists of interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


30203
30204
30205
# File 'lib/google/apis/compute_v1/classes.rb', line 30203

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30213
30214
30215
# File 'lib/google/apis/compute_v1/classes.rb', line 30213

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30218
30219
30220
# File 'lib/google/apis/compute_v1/classes.rb', line 30218

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30223
30224
30225
# File 'lib/google/apis/compute_v1/classes.rb', line 30223

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30230
30231
30232
30233
30234
30235
30236
30237
# File 'lib/google/apis/compute_v1/classes.rb', line 30230

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end