Class: Google::Apis::ComputeV1::InterconnectAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect attachments.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentList

Returns a new instance of InterconnectAttachmentList.



30028
30029
30030
# File 'lib/google/apis/compute_v1/classes.rb', line 30028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29994
29995
29996
# File 'lib/google/apis/compute_v1/classes.rb', line 29994

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachment>

A list of InterconnectAttachment resources. Corresponds to the JSON property items



29999
30000
30001
# File 'lib/google/apis/compute_v1/classes.rb', line 29999

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectAttachmentList for lists of interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


30006
30007
30008
# File 'lib/google/apis/compute_v1/classes.rb', line 30006

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30016
30017
30018
# File 'lib/google/apis/compute_v1/classes.rb', line 30016

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30021
30022
30023
# File 'lib/google/apis/compute_v1/classes.rb', line 30021

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30026
30027
30028
# File 'lib/google/apis/compute_v1/classes.rb', line 30026

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30033
30034
30035
30036
30037
30038
30039
30040
# File 'lib/google/apis/compute_v1/classes.rb', line 30033

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end