Class: Google::Apis::ComputeV1::InterconnectAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of interconnect attachments.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachment>
A list of InterconnectAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentList
constructor
A new instance of InterconnectAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentList
Returns a new instance of InterconnectAttachmentList.
25956 25957 25958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25922 25923 25924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25922 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectAttachment>
A list of InterconnectAttachment resources.
Corresponds to the JSON property items
25927 25928 25929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25927 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectAttachmentList for lists of interconnect
attachments.
Corresponds to the JSON property kind
25934 25935 25936 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25934 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25944 25945 25946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25944 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25949 25950 25951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25949 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
25954 25955 25956 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25954 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25961 25962 25963 25964 25965 25966 25967 25968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25961 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |