Class: Google::Apis::ComputeV1::InterconnectAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect attachments.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentList

Returns a new instance of InterconnectAttachmentList.



16451
16452
16453
# File 'lib/google/apis/compute_v1/classes.rb', line 16451

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16419
16420
16421
# File 'lib/google/apis/compute_v1/classes.rb', line 16419

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectAttachment>

A list of InterconnectAttachment resources. Corresponds to the JSON property items



16424
16425
16426
# File 'lib/google/apis/compute_v1/classes.rb', line 16424

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#interconnectAttachmentList for lists of interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


16430
16431
16432
# File 'lib/google/apis/compute_v1/classes.rb', line 16430

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16439
16440
16441
# File 'lib/google/apis/compute_v1/classes.rb', line 16439

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16444
16445
16446
# File 'lib/google/apis/compute_v1/classes.rb', line 16444

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16449
16450
16451
# File 'lib/google/apis/compute_v1/classes.rb', line 16449

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16456
16457
16458
16459
16460
16461
16462
16463
# File 'lib/google/apis/compute_v1/classes.rb', line 16456

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end