Class: Google::Apis::ComputeV1::InterconnectAttachmentPartnerMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentPartnerMetadata

Returns a new instance of InterconnectAttachmentPartnerMetadata.



26842
26843
26844
# File 'lib/google/apis/compute_v1/classes.rb', line 26842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interconnect_nameString

Plain text name of the Interconnect this attachment is connected to, as displayed in the Partner's portal. For instance "Chicago 1". This value may be validated to match approved Partner values. Corresponds to the JSON property interconnectName

Returns:

  • (String)


26827
26828
26829
# File 'lib/google/apis/compute_v1/classes.rb', line 26827

def interconnect_name
  @interconnect_name
end

#partner_nameString

Plain text name of the Partner providing this attachment. This value may be validated to match approved Partner values. Corresponds to the JSON property partnerName

Returns:

  • (String)


26833
26834
26835
# File 'lib/google/apis/compute_v1/classes.rb', line 26833

def partner_name
  @partner_name
end

#portal_urlString

URL of the Partner's portal for this Attachment. Partners may customise this to be a deep link to the specific resource on the Partner portal. This value may be validated to match approved Partner values. Corresponds to the JSON property portalUrl

Returns:

  • (String)


26840
26841
26842
# File 'lib/google/apis/compute_v1/classes.rb', line 26840

def portal_url
  @portal_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26847
26848
26849
26850
26851
# File 'lib/google/apis/compute_v1/classes.rb', line 26847

def update!(**args)
  @interconnect_name = args[:interconnect_name] if args.key?(:interconnect_name)
  @partner_name = args[:partner_name] if args.key?(:partner_name)
  @portal_url = args[:portal_url] if args.key?(:portal_url)
end