Class: Google::Apis::ComputeV1::InterconnectAttachmentsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentsScopedList

Returns a new instance of InterconnectAttachmentsScopedList.



30811
30812
30813
# File 'lib/google/apis/compute_v1/classes.rb', line 30811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interconnect_attachmentsArray<Google::Apis::ComputeV1::InterconnectAttachment>

A list of interconnect attachments contained in this scope. Corresponds to the JSON property interconnectAttachments



30803
30804
30805
# File 'lib/google/apis/compute_v1/classes.rb', line 30803

def interconnect_attachments
  @interconnect_attachments
end

#warningGoogle::Apis::ComputeV1::InterconnectAttachmentsScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



30809
30810
30811
# File 'lib/google/apis/compute_v1/classes.rb', line 30809

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30816
30817
30818
30819
# File 'lib/google/apis/compute_v1/classes.rb', line 30816

def update!(**args)
  @interconnect_attachments = args[:interconnect_attachments] if args.key?(:interconnect_attachments)
  @warning = args[:warning] if args.key?(:warning)
end