Class: Google::Apis::ComputeV1::InterconnectDiagnostics

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnostics

Returns a new instance of InterconnectDiagnostics.



30961
30962
30963
# File 'lib/google/apis/compute_v1/classes.rb', line 30961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeV1::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect. This will be empty when the Interconnect is not bundled. Corresponds to the JSON property arpCaches



30938
30939
30940
# File 'lib/google/apis/compute_v1/classes.rb', line 30938

def arp_caches
  @arp_caches
end

#bundle_aggregation_typeString

The aggregation type of the bundle interface. Corresponds to the JSON property bundleAggregationType

Returns:

  • (String)


30943
30944
30945
# File 'lib/google/apis/compute_v1/classes.rb', line 30943

def bundle_aggregation_type
  @bundle_aggregation_type
end

#bundle_operational_statusString

The operational status of the bundle interface. Corresponds to the JSON property bundleOperationalStatus

Returns:

  • (String)


30948
30949
30950
# File 'lib/google/apis/compute_v1/classes.rb', line 30948

def bundle_operational_status
  @bundle_operational_status
end

A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect. Corresponds to the JSON property links



30954
30955
30956
# File 'lib/google/apis/compute_v1/classes.rb', line 30954

def links
  @links
end

#mac_addressString

The MAC address of the Interconnect's bundle interface. Corresponds to the JSON property macAddress

Returns:

  • (String)


30959
30960
30961
# File 'lib/google/apis/compute_v1/classes.rb', line 30959

def mac_address
  @mac_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30966
30967
30968
30969
30970
30971
30972
# File 'lib/google/apis/compute_v1/classes.rb', line 30966

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @bundle_aggregation_type = args[:bundle_aggregation_type] if args.key?(:bundle_aggregation_type)
  @bundle_operational_status = args[:bundle_operational_status] if args.key?(:bundle_operational_status)
  @links = args[:links] if args.key?(:links)
  @mac_address = args[:mac_address] if args.key?(:mac_address)
end