Class: Google::Apis::ComputeV1::InterconnectDiagnostics
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectDiagnostics
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection.
Instance Attribute Summary collapse
-
#arp_caches ⇒ Array<Google::Apis::ComputeV1::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect.
-
#bundle_aggregation_type ⇒ String
The aggregation type of the bundle interface.
-
#bundle_operational_status ⇒ String
The operational status of the bundle interface.
-
#links ⇒ Array<Google::Apis::ComputeV1::InterconnectDiagnosticsLinkStatus>
A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect.
-
#mac_address ⇒ String
The MAC address of the Interconnect's bundle interface.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectDiagnostics
constructor
A new instance of InterconnectDiagnostics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectDiagnostics
Returns a new instance of InterconnectDiagnostics.
30369 30370 30371 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arp_caches ⇒ Array<Google::Apis::ComputeV1::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects,
describing individual neighbors currently seen by the Google router in
the ARP cache for the Interconnect.
This will be empty when the Interconnect is not bundled.
Corresponds to the JSON property arpCaches
30346 30347 30348 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30346 def arp_caches @arp_caches end |
#bundle_aggregation_type ⇒ String
The aggregation type of the bundle interface.
Corresponds to the JSON property bundleAggregationType
30351 30352 30353 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30351 def bundle_aggregation_type @bundle_aggregation_type end |
#bundle_operational_status ⇒ String
The operational status of the bundle interface.
Corresponds to the JSON property bundleOperationalStatus
30356 30357 30358 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30356 def bundle_operational_status @bundle_operational_status end |
#links ⇒ Array<Google::Apis::ComputeV1::InterconnectDiagnosticsLinkStatus>
A list of InterconnectDiagnostics.LinkStatus objects,
describing the status for each link on the Interconnect.
Corresponds to the JSON property links
30362 30363 30364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30362 def links @links end |
#mac_address ⇒ String
The MAC address of the Interconnect's bundle interface.
Corresponds to the JSON property macAddress
30367 30368 30369 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30367 def mac_address @mac_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30374 30375 30376 30377 30378 30379 30380 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30374 def update!(**args) @arp_caches = args[:arp_caches] if args.key?(:arp_caches) @bundle_aggregation_type = args[:bundle_aggregation_type] if args.key?(:bundle_aggregation_type) @bundle_operational_status = args[:bundle_operational_status] if args.key?(:bundle_operational_status) @links = args[:links] if args.key?(:links) @mac_address = args[:mac_address] if args.key?(:mac_address) end |