Class: Google::Apis::ComputeV1::InterconnectDiagnostics

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnostics

Returns a new instance of InterconnectDiagnostics.



26297
26298
26299
# File 'lib/google/apis/compute_v1/classes.rb', line 26297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeV1::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect. This will be empty when the Interconnect is not bundled. Corresponds to the JSON property arpCaches



26274
26275
26276
# File 'lib/google/apis/compute_v1/classes.rb', line 26274

def arp_caches
  @arp_caches
end

#bundle_aggregation_typeString

The aggregation type of the bundle interface. Corresponds to the JSON property bundleAggregationType

Returns:

  • (String)


26279
26280
26281
# File 'lib/google/apis/compute_v1/classes.rb', line 26279

def bundle_aggregation_type
  @bundle_aggregation_type
end

#bundle_operational_statusString

The operational status of the bundle interface. Corresponds to the JSON property bundleOperationalStatus

Returns:

  • (String)


26284
26285
26286
# File 'lib/google/apis/compute_v1/classes.rb', line 26284

def bundle_operational_status
  @bundle_operational_status
end

A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect. Corresponds to the JSON property links



26290
26291
26292
# File 'lib/google/apis/compute_v1/classes.rb', line 26290

def links
  @links
end

#mac_addressString

The MAC address of the Interconnect's bundle interface. Corresponds to the JSON property macAddress

Returns:

  • (String)


26295
26296
26297
# File 'lib/google/apis/compute_v1/classes.rb', line 26295

def mac_address
  @mac_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26302
26303
26304
26305
26306
26307
26308
# File 'lib/google/apis/compute_v1/classes.rb', line 26302

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @bundle_aggregation_type = args[:bundle_aggregation_type] if args.key?(:bundle_aggregation_type)
  @bundle_operational_status = args[:bundle_operational_status] if args.key?(:bundle_operational_status)
  @links = args[:links] if args.key?(:links)
  @mac_address = args[:mac_address] if args.key?(:mac_address)
end