Class: Google::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#google_system_id ⇒ String
System ID of the port on Google's side of the LACP exchange.
-
#neighbor_system_id ⇒ String
System ID of the port on the neighbor's side of the LACP exchange.
-
#state ⇒ String
The state of a LACP link, which can take one of the following values:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus
constructor
A new instance of InterconnectDiagnosticsLinkLacpStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus
Returns a new instance of InterconnectDiagnosticsLinkLacpStatus.
30439 30440 30441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_system_id ⇒ String
System ID of the port on Google's side of the LACP exchange.
Corresponds to the JSON property googleSystemId
30423 30424 30425 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30423 def google_system_id @google_system_id end |
#neighbor_system_id ⇒ String
System ID of the port on the neighbor's side of the LACP exchange.
Corresponds to the JSON property neighborSystemId
30428 30429 30430 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30428 def neighbor_system_id @neighbor_system_id end |
#state ⇒ String
The state of a LACP link, which can take one of the following values:
- ACTIVE: The link is configured and active within the bundle.
- DETACHED: The link is not configured within the bundle. This means
that the rest of the object should be empty.
Corresponds to the JSON property
state
30437 30438 30439 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30437 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30444 30445 30446 30447 30448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30444 def update!(**args) @google_system_id = args[:google_system_id] if args.key?(:google_system_id) @neighbor_system_id = args[:neighbor_system_id] if args.key?(:neighbor_system_id) @state = args[:state] if args.key?(:state) end |