Class: Google::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus

Returns a new instance of InterconnectDiagnosticsLinkLacpStatus.



30431
30432
30433
# File 'lib/google/apis/compute_v1/classes.rb', line 30431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_system_idString

System ID of the port on Google's side of the LACP exchange. Corresponds to the JSON property googleSystemId

Returns:

  • (String)


30415
30416
30417
# File 'lib/google/apis/compute_v1/classes.rb', line 30415

def google_system_id
  @google_system_id
end

#neighbor_system_idString

System ID of the port on the neighbor's side of the LACP exchange. Corresponds to the JSON property neighborSystemId

Returns:

  • (String)


30420
30421
30422
# File 'lib/google/apis/compute_v1/classes.rb', line 30420

def neighbor_system_id
  @neighbor_system_id
end

#stateString

The state of a LACP link, which can take one of the following values:

  • ACTIVE: The link is configured and active within the bundle.
  • DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty. Corresponds to the JSON property state

Returns:

  • (String)


30429
30430
30431
# File 'lib/google/apis/compute_v1/classes.rb', line 30429

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30436
30437
30438
30439
30440
# File 'lib/google/apis/compute_v1/classes.rb', line 30436

def update!(**args)
  @google_system_id = args[:google_system_id] if args.key?(:google_system_id)
  @neighbor_system_id = args[:neighbor_system_id] if args.key?(:neighbor_system_id)
  @state = args[:state] if args.key?(:state)
end