Class: Google::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#google_system_id ⇒ String
System ID of the port on Google's side of the LACP exchange.
-
#neighbor_system_id ⇒ String
System ID of the port on the neighbor's side of the LACP exchange.
-
#state ⇒ String
The state of a LACP link, which can take one of the following values:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus
constructor
A new instance of InterconnectDiagnosticsLinkLacpStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus
Returns a new instance of InterconnectDiagnosticsLinkLacpStatus.
26359 26360 26361 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_system_id ⇒ String
System ID of the port on Google's side of the LACP exchange.
Corresponds to the JSON property googleSystemId
26343 26344 26345 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26343 def google_system_id @google_system_id end |
#neighbor_system_id ⇒ String
System ID of the port on the neighbor's side of the LACP exchange.
Corresponds to the JSON property neighborSystemId
26348 26349 26350 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26348 def neighbor_system_id @neighbor_system_id end |
#state ⇒ String
The state of a LACP link, which can take one of the following values:
- ACTIVE: The link is configured and active within the bundle.
- DETACHED: The link is not configured within the bundle. This means
that the rest of the object should be empty.
Corresponds to the JSON property
state
26357 26358 26359 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26357 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26364 26365 26366 26367 26368 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26364 def update!(**args) @google_system_id = args[:google_system_id] if args.key?(:google_system_id) @neighbor_system_id = args[:neighbor_system_id] if args.key?(:neighbor_system_id) @state = args[:state] if args.key?(:state) end |