Class: Google::Apis::ComputeV1::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



31124
31125
31126
# File 'lib/google/apis/compute_v1/classes.rb', line 31124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeV1::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



31085
31086
31087
# File 'lib/google/apis/compute_v1/classes.rb', line 31085

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


31090
31091
31092
# File 'lib/google/apis/compute_v1/classes.rb', line 31090

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


31095
31096
31097
# File 'lib/google/apis/compute_v1/classes.rb', line 31095

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



31100
31101
31102
# File 'lib/google/apis/compute_v1/classes.rb', line 31100

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeV1::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



31105
31106
31107
# File 'lib/google/apis/compute_v1/classes.rb', line 31105

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


31110
31111
31112
# File 'lib/google/apis/compute_v1/classes.rb', line 31110

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



31116
31117
31118
# File 'lib/google/apis/compute_v1/classes.rb', line 31116

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



31122
31123
31124
# File 'lib/google/apis/compute_v1/classes.rb', line 31122

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31129
31130
31131
31132
31133
31134
31135
31136
31137
31138
# File 'lib/google/apis/compute_v1/classes.rb', line 31129

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end