Class: Google::Apis::ComputeV1::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



30764
30765
30766
# File 'lib/google/apis/compute_v1/classes.rb', line 30764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeV1::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



30725
30726
30727
# File 'lib/google/apis/compute_v1/classes.rb', line 30725

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


30730
30731
30732
# File 'lib/google/apis/compute_v1/classes.rb', line 30730

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


30735
30736
30737
# File 'lib/google/apis/compute_v1/classes.rb', line 30735

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



30740
30741
30742
# File 'lib/google/apis/compute_v1/classes.rb', line 30740

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeV1::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



30745
30746
30747
# File 'lib/google/apis/compute_v1/classes.rb', line 30745

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


30750
30751
30752
# File 'lib/google/apis/compute_v1/classes.rb', line 30750

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



30756
30757
30758
# File 'lib/google/apis/compute_v1/classes.rb', line 30756

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



30762
30763
30764
# File 'lib/google/apis/compute_v1/classes.rb', line 30762

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30769
30770
30771
30772
30773
30774
30775
30776
30777
30778
# File 'lib/google/apis/compute_v1/classes.rb', line 30769

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end