Class: Google::Apis::ComputeV1::InterconnectDiagnosticsLinkStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectDiagnosticsLinkStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#arp_caches ⇒ Array<Google::Apis::ComputeV1::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link.
-
#circuit_id ⇒ String
The unique ID for this link assigned during turn up by Google.
-
#google_demarc ⇒ String
The Demarc address assigned by Google and provided in the LoA.
-
#lacp_status ⇒ Google::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus
Corresponds to the JSON property
lacpStatus. -
#macsec ⇒ Google::Apis::ComputeV1::InterconnectDiagnosticsMacsecStatus
Describes the status of MACsec encryption on the link.
-
#operational_status ⇒ String
The operational status of the link.
-
#receiving_optical_power ⇒ Google::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.
-
#transmitting_optical_power ⇒ Google::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus
constructor
A new instance of InterconnectDiagnosticsLinkStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus
Returns a new instance of InterconnectDiagnosticsLinkStatus.
30028 30029 30030 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arp_caches ⇒ Array<Google::Apis::ComputeV1::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects,
describing the ARP neighbor entries seen on this link.
This will be empty if the link is bundled
Corresponds to the JSON property arpCaches
29989 29990 29991 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29989 def arp_caches @arp_caches end |
#circuit_id ⇒ String
The unique ID for this link assigned during turn up by Google.
Corresponds to the JSON property circuitId
29994 29995 29996 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29994 def circuit_id @circuit_id end |
#google_demarc ⇒ String
The Demarc address assigned by Google and provided in the LoA.
Corresponds to the JSON property googleDemarc
29999 30000 30001 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29999 def google_demarc @google_demarc end |
#lacp_status ⇒ Google::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus
Corresponds to the JSON property lacpStatus
30004 30005 30006 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30004 def lacp_status @lacp_status end |
#macsec ⇒ Google::Apis::ComputeV1::InterconnectDiagnosticsMacsecStatus
Describes the status of MACsec encryption on the link.
Corresponds to the JSON property macsec
30009 30010 30011 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30009 def macsec @macsec end |
#operational_status ⇒ String
The operational status of the link.
Corresponds to the JSON property operationalStatus
30014 30015 30016 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30014 def operational_status @operational_status end |
#receiving_optical_power ⇒ Google::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object,
describing the current value and status of the received light level.
Corresponds to the JSON property receivingOpticalPower
30020 30021 30022 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30020 def receiving_optical_power @receiving_optical_power end |
#transmitting_optical_power ⇒ Google::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object,
describing the current value and status of the transmitted light level.
Corresponds to the JSON property transmittingOpticalPower
30026 30027 30028 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30026 def transmitting_optical_power @transmitting_optical_power end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30033 def update!(**args) @arp_caches = args[:arp_caches] if args.key?(:arp_caches) @circuit_id = args[:circuit_id] if args.key?(:circuit_id) @google_demarc = args[:google_demarc] if args.key?(:google_demarc) @lacp_status = args[:lacp_status] if args.key?(:lacp_status) @macsec = args[:macsec] if args.key?(:macsec) @operational_status = args[:operational_status] if args.key?(:operational_status) @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power) @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power) end |