Class: Google::Apis::ComputeV1::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



27203
27204
27205
# File 'lib/google/apis/compute_v1/classes.rb', line 27203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeV1::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



27164
27165
27166
# File 'lib/google/apis/compute_v1/classes.rb', line 27164

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


27169
27170
27171
# File 'lib/google/apis/compute_v1/classes.rb', line 27169

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


27174
27175
27176
# File 'lib/google/apis/compute_v1/classes.rb', line 27174

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeV1::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



27179
27180
27181
# File 'lib/google/apis/compute_v1/classes.rb', line 27179

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeV1::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



27184
27185
27186
# File 'lib/google/apis/compute_v1/classes.rb', line 27184

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


27189
27190
27191
# File 'lib/google/apis/compute_v1/classes.rb', line 27189

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



27195
27196
27197
# File 'lib/google/apis/compute_v1/classes.rb', line 27195

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeV1::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



27201
27202
27203
# File 'lib/google/apis/compute_v1/classes.rb', line 27201

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27208
27209
27210
27211
27212
27213
27214
27215
27216
27217
# File 'lib/google/apis/compute_v1/classes.rb', line 27208

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end