Class: Google::Apis::ComputeV1::InterconnectGroupConfigured

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfigured

Returns a new instance of InterconnectGroupConfigured.



31286
31287
31288
# File 'lib/google/apis/compute_v1/classes.rb', line 31286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#topology_capabilityGoogle::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapability

[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability. Corresponds to the JSON property topologyCapability



31284
31285
31286
# File 'lib/google/apis/compute_v1/classes.rb', line 31284

def topology_capability
  @topology_capability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31291
31292
31293
# File 'lib/google/apis/compute_v1/classes.rb', line 31291

def update!(**args)
  @topology_capability = args[:topology_capability] if args.key?(:topology_capability)
end