Class: Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapability
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapability
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.
Instance Attribute Summary collapse
-
#intended_capability_blockers ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>
Corresponds to the JSON property
intendedCapabilityBlockers. -
#supported_sla ⇒ String
Corresponds to the JSON property
supportedSla.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapability
constructor
A new instance of InterconnectGroupConfiguredTopologyCapability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapability
Returns a new instance of InterconnectGroupConfiguredTopologyCapability.
30952 30953 30954 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30952 def initialize(**args) update!(**args) end |
Instance Attribute Details
#intended_capability_blockers ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>
Corresponds to the JSON property intendedCapabilityBlockers
30945 30946 30947 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30945 def intended_capability_blockers @intended_capability_blockers end |
#supported_sla ⇒ String
Corresponds to the JSON property supportedSla
30950 30951 30952 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30950 def supported_sla @supported_sla end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30957 30958 30959 30960 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30957 def update!(**args) @intended_capability_blockers = args[:intended_capability_blockers] if args.key?(:intended_capability_blockers) @supported_sla = args[:supported_sla] if args.key?(:supported_sla) end |