Class: Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapability
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapability
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.
Instance Attribute Summary collapse
-
#intended_capability_blockers ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>
Corresponds to the JSON property
intendedCapabilityBlockers. -
#supported_sla ⇒ String
Corresponds to the JSON property
supportedSla.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapability
constructor
A new instance of InterconnectGroupConfiguredTopologyCapability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapability
Returns a new instance of InterconnectGroupConfiguredTopologyCapability.
30216 30217 30218 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#intended_capability_blockers ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>
Corresponds to the JSON property intendedCapabilityBlockers
30209 30210 30211 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30209 def intended_capability_blockers @intended_capability_blockers end |
#supported_sla ⇒ String
Corresponds to the JSON property supportedSla
30214 30215 30216 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30214 def supported_sla @supported_sla end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30221 30222 30223 30224 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30221 def update!(**args) @intended_capability_blockers = args[:intended_capability_blockers] if args.key?(:intended_capability_blockers) @supported_sla = args[:supported_sla] if args.key?(:supported_sla) end |