Class: Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers

Returns a new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.



30982
30983
30984
# File 'lib/google/apis/compute_v1/classes.rb', line 30982

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocker_typeString

Corresponds to the JSON property blockerType

Returns:

  • (String)


30938
30939
30940
# File 'lib/google/apis/compute_v1/classes.rb', line 30938

def blocker_type
  @blocker_type
end

Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement. Corresponds to the JSON property documentationLink

Returns:

  • (String)


30945
30946
30947
# File 'lib/google/apis/compute_v1/classes.rb', line 30945

def documentation_link
  @documentation_link
end

#explanationString

Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement. Corresponds to the JSON property explanation

Returns:

  • (String)


30952
30953
30954
# File 'lib/google/apis/compute_v1/classes.rb', line 30952

def explanation
  @explanation
end

#facilitiesArray<String>

Output only. [Output Only] Facilities used to explain this blocker in more detail. Like physicalStructure.metros.facilities.facility, this is a numeric string like "5467". Corresponds to the JSON property facilities

Returns:

  • (Array<String>)


30960
30961
30962
# File 'lib/google/apis/compute_v1/classes.rb', line 30960

def facilities
  @facilities
end

#interconnectsArray<String>

Output only. [Output Only] Interconnects used to explain this blocker in more detail. Corresponds to the JSON property interconnects

Returns:

  • (Array<String>)


30966
30967
30968
# File 'lib/google/apis/compute_v1/classes.rb', line 30966

def interconnects
  @interconnects
end

#metrosArray<String>

Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field. Corresponds to the JSON property metros

Returns:

  • (Array<String>)


30974
30975
30976
# File 'lib/google/apis/compute_v1/classes.rb', line 30974

def metros
  @metros
end

#zonesArray<String>

Output only. [Output Only] Zones used to explain this blocker in more detail. Zone names are "zone1" and/or "zone2". Corresponds to the JSON property zones

Returns:

  • (Array<String>)


30980
30981
30982
# File 'lib/google/apis/compute_v1/classes.rb', line 30980

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30987
30988
30989
30990
30991
30992
30993
30994
30995
# File 'lib/google/apis/compute_v1/classes.rb', line 30987

def update!(**args)
  @blocker_type = args[:blocker_type] if args.key?(:blocker_type)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @explanation = args[:explanation] if args.key?(:explanation)
  @facilities = args[:facilities] if args.key?(:facilities)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @metros = args[:metros] if args.key?(:metros)
  @zones = args[:zones] if args.key?(:zones)
end