Class: Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.
Instance Attribute Summary collapse
-
#blocker_type ⇒ String
Corresponds to the JSON property
blockerType. -
#documentation_link ⇒ String
Output only.
-
#explanation ⇒ String
Output only.
-
#facilities ⇒ Array<String>
Output only.
-
#interconnects ⇒ Array<String>
Output only.
-
#metros ⇒ Array<String>
Output only.
-
#zones ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
constructor
A new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
Returns a new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.
27455 27456 27457 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocker_type ⇒ String
Corresponds to the JSON property blockerType
27411 27412 27413 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27411 def blocker_type @blocker_type end |
#documentation_link ⇒ String
Output only. [Output Only] The url of Google Cloud public documentation
explaining
this requirement. This is set for every type of requirement.
Corresponds to the JSON property documentationLink
27418 27419 27420 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27418 def documentation_link @documentation_link end |
#explanation ⇒ String
Output only. [Output Only] A human-readable explanation of this requirement
and
why it's not met. This is set for every type of requirement.
Corresponds to the JSON property explanation
27425 27426 27427 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27425 def explanation @explanation end |
#facilities ⇒ Array<String>
Output only. [Output Only] Facilities used to explain this blocker in more
detail.
Like physicalStructure.metros.facilities.facility, this is a numeric
string like "5467".
Corresponds to the JSON property facilities
27433 27434 27435 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27433 def facilities @facilities end |
#interconnects ⇒ Array<String>
Output only. [Output Only] Interconnects used to explain this blocker in more
detail.
Corresponds to the JSON property interconnects
27439 27440 27441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27439 def interconnects @interconnects end |
#metros ⇒ Array<String>
Output only. [Output Only] Metros used to explain this blocker in more detail.
These are three-letter lowercase strings like "iad". A blocker like
INCOMPATIBLE_METROS will specify the problematic metros in this
field.
Corresponds to the JSON property metros
27447 27448 27449 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27447 def metros @metros end |
#zones ⇒ Array<String>
Output only. [Output Only] Zones used to explain this blocker in more detail.
Zone names are "zone1" and/or "zone2".
Corresponds to the JSON property zones
27453 27454 27455 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27453 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27460 27461 27462 27463 27464 27465 27466 27467 27468 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27460 def update!(**args) @blocker_type = args[:blocker_type] if args.key?(:blocker_type) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @explanation = args[:explanation] if args.key?(:explanation) @facilities = args[:facilities] if args.key?(:facilities) @interconnects = args[:interconnects] if args.key?(:interconnects) @metros = args[:metros] if args.key?(:metros) @zones = args[:zones] if args.key?(:zones) end |