Class: Google::Apis::ComputeV1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers

Returns a new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.



26712
26713
26714
# File 'lib/google/apis/compute_v1/classes.rb', line 26712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocker_typeString

Corresponds to the JSON property blockerType

Returns:

  • (String)


26668
26669
26670
# File 'lib/google/apis/compute_v1/classes.rb', line 26668

def blocker_type
  @blocker_type
end

Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement. Corresponds to the JSON property documentationLink

Returns:

  • (String)


26675
26676
26677
# File 'lib/google/apis/compute_v1/classes.rb', line 26675

def documentation_link
  @documentation_link
end

#explanationString

Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement. Corresponds to the JSON property explanation

Returns:

  • (String)


26682
26683
26684
# File 'lib/google/apis/compute_v1/classes.rb', line 26682

def explanation
  @explanation
end

#facilitiesArray<String>

Output only. [Output Only] Facilities used to explain this blocker in more detail. Like physicalStructure.metros.facilities.facility, this is a numeric string like "5467". Corresponds to the JSON property facilities

Returns:

  • (Array<String>)


26690
26691
26692
# File 'lib/google/apis/compute_v1/classes.rb', line 26690

def facilities
  @facilities
end

#interconnectsArray<String>

Output only. [Output Only] Interconnects used to explain this blocker in more detail. Corresponds to the JSON property interconnects

Returns:

  • (Array<String>)


26696
26697
26698
# File 'lib/google/apis/compute_v1/classes.rb', line 26696

def interconnects
  @interconnects
end

#metrosArray<String>

Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field. Corresponds to the JSON property metros

Returns:

  • (Array<String>)


26704
26705
26706
# File 'lib/google/apis/compute_v1/classes.rb', line 26704

def metros
  @metros
end

#zonesArray<String>

Output only. [Output Only] Zones used to explain this blocker in more detail. Zone names are "zone1" and/or "zone2". Corresponds to the JSON property zones

Returns:

  • (Array<String>)


26710
26711
26712
# File 'lib/google/apis/compute_v1/classes.rb', line 26710

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26717
26718
26719
26720
26721
26722
26723
26724
26725
# File 'lib/google/apis/compute_v1/classes.rb', line 26717

def update!(**args)
  @blocker_type = args[:blocker_type] if args.key?(:blocker_type)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @explanation = args[:explanation] if args.key?(:explanation)
  @facilities = args[:facilities] if args.key?(:facilities)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @metros = args[:metros] if args.key?(:metros)
  @zones = args[:zones] if args.key?(:zones)
end