Class: Google::Apis::ComputeV1::InterconnectGroupPhysicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructure

Returns a new instance of InterconnectGroupPhysicalStructure.



31082
31083
31084
# File 'lib/google/apis/compute_v1/classes.rb', line 31082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metrosArray<Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetros>

Corresponds to the JSON property metros



31080
31081
31082
# File 'lib/google/apis/compute_v1/classes.rb', line 31080

def metros
  @metros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31087
31088
31089
# File 'lib/google/apis/compute_v1/classes.rb', line 31087

def update!(**args)
  @metros = args[:metros] if args.key?(:metros)
end