Class: Google::Apis::ComputeV1::InterconnectGroupPhysicalStructure
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupPhysicalStructure
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure.
Instance Attribute Summary collapse
-
#metros ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetros>
Corresponds to the JSON property
metros.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupPhysicalStructure
constructor
A new instance of InterconnectGroupPhysicalStructure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupPhysicalStructure
Returns a new instance of InterconnectGroupPhysicalStructure.
26778 26779 26780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metros ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetros>
Corresponds to the JSON property metros
26776 26777 26778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26776 def metros @metros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26783 26784 26785 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26783 def update!(**args) @metros = args[:metros] if args.key?(:metros) end |