Class: Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilities
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilities
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] The facilities Interconnects in this metro are present in.
Instance Attribute Summary collapse
-
#facility ⇒ String
Output only.
-
#zones ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>
Corresponds to the JSON property
zones.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities
constructor
A new instance of InterconnectGroupPhysicalStructureMetrosFacilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities
Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilities.
27576 27577 27578 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#facility ⇒ String
Output only. [Output Only] The ID of this facility, as a numeric string like
"5467". This is the third component of the location of Interconnects
in this facility.
Corresponds to the JSON property facility
27569 27570 27571 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27569 def facility @facility end |
#zones ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>
Corresponds to the JSON property zones
27574 27575 27576 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27574 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27581 27582 27583 27584 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27581 def update!(**args) @facility = args[:facility] if args.key?(:facility) @zones = args[:zones] if args.key?(:zones) end |