Class: Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilities

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] The facilities Interconnects in this metro are present in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities

Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilities.



26833
26834
26835
# File 'lib/google/apis/compute_v1/classes.rb', line 26833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilityString

Output only. [Output Only] The ID of this facility, as a numeric string like "5467". This is the third component of the location of Interconnects in this facility. Corresponds to the JSON property facility

Returns:

  • (String)


26826
26827
26828
# File 'lib/google/apis/compute_v1/classes.rb', line 26826

def facility
  @facility
end

#zonesArray<Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>

Corresponds to the JSON property zones



26831
26832
26833
# File 'lib/google/apis/compute_v1/classes.rb', line 26831

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26838
26839
26840
26841
# File 'lib/google/apis/compute_v1/classes.rb', line 26838

def update!(**args)
  @facility = args[:facility] if args.key?(:facility)
  @zones = args[:zones] if args.key?(:zones)
end