Class: Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilitiesZones

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] The zones that Interconnects in this facility are present in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilitiesZones

Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilitiesZones.



30431
30432
30433
# File 'lib/google/apis/compute_v1/classes.rb', line 30431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interconnectsArray<String>

Output only. [Output Only] URLs of Interconnects in this redundancy group in the given metro, facility, and zone. Corresponds to the JSON property interconnects

Returns:

  • (Array<String>)


30422
30423
30424
# File 'lib/google/apis/compute_v1/classes.rb', line 30422

def interconnects
  @interconnects
end

#zoneString

Output only. [Output Only] The name of the zone, either "zone1" or "zone2". This is the second component of the location of Interconnects in this facility. Corresponds to the JSON property zone

Returns:

  • (String)


30429
30430
30431
# File 'lib/google/apis/compute_v1/classes.rb', line 30429

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30436
30437
30438
30439
# File 'lib/google/apis/compute_v1/classes.rb', line 30436

def update!(**args)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @zone = args[:zone] if args.key?(:zone)
end