Class: Google::Apis::ComputeV1::InterconnectGroupPhysicalStructureMetrosFacilitiesZones

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] The zones that Interconnects in this facility are present in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilitiesZones

Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilitiesZones.



26863
26864
26865
# File 'lib/google/apis/compute_v1/classes.rb', line 26863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interconnectsArray<String>

Output only. [Output Only] URLs of Interconnects in this redundancy group in the given metro, facility, and zone. Corresponds to the JSON property interconnects

Returns:

  • (Array<String>)


26854
26855
26856
# File 'lib/google/apis/compute_v1/classes.rb', line 26854

def interconnects
  @interconnects
end

#zoneString

Output only. [Output Only] The name of the zone, either "zone1" or "zone2". This is the second component of the location of Interconnects in this facility. Corresponds to the JSON property zone

Returns:

  • (String)


26861
26862
26863
# File 'lib/google/apis/compute_v1/classes.rb', line 26861

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26868
26869
26870
26871
# File 'lib/google/apis/compute_v1/classes.rb', line 26868

def update!(**args)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @zone = args[:zone] if args.key?(:zone)
end