Class: Google::Apis::ComputeV1::InterconnectGroupsCreateMembersInterconnectInput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

LINT.IfChange

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsCreateMembersInterconnectInput

Returns a new instance of InterconnectGroupsCreateMembersInterconnectInput.



27010
27011
27012
# File 'lib/google/apis/compute_v1/classes.rb', line 27010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Administrative status of the interconnect. When this is set to true, the Interconnect is functional and can carry traffic. When set to false, no packets can be carried over the interconnect and no BGP routes are exchanged over it. By default, the status is set to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


26917
26918
26919
# File 'lib/google/apis/compute_v1/classes.rb', line 26917

def admin_enabled
  @admin_enabled
end

#customer_nameString

Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect. Corresponds to the JSON property customerName

Returns:

  • (String)


26924
26925
26926
# File 'lib/google/apis/compute_v1/classes.rb', line 26924

def customer_name
  @customer_name
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


26930
26931
26932
# File 'lib/google/apis/compute_v1/classes.rb', line 26930

def description
  @description
end

#facilityString

A zone-free location to use for all Interconnects created in this call, like "iad-1234". Corresponds to the JSON property facility

Returns:

  • (String)


26936
26937
26938
# File 'lib/google/apis/compute_v1/classes.rb', line 26936

def facility
  @facility
end

#interconnect_typeString

Type of interconnect, which can take one of the following values:

  • PARTNER: A partner-managed interconnection shared between customers though a partner.
  • DEDICATED: A dedicated physical interconnection with the customer. Note that a value IT_PRIVATE has been deprecated in favor of DEDICATED. Corresponds to the JSON property interconnectType

Returns:

  • (String)


26948
26949
26950
# File 'lib/google/apis/compute_v1/classes.rb', line 26948

def interconnect_type
  @interconnect_type
end

Type of link requested, which can take one of the following values:

  • LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics
  • LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics.
  • LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics. Note that this field indicates the speed of each of the links in the bundle, not the speed of the entire bundle. Corresponds to the JSON property linkType

Returns:

  • (String)


26960
26961
26962
# File 'lib/google/apis/compute_v1/classes.rb', line 26960

def link_type
  @link_type
end

#nameString

Name of the Interconnects to be created. This must be specified on the template and/or on each individual interconnect. The name, if not empty, must be 1-63 characters long, and comply with RFC1035. Specifically, any nonempty name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


26972
26973
26974
# File 'lib/google/apis/compute_v1/classes.rb', line 26972

def name
  @name
end

#noc_contact_emailString

Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect. If specified, this will be used for notifications in addition to all other forms described, such as Cloud Monitoring logs alerting and Cloud Notifications. This field is required for users who sign up for Cloud Interconnect using workforce identity federation. Corresponds to the JSON property nocContactEmail

Returns:

  • (String)


26982
26983
26984
# File 'lib/google/apis/compute_v1/classes.rb', line 26982

def noc_contact_email
  @noc_contact_email
end

#remote_locationString

Indicates that this is a Cross-Cloud Interconnect. This field specifies the location outside of Google's network that the interconnect is connected to. Corresponds to the JSON property remoteLocation

Returns:

  • (String)


26989
26990
26991
# File 'lib/google/apis/compute_v1/classes.rb', line 26989

def remote_location
  @remote_location
end

#requested_featuresArray<String>

Optional. List of features requested for this Interconnect connection, which can take one of the following values:

  • IF_MACSEC: If specified, then the connection is created on MACsec capable hardware ports. If not specified, non-MACsec capable ports will also be considered.
  • IF_CROSS_SITE_NETWORK: If specified, then the connection is created exclusively for Cross-Site Networking. The connection can not be used for Cross-Site Networking unless this feature is specified. Corresponds to the JSON property requestedFeatures

Returns:

  • (Array<String>)


27002
27003
27004
# File 'lib/google/apis/compute_v1/classes.rb', line 27002

def requested_features
  @requested_features
end

Target number of physical links in the link bundle, as requested by the customer. Corresponds to the JSON property requestedLinkCount

Returns:

  • (Fixnum)


27008
27009
27010
# File 'lib/google/apis/compute_v1/classes.rb', line 27008

def requested_link_count
  @requested_link_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27015
27016
27017
27018
27019
27020
27021
27022
27023
27024
27025
27026
27027
# File 'lib/google/apis/compute_v1/classes.rb', line 27015

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @customer_name = args[:customer_name] if args.key?(:customer_name)
  @description = args[:description] if args.key?(:description)
  @facility = args[:facility] if args.key?(:facility)
  @interconnect_type = args[:interconnect_type] if args.key?(:interconnect_type)
  @link_type = args[:link_type] if args.key?(:link_type)
  @name = args[:name] if args.key?(:name)
  @noc_contact_email = args[:noc_contact_email] if args.key?(:noc_contact_email)
  @remote_location = args[:remote_location] if args.key?(:remote_location)
  @requested_features = args[:requested_features] if args.key?(:requested_features)
  @requested_link_count = args[:requested_link_count] if args.key?(:requested_link_count)
end