Class: Google::Apis::ComputeV1::InterconnectGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectGroup>
A list of InterconnectGroup resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsListResponse
constructor
A new instance of InterconnectGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsListResponse
Returns a new instance of InterconnectGroupsListResponse.
31436 31437 31438 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
31393 31394 31395 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31393 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
31398 31399 31400 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31398 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectGroup>
A list of InterconnectGroup resources.
Corresponds to the JSON property items
31403 31404 31405 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31403 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
31408 31409 31410 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31408 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
31418 31419 31420 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31418 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
31423 31424 31425 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31423 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
31429 31430 31431 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31429 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
31434 31435 31436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31434 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31441 31442 31443 31444 31445 31446 31447 31448 31449 31450 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31441 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |