Class: Google::Apis::ComputeV1::InterconnectGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectGroup>
A list of InterconnectGroup resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsListResponse
constructor
A new instance of InterconnectGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsListResponse
Returns a new instance of InterconnectGroupsListResponse.
31393 31394 31395 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
31350 31351 31352 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31350 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
31355 31356 31357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31355 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectGroup>
A list of InterconnectGroup resources.
Corresponds to the JSON property items
31360 31361 31362 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31360 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
31365 31366 31367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31365 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
31375 31376 31377 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31375 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
31380 31381 31382 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31380 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
31386 31387 31388 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31386 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
31391 31392 31393 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31391 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31398 31399 31400 31401 31402 31403 31404 31405 31406 31407 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31398 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |