Class: Google::Apis::ComputeV1::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



31394
31395
31396
# File 'lib/google/apis/compute_v1/classes.rb', line 31394

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


31351
31352
31353
# File 'lib/google/apis/compute_v1/classes.rb', line 31351

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31356
31357
31358
# File 'lib/google/apis/compute_v1/classes.rb', line 31356

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



31361
31362
31363
# File 'lib/google/apis/compute_v1/classes.rb', line 31361

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


31366
31367
31368
# File 'lib/google/apis/compute_v1/classes.rb', line 31366

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31376
31377
31378
# File 'lib/google/apis/compute_v1/classes.rb', line 31376

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31381
31382
31383
# File 'lib/google/apis/compute_v1/classes.rb', line 31381

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


31387
31388
31389
# File 'lib/google/apis/compute_v1/classes.rb', line 31387

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31392
31393
31394
# File 'lib/google/apis/compute_v1/classes.rb', line 31392

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31399
31400
31401
31402
31403
31404
31405
31406
31407
31408
# File 'lib/google/apis/compute_v1/classes.rb', line 31399

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end