Class: Google::Apis::ComputeV1::InterconnectGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectGroup>
A list of InterconnectGroup resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsListResponse
constructor
A new instance of InterconnectGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsListResponse
Returns a new instance of InterconnectGroupsListResponse.
30692 30693 30694 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
30649 30650 30651 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30649 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
30654 30655 30656 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30654 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectGroup>
A list of InterconnectGroup resources.
Corresponds to the JSON property items
30659 30660 30661 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30659 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
30664 30665 30666 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30664 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
30674 30675 30676 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30674 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
30679 30680 30681 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30679 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
30685 30686 30687 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30685 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
30690 30691 30692 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30690 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30697 30698 30699 30700 30701 30702 30703 30704 30705 30706 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30697 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |