Class: Google::Apis::ComputeV1::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



27867
27868
27869
# File 'lib/google/apis/compute_v1/classes.rb', line 27867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


27824
27825
27826
# File 'lib/google/apis/compute_v1/classes.rb', line 27824

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27829
27830
27831
# File 'lib/google/apis/compute_v1/classes.rb', line 27829

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



27834
27835
27836
# File 'lib/google/apis/compute_v1/classes.rb', line 27834

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


27839
27840
27841
# File 'lib/google/apis/compute_v1/classes.rb', line 27839

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27849
27850
27851
# File 'lib/google/apis/compute_v1/classes.rb', line 27849

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27854
27855
27856
# File 'lib/google/apis/compute_v1/classes.rb', line 27854

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


27860
27861
27862
# File 'lib/google/apis/compute_v1/classes.rb', line 27860

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



27865
27866
27867
# File 'lib/google/apis/compute_v1/classes.rb', line 27865

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27872
27873
27874
27875
27876
27877
27878
27879
27880
27881
# File 'lib/google/apis/compute_v1/classes.rb', line 27872

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end