Class: Google::Apis::ComputeV1::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



27124
27125
27126
# File 'lib/google/apis/compute_v1/classes.rb', line 27124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


27081
27082
27083
# File 'lib/google/apis/compute_v1/classes.rb', line 27081

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27086
27087
27088
# File 'lib/google/apis/compute_v1/classes.rb', line 27086

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



27091
27092
27093
# File 'lib/google/apis/compute_v1/classes.rb', line 27091

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


27096
27097
27098
# File 'lib/google/apis/compute_v1/classes.rb', line 27096

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27106
27107
27108
# File 'lib/google/apis/compute_v1/classes.rb', line 27106

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27111
27112
27113
# File 'lib/google/apis/compute_v1/classes.rb', line 27111

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


27117
27118
27119
# File 'lib/google/apis/compute_v1/classes.rb', line 27117

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



27122
27123
27124
# File 'lib/google/apis/compute_v1/classes.rb', line 27122

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27129
27130
27131
27132
27133
27134
27135
27136
27137
27138
# File 'lib/google/apis/compute_v1/classes.rb', line 27129

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end