Class: Google::Apis::ComputeV1::InterconnectGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectGroupsOperationalStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Request to get the status of the interconnect group with extra detail.
Instance Attribute Summary collapse
-
#configured ⇒ Google::Apis::ComputeV1::InterconnectGroupConfigured
[Output Only] The status of the group as configured.
-
#group_status ⇒ String
Output only.
-
#intent ⇒ Google::Apis::ComputeV1::InterconnectGroupIntent
The user's intent for this group.
-
#interconnect_statuses ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupsOperationalStatusInterconnectStatus>
Corresponds to the JSON property
interconnectStatuses. -
#operational ⇒ Google::Apis::ComputeV1::InterconnectGroupConfigured
[Output Only] The status of the group as configured.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsOperationalStatus
constructor
A new instance of InterconnectGroupsOperationalStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsOperationalStatus
Returns a new instance of InterconnectGroupsOperationalStatus.
31911 31912 31913 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31911 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configured ⇒ Google::Apis::ComputeV1::InterconnectGroupConfigured
[Output Only] The status of the group as configured. This has the same
structure as the operational field reported by the OperationalStatus
method, but does not take into account the operational status of each
resource.
Corresponds to the JSON property configured
31885 31886 31887 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31885 def configured @configured end |
#group_status ⇒ String
Output only. Summarizes the status of the group.
Corresponds to the JSON property groupStatus
31890 31891 31892 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31890 def group_status @group_status end |
#intent ⇒ Google::Apis::ComputeV1::InterconnectGroupIntent
The user's intent for this group. This is the only required field besides
the name that must be specified on group creation.
Corresponds to the JSON property intent
31896 31897 31898 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31896 def intent @intent end |
#interconnect_statuses ⇒ Array<Google::Apis::ComputeV1::InterconnectGroupsOperationalStatusInterconnectStatus>
Corresponds to the JSON property interconnectStatuses
31901 31902 31903 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31901 def interconnect_statuses @interconnect_statuses end |
#operational ⇒ Google::Apis::ComputeV1::InterconnectGroupConfigured
[Output Only] The status of the group as configured. This has the same
structure as the operational field reported by the OperationalStatus
method, but does not take into account the operational status of each
resource.
Corresponds to the JSON property operational
31909 31910 31911 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31909 def operational @operational end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31916 31917 31918 31919 31920 31921 31922 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31916 def update!(**args) @configured = args[:configured] if args.key?(:configured) @group_status = args[:group_status] if args.key?(:group_status) @intent = args[:intent] if args.key?(:intent) @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses) @operational = args[:operational] if args.key?(:operational) end |