Class: Google::Apis::ComputeV1::InterconnectGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Request to get the status of the interconnect group with extra detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatus

Returns a new instance of InterconnectGroupsOperationalStatus.



31551
31552
31553
# File 'lib/google/apis/compute_v1/classes.rb', line 31551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeV1::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



31525
31526
31527
# File 'lib/google/apis/compute_v1/classes.rb', line 31525

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


31530
31531
31532
# File 'lib/google/apis/compute_v1/classes.rb', line 31530

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeV1::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



31536
31537
31538
# File 'lib/google/apis/compute_v1/classes.rb', line 31536

def intent
  @intent
end

#interconnect_statusesArray<Google::Apis::ComputeV1::InterconnectGroupsOperationalStatusInterconnectStatus>

Corresponds to the JSON property interconnectStatuses



31541
31542
31543
# File 'lib/google/apis/compute_v1/classes.rb', line 31541

def interconnect_statuses
  @interconnect_statuses
end

#operationalGoogle::Apis::ComputeV1::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property operational



31549
31550
31551
# File 'lib/google/apis/compute_v1/classes.rb', line 31549

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31556
31557
31558
31559
31560
31561
31562
# File 'lib/google/apis/compute_v1/classes.rb', line 31556

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses)
  @operational = args[:operational] if args.key?(:operational)
end