Class: Google::Apis::ComputeV1::InterconnectGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Request to get the status of the interconnect group with extra detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatus

Returns a new instance of InterconnectGroupsOperationalStatus.



31319
31320
31321
# File 'lib/google/apis/compute_v1/classes.rb', line 31319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeV1::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



31293
31294
31295
# File 'lib/google/apis/compute_v1/classes.rb', line 31293

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


31298
31299
31300
# File 'lib/google/apis/compute_v1/classes.rb', line 31298

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeV1::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



31304
31305
31306
# File 'lib/google/apis/compute_v1/classes.rb', line 31304

def intent
  @intent
end

#interconnect_statusesArray<Google::Apis::ComputeV1::InterconnectGroupsOperationalStatusInterconnectStatus>

Corresponds to the JSON property interconnectStatuses



31309
31310
31311
# File 'lib/google/apis/compute_v1/classes.rb', line 31309

def interconnect_statuses
  @interconnect_statuses
end

#operationalGoogle::Apis::ComputeV1::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property operational



31317
31318
31319
# File 'lib/google/apis/compute_v1/classes.rb', line 31317

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31324
31325
31326
31327
31328
31329
31330
# File 'lib/google/apis/compute_v1/classes.rb', line 31324

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses)
  @operational = args[:operational] if args.key?(:operational)
end