Class: Google::Apis::ComputeV1::InterconnectGroupsOperationalStatusInterconnectStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The status of one Interconnect in the group. The order is arbitrary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatusInterconnectStatus

Returns a new instance of InterconnectGroupsOperationalStatusInterconnectStatus.



28032
28033
28034
# File 'lib/google/apis/compute_v1/classes.rb', line 28032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Output only. Whether the Interconnect is enabled. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


28011
28012
28013
# File 'lib/google/apis/compute_v1/classes.rb', line 28011

def admin_enabled
  @admin_enabled
end

#diagnosticsGoogle::Apis::ComputeV1::InterconnectDiagnostics

Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection. Corresponds to the JSON property diagnostics



28019
28020
28021
# File 'lib/google/apis/compute_v1/classes.rb', line 28019

def diagnostics
  @diagnostics
end

#interconnectString

Output only. The URL of the Interconnect being described. Corresponds to the JSON property interconnect

Returns:

  • (String)


28024
28025
28026
# File 'lib/google/apis/compute_v1/classes.rb', line 28024

def interconnect
  @interconnect
end

#is_activeString

Output only. Whether this interconnect is participating in the redundant configuration. Corresponds to the JSON property isActive

Returns:

  • (String)


28030
28031
28032
# File 'lib/google/apis/compute_v1/classes.rb', line 28030

def is_active
  @is_active
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28037
28038
28039
28040
28041
28042
# File 'lib/google/apis/compute_v1/classes.rb', line 28037

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @diagnostics = args[:diagnostics] if args.key?(:diagnostics)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @is_active = args[:is_active] if args.key?(:is_active)
end