Class: Google::Apis::ComputeV1::InterconnectList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of interconnects.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Interconnect>
A list of Interconnect resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectList
constructor
A new instance of InterconnectList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectList
Returns a new instance of InterconnectList.
31646 31647 31648 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
31613 31614 31615 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31613 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Interconnect>
A list of Interconnect resources.
Corresponds to the JSON property items
31618 31619 31620 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31618 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#interconnectList
for lists of interconnects.
Corresponds to the JSON property kind
31624 31625 31626 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31624 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
31634 31635 31636 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31634 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
31639 31640 31641 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31639 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
31644 31645 31646 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31644 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31651 31652 31653 31654 31655 31656 31657 31658 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31651 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |