Class: Google::Apis::ComputeV1::InterconnectList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of interconnects.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Interconnect>
A list of Interconnect resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectList
constructor
A new instance of InterconnectList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectList
Returns a new instance of InterconnectList.
31422 31423 31424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31422 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
31389 31390 31391 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31389 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Interconnect>
A list of Interconnect resources.
Corresponds to the JSON property items
31394 31395 31396 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31394 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#interconnectList
for lists of interconnects.
Corresponds to the JSON property kind
31400 31401 31402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31400 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
31410 31411 31412 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31410 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
31415 31416 31417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31415 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
31420 31421 31422 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31420 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31427 31428 31429 31430 31431 31432 31433 31434 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31427 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |