Class: Google::Apis::ComputeV1::InterconnectList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnects.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectList

Returns a new instance of InterconnectList.



31414
31415
31416
# File 'lib/google/apis/compute_v1/classes.rb', line 31414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31381
31382
31383
# File 'lib/google/apis/compute_v1/classes.rb', line 31381

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Interconnect>

A list of Interconnect resources. Corresponds to the JSON property items



31386
31387
31388
# File 'lib/google/apis/compute_v1/classes.rb', line 31386

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#interconnectList for lists of interconnects. Corresponds to the JSON property kind

Returns:

  • (String)


31392
31393
31394
# File 'lib/google/apis/compute_v1/classes.rb', line 31392

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31402
31403
31404
# File 'lib/google/apis/compute_v1/classes.rb', line 31402

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31407
31408
31409
# File 'lib/google/apis/compute_v1/classes.rb', line 31407

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31412
31413
31414
# File 'lib/google/apis/compute_v1/classes.rb', line 31412

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31419
31420
31421
31422
31423
31424
31425
31426
# File 'lib/google/apis/compute_v1/classes.rb', line 31419

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end