Class: Google::Apis::ComputeV1::InterconnectList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnects.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectList

Returns a new instance of InterconnectList.



16932
16933
16934
# File 'lib/google/apis/compute_v1/classes.rb', line 16932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16900
16901
16902
# File 'lib/google/apis/compute_v1/classes.rb', line 16900

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Interconnect>

A list of Interconnect resources. Corresponds to the JSON property items



16905
16906
16907
# File 'lib/google/apis/compute_v1/classes.rb', line 16905

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#interconnectList for lists of interconnects. Corresponds to the JSON property kind

Returns:

  • (String)


16911
16912
16913
# File 'lib/google/apis/compute_v1/classes.rb', line 16911

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16920
16921
16922
# File 'lib/google/apis/compute_v1/classes.rb', line 16920

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16925
16926
16927
# File 'lib/google/apis/compute_v1/classes.rb', line 16925

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16930
16931
16932
# File 'lib/google/apis/compute_v1/classes.rb', line 16930

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16937
16938
16939
16940
16941
16942
16943
16944
# File 'lib/google/apis/compute_v1/classes.rb', line 16937

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end