Class: Google::Apis::ComputeV1::InterconnectLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents an Interconnect Attachment (VLAN) Location resource. You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.
Instance Attribute Summary collapse
-
#address ⇒ String
Output only.
-
#availability_zone ⇒ String
[Output Only] Availability zone for this InterconnectLocation.
-
#available_features ⇒ Array<String>
[Output only] List of features available at this InterconnectLocation, which can take one of the following values:.
-
#available_link_types ⇒ Array<String>
[Output only] List of link types available at this InterconnectLocation, which can take one of the following values:.
-
#city ⇒ String
[Output Only] Metropolitan area designator that indicates which city an interconnect is located.
-
#continent ⇒ String
[Output Only] Continent for this location, which can take one of the following values:.
-
#creation_timestamp ⇒ String
Output only.
-
#cross_site_interconnect_infos ⇒ Array<Google::Apis::ComputeV1::InterconnectLocationCrossSiteInterconnectInfo>
[Output Only] A list of InterconnectLocation.CrossSiteInterconnectInfo objects, that describe where Cross-Site Interconnect wires may connect to from this location and associated connection parameters.
-
#description ⇒ String
Output only.
-
#facility_provider ⇒ String
Output only.
-
#facility_provider_facility_id ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#peeringdb_facility_id ⇒ String
Output only.
-
#region_infos ⇒ Array<Google::Apis::ComputeV1::InterconnectLocationRegionInfo>
Output only.
-
#self_link ⇒ String
Output only.
-
#single_region_production_critical_peer_locations ⇒ Array<String>
Output only.
-
#status ⇒ String
[Output Only] The status of this InterconnectLocation, which can take one of the following values:.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectLocation
constructor
A new instance of InterconnectLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectLocation
Returns a new instance of InterconnectLocation.
31149 31150 31151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Output only. [Output Only] The postal address of the Point of Presence, each
line in
the address is separated by a newline character.
Corresponds to the JSON property address
31007 31008 31009 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31007 def address @address end |
#availability_zone ⇒ String
[Output Only] Availability zone for this InterconnectLocation. Within a
metropolitan area (metro), maintenance will not be simultaneously scheduled
in more than one availability zone. Example: "zone1" or "zone2".
Corresponds to the JSON property availabilityZone
31014 31015 31016 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31014 def availability_zone @availability_zone end |
#available_features ⇒ Array<String>
[Output only] List of features available at this InterconnectLocation, which can take one of the following values:
- IF_MACSEC
- IF_CROSS_SITE_NETWORK
Corresponds to the JSON property
availableFeatures
31023 31024 31025 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31023 def available_features @available_features end |
#available_link_types ⇒ Array<String>
[Output only] List of link types available at this InterconnectLocation, which can take one of the following values:
- LINK_TYPE_ETHERNET_10G_LR
- LINK_TYPE_ETHERNET_100G_LR
- LINK_TYPE_ETHERNET_400G_LR4
Corresponds to the JSON property
availableLinkTypes
31033 31034 31035 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31033 def available_link_types @available_link_types end |
#city ⇒ String
[Output Only] Metropolitan area designator that indicates which city an
interconnect is located.
For example: "Chicago, IL", "Amsterdam, Netherlands".
Corresponds to the JSON property city
31040 31041 31042 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31040 def city @city end |
#continent ⇒ String
[Output Only] Continent for this location, which can take one of the following values:
- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA
Corresponds to the JSON property
continent
31052 31053 31054 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31052 def continent @continent end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
31058 31059 31060 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31058 def @creation_timestamp end |
#cross_site_interconnect_infos ⇒ Array<Google::Apis::ComputeV1::InterconnectLocationCrossSiteInterconnectInfo>
[Output Only] A list of InterconnectLocation.CrossSiteInterconnectInfo
objects, that describe where Cross-Site Interconnect wires may connect to
from this location and associated connection parameters. Cross-Site
Interconnect isn't allowed to locations which are not listed.
Corresponds to the JSON property crossSiteInterconnectInfos
31066 31067 31068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31066 def cross_site_interconnect_infos @cross_site_interconnect_infos end |
#description ⇒ String
Output only. [Output Only] An optional description of the resource.
Corresponds to the JSON property description
31071 31072 31073 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31071 def description @description end |
#facility_provider ⇒ String
Output only. [Output Only] The name of the provider for this facility (e.g.,
EQUINIX).
Corresponds to the JSON property facilityProvider
31077 31078 31079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31077 def facility_provider @facility_provider end |
#facility_provider_facility_id ⇒ String
Output only. [Output Only] A provider-assigned Identifier for this facility (e.
g.,
Ashburn-DC1).
Corresponds to the JSON property facilityProviderFacilityId
31084 31085 31086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31084 def facility_provider_facility_id @facility_provider_facility_id end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
31091 31092 31093 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31091 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
interconnectLocation for interconnect locations.
Corresponds to the JSON property kind
31097 31098 31099 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31097 def kind @kind end |
#name ⇒ String
Output only. [Output Only] Name of the resource.
Corresponds to the JSON property name
31102 31103 31104 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31102 def name @name end |
#peeringdb_facility_id ⇒ String
Output only. [Output Only] The peeringdb identifier for this facility (
corresponding
with a netfac type in peeringdb).
Corresponds to the JSON property peeringdbFacilityId
31109 31110 31111 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31109 def peeringdb_facility_id @peeringdb_facility_id end |
#region_infos ⇒ Array<Google::Apis::ComputeV1::InterconnectLocationRegionInfo>
Output only. [Output Only] A list of InterconnectLocation.RegionInfo objects,
that
describe parameters pertaining to the relation between this
InterconnectLocation and various Google Cloud regions.
Corresponds to the JSON property regionInfos
31117 31118 31119 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31117 def region_infos @region_infos end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
31122 31123 31124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31122 def self_link @self_link end |
#single_region_production_critical_peer_locations ⇒ Array<String>
Output only. [Output Only] URLs of the other locations that can pair up with
this
location to support Single-Region 99.99% SLA. E.g. iad-zone1-1 and
iad-zone2-5467 are Single-Region 99.99% peer locations of each other.
Corresponds to the JSON property singleRegionProductionCriticalPeerLocations
31130 31131 31132 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31130 def single_region_production_critical_peer_locations @single_region_production_critical_peer_locations end |
#status ⇒ String
[Output Only] The status of this InterconnectLocation, which can take one of the following values:
- CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects.
- AVAILABLE: The InterconnectLocation is available for provisioning new
Interconnects.
Corresponds to the JSON property
status
31141 31142 31143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31141 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
31146 31147 31148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31146 def supports_pzs @supports_pzs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31154 31155 31156 31157 31158 31159 31160 31161 31162 31163 31164 31165 31166 31167 31168 31169 31170 31171 31172 31173 31174 31175 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31154 def update!(**args) @address = args[:address] if args.key?(:address) @availability_zone = args[:availability_zone] if args.key?(:availability_zone) @available_features = args[:available_features] if args.key?(:available_features) @available_link_types = args[:available_link_types] if args.key?(:available_link_types) @city = args[:city] if args.key?(:city) @continent = args[:continent] if args.key?(:continent) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @cross_site_interconnect_infos = args[:cross_site_interconnect_infos] if args.key?(:cross_site_interconnect_infos) @description = args[:description] if args.key?(:description) @facility_provider = args[:facility_provider] if args.key?(:facility_provider) @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id) @region_infos = args[:region_infos] if args.key?(:region_infos) @self_link = args[:self_link] if args.key?(:self_link) @single_region_production_critical_peer_locations = args[:single_region_production_critical_peer_locations] if args.key?(:single_region_production_critical_peer_locations) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) end |