Class: Google::Apis::ComputeV1::InterconnectLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an Interconnect Attachment (VLAN) Location resource. You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocation

Returns a new instance of InterconnectLocation.



17114
17115
17116
# File 'lib/google/apis/compute_v1/classes.rb', line 17114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

[Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character. Corresponds to the JSON property address

Returns:

  • (String)


17022
17023
17024
# File 'lib/google/apis/compute_v1/classes.rb', line 17022

def address
  @address
end

#availability_zoneString

[Output Only] Availability zone for this InterconnectLocation. Within a metropolitan area (metro), maintenance will not be simultaneously scheduled in more than one availability zone. Example: "zone1" or "zone2". Corresponds to the JSON property availabilityZone

Returns:

  • (String)


17029
17030
17031
# File 'lib/google/apis/compute_v1/classes.rb', line 17029

def availability_zone
  @availability_zone
end

#cityString

[Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands". Corresponds to the JSON property city

Returns:

  • (String)


17035
17036
17037
# File 'lib/google/apis/compute_v1/classes.rb', line 17035

def city
  @city
end

#continentString

[Output Only] Continent for this location, which can take one of the following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA - SOUTH_AMERICA Corresponds to the JSON property continent

Returns:

  • (String)


17041
17042
17043
# File 'lib/google/apis/compute_v1/classes.rb', line 17041

def continent
  @continent
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


17046
17047
17048
# File 'lib/google/apis/compute_v1/classes.rb', line 17046

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] An optional description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


17051
17052
17053
# File 'lib/google/apis/compute_v1/classes.rb', line 17051

def description
  @description
end

#facility_providerString

[Output Only] The name of the provider for this facility (e.g., EQUINIX). Corresponds to the JSON property facilityProvider

Returns:

  • (String)


17056
17057
17058
# File 'lib/google/apis/compute_v1/classes.rb', line 17056

def facility_provider
  @facility_provider
end

#facility_provider_facility_idString

[Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn- DC1). Corresponds to the JSON property facilityProviderFacilityId

Returns:

  • (String)


17062
17063
17064
# File 'lib/google/apis/compute_v1/classes.rb', line 17062

def facility_provider_facility_id
  @facility_provider_facility_id
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


17068
17069
17070
# File 'lib/google/apis/compute_v1/classes.rb', line 17068

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#interconnectLocation for interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


17074
17075
17076
# File 'lib/google/apis/compute_v1/classes.rb', line 17074

def kind
  @kind
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


17079
17080
17081
# File 'lib/google/apis/compute_v1/classes.rb', line 17079

def name
  @name
end

#peeringdb_facility_idString

[Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb). Corresponds to the JSON property peeringdbFacilityId

Returns:

  • (String)


17085
17086
17087
# File 'lib/google/apis/compute_v1/classes.rb', line 17085

def peeringdb_facility_id
  @peeringdb_facility_id
end

#region_infosArray<Google::Apis::ComputeV1::InterconnectLocationRegionInfo>

[Output Only] A list of InterconnectLocation.RegionInfo objects, that describe parameters pertaining to the relation between this InterconnectLocation and various Google Cloud regions. Corresponds to the JSON property regionInfos



17092
17093
17094
# File 'lib/google/apis/compute_v1/classes.rb', line 17092

def region_infos
  @region_infos
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17097
17098
17099
# File 'lib/google/apis/compute_v1/classes.rb', line 17097

def self_link
  @self_link
end

#statusString

[Output Only] The status of this InterconnectLocation, which can take one of the following values: - CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects. - AVAILABLE: The InterconnectLocation is available for provisioning new Interconnects. Corresponds to the JSON property status

Returns:

  • (String)


17105
17106
17107
# File 'lib/google/apis/compute_v1/classes.rb', line 17105

def status
  @status
end

#supports_pzsBoolean Also known as: supports_pzs?

[Output Only] Set to true for locations that support physical zone separation. Defaults to false if the field is not present. Corresponds to the JSON property supportsPzs

Returns:

  • (Boolean)


17111
17112
17113
# File 'lib/google/apis/compute_v1/classes.rb', line 17111

def supports_pzs
  @supports_pzs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17119
17120
17121
17122
17123
17124
17125
17126
17127
17128
17129
17130
17131
17132
17133
17134
17135
17136
# File 'lib/google/apis/compute_v1/classes.rb', line 17119

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @availability_zone = args[:availability_zone] if args.key?(:availability_zone)
  @city = args[:city] if args.key?(:city)
  @continent = args[:continent] if args.key?(:continent)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @facility_provider = args[:facility_provider] if args.key?(:facility_provider)
  @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id)
  @region_infos = args[:region_infos] if args.key?(:region_infos)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs)
end