Class: Google::Apis::ComputeV1::InterconnectLocationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectLocationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of interconnect locations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectLocation>
A list of InterconnectLocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectLocationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectLocationList
constructor
A new instance of InterconnectLocationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectLocationList
Returns a new instance of InterconnectLocationList.
31978 31979 31980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
31944 31945 31946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31944 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectLocation>
A list of InterconnectLocation resources.
Corresponds to the JSON property items
31949 31950 31951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31949 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectLocationList for lists of interconnect
locations.
Corresponds to the JSON property kind
31956 31957 31958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31956 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
31966 31967 31968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31966 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
31971 31972 31973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31971 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectLocationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
31976 31977 31978 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31976 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31983 31984 31985 31986 31987 31988 31989 31990 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31983 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |