Class: Google::Apis::ComputeV1::InterconnectLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationList

Returns a new instance of InterconnectLocationList.



31746
31747
31748
# File 'lib/google/apis/compute_v1/classes.rb', line 31746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31712
31713
31714
# File 'lib/google/apis/compute_v1/classes.rb', line 31712

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectLocation>

A list of InterconnectLocation resources. Corresponds to the JSON property items



31717
31718
31719
# File 'lib/google/apis/compute_v1/classes.rb', line 31717

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectLocationList for lists of interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


31724
31725
31726
# File 'lib/google/apis/compute_v1/classes.rb', line 31724

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31734
31735
31736
# File 'lib/google/apis/compute_v1/classes.rb', line 31734

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31739
31740
31741
# File 'lib/google/apis/compute_v1/classes.rb', line 31739

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31744
31745
31746
# File 'lib/google/apis/compute_v1/classes.rb', line 31744

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31751
31752
31753
31754
31755
31756
31757
31758
# File 'lib/google/apis/compute_v1/classes.rb', line 31751

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end