Class: Google::Apis::ComputeV1::InterconnectLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationList

Returns a new instance of InterconnectLocationList.



31242
31243
31244
# File 'lib/google/apis/compute_v1/classes.rb', line 31242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31208
31209
31210
# File 'lib/google/apis/compute_v1/classes.rb', line 31208

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectLocation>

A list of InterconnectLocation resources. Corresponds to the JSON property items



31213
31214
31215
# File 'lib/google/apis/compute_v1/classes.rb', line 31213

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectLocationList for lists of interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


31220
31221
31222
# File 'lib/google/apis/compute_v1/classes.rb', line 31220

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31230
31231
31232
# File 'lib/google/apis/compute_v1/classes.rb', line 31230

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31235
31236
31237
# File 'lib/google/apis/compute_v1/classes.rb', line 31235

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31240
31241
31242
# File 'lib/google/apis/compute_v1/classes.rb', line 31240

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31247
31248
31249
31250
31251
31252
31253
31254
# File 'lib/google/apis/compute_v1/classes.rb', line 31247

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end