Class: Google::Apis::ComputeV1::InterconnectOutageNotification
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectOutageNotification
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Description of a planned outage on this Interconnect.
Instance Attribute Summary collapse
-
#affected_circuits ⇒ Array<String>
If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.
-
#description ⇒ String
A description about the purpose of the outage.
-
#end_time ⇒ Fixnum
Scheduled end time for the outage (milliseconds since Unix epoch).
-
#issue_type ⇒ String
Form this outage is expected to take, which can take one of the following values:.
-
#name ⇒ String
Unique identifier for this outage notification.
-
#source ⇒ String
The party that generated this notification, which can take the following value:.
-
#start_time ⇒ Fixnum
Scheduled start time for the outage (milliseconds since Unix epoch).
-
#state ⇒ String
State of this notification, which can take one of the following values:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectOutageNotification
constructor
A new instance of InterconnectOutageNotification.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectOutageNotification
Returns a new instance of InterconnectOutageNotification.
28009 28010 28011 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_circuits ⇒ Array<String>
If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit
IDs that will be affected.
Corresponds to the JSON property affectedCircuits
27948 27949 27950 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27948 def affected_circuits @affected_circuits end |
#description ⇒ String
A description about the purpose of the outage.
Corresponds to the JSON property description
27953 27954 27955 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27953 def description @description end |
#end_time ⇒ Fixnum
Scheduled end time for the outage (milliseconds since Unix
epoch).
Corresponds to the JSON property endTime
27959 27960 27961 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27959 def end_time @end_time end |
#issue_type ⇒ String
Form this outage is expected to take, which can take one of the following values:
- OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
- PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
should remain up, but with reduced bandwidth.
Note that the versions of this enum prefixed with "IT_" have been
deprecated in favor of the unprefixed values.
Corresponds to the JSON property
issueType
27972 27973 27974 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27972 def issue_type @issue_type end |
#name ⇒ String
Unique identifier for this outage notification.
Corresponds to the JSON property name
27977 27978 27979 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27977 def name @name end |
#source ⇒ String
The party that generated this notification, which can take the following value:
- GOOGLE: this notification as generated by Google.
Note that the value of NSRC_GOOGLE has been deprecated in favor of
GOOGLE.
Corresponds to the JSON property
source
27987 27988 27989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27987 def source @source end |
#start_time ⇒ Fixnum
Scheduled start time for the outage (milliseconds since Unix
epoch).
Corresponds to the JSON property startTime
27993 27994 27995 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27993 def start_time @start_time end |
#state ⇒ String
State of this notification, which can take one of the following values:
- ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
- CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
- COMPLETED: The outage associated with this notification is complete.
Note that the versions of this enum prefixed with "NS_" have been
deprecated in favor of the unprefixed values.
Corresponds to the JSON property
state
28007 28008 28009 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28007 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28014 28015 28016 28017 28018 28019 28020 28021 28022 28023 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28014 def update!(**args) @affected_circuits = args[:affected_circuits] if args.key?(:affected_circuits) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @issue_type = args[:issue_type] if args.key?(:issue_type) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |