Class: Google::Apis::ComputeV1::InterconnectRemoteLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectRemoteLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Cross-Cloud Interconnect Remote Location resource. You can use this resource to find remote location details about an Interconnect attachment (VLAN).
Instance Attribute Summary collapse
-
#address ⇒ String
Output only.
-
#attachment_configuration_constraints ⇒ Google::Apis::ComputeV1::InterconnectAttachmentConfigurationConstraints
Output only.
-
#city ⇒ String
Output only.
-
#constraints ⇒ Google::Apis::ComputeV1::InterconnectRemoteLocationConstraints
Output only.
-
#continent ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#facility_provider ⇒ String
Output only.
-
#facility_provider_facility_id ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#lacp ⇒ String
Output only.
-
#max_lag_size100_gbps ⇒ Fixnum
Output only.
-
#max_lag_size10_gbps ⇒ Fixnum
Output only.
-
#max_lag_size400_gbps ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#peeringdb_facility_id ⇒ String
Output only.
-
#permitted_connections ⇒ Array<Google::Apis::ComputeV1::InterconnectRemoteLocationPermittedConnections>
Output only.
-
#remote_service ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectRemoteLocation
constructor
A new instance of InterconnectRemoteLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectRemoteLocation
Returns a new instance of InterconnectRemoteLocation.
28960 28961 28962 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Output only. [Output Only] The postal address of the Point of Presence, each
line in
the address is separated by a newline character.
Corresponds to the JSON property address
28812 28813 28814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28812 def address @address end |
#attachment_configuration_constraints ⇒ Google::Apis::ComputeV1::InterconnectAttachmentConfigurationConstraints
Output only. [Output Only] Subset of fields from InterconnectAttachment's
|configurationConstraints| field that apply to all attachments for this
remote location.
Corresponds to the JSON property attachmentConfigurationConstraints
28819 28820 28821 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28819 def @attachment_configuration_constraints end |
#city ⇒ String
Output only. [Output Only] Metropolitan area designator that indicates which
city an
interconnect is located.
For example: "Chicago, IL", "Amsterdam, Netherlands".
Corresponds to the JSON property city
28827 28828 28829 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28827 def city @city end |
#constraints ⇒ Google::Apis::ComputeV1::InterconnectRemoteLocationConstraints
Output only. [Output Only] Constraints on the parameters for creating Cross-
Cloud
Interconnect and associated InterconnectAttachments.
Corresponds to the JSON property constraints
28834 28835 28836 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28834 def constraints @constraints end |
#continent ⇒ String
Output only. [Output Only] Continent for this location, which can take one of the following values:
- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA
Corresponds to the JSON property
continent
28847 28848 28849 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28847 def continent @continent end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
28853 28854 28855 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28853 def @creation_timestamp end |
#description ⇒ String
Output only. [Output Only] An optional description of the resource.
Corresponds to the JSON property description
28858 28859 28860 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28858 def description @description end |
#facility_provider ⇒ String
Output only. [Output Only] The name of the provider for this facility (e.g.,
EQUINIX).
Corresponds to the JSON property facilityProvider
28864 28865 28866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28864 def facility_provider @facility_provider end |
#facility_provider_facility_id ⇒ String
Output only. [Output Only] A provider-assigned Identifier for this facility (e.
g.,
Ashburn-DC1).
Corresponds to the JSON property facilityProviderFacilityId
28871 28872 28873 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28871 def facility_provider_facility_id @facility_provider_facility_id end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
28878 28879 28880 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28878 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
interconnectRemoteLocation for interconnect remote
locations.
Corresponds to the JSON property kind
28885 28886 28887 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28885 def kind @kind end |
#lacp ⇒ String
Output only. [Output Only] Link Aggregation Control Protocol (LACP)
constraints, which
can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
Corresponds to the JSON property lacp
28892 28893 28894 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28892 def lacp @lacp end |
#max_lag_size100_gbps ⇒ Fixnum
Output only. [Output Only]
The maximum number of 100 Gbps ports supported in a link aggregation group
(LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed
max_lag_size_100_gbps.
Corresponds to the JSON property maxLagSize100Gbps
28900 28901 28902 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28900 def max_lag_size100_gbps @max_lag_size100_gbps end |
#max_lag_size10_gbps ⇒ Fixnum
Output only. [Output Only]
The maximum number of 10 Gbps ports supported in a link aggregation group
(LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed
max_lag_size_10_gbps.
Corresponds to the JSON property maxLagSize10Gbps
28908 28909 28910 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28908 def max_lag_size10_gbps @max_lag_size10_gbps end |
#max_lag_size400_gbps ⇒ Fixnum
Output only. [Output Only]
The maximum number of 400 Gbps ports supported in a link aggregation group
(LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed
max_lag_size_400_gbps.
Corresponds to the JSON property maxLagSize400Gbps
28916 28917 28918 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28916 def max_lag_size400_gbps @max_lag_size400_gbps end |
#name ⇒ String
Output only. [Output Only] Name of the resource.
Corresponds to the JSON property name
28921 28922 28923 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28921 def name @name end |
#peeringdb_facility_id ⇒ String
Output only. [Output Only] The peeringdb identifier for this facility (
corresponding
with a netfac type in peeringdb).
Corresponds to the JSON property peeringdbFacilityId
28928 28929 28930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28928 def peeringdb_facility_id @peeringdb_facility_id end |
#permitted_connections ⇒ Array<Google::Apis::ComputeV1::InterconnectRemoteLocationPermittedConnections>
Output only. [Output Only] Permitted connections.
Corresponds to the JSON property permittedConnections
28933 28934 28935 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28933 def permitted_connections @permitted_connections end |
#remote_service ⇒ String
Output only. [Output Only] Indicates the service provider present at the
remote
location. Example values: "Amazon Web Services", "Microsoft Azure".
Corresponds to the JSON property remoteService
28940 28941 28942 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28940 def remote_service @remote_service end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
28945 28946 28947 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28945 def self_link @self_link end |
#status ⇒ String
Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:
- CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects.
- AVAILABLE: The
InterconnectRemoteLocation is available for provisioning new
Cross-Cloud Interconnects.
Corresponds to the JSON property
status
28958 28959 28960 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28958 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28965 28966 28967 28968 28969 28970 28971 28972 28973 28974 28975 28976 28977 28978 28979 28980 28981 28982 28983 28984 28985 28986 28987 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28965 def update!(**args) @address = args[:address] if args.key?(:address) @attachment_configuration_constraints = args[:attachment_configuration_constraints] if args.key?(:attachment_configuration_constraints) @city = args[:city] if args.key?(:city) @constraints = args[:constraints] if args.key?(:constraints) @continent = args[:continent] if args.key?(:continent) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @facility_provider = args[:facility_provider] if args.key?(:facility_provider) @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @lacp = args[:lacp] if args.key?(:lacp) @max_lag_size100_gbps = args[:max_lag_size100_gbps] if args.key?(:max_lag_size100_gbps) @max_lag_size10_gbps = args[:max_lag_size10_gbps] if args.key?(:max_lag_size10_gbps) @max_lag_size400_gbps = args[:max_lag_size400_gbps] if args.key?(:max_lag_size400_gbps) @name = args[:name] if args.key?(:name) @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id) @permitted_connections = args[:permitted_connections] if args.key?(:permitted_connections) @remote_service = args[:remote_service] if args.key?(:remote_service) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) end |