Class: Google::Apis::ComputeV1::InterconnectRemoteLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectRemoteLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Cross-Cloud Interconnect Remote Location resource. You can use this resource to find remote location details about an Interconnect attachment (VLAN).
Instance Attribute Summary collapse
-
#address ⇒ String
Output only.
-
#attachment_configuration_constraints ⇒ Google::Apis::ComputeV1::InterconnectAttachmentConfigurationConstraints
Output only.
-
#city ⇒ String
Output only.
-
#constraints ⇒ Google::Apis::ComputeV1::InterconnectRemoteLocationConstraints
Output only.
-
#continent ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#facility_provider ⇒ String
Output only.
-
#facility_provider_facility_id ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#lacp ⇒ String
Output only.
-
#max_lag_size100_gbps ⇒ Fixnum
Output only.
-
#max_lag_size10_gbps ⇒ Fixnum
Output only.
-
#max_lag_size400_gbps ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#peeringdb_facility_id ⇒ String
Output only.
-
#permitted_connections ⇒ Array<Google::Apis::ComputeV1::InterconnectRemoteLocationPermittedConnections>
Output only.
-
#remote_service ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectRemoteLocation
constructor
A new instance of InterconnectRemoteLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectRemoteLocation
Returns a new instance of InterconnectRemoteLocation.
28217 28218 28219 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Output only. [Output Only] The postal address of the Point of Presence, each
line in
the address is separated by a newline character.
Corresponds to the JSON property address
28069 28070 28071 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28069 def address @address end |
#attachment_configuration_constraints ⇒ Google::Apis::ComputeV1::InterconnectAttachmentConfigurationConstraints
Output only. [Output Only] Subset of fields from InterconnectAttachment's
|configurationConstraints| field that apply to all attachments for this
remote location.
Corresponds to the JSON property attachmentConfigurationConstraints
28076 28077 28078 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28076 def @attachment_configuration_constraints end |
#city ⇒ String
Output only. [Output Only] Metropolitan area designator that indicates which
city an
interconnect is located.
For example: "Chicago, IL", "Amsterdam, Netherlands".
Corresponds to the JSON property city
28084 28085 28086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28084 def city @city end |
#constraints ⇒ Google::Apis::ComputeV1::InterconnectRemoteLocationConstraints
Output only. [Output Only] Constraints on the parameters for creating Cross-
Cloud
Interconnect and associated InterconnectAttachments.
Corresponds to the JSON property constraints
28091 28092 28093 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28091 def constraints @constraints end |
#continent ⇒ String
Output only. [Output Only] Continent for this location, which can take one of the following values:
- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA
Corresponds to the JSON property
continent
28104 28105 28106 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28104 def continent @continent end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
28110 28111 28112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28110 def @creation_timestamp end |
#description ⇒ String
Output only. [Output Only] An optional description of the resource.
Corresponds to the JSON property description
28115 28116 28117 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28115 def description @description end |
#facility_provider ⇒ String
Output only. [Output Only] The name of the provider for this facility (e.g.,
EQUINIX).
Corresponds to the JSON property facilityProvider
28121 28122 28123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28121 def facility_provider @facility_provider end |
#facility_provider_facility_id ⇒ String
Output only. [Output Only] A provider-assigned Identifier for this facility (e.
g.,
Ashburn-DC1).
Corresponds to the JSON property facilityProviderFacilityId
28128 28129 28130 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28128 def facility_provider_facility_id @facility_provider_facility_id end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
28135 28136 28137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28135 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
interconnectRemoteLocation for interconnect remote
locations.
Corresponds to the JSON property kind
28142 28143 28144 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28142 def kind @kind end |
#lacp ⇒ String
Output only. [Output Only] Link Aggregation Control Protocol (LACP)
constraints, which
can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
Corresponds to the JSON property lacp
28149 28150 28151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28149 def lacp @lacp end |
#max_lag_size100_gbps ⇒ Fixnum
Output only. [Output Only]
The maximum number of 100 Gbps ports supported in a link aggregation group
(LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed
max_lag_size_100_gbps.
Corresponds to the JSON property maxLagSize100Gbps
28157 28158 28159 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28157 def max_lag_size100_gbps @max_lag_size100_gbps end |
#max_lag_size10_gbps ⇒ Fixnum
Output only. [Output Only]
The maximum number of 10 Gbps ports supported in a link aggregation group
(LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed
max_lag_size_10_gbps.
Corresponds to the JSON property maxLagSize10Gbps
28165 28166 28167 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28165 def max_lag_size10_gbps @max_lag_size10_gbps end |
#max_lag_size400_gbps ⇒ Fixnum
Output only. [Output Only]
The maximum number of 400 Gbps ports supported in a link aggregation group
(LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed
max_lag_size_400_gbps.
Corresponds to the JSON property maxLagSize400Gbps
28173 28174 28175 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28173 def max_lag_size400_gbps @max_lag_size400_gbps end |
#name ⇒ String
Output only. [Output Only] Name of the resource.
Corresponds to the JSON property name
28178 28179 28180 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28178 def name @name end |
#peeringdb_facility_id ⇒ String
Output only. [Output Only] The peeringdb identifier for this facility (
corresponding
with a netfac type in peeringdb).
Corresponds to the JSON property peeringdbFacilityId
28185 28186 28187 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28185 def peeringdb_facility_id @peeringdb_facility_id end |
#permitted_connections ⇒ Array<Google::Apis::ComputeV1::InterconnectRemoteLocationPermittedConnections>
Output only. [Output Only] Permitted connections.
Corresponds to the JSON property permittedConnections
28190 28191 28192 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28190 def permitted_connections @permitted_connections end |
#remote_service ⇒ String
Output only. [Output Only] Indicates the service provider present at the
remote
location. Example values: "Amazon Web Services", "Microsoft Azure".
Corresponds to the JSON property remoteService
28197 28198 28199 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28197 def remote_service @remote_service end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
28202 28203 28204 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28202 def self_link @self_link end |
#status ⇒ String
Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:
- CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects.
- AVAILABLE: The
InterconnectRemoteLocation is available for provisioning new
Cross-Cloud Interconnects.
Corresponds to the JSON property
status
28215 28216 28217 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28215 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28222 28223 28224 28225 28226 28227 28228 28229 28230 28231 28232 28233 28234 28235 28236 28237 28238 28239 28240 28241 28242 28243 28244 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28222 def update!(**args) @address = args[:address] if args.key?(:address) @attachment_configuration_constraints = args[:attachment_configuration_constraints] if args.key?(:attachment_configuration_constraints) @city = args[:city] if args.key?(:city) @constraints = args[:constraints] if args.key?(:constraints) @continent = args[:continent] if args.key?(:continent) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @facility_provider = args[:facility_provider] if args.key?(:facility_provider) @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @lacp = args[:lacp] if args.key?(:lacp) @max_lag_size100_gbps = args[:max_lag_size100_gbps] if args.key?(:max_lag_size100_gbps) @max_lag_size10_gbps = args[:max_lag_size10_gbps] if args.key?(:max_lag_size10_gbps) @max_lag_size400_gbps = args[:max_lag_size400_gbps] if args.key?(:max_lag_size400_gbps) @name = args[:name] if args.key?(:name) @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id) @permitted_connections = args[:permitted_connections] if args.key?(:permitted_connections) @remote_service = args[:remote_service] if args.key?(:remote_service) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) end |