Class: Google::Apis::ComputeV1::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



32636
32637
32638
# File 'lib/google/apis/compute_v1/classes.rb', line 32636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32602
32603
32604
# File 'lib/google/apis/compute_v1/classes.rb', line 32602

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



32607
32608
32609
# File 'lib/google/apis/compute_v1/classes.rb', line 32607

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


32614
32615
32616
# File 'lib/google/apis/compute_v1/classes.rb', line 32614

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32624
32625
32626
# File 'lib/google/apis/compute_v1/classes.rb', line 32624

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32629
32630
32631
# File 'lib/google/apis/compute_v1/classes.rb', line 32629

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32634
32635
32636
# File 'lib/google/apis/compute_v1/classes.rb', line 32634

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32641
32642
32643
32644
32645
32646
32647
32648
# File 'lib/google/apis/compute_v1/classes.rb', line 32641

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end