Class: Google::Apis::ComputeV1::InterconnectRemoteLocationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectRemoteLocationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of interconnect remote locations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectRemoteLocation>
A list of InterconnectRemoteLocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token lets you get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectRemoteLocationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectRemoteLocationList
constructor
A new instance of InterconnectRemoteLocationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectRemoteLocationList
Returns a new instance of InterconnectRemoteLocationList.
32637 32638 32639 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
32603 32604 32605 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32603 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectRemoteLocation>
A list of InterconnectRemoteLocation resources.
Corresponds to the JSON property items
32608 32609 32610 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32608 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectRemoteLocationList for lists of
interconnect remote locations.
Corresponds to the JSON property kind
32615 32616 32617 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32615 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token lets you get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
32625 32626 32627 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32625 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
32630 32631 32632 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32630 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectRemoteLocationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
32635 32636 32637 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32635 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32642 32643 32644 32645 32646 32647 32648 32649 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32642 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |