Class: Google::Apis::ComputeV1::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



32439
32440
32441
# File 'lib/google/apis/compute_v1/classes.rb', line 32439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32405
32406
32407
# File 'lib/google/apis/compute_v1/classes.rb', line 32405

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



32410
32411
32412
# File 'lib/google/apis/compute_v1/classes.rb', line 32410

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


32417
32418
32419
# File 'lib/google/apis/compute_v1/classes.rb', line 32417

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32427
32428
32429
# File 'lib/google/apis/compute_v1/classes.rb', line 32427

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32432
32433
32434
# File 'lib/google/apis/compute_v1/classes.rb', line 32432

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32437
32438
32439
# File 'lib/google/apis/compute_v1/classes.rb', line 32437

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32444
32445
32446
32447
32448
32449
32450
32451
# File 'lib/google/apis/compute_v1/classes.rb', line 32444

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end