Class: Google::Apis::ComputeV1::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



29110
29111
29112
# File 'lib/google/apis/compute_v1/classes.rb', line 29110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29076
29077
29078
# File 'lib/google/apis/compute_v1/classes.rb', line 29076

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



29081
29082
29083
# File 'lib/google/apis/compute_v1/classes.rb', line 29081

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


29088
29089
29090
# File 'lib/google/apis/compute_v1/classes.rb', line 29088

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29098
29099
29100
# File 'lib/google/apis/compute_v1/classes.rb', line 29098

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29103
29104
29105
# File 'lib/google/apis/compute_v1/classes.rb', line 29103

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



29108
29109
29110
# File 'lib/google/apis/compute_v1/classes.rb', line 29108

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29115
29116
29117
29118
29119
29120
29121
29122
# File 'lib/google/apis/compute_v1/classes.rb', line 29115

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end