Class: Google::Apis::ComputeV1::InterconnectRemoteLocationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InterconnectRemoteLocationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response to the list request, and contains a list of interconnect remote locations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectRemoteLocation>
A list of InterconnectRemoteLocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token lets you get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::InterconnectRemoteLocationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectRemoteLocationList
constructor
A new instance of InterconnectRemoteLocationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectRemoteLocationList
Returns a new instance of InterconnectRemoteLocationList.
28367 28368 28369 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28367 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
28333 28334 28335 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28333 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InterconnectRemoteLocation>
A list of InterconnectRemoteLocation resources.
Corresponds to the JSON property items
28338 28339 28340 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28338 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectRemoteLocationList for lists of
interconnect remote locations.
Corresponds to the JSON property kind
28345 28346 28347 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28345 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token lets you get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
28355 28356 28357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28355 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
28360 28361 28362 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28360 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::InterconnectRemoteLocationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
28365 28366 28367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28365 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28372 28373 28374 28375 28376 28377 28378 28379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28372 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |