Class: Google::Apis::ComputeV1::License
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::License
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a License resource. A License represents billing and aggregate usage data forpublic andmarketplace images. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Instance Attribute Summary collapse
-
#allowed_replacement_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that can replace this license.
-
#appendable_to_disk ⇒ Boolean
(also: #appendable_to_disk?)
If true, this license can be appended to an existing disk's set of licenses.
-
#charges_use_fee ⇒ Boolean
(also: #charges_use_fee?)
[Output Only] Deprecated.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional textual description of the resource; provided by the client when the resource is created.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#incompatible_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that are incompatible with this license.
-
#kind ⇒ String
Output only.
-
#license_code ⇒ Fixnum
[Output Only] The unique code used to attach this license to images, snapshots, and disks.
-
#minimum_retention ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#multi_tenant_only ⇒ Boolean
(also: #multi_tenant_only?)
If true, this license can only be used on VMs on multi tenant nodes.
-
#name ⇒ String
Name of the resource.
-
#os_license ⇒ Boolean
(also: #os_license?)
If true, indicates this is an OS license.
-
#params ⇒ Google::Apis::ComputeV1::LicenseParams
Additional license params.
-
#removable_from_disk ⇒ Boolean
(also: #removable_from_disk?)
If true, this license can be removed from a disk's set of licenses, with no replacement license needed.
-
#required_coattached_licenses ⇒ Array<String>
Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license.
-
#resource_requirements ⇒ Google::Apis::ComputeV1::LicenseResourceRequirements
[Input Only] Deprecated.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#sole_tenant_only ⇒ Boolean
(also: #sole_tenant_only?)
If true, this license can only be used on VMs on sole tenant nodes.
-
#transferable ⇒ Boolean
(also: #transferable?)
If false, licenses will not be copied from the source resource when creating an image from a disk, disk from snapshot, or snapshot from disk.
-
#update_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ License
constructor
A new instance of License.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ License
Returns a new instance of License.
32980 32981 32982 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_replacement_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that can replace this license. Note:
such replacements are allowed even if removable_from_disk is false.
Corresponds to the JSON property allowedReplacementLicenses
32846 32847 32848 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32846 def allowed_replacement_licenses @allowed_replacement_licenses end |
#appendable_to_disk ⇒ Boolean Also known as: appendable_to_disk?
If true, this license can be appended to an existing disk's set of
licenses.
Corresponds to the JSON property appendableToDisk
32852 32853 32854 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32852 def appendable_to_disk @appendable_to_disk end |
#charges_use_fee ⇒ Boolean Also known as: charges_use_fee?
[Output Only] Deprecated. This field no longer reflects whether a license
charges a usage fee.
Corresponds to the JSON property chargesUseFee
32859 32860 32861 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32859 def charges_use_fee @charges_use_fee end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
32866 32867 32868 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32866 def @creation_timestamp end |
#description ⇒ String
An optional textual description of the resource; provided by the client
when the resource is created.
Corresponds to the JSON property description
32872 32873 32874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32872 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
32878 32879 32880 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32878 def id @id end |
#incompatible_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that are incompatible with this license.
If a license is incompatible with this license, it cannot be attached to
the same disk or image.
Corresponds to the JSON property incompatibleLicenses
32885 32886 32887 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32885 def incompatible_licenses @incompatible_licenses end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#license for
licenses.
Corresponds to the JSON property kind
32891 32892 32893 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32891 def kind @kind end |
#license_code ⇒ Fixnum
[Output Only] The unique code used to attach this license to images,
snapshots, and disks.
Corresponds to the JSON property licenseCode
32897 32898 32899 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32897 def license_code @license_code end |
#minimum_retention ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property minimumRetention
32905 32906 32907 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32905 def minimum_retention @minimum_retention end |
#multi_tenant_only ⇒ Boolean Also known as: multi_tenant_only?
If true, this license can only be used on VMs on multi tenant nodes.
Corresponds to the JSON property multiTenantOnly
32910 32911 32912 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32910 def multi_tenant_only @multi_tenant_only end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long and
comply withRFC1035.
Corresponds to the JSON property name
32917 32918 32919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32917 def name @name end |
#os_license ⇒ Boolean Also known as: os_license?
If true, indicates this is an OS license. Only one OS license can be
attached to a disk or image at a time.
Corresponds to the JSON property osLicense
32923 32924 32925 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32923 def os_license @os_license end |
#params ⇒ Google::Apis::ComputeV1::LicenseParams
Additional license params.
Corresponds to the JSON property params
32929 32930 32931 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32929 def params @params end |
#removable_from_disk ⇒ Boolean Also known as: removable_from_disk?
If true, this license can be removed from a disk's set of licenses, with no
replacement license needed.
Corresponds to the JSON property removableFromDisk
32935 32936 32937 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32935 def removable_from_disk @removable_from_disk end |
#required_coattached_licenses ⇒ Array<String>
Specifies the set of permissible coattached licenseCodes of licenses that
satisfy the coattachment requirement of this license. At least one license
from the set must be attached to the same disk or image as this license.
Corresponds to the JSON property requiredCoattachedLicenses
32943 32944 32945 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32943 def required_coattached_licenses @required_coattached_licenses end |
#resource_requirements ⇒ Google::Apis::ComputeV1::LicenseResourceRequirements
[Input Only] Deprecated.
Corresponds to the JSON property resourceRequirements
32948 32949 32950 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32948 def resource_requirements @resource_requirements end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
32953 32954 32955 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32953 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
32959 32960 32961 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32959 def self_link_with_id @self_link_with_id end |
#sole_tenant_only ⇒ Boolean Also known as: sole_tenant_only?
If true, this license can only be used on VMs on sole tenant nodes.
Corresponds to the JSON property soleTenantOnly
32964 32965 32966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32964 def sole_tenant_only @sole_tenant_only end |
#transferable ⇒ Boolean Also known as: transferable?
If false, licenses will not be copied from the source resource when
creating an image from a disk, disk from snapshot, or snapshot from disk.
Corresponds to the JSON property transferable
32971 32972 32973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32971 def transferable @transferable end |
#update_timestamp ⇒ String
Output only. [Output Only] Last update timestamp inRFC3339
text format.
Corresponds to the JSON property updateTimestamp
32978 32979 32980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32978 def @update_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32985 32986 32987 32988 32989 32990 32991 32992 32993 32994 32995 32996 32997 32998 32999 33000 33001 33002 33003 33004 33005 33006 33007 33008 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32985 def update!(**args) @allowed_replacement_licenses = args[:allowed_replacement_licenses] if args.key?(:allowed_replacement_licenses) @appendable_to_disk = args[:appendable_to_disk] if args.key?(:appendable_to_disk) @charges_use_fee = args[:charges_use_fee] if args.key?(:charges_use_fee) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @incompatible_licenses = args[:incompatible_licenses] if args.key?(:incompatible_licenses) @kind = args[:kind] if args.key?(:kind) @license_code = args[:license_code] if args.key?(:license_code) @minimum_retention = args[:minimum_retention] if args.key?(:minimum_retention) @multi_tenant_only = args[:multi_tenant_only] if args.key?(:multi_tenant_only) @name = args[:name] if args.key?(:name) @os_license = args[:os_license] if args.key?(:os_license) @params = args[:params] if args.key?(:params) @removable_from_disk = args[:removable_from_disk] if args.key?(:removable_from_disk) @required_coattached_licenses = args[:required_coattached_licenses] if args.key?(:required_coattached_licenses) @resource_requirements = args[:resource_requirements] if args.key?(:resource_requirements) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @sole_tenant_only = args[:sole_tenant_only] if args.key?(:sole_tenant_only) @transferable = args[:transferable] if args.key?(:transferable) @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp) end |