Class: Google::Apis::ComputeV1::License

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a License resource. A License represents billing and aggregate usage data forpublic andmarketplace images. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ License

Returns a new instance of License.



32236
32237
32238
# File 'lib/google/apis/compute_v1/classes.rb', line 32236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_replacement_licensesArray<String>

Specifies licenseCodes of licenses that can replace this license. Note: such replacements are allowed even if removable_from_disk is false. Corresponds to the JSON property allowedReplacementLicenses

Returns:

  • (Array<String>)


32102
32103
32104
# File 'lib/google/apis/compute_v1/classes.rb', line 32102

def allowed_replacement_licenses
  @allowed_replacement_licenses
end

#appendable_to_diskBoolean Also known as: appendable_to_disk?

If true, this license can be appended to an existing disk's set of licenses. Corresponds to the JSON property appendableToDisk

Returns:

  • (Boolean)


32108
32109
32110
# File 'lib/google/apis/compute_v1/classes.rb', line 32108

def appendable_to_disk
  @appendable_to_disk
end

#charges_use_feeBoolean Also known as: charges_use_fee?

[Output Only] Deprecated. This field no longer reflects whether a license charges a usage fee. Corresponds to the JSON property chargesUseFee

Returns:

  • (Boolean)


32115
32116
32117
# File 'lib/google/apis/compute_v1/classes.rb', line 32115

def charges_use_fee
  @charges_use_fee
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


32122
32123
32124
# File 'lib/google/apis/compute_v1/classes.rb', line 32122

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional textual description of the resource; provided by the client when the resource is created. Corresponds to the JSON property description

Returns:

  • (String)


32128
32129
32130
# File 'lib/google/apis/compute_v1/classes.rb', line 32128

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


32134
32135
32136
# File 'lib/google/apis/compute_v1/classes.rb', line 32134

def id
  @id
end

#incompatible_licensesArray<String>

Specifies licenseCodes of licenses that are incompatible with this license. If a license is incompatible with this license, it cannot be attached to the same disk or image. Corresponds to the JSON property incompatibleLicenses

Returns:

  • (Array<String>)


32141
32142
32143
# File 'lib/google/apis/compute_v1/classes.rb', line 32141

def incompatible_licenses
  @incompatible_licenses
end

#kindString

Output only. [Output Only] Type of resource. Always compute#license for licenses. Corresponds to the JSON property kind

Returns:

  • (String)


32147
32148
32149
# File 'lib/google/apis/compute_v1/classes.rb', line 32147

def kind
  @kind
end

#license_codeFixnum

[Output Only] The unique code used to attach this license to images, snapshots, and disks. Corresponds to the JSON property licenseCode

Returns:

  • (Fixnum)


32153
32154
32155
# File 'lib/google/apis/compute_v1/classes.rb', line 32153

def license_code
  @license_code
end

#minimum_retentionGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property minimumRetention



32161
32162
32163
# File 'lib/google/apis/compute_v1/classes.rb', line 32161

def minimum_retention
  @minimum_retention
end

#multi_tenant_onlyBoolean Also known as: multi_tenant_only?

If true, this license can only be used on VMs on multi tenant nodes. Corresponds to the JSON property multiTenantOnly

Returns:

  • (Boolean)


32166
32167
32168
# File 'lib/google/apis/compute_v1/classes.rb', line 32166

def multi_tenant_only
  @multi_tenant_only
end

#nameString

Name of the resource. The name must be 1-63 characters long and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


32173
32174
32175
# File 'lib/google/apis/compute_v1/classes.rb', line 32173

def name
  @name
end

#os_licenseBoolean Also known as: os_license?

If true, indicates this is an OS license. Only one OS license can be attached to a disk or image at a time. Corresponds to the JSON property osLicense

Returns:

  • (Boolean)


32179
32180
32181
# File 'lib/google/apis/compute_v1/classes.rb', line 32179

def os_license
  @os_license
end

#paramsGoogle::Apis::ComputeV1::LicenseParams

Additional license params. Corresponds to the JSON property params



32185
32186
32187
# File 'lib/google/apis/compute_v1/classes.rb', line 32185

def params
  @params
end

#removable_from_diskBoolean Also known as: removable_from_disk?

If true, this license can be removed from a disk's set of licenses, with no replacement license needed. Corresponds to the JSON property removableFromDisk

Returns:

  • (Boolean)


32191
32192
32193
# File 'lib/google/apis/compute_v1/classes.rb', line 32191

def removable_from_disk
  @removable_from_disk
end

#required_coattached_licensesArray<String>

Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license. At least one license from the set must be attached to the same disk or image as this license. Corresponds to the JSON property requiredCoattachedLicenses

Returns:

  • (Array<String>)


32199
32200
32201
# File 'lib/google/apis/compute_v1/classes.rb', line 32199

def required_coattached_licenses
  @required_coattached_licenses
end

#resource_requirementsGoogle::Apis::ComputeV1::LicenseResourceRequirements

[Input Only] Deprecated. Corresponds to the JSON property resourceRequirements



32204
32205
32206
# File 'lib/google/apis/compute_v1/classes.rb', line 32204

def resource_requirements
  @resource_requirements
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32209
32210
32211
# File 'lib/google/apis/compute_v1/classes.rb', line 32209

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


32215
32216
32217
# File 'lib/google/apis/compute_v1/classes.rb', line 32215

def self_link_with_id
  @self_link_with_id
end

#sole_tenant_onlyBoolean Also known as: sole_tenant_only?

If true, this license can only be used on VMs on sole tenant nodes. Corresponds to the JSON property soleTenantOnly

Returns:

  • (Boolean)


32220
32221
32222
# File 'lib/google/apis/compute_v1/classes.rb', line 32220

def sole_tenant_only
  @sole_tenant_only
end

#transferableBoolean Also known as: transferable?

If false, licenses will not be copied from the source resource when creating an image from a disk, disk from snapshot, or snapshot from disk. Corresponds to the JSON property transferable

Returns:

  • (Boolean)


32227
32228
32229
# File 'lib/google/apis/compute_v1/classes.rb', line 32227

def transferable
  @transferable
end

#update_timestampString

Output only. [Output Only] Last update timestamp inRFC3339 text format. Corresponds to the JSON property updateTimestamp

Returns:

  • (String)


32234
32235
32236
# File 'lib/google/apis/compute_v1/classes.rb', line 32234

def update_timestamp
  @update_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32241
32242
32243
32244
32245
32246
32247
32248
32249
32250
32251
32252
32253
32254
32255
32256
32257
32258
32259
32260
32261
32262
32263
32264
# File 'lib/google/apis/compute_v1/classes.rb', line 32241

def update!(**args)
  @allowed_replacement_licenses = args[:allowed_replacement_licenses] if args.key?(:allowed_replacement_licenses)
  @appendable_to_disk = args[:appendable_to_disk] if args.key?(:appendable_to_disk)
  @charges_use_fee = args[:charges_use_fee] if args.key?(:charges_use_fee)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @incompatible_licenses = args[:incompatible_licenses] if args.key?(:incompatible_licenses)
  @kind = args[:kind] if args.key?(:kind)
  @license_code = args[:license_code] if args.key?(:license_code)
  @minimum_retention = args[:minimum_retention] if args.key?(:minimum_retention)
  @multi_tenant_only = args[:multi_tenant_only] if args.key?(:multi_tenant_only)
  @name = args[:name] if args.key?(:name)
  @os_license = args[:os_license] if args.key?(:os_license)
  @params = args[:params] if args.key?(:params)
  @removable_from_disk = args[:removable_from_disk] if args.key?(:removable_from_disk)
  @required_coattached_licenses = args[:required_coattached_licenses] if args.key?(:required_coattached_licenses)
  @resource_requirements = args[:resource_requirements] if args.key?(:resource_requirements)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @sole_tenant_only = args[:sole_tenant_only] if args.key?(:sole_tenant_only)
  @transferable = args[:transferable] if args.key?(:transferable)
  @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp)
end