Class: Google::Apis::ComputeV1::License

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a License resource. A License represents billing and aggregate usage data forpublic andmarketplace images. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ License

Returns a new instance of License.



28668
28669
28670
# File 'lib/google/apis/compute_v1/classes.rb', line 28668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_replacement_licensesArray<String>

Specifies licenseCodes of licenses that can replace this license. Note: such replacements are allowed even if removable_from_disk is false. Corresponds to the JSON property allowedReplacementLicenses

Returns:

  • (Array<String>)


28534
28535
28536
# File 'lib/google/apis/compute_v1/classes.rb', line 28534

def allowed_replacement_licenses
  @allowed_replacement_licenses
end

#appendable_to_diskBoolean Also known as: appendable_to_disk?

If true, this license can be appended to an existing disk's set of licenses. Corresponds to the JSON property appendableToDisk

Returns:

  • (Boolean)


28540
28541
28542
# File 'lib/google/apis/compute_v1/classes.rb', line 28540

def appendable_to_disk
  @appendable_to_disk
end

#charges_use_feeBoolean Also known as: charges_use_fee?

[Output Only] Deprecated. This field no longer reflects whether a license charges a usage fee. Corresponds to the JSON property chargesUseFee

Returns:

  • (Boolean)


28547
28548
28549
# File 'lib/google/apis/compute_v1/classes.rb', line 28547

def charges_use_fee
  @charges_use_fee
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


28554
28555
28556
# File 'lib/google/apis/compute_v1/classes.rb', line 28554

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional textual description of the resource; provided by the client when the resource is created. Corresponds to the JSON property description

Returns:

  • (String)


28560
28561
28562
# File 'lib/google/apis/compute_v1/classes.rb', line 28560

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28566
28567
28568
# File 'lib/google/apis/compute_v1/classes.rb', line 28566

def id
  @id
end

#incompatible_licensesArray<String>

Specifies licenseCodes of licenses that are incompatible with this license. If a license is incompatible with this license, it cannot be attached to the same disk or image. Corresponds to the JSON property incompatibleLicenses

Returns:

  • (Array<String>)


28573
28574
28575
# File 'lib/google/apis/compute_v1/classes.rb', line 28573

def incompatible_licenses
  @incompatible_licenses
end

#kindString

Output only. [Output Only] Type of resource. Always compute#license for licenses. Corresponds to the JSON property kind

Returns:

  • (String)


28579
28580
28581
# File 'lib/google/apis/compute_v1/classes.rb', line 28579

def kind
  @kind
end

#license_codeFixnum

[Output Only] The unique code used to attach this license to images, snapshots, and disks. Corresponds to the JSON property licenseCode

Returns:

  • (Fixnum)


28585
28586
28587
# File 'lib/google/apis/compute_v1/classes.rb', line 28585

def license_code
  @license_code
end

#minimum_retentionGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property minimumRetention



28593
28594
28595
# File 'lib/google/apis/compute_v1/classes.rb', line 28593

def minimum_retention
  @minimum_retention
end

#multi_tenant_onlyBoolean Also known as: multi_tenant_only?

If true, this license can only be used on VMs on multi tenant nodes. Corresponds to the JSON property multiTenantOnly

Returns:

  • (Boolean)


28598
28599
28600
# File 'lib/google/apis/compute_v1/classes.rb', line 28598

def multi_tenant_only
  @multi_tenant_only
end

#nameString

Name of the resource. The name must be 1-63 characters long and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


28605
28606
28607
# File 'lib/google/apis/compute_v1/classes.rb', line 28605

def name
  @name
end

#os_licenseBoolean Also known as: os_license?

If true, indicates this is an OS license. Only one OS license can be attached to a disk or image at a time. Corresponds to the JSON property osLicense

Returns:

  • (Boolean)


28611
28612
28613
# File 'lib/google/apis/compute_v1/classes.rb', line 28611

def os_license
  @os_license
end

#paramsGoogle::Apis::ComputeV1::LicenseParams

Additional license params. Corresponds to the JSON property params



28617
28618
28619
# File 'lib/google/apis/compute_v1/classes.rb', line 28617

def params
  @params
end

#removable_from_diskBoolean Also known as: removable_from_disk?

If true, this license can be removed from a disk's set of licenses, with no replacement license needed. Corresponds to the JSON property removableFromDisk

Returns:

  • (Boolean)


28623
28624
28625
# File 'lib/google/apis/compute_v1/classes.rb', line 28623

def removable_from_disk
  @removable_from_disk
end

#required_coattached_licensesArray<String>

Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license. At least one license from the set must be attached to the same disk or image as this license. Corresponds to the JSON property requiredCoattachedLicenses

Returns:

  • (Array<String>)


28631
28632
28633
# File 'lib/google/apis/compute_v1/classes.rb', line 28631

def required_coattached_licenses
  @required_coattached_licenses
end

#resource_requirementsGoogle::Apis::ComputeV1::LicenseResourceRequirements

[Input Only] Deprecated. Corresponds to the JSON property resourceRequirements



28636
28637
28638
# File 'lib/google/apis/compute_v1/classes.rb', line 28636

def resource_requirements
  @resource_requirements
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28641
28642
28643
# File 'lib/google/apis/compute_v1/classes.rb', line 28641

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


28647
28648
28649
# File 'lib/google/apis/compute_v1/classes.rb', line 28647

def self_link_with_id
  @self_link_with_id
end

#sole_tenant_onlyBoolean Also known as: sole_tenant_only?

If true, this license can only be used on VMs on sole tenant nodes. Corresponds to the JSON property soleTenantOnly

Returns:

  • (Boolean)


28652
28653
28654
# File 'lib/google/apis/compute_v1/classes.rb', line 28652

def sole_tenant_only
  @sole_tenant_only
end

#transferableBoolean Also known as: transferable?

If false, licenses will not be copied from the source resource when creating an image from a disk, disk from snapshot, or snapshot from disk. Corresponds to the JSON property transferable

Returns:

  • (Boolean)


28659
28660
28661
# File 'lib/google/apis/compute_v1/classes.rb', line 28659

def transferable
  @transferable
end

#update_timestampString

Output only. [Output Only] Last update timestamp inRFC3339 text format. Corresponds to the JSON property updateTimestamp

Returns:

  • (String)


28666
28667
28668
# File 'lib/google/apis/compute_v1/classes.rb', line 28666

def update_timestamp
  @update_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28673
28674
28675
28676
28677
28678
28679
28680
28681
28682
28683
28684
28685
28686
28687
28688
28689
28690
28691
28692
28693
28694
28695
28696
# File 'lib/google/apis/compute_v1/classes.rb', line 28673

def update!(**args)
  @allowed_replacement_licenses = args[:allowed_replacement_licenses] if args.key?(:allowed_replacement_licenses)
  @appendable_to_disk = args[:appendable_to_disk] if args.key?(:appendable_to_disk)
  @charges_use_fee = args[:charges_use_fee] if args.key?(:charges_use_fee)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @incompatible_licenses = args[:incompatible_licenses] if args.key?(:incompatible_licenses)
  @kind = args[:kind] if args.key?(:kind)
  @license_code = args[:license_code] if args.key?(:license_code)
  @minimum_retention = args[:minimum_retention] if args.key?(:minimum_retention)
  @multi_tenant_only = args[:multi_tenant_only] if args.key?(:multi_tenant_only)
  @name = args[:name] if args.key?(:name)
  @os_license = args[:os_license] if args.key?(:os_license)
  @params = args[:params] if args.key?(:params)
  @removable_from_disk = args[:removable_from_disk] if args.key?(:removable_from_disk)
  @required_coattached_licenses = args[:required_coattached_licenses] if args.key?(:required_coattached_licenses)
  @resource_requirements = args[:resource_requirements] if args.key?(:resource_requirements)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @sole_tenant_only = args[:sole_tenant_only] if args.key?(:sole_tenant_only)
  @transferable = args[:transferable] if args.key?(:transferable)
  @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp)
end