Class: Google::Apis::ComputeV1::LicenseCode
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::LicenseCode
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a License Code resource. A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Instance Attribute Summary collapse
-
#allowed_replacement_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that can replace this license.
-
#appendable_to_disk ⇒ Boolean
(also: #appendable_to_disk?)
If true, this license can be appended to an existing disk's set of licenses.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#incompatible_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that are incompatible with this license.
-
#kind ⇒ String
Output only.
-
#license_alias ⇒ Array<Google::Apis::ComputeV1::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same License Code.
-
#minimum_retention ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#multi_tenant_only ⇒ Boolean
(also: #multi_tenant_only?)
If true, this license can only be used on VMs on multi tenant nodes.
-
#name ⇒ String
Output only.
-
#os_license ⇒ Boolean
(also: #os_license?)
If true, indicates this is an OS license.
-
#removable_from_disk ⇒ Boolean
(also: #removable_from_disk?)
If true, this license can be removed from a disk's set of licenses, with no replacement license needed.
-
#required_coattached_licenses ⇒ Array<String>
Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license.
-
#self_link ⇒ String
Output only.
-
#sole_tenant_only ⇒ Boolean
(also: #sole_tenant_only?)
If true, this license can only be used on VMs on sole tenant nodes.
-
#state ⇒ String
Output only.
-
#transferable ⇒ Boolean
(also: #transferable?)
Output only.
-
#update_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicenseCode
constructor
A new instance of LicenseCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicenseCode
Returns a new instance of LicenseCode.
33099 33100 33101 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_replacement_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that can replace this license. Note:
such replacements are allowed even if removable_from_disk is false.
Corresponds to the JSON property allowedReplacementLicenses
32981 32982 32983 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32981 def allowed_replacement_licenses @allowed_replacement_licenses end |
#appendable_to_disk ⇒ Boolean Also known as: appendable_to_disk?
If true, this license can be appended to an existing disk's set of
licenses.
Corresponds to the JSON property appendableToDisk
32987 32988 32989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32987 def appendable_to_disk @appendable_to_disk end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
32994 32995 32996 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32994 def @creation_timestamp end |
#description ⇒ String
Output only. [Output Only] Description of this License Code.
Corresponds to the JSON property description
32999 33000 33001 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32999 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
33006 33007 33008 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33006 def id @id end |
#incompatible_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that are incompatible with this license.
If a license is incompatible with this license, it cannot be attached to
the same disk or image.
Corresponds to the JSON property incompatibleLicenses
33013 33014 33015 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33013 def incompatible_licenses @incompatible_licenses end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#licenseCode for
licenses.
Corresponds to the JSON property kind
33019 33020 33021 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33019 def kind @kind end |
#license_alias ⇒ Array<Google::Apis::ComputeV1::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same
License Code.
Corresponds to the JSON property licenseAlias
33025 33026 33027 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33025 def license_alias @license_alias end |
#minimum_retention ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property minimumRetention
33033 33034 33035 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33033 def minimum_retention @minimum_retention end |
#multi_tenant_only ⇒ Boolean Also known as: multi_tenant_only?
If true, this license can only be used on VMs on multi tenant nodes.
Corresponds to the JSON property multiTenantOnly
33038 33039 33040 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33038 def multi_tenant_only @multi_tenant_only end |
#name ⇒ String
Output only. [Output Only] Name of the resource. The name is 1-20 characters
long and
must be a valid 64 bit integer.
Corresponds to the JSON property name
33046 33047 33048 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33046 def name @name end |
#os_license ⇒ Boolean Also known as: os_license?
If true, indicates this is an OS license. Only one OS license can be
attached to a disk or image at a time.
Corresponds to the JSON property osLicense
33052 33053 33054 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33052 def os_license @os_license end |
#removable_from_disk ⇒ Boolean Also known as: removable_from_disk?
If true, this license can be removed from a disk's set of licenses, with no
replacement license needed.
Corresponds to the JSON property removableFromDisk
33059 33060 33061 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33059 def removable_from_disk @removable_from_disk end |
#required_coattached_licenses ⇒ Array<String>
Specifies the set of permissible coattached licenseCodes of licenses that
satisfy the coattachment requirement of this license. At least one license
from the set must be attached to the same disk or image as this license.
Corresponds to the JSON property requiredCoattachedLicenses
33067 33068 33069 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33067 def required_coattached_licenses @required_coattached_licenses end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
33072 33073 33074 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33072 def self_link @self_link end |
#sole_tenant_only ⇒ Boolean Also known as: sole_tenant_only?
If true, this license can only be used on VMs on sole tenant nodes.
Corresponds to the JSON property soleTenantOnly
33077 33078 33079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33077 def sole_tenant_only @sole_tenant_only end |
#state ⇒ String
Output only. [Output Only] Current state of this License Code.
Corresponds to the JSON property state
33083 33084 33085 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33083 def state @state end |
#transferable ⇒ Boolean Also known as: transferable?
Output only. [Output Only] If true, the license will remain attached when
creating
images or snapshots from disks. Otherwise, the license is not transferred.
Corresponds to the JSON property transferable
33090 33091 33092 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33090 def transferable @transferable end |
#update_timestamp ⇒ String
Output only. [Output Only] Last update timestamp inRFC3339
text format.
Corresponds to the JSON property updateTimestamp
33097 33098 33099 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33097 def @update_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33104 33105 33106 33107 33108 33109 33110 33111 33112 33113 33114 33115 33116 33117 33118 33119 33120 33121 33122 33123 33124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33104 def update!(**args) @allowed_replacement_licenses = args[:allowed_replacement_licenses] if args.key?(:allowed_replacement_licenses) @appendable_to_disk = args[:appendable_to_disk] if args.key?(:appendable_to_disk) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @incompatible_licenses = args[:incompatible_licenses] if args.key?(:incompatible_licenses) @kind = args[:kind] if args.key?(:kind) @license_alias = args[:license_alias] if args.key?(:license_alias) @minimum_retention = args[:minimum_retention] if args.key?(:minimum_retention) @multi_tenant_only = args[:multi_tenant_only] if args.key?(:multi_tenant_only) @name = args[:name] if args.key?(:name) @os_license = args[:os_license] if args.key?(:os_license) @removable_from_disk = args[:removable_from_disk] if args.key?(:removable_from_disk) @required_coattached_licenses = args[:required_coattached_licenses] if args.key?(:required_coattached_licenses) @self_link = args[:self_link] if args.key?(:self_link) @sole_tenant_only = args[:sole_tenant_only] if args.key?(:sole_tenant_only) @state = args[:state] if args.key?(:state) @transferable = args[:transferable] if args.key?(:transferable) @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp) end |