Class: Google::Apis::ComputeV1::LicenseCode

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a License Code resource. A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicenseCode

Returns a new instance of LicenseCode.



29506
29507
29508
# File 'lib/google/apis/compute_v1/classes.rb', line 29506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


29455
29456
29457
# File 'lib/google/apis/compute_v1/classes.rb', line 29455

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Output only. [Output Only] Description of this License Code. Corresponds to the JSON property description

Returns:

  • (String)


29460
29461
29462
# File 'lib/google/apis/compute_v1/classes.rb', line 29460

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


29467
29468
29469
# File 'lib/google/apis/compute_v1/classes.rb', line 29467

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Always compute#licenseCode for licenses. Corresponds to the JSON property kind

Returns:

  • (String)


29473
29474
29475
# File 'lib/google/apis/compute_v1/classes.rb', line 29473

def kind
  @kind
end

#license_aliasArray<Google::Apis::ComputeV1::LicenseCodeLicenseAlias>

[Output Only] URL and description aliases of Licenses with the same License Code. Corresponds to the JSON property licenseAlias



29479
29480
29481
# File 'lib/google/apis/compute_v1/classes.rb', line 29479

def license_alias
  @license_alias
end

#nameString

Output only. [Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer. Corresponds to the JSON property name

Returns:

  • (String)


29486
29487
29488
# File 'lib/google/apis/compute_v1/classes.rb', line 29486

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29491
29492
29493
# File 'lib/google/apis/compute_v1/classes.rb', line 29491

def self_link
  @self_link
end

#stateString

Output only. [Output Only] Current state of this License Code. Corresponds to the JSON property state

Returns:

  • (String)


29496
29497
29498
# File 'lib/google/apis/compute_v1/classes.rb', line 29496

def state
  @state
end

#transferableBoolean Also known as: transferable?

Output only. [Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred. Corresponds to the JSON property transferable

Returns:

  • (Boolean)


29503
29504
29505
# File 'lib/google/apis/compute_v1/classes.rb', line 29503

def transferable
  @transferable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29511
29512
29513
29514
29515
29516
29517
29518
29519
29520
29521
# File 'lib/google/apis/compute_v1/classes.rb', line 29511

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @license_alias = args[:license_alias] if args.key?(:license_alias)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @state = args[:state] if args.key?(:state)
  @transferable = args[:transferable] if args.key?(:transferable)
end