Class: Google::Apis::ComputeV1::LicenseCode
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::LicenseCode
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a License Code resource. A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#license_alias ⇒ Array<Google::Apis::ComputeV1::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same License Code.
-
#name ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#transferable ⇒ Boolean
(also: #transferable?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicenseCode
constructor
A new instance of LicenseCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicenseCode
Returns a new instance of LicenseCode.
28763 28764 28765 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
28712 28713 28714 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28712 def @creation_timestamp end |
#description ⇒ String
Output only. [Output Only] Description of this License Code.
Corresponds to the JSON property description
28717 28718 28719 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28717 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
28724 28725 28726 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28724 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#licenseCode for
licenses.
Corresponds to the JSON property kind
28730 28731 28732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28730 def kind @kind end |
#license_alias ⇒ Array<Google::Apis::ComputeV1::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same
License Code.
Corresponds to the JSON property licenseAlias
28736 28737 28738 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28736 def license_alias @license_alias end |
#name ⇒ String
Output only. [Output Only] Name of the resource. The name is 1-20 characters
long and
must be a valid 64 bit integer.
Corresponds to the JSON property name
28743 28744 28745 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28743 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
28748 28749 28750 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28748 def self_link @self_link end |
#state ⇒ String
Output only. [Output Only] Current state of this License Code.
Corresponds to the JSON property state
28753 28754 28755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28753 def state @state end |
#transferable ⇒ Boolean Also known as: transferable?
Output only. [Output Only] If true, the license will remain attached when
creating
images or snapshots from disks. Otherwise, the license is not transferred.
Corresponds to the JSON property transferable
28760 28761 28762 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28760 def transferable @transferable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28768 28769 28770 28771 28772 28773 28774 28775 28776 28777 28778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28768 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @license_alias = args[:license_alias] if args.key?(:license_alias) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @state = args[:state] if args.key?(:state) @transferable = args[:transferable] if args.key?(:transferable) end |