Class: Google::Apis::ComputeV1::LicenseParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Additional license params.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicenseParams

Returns a new instance of LicenseParams.



33211
33212
33213
# File 'lib/google/apis/compute_v1/classes.rb', line 33211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the license. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


33209
33210
33211
# File 'lib/google/apis/compute_v1/classes.rb', line 33209

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33216
33217
33218
# File 'lib/google/apis/compute_v1/classes.rb', line 33216

def update!(**args)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end