Class: Google::Apis::ComputeV1::LicenseParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Additional license params.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicenseParams

Returns a new instance of LicenseParams.



29565
29566
29567
# File 'lib/google/apis/compute_v1/classes.rb', line 29565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the license. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/456` or in namespaced format such asorg_id|project_id/tag_key_short_nameand tag_value_short_name`. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON propertyresourceManagerTags`

Returns:

  • (Hash<String,String>)


29563
29564
29565
# File 'lib/google/apis/compute_v1/classes.rb', line 29563

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29570
29571
29572
# File 'lib/google/apis/compute_v1/classes.rb', line 29570

def update!(**args)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end