Class: Google::Apis::ComputeV1::LicensesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicensesListResponse

Returns a new instance of LicensesListResponse.



33665
33666
33667
# File 'lib/google/apis/compute_v1/classes.rb', line 33665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33638
33639
33640
# File 'lib/google/apis/compute_v1/classes.rb', line 33638

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::License>

A list of License resources. Corresponds to the JSON property items



33643
33644
33645
# File 'lib/google/apis/compute_v1/classes.rb', line 33643

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33653
33654
33655
# File 'lib/google/apis/compute_v1/classes.rb', line 33653

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33658
33659
33660
# File 'lib/google/apis/compute_v1/classes.rb', line 33658

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::LicensesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33663
33664
33665
# File 'lib/google/apis/compute_v1/classes.rb', line 33663

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33670
33671
33672
33673
33674
33675
33676
# File 'lib/google/apis/compute_v1/classes.rb', line 33670

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end