Class: Google::Apis::ComputeV1::LicensesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::LicensesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::License>
A list of License resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::LicensesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicensesListResponse
constructor
A new instance of LicensesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicensesListResponse
Returns a new instance of LicensesListResponse.
33271 33272 33273 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33244 33245 33246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33244 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::License>
A list of License resources.
Corresponds to the JSON property items
33249 33250 33251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33249 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33259 33260 33261 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33259 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33264 33265 33266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33264 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::LicensesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33269 33270 33271 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33269 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33276 33277 33278 33279 33280 33281 33282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33276 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |