Class: Google::Apis::ComputeV1::LicensesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicensesListResponse

Returns a new instance of LicensesListResponse.



33073
33074
33075
# File 'lib/google/apis/compute_v1/classes.rb', line 33073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33046
33047
33048
# File 'lib/google/apis/compute_v1/classes.rb', line 33046

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::License>

A list of License resources. Corresponds to the JSON property items



33051
33052
33053
# File 'lib/google/apis/compute_v1/classes.rb', line 33051

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33061
33062
33063
# File 'lib/google/apis/compute_v1/classes.rb', line 33061

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33066
33067
33068
# File 'lib/google/apis/compute_v1/classes.rb', line 33066

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::LicensesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33071
33072
33073
# File 'lib/google/apis/compute_v1/classes.rb', line 33071

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33078
33079
33080
33081
33082
33083
33084
# File 'lib/google/apis/compute_v1/classes.rb', line 33078

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end