Class: Google::Apis::ComputeV1::ListInstantSnapshotGroups
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ListInstantSnapshotGroups
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of InstantSnapshotGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInstantSnapshotGroups
constructor
A new instance of ListInstantSnapshotGroups.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInstantSnapshotGroups
Returns a new instance of ListInstantSnapshotGroups.
33799 33800 33801 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
33756 33757 33758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33756 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33761 33762 33763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33761 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
Corresponds to the JSON property items
33766 33767 33768 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33766 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
33771 33772 33773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33771 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33781 33782 33783 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33781 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33786 33787 33788 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33786 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
33792 33793 33794 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33792 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33797 33798 33799 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33797 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33804 33805 33806 33807 33808 33809 33810 33811 33812 33813 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33804 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |