Class: Google::Apis::ComputeV1::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



33447
33448
33449
# File 'lib/google/apis/compute_v1/classes.rb', line 33447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33404
33405
33406
# File 'lib/google/apis/compute_v1/classes.rb', line 33404

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33409
33410
33411
# File 'lib/google/apis/compute_v1/classes.rb', line 33409

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



33414
33415
33416
# File 'lib/google/apis/compute_v1/classes.rb', line 33414

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


33419
33420
33421
# File 'lib/google/apis/compute_v1/classes.rb', line 33419

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33429
33430
33431
# File 'lib/google/apis/compute_v1/classes.rb', line 33429

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33434
33435
33436
# File 'lib/google/apis/compute_v1/classes.rb', line 33434

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33440
33441
33442
# File 'lib/google/apis/compute_v1/classes.rb', line 33440

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33445
33446
33447
# File 'lib/google/apis/compute_v1/classes.rb', line 33445

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33452
33453
33454
33455
33456
33457
33458
33459
33460
33461
# File 'lib/google/apis/compute_v1/classes.rb', line 33452

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end