Class: Google::Apis::ComputeV1::ListInstantSnapshotGroups
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ListInstantSnapshotGroups
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of InstantSnapshotGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInstantSnapshotGroups
constructor
A new instance of ListInstantSnapshotGroups.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInstantSnapshotGroups
Returns a new instance of ListInstantSnapshotGroups.
33404 33405 33406 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33404 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
33361 33362 33363 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33361 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33366 33367 33368 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33366 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
Corresponds to the JSON property items
33371 33372 33373 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33371 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
33376 33377 33378 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33376 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33386 33387 33388 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33386 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33391 33392 33393 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33391 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
33397 33398 33399 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33397 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33402 33403 33404 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33402 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33409 33410 33411 33412 33413 33414 33415 33416 33417 33418 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33409 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |