Class: Google::Apis::ComputeV1::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



33405
33406
33407
# File 'lib/google/apis/compute_v1/classes.rb', line 33405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33362
33363
33364
# File 'lib/google/apis/compute_v1/classes.rb', line 33362

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33367
33368
33369
# File 'lib/google/apis/compute_v1/classes.rb', line 33367

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



33372
33373
33374
# File 'lib/google/apis/compute_v1/classes.rb', line 33372

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


33377
33378
33379
# File 'lib/google/apis/compute_v1/classes.rb', line 33377

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33387
33388
33389
# File 'lib/google/apis/compute_v1/classes.rb', line 33387

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33392
33393
33394
# File 'lib/google/apis/compute_v1/classes.rb', line 33392

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33398
33399
33400
# File 'lib/google/apis/compute_v1/classes.rb', line 33398

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33403
33404
33405
# File 'lib/google/apis/compute_v1/classes.rb', line 33403

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33410
33411
33412
33413
33414
33415
33416
33417
33418
33419
# File 'lib/google/apis/compute_v1/classes.rb', line 33410

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end