Class: Google::Apis::ComputeV1::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



33215
33216
33217
# File 'lib/google/apis/compute_v1/classes.rb', line 33215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33172
33173
33174
# File 'lib/google/apis/compute_v1/classes.rb', line 33172

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33177
33178
33179
# File 'lib/google/apis/compute_v1/classes.rb', line 33177

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



33182
33183
33184
# File 'lib/google/apis/compute_v1/classes.rb', line 33182

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


33187
33188
33189
# File 'lib/google/apis/compute_v1/classes.rb', line 33187

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33197
33198
33199
# File 'lib/google/apis/compute_v1/classes.rb', line 33197

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33202
33203
33204
# File 'lib/google/apis/compute_v1/classes.rb', line 33202

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33208
33209
33210
# File 'lib/google/apis/compute_v1/classes.rb', line 33208

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33213
33214
33215
# File 'lib/google/apis/compute_v1/classes.rb', line 33213

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33220
33221
33222
33223
33224
33225
33226
33227
33228
33229
# File 'lib/google/apis/compute_v1/classes.rb', line 33220

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end