Class: Google::Apis::ComputeV1::LocationPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::LocationPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Configuration for location policy among multiple possible locations (e.g. preferences for zone selection among zones in a single region).
Instance Attribute Summary collapse
-
#locations ⇒ Hash<String,Google::Apis::ComputeV1::LocationPolicyLocation>
Location configurations mapped by location name.
-
#target_shape ⇒ String
Strategy for distributing VMs across zones in a region.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationPolicy
constructor
A new instance of LocationPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationPolicy
Returns a new instance of LocationPolicy.
29087 29088 29089 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Hash<String,Google::Apis::ComputeV1::LocationPolicyLocation>
Location configurations mapped by location name.
Currently only zone names are supported and must be represented as valid
internal URLs, such as zones/us-central1-a.
Corresponds to the JSON property locations
29080 29081 29082 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29080 def locations @locations end |
#target_shape ⇒ String
Strategy for distributing VMs across zones in a region.
Corresponds to the JSON property targetShape
29085 29086 29087 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29085 def target_shape @target_shape end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29092 29093 29094 29095 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29092 def update!(**args) @locations = args[:locations] if args.key?(:locations) @target_shape = args[:target_shape] if args.key?(:target_shape) end |