Class: Google::Apis::ComputeV1::MachineImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::MachineImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of machine images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::MachineImage>
A list of MachineImage resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::MachineImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineImageList
constructor
A new instance of MachineImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineImageList
Returns a new instance of MachineImageList.
33896 33897 33898 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33863 33864 33865 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33863 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::MachineImage>
A list of MachineImage resources.
Corresponds to the JSON property items
33868 33869 33870 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33868 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
machineImagesListResponse for machine image lists.
Corresponds to the JSON property kind
33874 33875 33876 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33874 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33884 33885 33886 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33884 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33889 33890 33891 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33889 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::MachineImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33894 33895 33896 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33894 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33901 33902 33903 33904 33905 33906 33907 33908 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33901 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |