Class: Google::Apis::ComputeV1::MachineImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::MachineImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of machine images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::MachineImage>
A list of MachineImage resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::MachineImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineImageList
constructor
A new instance of MachineImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineImageList
Returns a new instance of MachineImageList.
33707 33708 33709 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33674 33675 33676 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33674 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::MachineImage>
A list of MachineImage resources.
Corresponds to the JSON property items
33679 33680 33681 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33679 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
machineImagesListResponse for machine image lists.
Corresponds to the JSON property kind
33685 33686 33687 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33685 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33695 33696 33697 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33695 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33700 33701 33702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33700 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::MachineImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33705 33706 33707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33705 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33712 33713 33714 33715 33716 33717 33718 33719 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33712 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |