Class: Google::Apis::ComputeV1::MachineImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of machine images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageList

Returns a new instance of MachineImageList.



33118
33119
33120
# File 'lib/google/apis/compute_v1/classes.rb', line 33118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33085
33086
33087
# File 'lib/google/apis/compute_v1/classes.rb', line 33085

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::MachineImage>

A list of MachineImage resources. Corresponds to the JSON property items



33090
33091
33092
# File 'lib/google/apis/compute_v1/classes.rb', line 33090

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImagesListResponse for machine image lists. Corresponds to the JSON property kind

Returns:

  • (String)


33096
33097
33098
# File 'lib/google/apis/compute_v1/classes.rb', line 33096

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33106
33107
33108
# File 'lib/google/apis/compute_v1/classes.rb', line 33106

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33111
33112
33113
# File 'lib/google/apis/compute_v1/classes.rb', line 33111

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::MachineImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33116
33117
33118
# File 'lib/google/apis/compute_v1/classes.rb', line 33116

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33123
33124
33125
33126
33127
33128
33129
33130
# File 'lib/google/apis/compute_v1/classes.rb', line 33123

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end