Class: Google::Apis::ComputeV1::MachineImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of machine images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageList

Returns a new instance of MachineImageList.



18128
18129
18130
# File 'lib/google/apis/compute_v1/classes.rb', line 18128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18096
18097
18098
# File 'lib/google/apis/compute_v1/classes.rb', line 18096

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::MachineImage>

A list of MachineImage resources. Corresponds to the JSON property items



18101
18102
18103
# File 'lib/google/apis/compute_v1/classes.rb', line 18101

def items
  @items
end

#kindString

[Output Only] The resource type, which is always compute# machineImagesListResponse for machine image lists. Corresponds to the JSON property kind

Returns:

  • (String)


18107
18108
18109
# File 'lib/google/apis/compute_v1/classes.rb', line 18107

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18116
18117
18118
# File 'lib/google/apis/compute_v1/classes.rb', line 18116

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18121
18122
18123
# File 'lib/google/apis/compute_v1/classes.rb', line 18121

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::MachineImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18126
18127
18128
# File 'lib/google/apis/compute_v1/classes.rb', line 18126

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18133
18134
18135
18136
18137
18138
18139
18140
# File 'lib/google/apis/compute_v1/classes.rb', line 18133

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end