Class: Google::Apis::ComputeV1::MachineType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.

Defined Under Namespace

Classes: Accelerator

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineType

Returns a new instance of MachineType.



34144
34145
34146
# File 'lib/google/apis/compute_v1/classes.rb', line 34144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ComputeV1::MachineType::Accelerator>

[Output Only] A list of accelerator configurations assigned to this machine type. Corresponds to the JSON property accelerators



34052
34053
34054
# File 'lib/google/apis/compute_v1/classes.rb', line 34052

def accelerators
  @accelerators
end

#architectureString

[Output Only] The architecture of the machine type. Corresponds to the JSON property architecture

Returns:

  • (String)


34057
34058
34059
# File 'lib/google/apis/compute_v1/classes.rb', line 34057

def architecture
  @architecture
end

#bundled_local_ssdsGoogle::Apis::ComputeV1::BundledLocalSsds

[Output Only] The configuration of bundled local SSD for the machine type. Corresponds to the JSON property bundledLocalSsds



34062
34063
34064
# File 'lib/google/apis/compute_v1/classes.rb', line 34062

def bundled_local_ssds
  @bundled_local_ssds
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


34068
34069
34070
# File 'lib/google/apis/compute_v1/classes.rb', line 34068

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeV1::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



34073
34074
34075
# File 'lib/google/apis/compute_v1/classes.rb', line 34073

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


34078
34079
34080
# File 'lib/google/apis/compute_v1/classes.rb', line 34078

def description
  @description
end

#guest_cpusFixnum

[Output Only] The number of virtual CPUs that are available to the instance. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


34084
34085
34086
# File 'lib/google/apis/compute_v1/classes.rb', line 34084

def guest_cpus
  @guest_cpus
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


34090
34091
34092
# File 'lib/google/apis/compute_v1/classes.rb', line 34090

def id
  @id
end

#image_space_gbFixnum

[Deprecated] This property is deprecated and will never be populated with any relevant values. Corresponds to the JSON property imageSpaceGb

Returns:

  • (Fixnum)


34096
34097
34098
# File 'lib/google/apis/compute_v1/classes.rb', line 34096

def image_space_gb
  @image_space_gb
end

#is_shared_cpuBoolean Also known as: is_shared_cpu?

[Output Only] Whether this machine type has a shared CPU. SeeShared-core machine types for more information. Corresponds to the JSON property isSharedCpu

Returns:

  • (Boolean)


34103
34104
34105
# File 'lib/google/apis/compute_v1/classes.rb', line 34103

def is_shared_cpu
  @is_shared_cpu
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#machineType for machine types. Corresponds to the JSON property kind

Returns:

  • (String)


34110
34111
34112
# File 'lib/google/apis/compute_v1/classes.rb', line 34110

def kind
  @kind
end

#maximum_persistent_disksFixnum

[Output Only] Maximum persistent disks allowed. Corresponds to the JSON property maximumPersistentDisks

Returns:

  • (Fixnum)


34115
34116
34117
# File 'lib/google/apis/compute_v1/classes.rb', line 34115

def maximum_persistent_disks
  @maximum_persistent_disks
end

#maximum_persistent_disks_size_gbFixnum

[Output Only] Maximum total persistent disks size (GB) allowed. Corresponds to the JSON property maximumPersistentDisksSizeGb

Returns:

  • (Fixnum)


34120
34121
34122
# File 'lib/google/apis/compute_v1/classes.rb', line 34120

def maximum_persistent_disks_size_gb
  @maximum_persistent_disks_size_gb
end

#memory_mbFixnum

[Output Only] The amount of physical memory available to the instance, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


34126
34127
34128
# File 'lib/google/apis/compute_v1/classes.rb', line 34126

def memory_mb
  @memory_mb
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


34131
34132
34133
# File 'lib/google/apis/compute_v1/classes.rb', line 34131

def name
  @name
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34136
34137
34138
# File 'lib/google/apis/compute_v1/classes.rb', line 34136

def self_link
  @self_link
end

#zoneString

[Output Only] The name of the zone where the machine type resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


34142
34143
34144
# File 'lib/google/apis/compute_v1/classes.rb', line 34142

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34149
34150
34151
34152
34153
34154
34155
34156
34157
34158
34159
34160
34161
34162
34163
34164
34165
34166
34167
# File 'lib/google/apis/compute_v1/classes.rb', line 34149

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @architecture = args[:architecture] if args.key?(:architecture)
  @bundled_local_ssds = args[:bundled_local_ssds] if args.key?(:bundled_local_ssds)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @id = args[:id] if args.key?(:id)
  @image_space_gb = args[:image_space_gb] if args.key?(:image_space_gb)
  @is_shared_cpu = args[:is_shared_cpu] if args.key?(:is_shared_cpu)
  @kind = args[:kind] if args.key?(:kind)
  @maximum_persistent_disks = args[:maximum_persistent_disks] if args.key?(:maximum_persistent_disks)
  @maximum_persistent_disks_size_gb = args[:maximum_persistent_disks_size_gb] if args.key?(:maximum_persistent_disks_size_gb)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @zone = args[:zone] if args.key?(:zone)
end