Class: Google::Apis::ComputeV1::MachineType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::MachineType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.
Defined Under Namespace
Classes: Accelerator
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::ComputeV1::MachineType::Accelerator>
[Output Only] A list of accelerator configurations assigned to this machine type.
-
#architecture ⇒ String
[Output Only] The architecture of the machine type.
-
#bundled_local_ssds ⇒ Google::Apis::ComputeV1::BundledLocalSsds
[Output Only] The configuration of bundled local SSD for the machine type.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional textual description of the resource.
-
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the instance.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#image_space_gb ⇒ Fixnum
[Deprecated] This property is deprecated and will never be populated with any relevant values.
-
#is_shared_cpu ⇒ Boolean
(also: #is_shared_cpu?)
[Output Only] Whether this machine type has a shared CPU.
-
#kind ⇒ String
Output only.
-
#maximum_persistent_disks ⇒ Fixnum
[Output Only] Maximum persistent disks allowed.
-
#maximum_persistent_disks_size_gb ⇒ Fixnum
[Output Only] Maximum total persistent disks size (GB) allowed.
-
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the instance, defined in MB.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#zone ⇒ String
[Output Only] The name of the zone where the machine type resides, such as us-central1-a.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineType
constructor
A new instance of MachineType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineType
Returns a new instance of MachineType.
30369 30370 30371 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::ComputeV1::MachineType::Accelerator>
[Output Only] A list of accelerator configurations assigned to this
machine type.
Corresponds to the JSON property accelerators
30277 30278 30279 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30277 def accelerators @accelerators end |
#architecture ⇒ String
[Output Only] The architecture of the machine type.
Corresponds to the JSON property architecture
30282 30283 30284 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30282 def architecture @architecture end |
#bundled_local_ssds ⇒ Google::Apis::ComputeV1::BundledLocalSsds
[Output Only] The configuration of bundled local SSD for the machine type.
Corresponds to the JSON property bundledLocalSsds
30287 30288 30289 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30287 def bundled_local_ssds @bundled_local_ssds end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
30293 30294 30295 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30293 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
30298 30299 30300 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30298 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional textual description of the resource.
Corresponds to the JSON property description
30303 30304 30305 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30303 def description @description end |
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the
instance.
Corresponds to the JSON property guestCpus
30309 30310 30311 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30309 def guest_cpus @guest_cpus end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
30315 30316 30317 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30315 def id @id end |
#image_space_gb ⇒ Fixnum
[Deprecated] This property is deprecated and will never be populated with
any relevant values.
Corresponds to the JSON property imageSpaceGb
30321 30322 30323 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30321 def image_space_gb @image_space_gb end |
#is_shared_cpu ⇒ Boolean Also known as:
[Output Only] Whether this machine type has a shared CPU. SeeShared-core
machine
types for more information.
Corresponds to the JSON property isSharedCpu
30328 30329 30330 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30328 def is_shared_cpu @is_shared_cpu end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#machineType
for machine types.
Corresponds to the JSON property kind
30335 30336 30337 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30335 def kind @kind end |
#maximum_persistent_disks ⇒ Fixnum
[Output Only] Maximum persistent disks allowed.
Corresponds to the JSON property maximumPersistentDisks
30340 30341 30342 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30340 def maximum_persistent_disks @maximum_persistent_disks end |
#maximum_persistent_disks_size_gb ⇒ Fixnum
[Output Only] Maximum total persistent disks size (GB) allowed.
Corresponds to the JSON property maximumPersistentDisksSizeGb
30345 30346 30347 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30345 def maximum_persistent_disks_size_gb @maximum_persistent_disks_size_gb end |
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the instance,
defined in MB.
Corresponds to the JSON property memoryMb
30351 30352 30353 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30351 def memory_mb @memory_mb end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
30356 30357 30358 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30356 def name @name end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
30361 30362 30363 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30361 def self_link @self_link end |
#zone ⇒ String
[Output Only] The name of the zone where the machine type resides,
such as us-central1-a.
Corresponds to the JSON property zone
30367 30368 30369 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30367 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30374 30375 30376 30377 30378 30379 30380 30381 30382 30383 30384 30385 30386 30387 30388 30389 30390 30391 30392 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30374 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @architecture = args[:architecture] if args.key?(:architecture) @bundled_local_ssds = args[:bundled_local_ssds] if args.key?(:bundled_local_ssds) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus) @id = args[:id] if args.key?(:id) @image_space_gb = args[:image_space_gb] if args.key?(:image_space_gb) @is_shared_cpu = args[:is_shared_cpu] if args.key?(:is_shared_cpu) @kind = args[:kind] if args.key?(:kind) @maximum_persistent_disks = args[:maximum_persistent_disks] if args.key?(:maximum_persistent_disks) @maximum_persistent_disks_size_gb = args[:maximum_persistent_disks_size_gb] if args.key?(:maximum_persistent_disks_size_gb) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @zone = args[:zone] if args.key?(:zone) end |