Class: Google::Apis::ComputeV1::MachineType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.

Defined Under Namespace

Classes: Accelerator

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineType

Returns a new instance of MachineType.



29552
29553
29554
# File 'lib/google/apis/compute_v1/classes.rb', line 29552

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ComputeV1::MachineType::Accelerator>

[Output Only] A list of accelerator configurations assigned to this machine type. Corresponds to the JSON property accelerators



29465
29466
29467
# File 'lib/google/apis/compute_v1/classes.rb', line 29465

def accelerators
  @accelerators
end

#architectureString

[Output Only] The architecture of the machine type. Corresponds to the JSON property architecture

Returns:

  • (String)


29470
29471
29472
# File 'lib/google/apis/compute_v1/classes.rb', line 29470

def architecture
  @architecture
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


29476
29477
29478
# File 'lib/google/apis/compute_v1/classes.rb', line 29476

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeV1::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



29481
29482
29483
# File 'lib/google/apis/compute_v1/classes.rb', line 29481

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


29486
29487
29488
# File 'lib/google/apis/compute_v1/classes.rb', line 29486

def description
  @description
end

#guest_cpusFixnum

[Output Only] The number of virtual CPUs that are available to the instance. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


29492
29493
29494
# File 'lib/google/apis/compute_v1/classes.rb', line 29492

def guest_cpus
  @guest_cpus
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


29498
29499
29500
# File 'lib/google/apis/compute_v1/classes.rb', line 29498

def id
  @id
end

#image_space_gbFixnum

[Deprecated] This property is deprecated and will never be populated with any relevant values. Corresponds to the JSON property imageSpaceGb

Returns:

  • (Fixnum)


29504
29505
29506
# File 'lib/google/apis/compute_v1/classes.rb', line 29504

def image_space_gb
  @image_space_gb
end

#is_shared_cpuBoolean Also known as: is_shared_cpu?

[Output Only] Whether this machine type has a shared CPU. SeeShared-core machine types for more information. Corresponds to the JSON property isSharedCpu

Returns:

  • (Boolean)


29511
29512
29513
# File 'lib/google/apis/compute_v1/classes.rb', line 29511

def is_shared_cpu
  @is_shared_cpu
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#machineType for machine types. Corresponds to the JSON property kind

Returns:

  • (String)


29518
29519
29520
# File 'lib/google/apis/compute_v1/classes.rb', line 29518

def kind
  @kind
end

#maximum_persistent_disksFixnum

[Output Only] Maximum persistent disks allowed. Corresponds to the JSON property maximumPersistentDisks

Returns:

  • (Fixnum)


29523
29524
29525
# File 'lib/google/apis/compute_v1/classes.rb', line 29523

def maximum_persistent_disks
  @maximum_persistent_disks
end

#maximum_persistent_disks_size_gbFixnum

[Output Only] Maximum total persistent disks size (GB) allowed. Corresponds to the JSON property maximumPersistentDisksSizeGb

Returns:

  • (Fixnum)


29528
29529
29530
# File 'lib/google/apis/compute_v1/classes.rb', line 29528

def maximum_persistent_disks_size_gb
  @maximum_persistent_disks_size_gb
end

#memory_mbFixnum

[Output Only] The amount of physical memory available to the instance, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


29534
29535
29536
# File 'lib/google/apis/compute_v1/classes.rb', line 29534

def memory_mb
  @memory_mb
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


29539
29540
29541
# File 'lib/google/apis/compute_v1/classes.rb', line 29539

def name
  @name
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29544
29545
29546
# File 'lib/google/apis/compute_v1/classes.rb', line 29544

def self_link
  @self_link
end

#zoneString

[Output Only] The name of the zone where the machine type resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


29550
29551
29552
# File 'lib/google/apis/compute_v1/classes.rb', line 29550

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29557
29558
29559
29560
29561
29562
29563
29564
29565
29566
29567
29568
29569
29570
29571
29572
29573
29574
# File 'lib/google/apis/compute_v1/classes.rb', line 29557

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @architecture = args[:architecture] if args.key?(:architecture)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @id = args[:id] if args.key?(:id)
  @image_space_gb = args[:image_space_gb] if args.key?(:image_space_gb)
  @is_shared_cpu = args[:is_shared_cpu] if args.key?(:is_shared_cpu)
  @kind = args[:kind] if args.key?(:kind)
  @maximum_persistent_disks = args[:maximum_persistent_disks] if args.key?(:maximum_persistent_disks)
  @maximum_persistent_disks_size_gb = args[:maximum_persistent_disks_size_gb] if args.key?(:maximum_persistent_disks_size_gb)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @zone = args[:zone] if args.key?(:zone)
end