Class: Google::Apis::ComputeV1::ManagedInstance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A Managed Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstance

Returns a new instance of ManagedInstance.



35019
35020
35021
# File 'lib/google/apis/compute_v1/classes.rb', line 35019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_actionString

Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:

  • NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
  • CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
  • CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
  • RECREATING The managed instance group is recreating this instance.
  • DELETING The managed instance group is permanently deleting this instance.
  • ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
  • RESTARTING The managed instance group is restarting the instance.
  • REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
  • VERIFYING The managed instance group has created the instance and it is in the process of being verified. Corresponds to the JSON property currentAction

Returns:

  • (String)


34943
34944
34945
# File 'lib/google/apis/compute_v1/classes.rb', line 34943

def current_action
  @current_action
end

#idFixnum

Output only. [Output only] The unique identifier for this resource. This field is empty when instance does not exist. Corresponds to the JSON property id

Returns:

  • (Fixnum)


34950
34951
34952
# File 'lib/google/apis/compute_v1/classes.rb', line 34950

def id
  @id
end

#instanceString

Output only. [Output Only] The URL of the instance. The URL can exist even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


34957
34958
34959
# File 'lib/google/apis/compute_v1/classes.rb', line 34957

def instance
  @instance
end

#instance_healthArray<Google::Apis::ComputeV1::ManagedInstanceInstanceHealth>

Output only. [Output Only] Health state of the instance per health-check. Corresponds to the JSON property instanceHealth



34962
34963
34964
# File 'lib/google/apis/compute_v1/classes.rb', line 34962

def instance_health
  @instance_health
end

#instance_statusString

Output only. [Output Only] The status of the instance. This field is empty when the instance does not exist. Corresponds to the JSON property instanceStatus

Returns:

  • (String)


34969
34970
34971
# File 'lib/google/apis/compute_v1/classes.rb', line 34969

def instance_status
  @instance_status
end

#last_attemptGoogle::Apis::ComputeV1::ManagedInstanceLastAttempt

Output only. [Output Only] Information about the last attempt to create or delete the instance. Corresponds to the JSON property lastAttempt



34976
34977
34978
# File 'lib/google/apis/compute_v1/classes.rb', line 34976

def last_attempt
  @last_attempt
end

#nameString

Output only. [Output Only] The name of the instance. The name always exists even if the instance has not yet been created. Corresponds to the JSON property name

Returns:

  • (String)


34983
34984
34985
# File 'lib/google/apis/compute_v1/classes.rb', line 34983

def name
  @name
end

#preserved_state_from_configGoogle::Apis::ComputeV1::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromConfig



34988
34989
34990
# File 'lib/google/apis/compute_v1/classes.rb', line 34988

def preserved_state_from_config
  @preserved_state_from_config
end

#preserved_state_from_policyGoogle::Apis::ComputeV1::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromPolicy



34993
34994
34995
# File 'lib/google/apis/compute_v1/classes.rb', line 34993

def preserved_state_from_policy
  @preserved_state_from_policy
end

#properties_from_flexibility_policyGoogle::Apis::ComputeV1::ManagedInstancePropertiesFromFlexibilityPolicy

Output only. [Output Only] Instance properties selected for this instance resulting from InstanceFlexibilityPolicy. Corresponds to the JSON property propertiesFromFlexibilityPolicy



35000
35001
35002
# File 'lib/google/apis/compute_v1/classes.rb', line 35000

def properties_from_flexibility_policy
  @properties_from_flexibility_policy
end

#schedulingGoogle::Apis::ComputeV1::ManagedInstanceScheduling

Output only. Information about the termination timestamp of the instance, if applicable. Corresponds to the JSON property scheduling



35006
35007
35008
# File 'lib/google/apis/compute_v1/classes.rb', line 35006

def scheduling
  @scheduling
end

#shutdown_detailsGoogle::Apis::ComputeV1::ManagedInstanceShutdownDetails

Output only. Specifies the graceful shutdown details if the instance is in PENDING_STOP state or there is a programmed stop scheduled. Corresponds to the JSON property shutdownDetails



35012
35013
35014
# File 'lib/google/apis/compute_v1/classes.rb', line 35012

def shutdown_details
  @shutdown_details
end

#versionGoogle::Apis::ComputeV1::ManagedInstanceVersion

Output only. [Output Only] Intended version of this instance. Corresponds to the JSON property version



35017
35018
35019
# File 'lib/google/apis/compute_v1/classes.rb', line 35017

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35024
35025
35026
35027
35028
35029
35030
35031
35032
35033
35034
35035
35036
35037
35038
# File 'lib/google/apis/compute_v1/classes.rb', line 35024

def update!(**args)
  @current_action = args[:current_action] if args.key?(:current_action)
  @id = args[:id] if args.key?(:id)
  @instance = args[:instance] if args.key?(:instance)
  @instance_health = args[:instance_health] if args.key?(:instance_health)
  @instance_status = args[:instance_status] if args.key?(:instance_status)
  @last_attempt = args[:last_attempt] if args.key?(:last_attempt)
  @name = args[:name] if args.key?(:name)
  @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config)
  @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy)
  @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details)
  @version = args[:version] if args.key?(:version)
end