Class: Google::Apis::ComputeV1::ManagedInstance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A Managed Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstance

Returns a new instance of ManagedInstance.



34659
34660
34661
# File 'lib/google/apis/compute_v1/classes.rb', line 34659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_actionString

Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:

  • NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
  • CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
  • CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
  • RECREATING The managed instance group is recreating this instance.
  • DELETING The managed instance group is permanently deleting this instance.
  • ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
  • RESTARTING The managed instance group is restarting the instance.
  • REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
  • VERIFYING The managed instance group has created the instance and it is in the process of being verified. Corresponds to the JSON property currentAction

Returns:

  • (String)


34583
34584
34585
# File 'lib/google/apis/compute_v1/classes.rb', line 34583

def current_action
  @current_action
end

#idFixnum

Output only. [Output only] The unique identifier for this resource. This field is empty when instance does not exist. Corresponds to the JSON property id

Returns:

  • (Fixnum)


34590
34591
34592
# File 'lib/google/apis/compute_v1/classes.rb', line 34590

def id
  @id
end

#instanceString

Output only. [Output Only] The URL of the instance. The URL can exist even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


34597
34598
34599
# File 'lib/google/apis/compute_v1/classes.rb', line 34597

def instance
  @instance
end

#instance_healthArray<Google::Apis::ComputeV1::ManagedInstanceInstanceHealth>

Output only. [Output Only] Health state of the instance per health-check. Corresponds to the JSON property instanceHealth



34602
34603
34604
# File 'lib/google/apis/compute_v1/classes.rb', line 34602

def instance_health
  @instance_health
end

#instance_statusString

Output only. [Output Only] The status of the instance. This field is empty when the instance does not exist. Corresponds to the JSON property instanceStatus

Returns:

  • (String)


34609
34610
34611
# File 'lib/google/apis/compute_v1/classes.rb', line 34609

def instance_status
  @instance_status
end

#last_attemptGoogle::Apis::ComputeV1::ManagedInstanceLastAttempt

Output only. [Output Only] Information about the last attempt to create or delete the instance. Corresponds to the JSON property lastAttempt



34616
34617
34618
# File 'lib/google/apis/compute_v1/classes.rb', line 34616

def last_attempt
  @last_attempt
end

#nameString

Output only. [Output Only] The name of the instance. The name always exists even if the instance has not yet been created. Corresponds to the JSON property name

Returns:

  • (String)


34623
34624
34625
# File 'lib/google/apis/compute_v1/classes.rb', line 34623

def name
  @name
end

#preserved_state_from_configGoogle::Apis::ComputeV1::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromConfig



34628
34629
34630
# File 'lib/google/apis/compute_v1/classes.rb', line 34628

def preserved_state_from_config
  @preserved_state_from_config
end

#preserved_state_from_policyGoogle::Apis::ComputeV1::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromPolicy



34633
34634
34635
# File 'lib/google/apis/compute_v1/classes.rb', line 34633

def preserved_state_from_policy
  @preserved_state_from_policy
end

#properties_from_flexibility_policyGoogle::Apis::ComputeV1::ManagedInstancePropertiesFromFlexibilityPolicy

Output only. [Output Only] Instance properties selected for this instance resulting from InstanceFlexibilityPolicy. Corresponds to the JSON property propertiesFromFlexibilityPolicy



34640
34641
34642
# File 'lib/google/apis/compute_v1/classes.rb', line 34640

def properties_from_flexibility_policy
  @properties_from_flexibility_policy
end

#schedulingGoogle::Apis::ComputeV1::ManagedInstanceScheduling

Output only. Information about the termination timestamp of the instance, if applicable. Corresponds to the JSON property scheduling



34646
34647
34648
# File 'lib/google/apis/compute_v1/classes.rb', line 34646

def scheduling
  @scheduling
end

#shutdown_detailsGoogle::Apis::ComputeV1::ManagedInstanceShutdownDetails

Output only. Specifies the graceful shutdown details if the instance is in PENDING_STOP state or there is a programmed stop scheduled. Corresponds to the JSON property shutdownDetails



34652
34653
34654
# File 'lib/google/apis/compute_v1/classes.rb', line 34652

def shutdown_details
  @shutdown_details
end

#versionGoogle::Apis::ComputeV1::ManagedInstanceVersion

Output only. [Output Only] Intended version of this instance. Corresponds to the JSON property version



34657
34658
34659
# File 'lib/google/apis/compute_v1/classes.rb', line 34657

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34664
34665
34666
34667
34668
34669
34670
34671
34672
34673
34674
34675
34676
34677
34678
# File 'lib/google/apis/compute_v1/classes.rb', line 34664

def update!(**args)
  @current_action = args[:current_action] if args.key?(:current_action)
  @id = args[:id] if args.key?(:id)
  @instance = args[:instance] if args.key?(:instance)
  @instance_health = args[:instance_health] if args.key?(:instance_health)
  @instance_status = args[:instance_status] if args.key?(:instance_status)
  @last_attempt = args[:last_attempt] if args.key?(:last_attempt)
  @name = args[:name] if args.key?(:name)
  @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config)
  @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy)
  @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details)
  @version = args[:version] if args.key?(:version)
end