Class: Google::Apis::ComputeV1::ManagedInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ManagedInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A Managed Instance resource.
Instance Attribute Summary collapse
-
#current_action ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#instance ⇒ String
Output only.
-
#instance_health ⇒ Array<Google::Apis::ComputeV1::ManagedInstanceInstanceHealth>
Output only.
-
#instance_status ⇒ String
Output only.
-
#last_attempt ⇒ Google::Apis::ComputeV1::ManagedInstanceLastAttempt
Output only.
-
#name ⇒ String
Output only.
-
#preserved_state_from_config ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
-
#preserved_state_from_policy ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
-
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeV1::ManagedInstancePropertiesFromFlexibilityPolicy
Output only.
-
#version ⇒ Google::Apis::ComputeV1::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstance
constructor
A new instance of ManagedInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstance
Returns a new instance of ManagedInstance.
30872 30873 30874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_action ⇒ String
Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:
- NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
- CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
- CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
- RECREATING The managed instance group is recreating this instance.
- DELETING The managed instance group is permanently deleting this instance.
- ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
- RESTARTING The managed instance group is restarting the instance.
- REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
- VERIFYING The managed instance group has created the
instance and it is in the process of being verified.
Corresponds to the JSON property
currentAction
30808 30809 30810 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30808 def current_action @current_action end |
#id ⇒ Fixnum
Output only. [Output only] The unique identifier for this resource. This field
is empty
when instance does not exist.
Corresponds to the JSON property id
30815 30816 30817 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30815 def id @id end |
#instance ⇒ String
Output only. [Output Only] The URL of the instance. The URL can exist even if
the
instance has not yet been created.
Corresponds to the JSON property instance
30822 30823 30824 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30822 def instance @instance end |
#instance_health ⇒ Array<Google::Apis::ComputeV1::ManagedInstanceInstanceHealth>
Output only. [Output Only] Health state of the instance per health-check.
Corresponds to the JSON property instanceHealth
30827 30828 30829 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30827 def instance_health @instance_health end |
#instance_status ⇒ String
Output only. [Output Only] The status of the instance. This field is empty
when
the instance does not exist.
Corresponds to the JSON property instanceStatus
30834 30835 30836 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30834 def instance_status @instance_status end |
#last_attempt ⇒ Google::Apis::ComputeV1::ManagedInstanceLastAttempt
Output only. [Output Only] Information about the last attempt to create or
delete
the instance.
Corresponds to the JSON property lastAttempt
30841 30842 30843 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30841 def last_attempt @last_attempt end |
#name ⇒ String
Output only. [Output Only] The name of the instance. The name always exists
even if the
instance has not yet been created.
Corresponds to the JSON property name
30848 30849 30850 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30848 def name @name end |
#preserved_state_from_config ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromConfig
30853 30854 30855 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30853 def preserved_state_from_config @preserved_state_from_config end |
#preserved_state_from_policy ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromPolicy
30858 30859 30860 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30858 def preserved_state_from_policy @preserved_state_from_policy end |
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeV1::ManagedInstancePropertiesFromFlexibilityPolicy
Output only. [Output Only] Instance properties selected for this instance
resulting from
InstanceFlexibilityPolicy.
Corresponds to the JSON property propertiesFromFlexibilityPolicy
30865 30866 30867 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30865 def properties_from_flexibility_policy @properties_from_flexibility_policy end |
#version ⇒ Google::Apis::ComputeV1::ManagedInstanceVersion
Output only. [Output Only] Intended version of this instance.
Corresponds to the JSON property version
30870 30871 30872 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30870 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30877 30878 30879 30880 30881 30882 30883 30884 30885 30886 30887 30888 30889 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30877 def update!(**args) @current_action = args[:current_action] if args.key?(:current_action) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @instance_health = args[:instance_health] if args.key?(:instance_health) @instance_status = args[:instance_status] if args.key?(:instance_status) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) @name = args[:name] if args.key?(:name) @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config) @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy) @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy) @version = args[:version] if args.key?(:version) end |