Class: Google::Apis::ComputeV1::ManagedInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ManagedInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A Managed Instance resource.
Instance Attribute Summary collapse
-
#current_action ⇒ String
[Output Only] The current action that the managed instance group has scheduled for the instance.
-
#id ⇒ Fixnum
[Output only] The unique identifier for this resource.
-
#instance ⇒ String
[Output Only] The URL of the instance.
-
#instance_health ⇒ Array<Google::Apis::ComputeV1::ManagedInstanceInstanceHealth>
[Output Only] Health state of the instance per health-check.
-
#instance_status ⇒ String
[Output Only] The status of the instance.
-
#last_attempt ⇒ Google::Apis::ComputeV1::ManagedInstanceLastAttempt
[Output Only] Information about the last attempt to create or delete the instance.
-
#preserved_state_from_config ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
-
#preserved_state_from_policy ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
-
#version ⇒ Google::Apis::ComputeV1::ManagedInstanceVersion
[Output Only] Intended version of this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstance
constructor
A new instance of ManagedInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstance
Returns a new instance of ManagedInstance.
18773 18774 18775 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_action ⇒ String
[Output Only] The current action that the managed instance group has scheduled
for the instance. Possible values: - NONE The instance is running, and the
managed instance group does not have any scheduled actions for this instance. -
CREATING The managed instance group is creating this instance. If the group
fails to create this instance, it will try again until it is successful. -
CREATING_WITHOUT_RETRIES The managed instance group is attempting to create
this instance only once. If the group fails to create this instance, it does
not try again and the group's targetSize value is decreased instead. -
RECREATING The managed instance group is recreating this instance. - DELETING
The managed instance group is permanently deleting this instance. - ABANDONING
The managed instance group is abandoning this instance. The instance will be
removed from the instance group and from any target pools that are associated
with this group. - RESTARTING The managed instance group is restarting the
instance. - REFRESHING The managed instance group is applying configuration
changes to the instance without stopping it. For example, the group can update
the target pool list for an instance without stopping that instance. -
VERIFYING The managed instance group has created the instance and it is in the
process of being verified.
Corresponds to the JSON property currentAction
18727 18728 18729 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18727 def current_action @current_action end |
#id ⇒ Fixnum
[Output only] The unique identifier for this resource. This field is empty
when instance does not exist.
Corresponds to the JSON property id
18733 18734 18735 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18733 def id @id end |
#instance ⇒ String
[Output Only] The URL of the instance. The URL can exist even if the instance
has not yet been created.
Corresponds to the JSON property instance
18739 18740 18741 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18739 def instance @instance end |
#instance_health ⇒ Array<Google::Apis::ComputeV1::ManagedInstanceInstanceHealth>
[Output Only] Health state of the instance per health-check.
Corresponds to the JSON property instanceHealth
18744 18745 18746 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18744 def instance_health @instance_health end |
#instance_status ⇒ String
[Output Only] The status of the instance. This field is empty when the
instance does not exist.
Corresponds to the JSON property instanceStatus
18750 18751 18752 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18750 def instance_status @instance_status end |
#last_attempt ⇒ Google::Apis::ComputeV1::ManagedInstanceLastAttempt
[Output Only] Information about the last attempt to create or delete the
instance.
Corresponds to the JSON property lastAttempt
18756 18757 18758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18756 def last_attempt @last_attempt end |
#preserved_state_from_config ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromConfig
18761 18762 18763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18761 def preserved_state_from_config @preserved_state_from_config end |
#preserved_state_from_policy ⇒ Google::Apis::ComputeV1::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromPolicy
18766 18767 18768 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18766 def preserved_state_from_policy @preserved_state_from_policy end |
#version ⇒ Google::Apis::ComputeV1::ManagedInstanceVersion
[Output Only] Intended version of this instance.
Corresponds to the JSON property version
18771 18772 18773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18771 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18778 18779 18780 18781 18782 18783 18784 18785 18786 18787 18788 |
# File 'lib/google/apis/compute_v1/classes.rb', line 18778 def update!(**args) @current_action = args[:current_action] if args.key?(:current_action) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @instance_health = args[:instance_health] if args.key?(:instance_health) @instance_status = args[:instance_status] if args.key?(:instance_status) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config) @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy) @version = args[:version] if args.key?(:version) end |