Class: Google::Apis::ComputeV1::ManagedInstanceLastAttempt::Errors

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] Encountered errors during the last attempt to create or delete the instance.

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Errors

Returns a new instance of Errors.



18846
18847
18848
# File 'lib/google/apis/compute_v1/classes.rb', line 18846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::ComputeV1::ManagedInstanceLastAttempt::Errors::Error>

[Output Only] The array of errors encountered while processing this operation. Corresponds to the JSON property errors



18844
18845
18846
# File 'lib/google/apis/compute_v1/classes.rb', line 18844

def errors
  @errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18851
18852
18853
# File 'lib/google/apis/compute_v1/classes.rb', line 18851

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
end