Class: Google::Apis::ComputeV1::ManagedInstanceScheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ManagedInstanceScheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#graceful_shutdown_timestamp ⇒ String
Output only.
-
#termination_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceScheduling
constructor
A new instance of ManagedInstanceScheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceScheduling
Returns a new instance of ManagedInstanceScheduling.
35264 35265 35266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#graceful_shutdown_timestamp ⇒ String
Output only. The timestamp at which the underlying instance will be
triggered for graceful shutdown if it is configured. This is in RFC3339 text
format.
Corresponds to the JSON property gracefulShutdownTimestamp
35254 35255 35256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35254 def @graceful_shutdown_timestamp end |
#termination_timestamp ⇒ String
Output only. The timestamp at which the managed instance will be terminated.
This is
in RFC3339 text
format.
Corresponds to the JSON property terminationTimestamp
35262 35263 35264 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35262 def @termination_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35269 35270 35271 35272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35269 def update!(**args) @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp) @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp) end |