Class: Google::Apis::ComputeV1::ManagedInstanceScheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstanceScheduling

Returns a new instance of ManagedInstanceScheduling.



34900
34901
34902
# File 'lib/google/apis/compute_v1/classes.rb', line 34900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#graceful_shutdown_timestampString

Output only. The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured. This is in RFC3339 text format. Corresponds to the JSON property gracefulShutdownTimestamp

Returns:

  • (String)


34890
34891
34892
# File 'lib/google/apis/compute_v1/classes.rb', line 34890

def graceful_shutdown_timestamp
  @graceful_shutdown_timestamp
end

#termination_timestampString

Output only. The timestamp at which the managed instance will be terminated. This is in RFC3339 text format. Corresponds to the JSON property terminationTimestamp

Returns:

  • (String)


34898
34899
34900
# File 'lib/google/apis/compute_v1/classes.rb', line 34898

def termination_timestamp
  @termination_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34905
34906
34907
34908
# File 'lib/google/apis/compute_v1/classes.rb', line 34905

def update!(**args)
  @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp)
  @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp)
end