Class: Google::Apis::ComputeV1::ManagedInstanceScheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ManagedInstanceScheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#graceful_shutdown_timestamp ⇒ String
Output only.
-
#termination_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceScheduling
constructor
A new instance of ManagedInstanceScheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceScheduling
Returns a new instance of ManagedInstanceScheduling.
34900 34901 34902 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34900 def initialize(**args) update!(**args) end |
Instance Attribute Details
#graceful_shutdown_timestamp ⇒ String
Output only. The timestamp at which the underlying instance will be
triggered for graceful shutdown if it is configured. This is in RFC3339 text
format.
Corresponds to the JSON property gracefulShutdownTimestamp
34890 34891 34892 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34890 def @graceful_shutdown_timestamp end |
#termination_timestamp ⇒ String
Output only. The timestamp at which the managed instance will be terminated.
This is
in RFC3339 text
format.
Corresponds to the JSON property terminationTimestamp
34898 34899 34900 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34898 def @termination_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34905 34906 34907 34908 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34905 def update!(**args) @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp) @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp) end |