Class: Google::Apis::ComputeV1::ManagedInstanceShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ManagedInstanceShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
constructor
A new instance of ManagedInstanceShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
Returns a new instance of ManagedInstanceShutdownDetails.
34921 34922 34923 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
34911 34912 34913 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34911 def max_duration @max_duration end |
#request_timestamp ⇒ String
Output only. Past timestamp indicating the beginning of PENDING_STOP state
of
instance in RFC3339
text format.
Corresponds to the JSON property requestTimestamp
34919 34920 34921 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34919 def @request_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34926 34927 34928 34929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34926 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) end |