Class: Google::Apis::ComputeV1::Metadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Metadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A metadata key/value entry.
Defined Under Namespace
Classes: Item
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#items ⇒ Array<Google::Apis::ComputeV1::Metadata::Item>
Array of key/value pairs.
-
#kind ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Metadata
constructor
A new instance of Metadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Metadata
Returns a new instance of Metadata.
35362 35363 35364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of
the metadata's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update metadata. You must always provide an
up-to-date fingerprint hash in order to update or change metadata,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve the resource.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
35348 35349 35350 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35348 def fingerprint @fingerprint end |
#items ⇒ Array<Google::Apis::ComputeV1::Metadata::Item>
Array of key/value pairs. The total size of all keys and values must be
less than 512 KB.
Corresponds to the JSON property items
35354 35355 35356 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35354 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#metadata
for metadata.
Corresponds to the JSON property kind
35360 35361 35362 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35360 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35367 35368 35369 35370 35371 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35367 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) end |