Class: Google::Apis::ComputeV1::Metadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A metadata key/value entry.

Defined Under Namespace

Classes: Item

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Metadata

Returns a new instance of Metadata.



34879
34880
34881
# File 'lib/google/apis/compute_v1/classes.rb', line 34879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the resource. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


34865
34866
34867
# File 'lib/google/apis/compute_v1/classes.rb', line 34865

def fingerprint
  @fingerprint
end

#itemsArray<Google::Apis::ComputeV1::Metadata::Item>

Array of key/value pairs. The total size of all keys and values must be less than 512 KB. Corresponds to the JSON property items



34871
34872
34873
# File 'lib/google/apis/compute_v1/classes.rb', line 34871

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#metadata for metadata. Corresponds to the JSON property kind

Returns:

  • (String)


34877
34878
34879
# File 'lib/google/apis/compute_v1/classes.rb', line 34877

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34884
34885
34886
34887
34888
# File 'lib/google/apis/compute_v1/classes.rb', line 34884

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
end