Class: Google::Apis::ComputeV1::Metadata::Item
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Metadata::Item
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Metadata
Instance Attribute Summary collapse
-
#key ⇒ String
Key for the metadata entry.
-
#value ⇒ String
Value for the metadata entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Item
constructor
A new instance of Item.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Item
Returns a new instance of Item.
35382 35383 35384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Key for the metadata entry. Keys must conform to the following
regexp: [a-zA-Z0-9-_]+, and be less than 128 bytes in length.
This is reflected as part of a URL in the metadata server. Additionally, to
avoid ambiguity, keys must not conflict with any other metadata keys
for the project.
Corresponds to the JSON property key
35372 35373 35374 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35372 def key @key end |
#value ⇒ String
Value for the metadata entry. These are free-form strings, and only
have meaning as interpreted by the image running in the instance. The
only restriction placed on values is that their size must be less than
or equal to 262144 bytes (256 KiB).
Corresponds to the JSON property value
35380 35381 35382 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35380 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35387 35388 35389 35390 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35387 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |