Class: Google::Apis::ComputeV1::NamedSet
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NamedSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of named set.
-
#elements ⇒ Array<Google::Apis::ComputeV1::Expr>
CEL expressions that are comparable to constructs of this set's type (see Policy Language).
-
#fingerprint ⇒ String
A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking.
-
#name ⇒ String
This set's name, which must be a resource ID segment and unique within all named sets owned by the Router.
-
#type ⇒ String
This named set's type Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NamedSet
constructor
A new instance of NamedSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NamedSet
Returns a new instance of NamedSet.
35550 35551 35552 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of named set.
Corresponds to the JSON property description
35518 35519 35520 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35518 def description @description end |
#elements ⇒ Array<Google::Apis::ComputeV1::Expr>
CEL expressions that are comparable to constructs of this set's type
(see Policy Language).
Corresponds to the JSON property elements
35524 35525 35526 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35524 def elements @elements end |
#fingerprint ⇒ String
A fingerprint for the Named Set being applied to this Router, which is
essentially a hash of the Named Set used for optimistic locking.
The fingerprint is initially generated by Compute Engine and changes
after every request to modify or update the Named Set. You must always
provide an up-to-date fingerprint hash in order to update or change
labels.
To see the latest fingerprint, make a getNamedSet() request
to retrieve a Named Set.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
35537 35538 35539 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35537 def fingerprint @fingerprint end |
#name ⇒ String
This set's name, which must be a resource ID segment and unique within all
named sets owned by the Router. Name should conform to RFC1035.
Corresponds to the JSON property name
35543 35544 35545 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35543 def name @name end |
#type ⇒ String
This named set's type
Corresponds to the JSON property type
35548 35549 35550 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35548 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35555 35556 35557 35558 35559 35560 35561 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35555 def update!(**args) @description = args[:description] if args.key?(:description) @elements = args[:elements] if args.key?(:elements) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |