Class: Google::Apis::ComputeV1::NamedSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedSet

Returns a new instance of NamedSet.



35186
35187
35188
# File 'lib/google/apis/compute_v1/classes.rb', line 35186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of named set. Corresponds to the JSON property description

Returns:

  • (String)


35154
35155
35156
# File 'lib/google/apis/compute_v1/classes.rb', line 35154

def description
  @description
end

#elementsArray<Google::Apis::ComputeV1::Expr>

CEL expressions that are comparable to constructs of this set's type (see Policy Language). Corresponds to the JSON property elements

Returns:



35160
35161
35162
# File 'lib/google/apis/compute_v1/classes.rb', line 35160

def elements
  @elements
end

#fingerprintString

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


35173
35174
35175
# File 'lib/google/apis/compute_v1/classes.rb', line 35173

def fingerprint
  @fingerprint
end

#nameString

This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


35179
35180
35181
# File 'lib/google/apis/compute_v1/classes.rb', line 35179

def name
  @name
end

#typeString

This named set's type Corresponds to the JSON property type

Returns:

  • (String)


35184
35185
35186
# File 'lib/google/apis/compute_v1/classes.rb', line 35184

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35191
35192
35193
35194
35195
35196
35197
# File 'lib/google/apis/compute_v1/classes.rb', line 35191

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @elements = args[:elements] if args.key?(:elements)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end