Class: Google::Apis::ComputeV1::NamedSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedSet

Returns a new instance of NamedSet.



35176
35177
35178
# File 'lib/google/apis/compute_v1/classes.rb', line 35176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of named set. Corresponds to the JSON property description

Returns:

  • (String)


35144
35145
35146
# File 'lib/google/apis/compute_v1/classes.rb', line 35144

def description
  @description
end

#elementsArray<Google::Apis::ComputeV1::Expr>

CEL expressions that are comparable to constructs of this set's type (see Policy Language). Corresponds to the JSON property elements

Returns:



35150
35151
35152
# File 'lib/google/apis/compute_v1/classes.rb', line 35150

def elements
  @elements
end

#fingerprintString

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


35163
35164
35165
# File 'lib/google/apis/compute_v1/classes.rb', line 35163

def fingerprint
  @fingerprint
end

#nameString

This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


35169
35170
35171
# File 'lib/google/apis/compute_v1/classes.rb', line 35169

def name
  @name
end

#typeString

This named set's type Corresponds to the JSON property type

Returns:

  • (String)


35174
35175
35176
# File 'lib/google/apis/compute_v1/classes.rb', line 35174

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35181
35182
35183
35184
35185
35186
35187
# File 'lib/google/apis/compute_v1/classes.rb', line 35181

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @elements = args[:elements] if args.key?(:elements)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end