Class: Google::Apis::ComputeV1::Network
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Network
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a VPC Network resource. Networks connect resources to each other and to the internet. For more information, read Virtual Private Cloud (VPC) Network.
Instance Attribute Summary collapse
-
#auto_create_subnetworks ⇒ Boolean
(also: #auto_create_subnetworks?)
Must be set to create a VPC network.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#enable_ula_internal_ipv6 ⇒ Boolean
(also: #enable_ula_internal_ipv6?)
Enable ULA internal ipv6 on this network.
-
#gateway_i_pv4 ⇒ String
[Output Only] The gateway address for default routing out of the network, selected by GCP.
-
#i_pv4_range ⇒ String
Deprecated in favor of subnet mode networks.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#internal_ipv6_range ⇒ String
When enabling ula internal ipv6, caller optionally can specify the /48 range they want from the google defined ULA prefix fd20::/20.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#mtu ⇒ Fixnum
Maximum Transmission Unit in bytes.
-
#name ⇒ String
Name of the resource.
-
#network_firewall_policy_enforcement_order ⇒ String
The network firewall policy enforcement order.
-
#peerings ⇒ Array<Google::Apis::ComputeV1::NetworkPeering>
[Output Only] A list of network peerings for the resource.
-
#routing_config ⇒ Google::Apis::ComputeV1::NetworkRoutingConfig
A routing configuration attached to a network resource.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
[Output Only] Server-defined URL for this resource with the resource id.
-
#subnetworks ⇒ Array<String>
[Output Only] Server-defined fully-qualified URLs for all subnetworks in this VPC network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Network
constructor
A new instance of Network.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Network
Returns a new instance of Network.
19201 19202 19203 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_create_subnetworks ⇒ Boolean Also known as: auto_create_subnetworks?
Must be set to create a VPC network. If not set, a legacy network is created.
When set to true, the VPC network is created in auto mode. When set to false,
the VPC network is created in custom mode. An auto mode VPC network starts
with one subnet per region. Each subnet has a predetermined range as described
in Auto mode VPC network IP ranges. For custom mode VPC networks, you can add
subnets using the subnetworks insert method.
Corresponds to the JSON property autoCreateSubnetworks
19102 19103 19104 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19102 def auto_create_subnetworks @auto_create_subnetworks end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
19108 19109 19110 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19108 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this field when you create
the resource.
Corresponds to the JSON property description
19114 19115 19116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19114 def description @description end |
#enable_ula_internal_ipv6 ⇒ Boolean Also known as: enable_ula_internal_ipv6?
Enable ULA internal ipv6 on this network. Enabling this feature will assign a /
48 from google defined ULA prefix fd20::/20. .
Corresponds to the JSON property enableUlaInternalIpv6
19120 19121 19122 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19120 def enable_ula_internal_ipv6 @enable_ula_internal_ipv6 end |
#gateway_i_pv4 ⇒ String
[Output Only] The gateway address for default routing out of the network,
selected by GCP.
Corresponds to the JSON property gatewayIPv4
19127 19128 19129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19127 def gateway_i_pv4 @gateway_i_pv4 end |
#i_pv4_range ⇒ String
Deprecated in favor of subnet mode networks. The range of internal addresses
that are legal on this network. This range is a CIDR specification, for
example: 192.168.0.0/16. Provided by the client when the network is created.
Corresponds to the JSON property IPv4Range
19092 19093 19094 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19092 def i_pv4_range @i_pv4_range end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
19133 19134 19135 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19133 def id @id end |
#internal_ipv6_range ⇒ String
When enabling ula internal ipv6, caller optionally can specify the /48 range
they want from the google defined ULA prefix fd20::/20. The input must be a
valid /48 ULA IPv6 address and must be within the fd20::/20. Operation will
fail if the speficied /48 is already in used by another resource. If the field
is not speficied, then a /48 range will be randomly allocated from fd20::/20
and returned via this field. .
Corresponds to the JSON property internalIpv6Range
19143 19144 19145 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19143 def internal_ipv6_range @internal_ipv6_range end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#network for networks.
Corresponds to the JSON property kind
19148 19149 19150 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19148 def kind @kind end |
#mtu ⇒ Fixnum
Maximum Transmission Unit in bytes. The minimum value for this field is 1460
and the maximum value is 1500 bytes. If unspecified, defaults to 1460.
Corresponds to the JSON property mtu
19154 19155 19156 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19154 def mtu @mtu end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all
following characters (except for the last character) must be a dash, lowercase
letter, or digit. The last character must be a lowercase letter or digit.
Corresponds to the JSON property name
19164 19165 19166 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19164 def name @name end |
#network_firewall_policy_enforcement_order ⇒ String
The network firewall policy enforcement order. Can be either
AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to
AFTER_CLASSIC_FIREWALL if the field is not specified.
Corresponds to the JSON property networkFirewallPolicyEnforcementOrder
19171 19172 19173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19171 def network_firewall_policy_enforcement_order @network_firewall_policy_enforcement_order end |
#peerings ⇒ Array<Google::Apis::ComputeV1::NetworkPeering>
[Output Only] A list of network peerings for the resource.
Corresponds to the JSON property peerings
19176 19177 19178 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19176 def peerings @peerings end |
#routing_config ⇒ Google::Apis::ComputeV1::NetworkRoutingConfig
A routing configuration attached to a network resource. The message includes
the list of routers associated with the network, and a flag indicating the
type of routing behavior to enforce network-wide.
Corresponds to the JSON property routingConfig
19183 19184 19185 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19183 def routing_config @routing_config end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
19188 19189 19190 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19188 def self_link @self_link end |
#self_link_with_id ⇒ String
[Output Only] Server-defined URL for this resource with the resource id.
Corresponds to the JSON property selfLinkWithId
19193 19194 19195 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19193 def self_link_with_id @self_link_with_id end |
#subnetworks ⇒ Array<String>
[Output Only] Server-defined fully-qualified URLs for all subnetworks in this
VPC network.
Corresponds to the JSON property subnetworks
19199 19200 19201 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19199 def subnetworks @subnetworks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19206 19207 19208 19209 19210 19211 19212 19213 19214 19215 19216 19217 19218 19219 19220 19221 19222 19223 19224 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19206 def update!(**args) @i_pv4_range = args[:i_pv4_range] if args.key?(:i_pv4_range) @auto_create_subnetworks = args[:auto_create_subnetworks] if args.key?(:auto_create_subnetworks) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @enable_ula_internal_ipv6 = args[:enable_ula_internal_ipv6] if args.key?(:enable_ula_internal_ipv6) @gateway_i_pv4 = args[:gateway_i_pv4] if args.key?(:gateway_i_pv4) @id = args[:id] if args.key?(:id) @internal_ipv6_range = args[:internal_ipv6_range] if args.key?(:internal_ipv6_range) @kind = args[:kind] if args.key?(:kind) @mtu = args[:mtu] if args.key?(:mtu) @name = args[:name] if args.key?(:name) @network_firewall_policy_enforcement_order = args[:network_firewall_policy_enforcement_order] if args.key?(:network_firewall_policy_enforcement_order) @peerings = args[:peerings] if args.key?(:peerings) @routing_config = args[:routing_config] if args.key?(:routing_config) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) end |