Class: Google::Apis::ComputeV1::NetworkAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

NetworkAttachments A network attachment resource ...

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachment

Returns a new instance of NetworkAttachment.



35561
35562
35563
# File 'lib/google/apis/compute_v1/classes.rb', line 35561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_endpointsArray<Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint>

Output only. [Output Only] An array of connections for all the producers connected to this network attachment. Corresponds to the JSON property connectionEndpoints



35462
35463
35464
# File 'lib/google/apis/compute_v1/classes.rb', line 35462

def connection_endpoints
  @connection_endpoints
end

#connection_preferenceString

Corresponds to the JSON property connectionPreference

Returns:

  • (String)


35467
35468
35469
# File 'lib/google/apis/compute_v1/classes.rb', line 35467

def connection_preference
  @connection_preference
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


35473
35474
35475
# File 'lib/google/apis/compute_v1/classes.rb', line 35473

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


35479
35480
35481
# File 'lib/google/apis/compute_v1/classes.rb', line 35479

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. An up-to-date fingerprint must be provided in order to patch. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


35487
35488
35489
# File 'lib/google/apis/compute_v1/classes.rb', line 35487

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


35494
35495
35496
# File 'lib/google/apis/compute_v1/classes.rb', line 35494

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Corresponds to the JSON property kind

Returns:

  • (String)


35499
35500
35501
# File 'lib/google/apis/compute_v1/classes.rb', line 35499

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


35510
35511
35512
# File 'lib/google/apis/compute_v1/classes.rb', line 35510

def name
  @name
end

#networkString

Output only. [Output Only] The URL of the network which the Network Attachment belongs to. Practically it is inferred by fetching the network of the first subnetwork associated. Because it is required that all the subnetworks must be from the same network, it is assured that the Network Attachment belongs to the same network as all the subnetworks. Corresponds to the JSON property network

Returns:

  • (String)


35519
35520
35521
# File 'lib/google/apis/compute_v1/classes.rb', line 35519

def network
  @network
end

#producer_accept_listsArray<String>

Projects or service class ids that are allowed to connect to this network attachment. The project can be specified using its id or number. Service class id can be specified as "serviceclasses/service_class_id". Corresponds to the JSON property producerAcceptLists

Returns:

  • (Array<String>)


35526
35527
35528
# File 'lib/google/apis/compute_v1/classes.rb', line 35526

def producer_accept_lists
  @producer_accept_lists
end

#producer_reject_listsArray<String>

Projects or service class ids that are not allowed to connect to this network attachment. The project can be specified using its id or number. Service class id can be specified as "serviceclasses/service_class_id". Corresponds to the JSON property producerRejectLists

Returns:

  • (Array<String>)


35533
35534
35535
# File 'lib/google/apis/compute_v1/classes.rb', line 35533

def producer_reject_lists
  @producer_reject_lists
end

#regionString

Output only. [Output Only] URL of the region where the network attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


35542
35543
35544
# File 'lib/google/apis/compute_v1/classes.rb', line 35542

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35547
35548
35549
# File 'lib/google/apis/compute_v1/classes.rb', line 35547

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


35552
35553
35554
# File 'lib/google/apis/compute_v1/classes.rb', line 35552

def self_link_with_id
  @self_link_with_id
end

#subnetworksArray<String>

An array of URLs where each entry is the URL of a subnet provided by the service consumer to use for endpoints in the producers that connect to this network attachment. Corresponds to the JSON property subnetworks

Returns:

  • (Array<String>)


35559
35560
35561
# File 'lib/google/apis/compute_v1/classes.rb', line 35559

def subnetworks
  @subnetworks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35566
35567
35568
35569
35570
35571
35572
35573
35574
35575
35576
35577
35578
35579
35580
35581
35582
# File 'lib/google/apis/compute_v1/classes.rb', line 35566

def update!(**args)
  @connection_endpoints = args[:connection_endpoints] if args.key?(:connection_endpoints)
  @connection_preference = args[:connection_preference] if args.key?(:connection_preference)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @producer_accept_lists = args[:producer_accept_lists] if args.key?(:producer_accept_lists)
  @producer_reject_lists = args[:producer_reject_lists] if args.key?(:producer_reject_lists)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
end