Class: Google::Apis::ComputeV1::NetworkAttachment
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkAttachment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
NetworkAttachments A network attachment resource ...
Instance Attribute Summary collapse
-
#connection_endpoints ⇒ Array<Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint>
Output only.
-
#connection_preference ⇒ String
Corresponds to the JSON property
connectionPreference. -
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
Output only.
-
#producer_accept_lists ⇒ Array<String>
Projects that are allowed to connect to this network attachment.
-
#producer_reject_lists ⇒ Array<String>
Projects that are not allowed to connect to this network attachment.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#subnetworks ⇒ Array<String>
An array of URLs where each entry is the URL of a subnet provided by the service consumer to use for endpoints in the producers that connect to this network attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkAttachment
constructor
A new instance of NetworkAttachment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkAttachment
Returns a new instance of NetworkAttachment.
30838 30839 30840 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_endpoints ⇒ Array<Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint>
Output only. [Output Only] An array of connections for all the producers
connected
to this network attachment.
Corresponds to the JSON property connectionEndpoints
30741 30742 30743 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30741 def connection_endpoints @connection_endpoints end |
#connection_preference ⇒ String
Corresponds to the JSON property connectionPreference
30746 30747 30748 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30746 def connection_preference @connection_preference end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
30752 30753 30754 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30752 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
30758 30759 30760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30758 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored
in this object. This field is used in optimistic locking. An up-to-date
fingerprint must be provided in order to patch.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
30766 30767 30768 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30766 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
30773 30774 30775 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30773 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource.
Corresponds to the JSON property kind
30778 30779 30780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30778 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
30789 30790 30791 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30789 def name @name end |
#network ⇒ String
Output only. [Output Only] The URL of the network which the Network Attachment
belongs to. Practically it is inferred by fetching the network of the first
subnetwork associated. Because it is required that all the subnetworks must
be from the same network, it is assured that the Network Attachment belongs
to the same network as all the subnetworks.
Corresponds to the JSON property network
30798 30799 30800 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30798 def network @network end |
#producer_accept_lists ⇒ Array<String>
Projects that are allowed to connect to this network attachment.
The project can be specified using its id or number.
Corresponds to the JSON property producerAcceptLists
30804 30805 30806 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30804 def producer_accept_lists @producer_accept_lists end |
#producer_reject_lists ⇒ Array<String>
Projects that are not allowed to connect to this network attachment.
The project can be specified using its id or number.
Corresponds to the JSON property producerRejectLists
30810 30811 30812 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30810 def producer_reject_lists @producer_reject_lists end |
#region ⇒ String
Output only. [Output Only] URL of the region where the network attachment
resides.
This field applies only to the region resource. You must specify this
field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
30819 30820 30821 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30819 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
30824 30825 30826 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30824 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
30829 30830 30831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30829 def self_link_with_id @self_link_with_id end |
#subnetworks ⇒ Array<String>
An array of URLs where each entry is the URL of a subnet
provided by the service consumer to use for
endpoints in the producers that connect to this network attachment.
Corresponds to the JSON property subnetworks
30836 30837 30838 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30836 def subnetworks @subnetworks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30843 30844 30845 30846 30847 30848 30849 30850 30851 30852 30853 30854 30855 30856 30857 30858 30859 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30843 def update!(**args) @connection_endpoints = args[:connection_endpoints] if args.key?(:connection_endpoints) @connection_preference = args[:connection_preference] if args.key?(:connection_preference) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @producer_accept_lists = args[:producer_accept_lists] if args.key?(:producer_accept_lists) @producer_reject_lists = args[:producer_reject_lists] if args.key?(:producer_reject_lists) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) end |