Class: Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] A connection connected to this network attachment.
Instance Attribute Summary collapse
-
#ip_address ⇒ String
The IPv4 address assigned to the producer instance network interface.
-
#ipv6_address ⇒ String
The IPv6 address assigned to the producer instance network interface.
-
#project_id_or_num ⇒ String
The project id or number of the interface to which the IP was assigned.
-
#secondary_ip_cidr_ranges ⇒ Array<String>
Alias IP ranges from the same subnetwork.
-
#service_class_id ⇒ String
The service class id of the producer service to which the IP was assigned.
-
#status ⇒ String
The status of a connected endpoint to this network attachment.
-
#subnetwork ⇒ String
The subnetwork used to assign the IP to the producer instance network interface.
-
#subnetwork_cidr_range ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint
constructor
A new instance of NetworkAttachmentConnectedEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint
Returns a new instance of NetworkAttachmentConnectedEndpoint.
35760 35761 35762 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
The IPv4 address assigned to the producer instance network interface.
This value will be a range in case of Serverless.
Corresponds to the JSON property ipAddress
35717 35718 35719 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35717 def ip_address @ip_address end |
#ipv6_address ⇒ String
The IPv6 address assigned to the producer instance network interface.
This is only assigned when the stack types of both the instance network
interface and the consumer subnet are IPv4_IPv6.
Corresponds to the JSON property ipv6Address
35724 35725 35726 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35724 def ipv6_address @ipv6_address end |
#project_id_or_num ⇒ String
The project id or number of the interface to which the IP was assigned.
Corresponds to the JSON property projectIdOrNum
35729 35730 35731 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35729 def project_id_or_num @project_id_or_num end |
#secondary_ip_cidr_ranges ⇒ Array<String>
Alias IP ranges from the same subnetwork.
Corresponds to the JSON property secondaryIpCidrRanges
35734 35735 35736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35734 def secondary_ip_cidr_ranges @secondary_ip_cidr_ranges end |
#service_class_id ⇒ String
The service class id of the producer service to which the IP was
assigned.
Corresponds to the JSON property serviceClassId
35740 35741 35742 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35740 def service_class_id @service_class_id end |
#status ⇒ String
The status of a connected endpoint to this network attachment.
Corresponds to the JSON property status
35745 35746 35747 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35745 def status @status end |
#subnetwork ⇒ String
The subnetwork used to assign the IP to the producer
instance network interface.
Corresponds to the JSON property subnetwork
35751 35752 35753 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35751 def subnetwork @subnetwork end |
#subnetwork_cidr_range ⇒ String
Output only. [Output Only] The CIDR range of the subnet from which the IPv4
internal
IP was allocated from.
Corresponds to the JSON property subnetworkCidrRange
35758 35759 35760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35758 def subnetwork_cidr_range @subnetwork_cidr_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35765 35766 35767 35768 35769 35770 35771 35772 35773 35774 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35765 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num) @secondary_ip_cidr_ranges = args[:secondary_ip_cidr_ranges] if args.key?(:secondary_ip_cidr_ranges) @service_class_id = args[:service_class_id] if args.key?(:service_class_id) @status = args[:status] if args.key?(:status) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @subnetwork_cidr_range = args[:subnetwork_cidr_range] if args.key?(:subnetwork_cidr_range) end |