Class: Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] A connection connected to this network attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint

Returns a new instance of NetworkAttachmentConnectedEndpoint.



35595
35596
35597
# File 'lib/google/apis/compute_v1/classes.rb', line 35595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The IPv4 address assigned to the producer instance network interface. This value will be a range in case of Serverless. Corresponds to the JSON property ipAddress

Returns:

  • (String)


35552
35553
35554
# File 'lib/google/apis/compute_v1/classes.rb', line 35552

def ip_address
  @ip_address
end

#ipv6_addressString

The IPv6 address assigned to the producer instance network interface. This is only assigned when the stack types of both the instance network interface and the consumer subnet are IPv4_IPv6. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


35559
35560
35561
# File 'lib/google/apis/compute_v1/classes.rb', line 35559

def ipv6_address
  @ipv6_address
end

#project_id_or_numString

The project id or number of the interface to which the IP was assigned. Corresponds to the JSON property projectIdOrNum

Returns:

  • (String)


35564
35565
35566
# File 'lib/google/apis/compute_v1/classes.rb', line 35564

def project_id_or_num
  @project_id_or_num
end

#secondary_ip_cidr_rangesArray<String>

Alias IP ranges from the same subnetwork. Corresponds to the JSON property secondaryIpCidrRanges

Returns:

  • (Array<String>)


35569
35570
35571
# File 'lib/google/apis/compute_v1/classes.rb', line 35569

def secondary_ip_cidr_ranges
  @secondary_ip_cidr_ranges
end

#service_class_idString

The service class id of the producer service to which the IP was assigned. Corresponds to the JSON property serviceClassId

Returns:

  • (String)


35575
35576
35577
# File 'lib/google/apis/compute_v1/classes.rb', line 35575

def service_class_id
  @service_class_id
end

#statusString

The status of a connected endpoint to this network attachment. Corresponds to the JSON property status

Returns:

  • (String)


35580
35581
35582
# File 'lib/google/apis/compute_v1/classes.rb', line 35580

def status
  @status
end

#subnetworkString

The subnetwork used to assign the IP to the producer instance network interface. Corresponds to the JSON property subnetwork

Returns:

  • (String)


35586
35587
35588
# File 'lib/google/apis/compute_v1/classes.rb', line 35586

def subnetwork
  @subnetwork
end

#subnetwork_cidr_rangeString

Output only. [Output Only] The CIDR range of the subnet from which the IPv4 internal IP was allocated from. Corresponds to the JSON property subnetworkCidrRange

Returns:

  • (String)


35593
35594
35595
# File 'lib/google/apis/compute_v1/classes.rb', line 35593

def subnetwork_cidr_range
  @subnetwork_cidr_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35600
35601
35602
35603
35604
35605
35606
35607
35608
35609
# File 'lib/google/apis/compute_v1/classes.rb', line 35600

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num)
  @secondary_ip_cidr_ranges = args[:secondary_ip_cidr_ranges] if args.key?(:secondary_ip_cidr_ranges)
  @service_class_id = args[:service_class_id] if args.key?(:service_class_id)
  @status = args[:status] if args.key?(:status)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @subnetwork_cidr_range = args[:subnetwork_cidr_range] if args.key?(:subnetwork_cidr_range)
end