Class: Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] A connection connected to this network attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint

Returns a new instance of NetworkAttachmentConnectedEndpoint.



35406
35407
35408
# File 'lib/google/apis/compute_v1/classes.rb', line 35406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The IPv4 address assigned to the producer instance network interface. This value will be a range in case of Serverless. Corresponds to the JSON property ipAddress

Returns:

  • (String)


35363
35364
35365
# File 'lib/google/apis/compute_v1/classes.rb', line 35363

def ip_address
  @ip_address
end

#ipv6_addressString

The IPv6 address assigned to the producer instance network interface. This is only assigned when the stack types of both the instance network interface and the consumer subnet are IPv4_IPv6. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


35370
35371
35372
# File 'lib/google/apis/compute_v1/classes.rb', line 35370

def ipv6_address
  @ipv6_address
end

#project_id_or_numString

The project id or number of the interface to which the IP was assigned. Corresponds to the JSON property projectIdOrNum

Returns:

  • (String)


35375
35376
35377
# File 'lib/google/apis/compute_v1/classes.rb', line 35375

def project_id_or_num
  @project_id_or_num
end

#secondary_ip_cidr_rangesArray<String>

Alias IP ranges from the same subnetwork. Corresponds to the JSON property secondaryIpCidrRanges

Returns:

  • (Array<String>)


35380
35381
35382
# File 'lib/google/apis/compute_v1/classes.rb', line 35380

def secondary_ip_cidr_ranges
  @secondary_ip_cidr_ranges
end

#service_class_idString

The service class id of the producer service to which the IP was assigned. Corresponds to the JSON property serviceClassId

Returns:

  • (String)


35386
35387
35388
# File 'lib/google/apis/compute_v1/classes.rb', line 35386

def service_class_id
  @service_class_id
end

#statusString

The status of a connected endpoint to this network attachment. Corresponds to the JSON property status

Returns:

  • (String)


35391
35392
35393
# File 'lib/google/apis/compute_v1/classes.rb', line 35391

def status
  @status
end

#subnetworkString

The subnetwork used to assign the IP to the producer instance network interface. Corresponds to the JSON property subnetwork

Returns:

  • (String)


35397
35398
35399
# File 'lib/google/apis/compute_v1/classes.rb', line 35397

def subnetwork
  @subnetwork
end

#subnetwork_cidr_rangeString

Output only. [Output Only] The CIDR range of the subnet from which the IPv4 internal IP was allocated from. Corresponds to the JSON property subnetworkCidrRange

Returns:

  • (String)


35404
35405
35406
# File 'lib/google/apis/compute_v1/classes.rb', line 35404

def subnetwork_cidr_range
  @subnetwork_cidr_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35411
35412
35413
35414
35415
35416
35417
35418
35419
35420
# File 'lib/google/apis/compute_v1/classes.rb', line 35411

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num)
  @secondary_ip_cidr_ranges = args[:secondary_ip_cidr_ranges] if args.key?(:secondary_ip_cidr_ranges)
  @service_class_id = args[:service_class_id] if args.key?(:service_class_id)
  @status = args[:status] if args.key?(:status)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @subnetwork_cidr_range = args[:subnetwork_cidr_range] if args.key?(:subnetwork_cidr_range)
end