Class: Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] A connection connected to this network attachment.
Instance Attribute Summary collapse
-
#ip_address ⇒ String
The IPv4 address assigned to the producer instance network interface.
-
#ipv6_address ⇒ String
The IPv6 address assigned to the producer instance network interface.
-
#project_id_or_num ⇒ String
The project id or number of the interface to which the IP was assigned.
-
#secondary_ip_cidr_ranges ⇒ Array<String>
Alias IP ranges from the same subnetwork.
-
#service_class_id ⇒ String
The service class id of the producer service to which the IP was assigned.
-
#status ⇒ String
The status of a connected endpoint to this network attachment.
-
#subnetwork ⇒ String
The subnetwork used to assign the IP to the producer instance network interface.
-
#subnetwork_cidr_range ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint
constructor
A new instance of NetworkAttachmentConnectedEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint
Returns a new instance of NetworkAttachmentConnectedEndpoint.
35398 35399 35400 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
The IPv4 address assigned to the producer instance network interface.
This value will be a range in case of Serverless.
Corresponds to the JSON property ipAddress
35355 35356 35357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35355 def ip_address @ip_address end |
#ipv6_address ⇒ String
The IPv6 address assigned to the producer instance network interface.
This is only assigned when the stack types of both the instance network
interface and the consumer subnet are IPv4_IPv6.
Corresponds to the JSON property ipv6Address
35362 35363 35364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35362 def ipv6_address @ipv6_address end |
#project_id_or_num ⇒ String
The project id or number of the interface to which the IP was assigned.
Corresponds to the JSON property projectIdOrNum
35367 35368 35369 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35367 def project_id_or_num @project_id_or_num end |
#secondary_ip_cidr_ranges ⇒ Array<String>
Alias IP ranges from the same subnetwork.
Corresponds to the JSON property secondaryIpCidrRanges
35372 35373 35374 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35372 def secondary_ip_cidr_ranges @secondary_ip_cidr_ranges end |
#service_class_id ⇒ String
The service class id of the producer service to which the IP was
assigned.
Corresponds to the JSON property serviceClassId
35378 35379 35380 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35378 def service_class_id @service_class_id end |
#status ⇒ String
The status of a connected endpoint to this network attachment.
Corresponds to the JSON property status
35383 35384 35385 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35383 def status @status end |
#subnetwork ⇒ String
The subnetwork used to assign the IP to the producer
instance network interface.
Corresponds to the JSON property subnetwork
35389 35390 35391 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35389 def subnetwork @subnetwork end |
#subnetwork_cidr_range ⇒ String
Output only. [Output Only] The CIDR range of the subnet from which the IPv4
internal
IP was allocated from.
Corresponds to the JSON property subnetworkCidrRange
35396 35397 35398 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35396 def subnetwork_cidr_range @subnetwork_cidr_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35403 35404 35405 35406 35407 35408 35409 35410 35411 35412 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35403 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num) @secondary_ip_cidr_ranges = args[:secondary_ip_cidr_ranges] if args.key?(:secondary_ip_cidr_ranges) @service_class_id = args[:service_class_id] if args.key?(:service_class_id) @status = args[:status] if args.key?(:status) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @subnetwork_cidr_range = args[:subnetwork_cidr_range] if args.key?(:subnetwork_cidr_range) end |