Class: Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkAttachmentConnectedEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] A connection connected to this network attachment.
Instance Attribute Summary collapse
-
#ip_address ⇒ String
The IPv4 address assigned to the producer instance network interface.
-
#ipv6_address ⇒ String
The IPv6 address assigned to the producer instance network interface.
-
#project_id_or_num ⇒ String
The project id or number of the interface to which the IP was assigned.
-
#secondary_ip_cidr_ranges ⇒ Array<String>
Alias IP ranges from the same subnetwork.
-
#service_class_id ⇒ String
The service class id of the producer service to which the IP was assigned.
-
#status ⇒ String
The status of a connected endpoint to this network attachment.
-
#subnetwork ⇒ String
The subnetwork used to assign the IP to the producer instance network interface.
-
#subnetwork_cidr_range ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint
constructor
A new instance of NetworkAttachmentConnectedEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint
Returns a new instance of NetworkAttachmentConnectedEndpoint.
34817 34818 34819 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34817 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
The IPv4 address assigned to the producer instance network interface.
This value will be a range in case of Serverless.
Corresponds to the JSON property ipAddress
34774 34775 34776 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34774 def ip_address @ip_address end |
#ipv6_address ⇒ String
The IPv6 address assigned to the producer instance network interface.
This is only assigned when the stack types of both the instance network
interface and the consumer subnet are IPv4_IPv6.
Corresponds to the JSON property ipv6Address
34781 34782 34783 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34781 def ipv6_address @ipv6_address end |
#project_id_or_num ⇒ String
The project id or number of the interface to which the IP was assigned.
Corresponds to the JSON property projectIdOrNum
34786 34787 34788 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34786 def project_id_or_num @project_id_or_num end |
#secondary_ip_cidr_ranges ⇒ Array<String>
Alias IP ranges from the same subnetwork.
Corresponds to the JSON property secondaryIpCidrRanges
34791 34792 34793 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34791 def secondary_ip_cidr_ranges @secondary_ip_cidr_ranges end |
#service_class_id ⇒ String
The service class id of the producer service to which the IP was
assigned.
Corresponds to the JSON property serviceClassId
34797 34798 34799 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34797 def service_class_id @service_class_id end |
#status ⇒ String
The status of a connected endpoint to this network attachment.
Corresponds to the JSON property status
34802 34803 34804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34802 def status @status end |
#subnetwork ⇒ String
The subnetwork used to assign the IP to the producer
instance network interface.
Corresponds to the JSON property subnetwork
34808 34809 34810 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34808 def subnetwork @subnetwork end |
#subnetwork_cidr_range ⇒ String
Output only. [Output Only] The CIDR range of the subnet from which the IPv4
internal
IP was allocated from.
Corresponds to the JSON property subnetworkCidrRange
34815 34816 34817 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34815 def subnetwork_cidr_range @subnetwork_cidr_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34822 34823 34824 34825 34826 34827 34828 34829 34830 34831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34822 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num) @secondary_ip_cidr_ranges = args[:secondary_ip_cidr_ranges] if args.key?(:secondary_ip_cidr_ranges) @service_class_id = args[:service_class_id] if args.key?(:service_class_id) @status = args[:status] if args.key?(:status) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @subnetwork_cidr_range = args[:subnetwork_cidr_range] if args.key?(:subnetwork_cidr_range) end |