Class: Google::Apis::ComputeV1::NetworkAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkAttachment>
A list of NetworkAttachment resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkAttachmentList
constructor
A new instance of NetworkAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkAttachmentList
Returns a new instance of NetworkAttachmentList.
35462 35463 35464 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35430 35431 35432 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35430 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkAttachment>
A list of NetworkAttachment resources.
Corresponds to the JSON property items
35435 35436 35437 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35435 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
35440 35441 35442 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35440 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35450 35451 35452 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35450 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35455 35456 35457 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35455 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NetworkAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35460 35461 35462 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35460 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35467 35468 35469 35470 35471 35472 35473 35474 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35467 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |