Class: Google::Apis::ComputeV1::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



34873
34874
34875
# File 'lib/google/apis/compute_v1/classes.rb', line 34873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34841
34842
34843
# File 'lib/google/apis/compute_v1/classes.rb', line 34841

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



34846
34847
34848
# File 'lib/google/apis/compute_v1/classes.rb', line 34846

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


34851
34852
34853
# File 'lib/google/apis/compute_v1/classes.rb', line 34851

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34861
34862
34863
# File 'lib/google/apis/compute_v1/classes.rb', line 34861

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34866
34867
34868
# File 'lib/google/apis/compute_v1/classes.rb', line 34866

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34871
34872
34873
# File 'lib/google/apis/compute_v1/classes.rb', line 34871

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34878
34879
34880
34881
34882
34883
34884
34885
# File 'lib/google/apis/compute_v1/classes.rb', line 34878

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end