Class: Google::Apis::ComputeV1::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



31904
31905
31906
# File 'lib/google/apis/compute_v1/classes.rb', line 31904

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31872
31873
31874
# File 'lib/google/apis/compute_v1/classes.rb', line 31872

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



31877
31878
31879
# File 'lib/google/apis/compute_v1/classes.rb', line 31877

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


31882
31883
31884
# File 'lib/google/apis/compute_v1/classes.rb', line 31882

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31892
31893
31894
# File 'lib/google/apis/compute_v1/classes.rb', line 31892

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31897
31898
31899
# File 'lib/google/apis/compute_v1/classes.rb', line 31897

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31902
31903
31904
# File 'lib/google/apis/compute_v1/classes.rb', line 31902

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31909
31910
31911
31912
31913
31914
31915
31916
# File 'lib/google/apis/compute_v1/classes.rb', line 31909

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end