Class: Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::NetworkEdgeSecurityServicesScopedList>
A list of NetworkEdgeSecurityServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList
constructor
A new instance of NetworkEdgeSecurityServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList
Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.
36520 36521 36522 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
36476 36477 36478 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36476 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36481 36482 36483 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36481 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::NetworkEdgeSecurityServicesScopedList>
A list of NetworkEdgeSecurityServicesScopedList resources.
Corresponds to the JSON property items
36486 36487 36488 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36486 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkEdgeSecurityServiceAggregatedList for lists of
Network Edge Security Services.
Corresponds to the JSON property kind
36493 36494 36495 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36493 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36503 36504 36505 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36503 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36508 36509 36510 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36508 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
36513 36514 36515 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36513 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36518 36519 36520 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36518 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36525 36526 36527 36528 36529 36530 36531 36532 36533 36534 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36525 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |