Class: Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



36146
36147
36148
# File 'lib/google/apis/compute_v1/classes.rb', line 36146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


36102
36103
36104
# File 'lib/google/apis/compute_v1/classes.rb', line 36102

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36107
36108
36109
# File 'lib/google/apis/compute_v1/classes.rb', line 36107

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



36112
36113
36114
# File 'lib/google/apis/compute_v1/classes.rb', line 36112

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


36119
36120
36121
# File 'lib/google/apis/compute_v1/classes.rb', line 36119

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36129
36130
36131
# File 'lib/google/apis/compute_v1/classes.rb', line 36129

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36134
36135
36136
# File 'lib/google/apis/compute_v1/classes.rb', line 36134

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36139
36140
36141
# File 'lib/google/apis/compute_v1/classes.rb', line 36139

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36144
36145
36146
# File 'lib/google/apis/compute_v1/classes.rb', line 36144

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36151
36152
36153
36154
36155
36156
36157
36158
36159
36160
# File 'lib/google/apis/compute_v1/classes.rb', line 36151

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end