Class: Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::NetworkEdgeSecurityServicesScopedList>
A list of NetworkEdgeSecurityServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList
constructor
A new instance of NetworkEdgeSecurityServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList
Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.
35784 35785 35786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
35740 35741 35742 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35740 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35745 35746 35747 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35745 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::NetworkEdgeSecurityServicesScopedList>
A list of NetworkEdgeSecurityServicesScopedList resources.
Corresponds to the JSON property items
35750 35751 35752 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35750 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkEdgeSecurityServiceAggregatedList for lists of
Network Edge Security Services.
Corresponds to the JSON property kind
35757 35758 35759 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35757 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35767 35768 35769 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35767 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35772 35773 35774 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35772 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
35777 35778 35779 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35777 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35782 35783 35784 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35782 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35789 35790 35791 35792 35793 35794 35795 35796 35797 35798 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35789 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |