Class: Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



32234
32235
32236
# File 'lib/google/apis/compute_v1/classes.rb', line 32234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


32190
32191
32192
# File 'lib/google/apis/compute_v1/classes.rb', line 32190

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32195
32196
32197
# File 'lib/google/apis/compute_v1/classes.rb', line 32195

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



32200
32201
32202
# File 'lib/google/apis/compute_v1/classes.rb', line 32200

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


32207
32208
32209
# File 'lib/google/apis/compute_v1/classes.rb', line 32207

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32217
32218
32219
# File 'lib/google/apis/compute_v1/classes.rb', line 32217

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32222
32223
32224
# File 'lib/google/apis/compute_v1/classes.rb', line 32222

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


32227
32228
32229
# File 'lib/google/apis/compute_v1/classes.rb', line 32227

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32232
32233
32234
# File 'lib/google/apis/compute_v1/classes.rb', line 32232

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32239
32240
32241
32242
32243
32244
32245
32246
32247
32248
# File 'lib/google/apis/compute_v1/classes.rb', line 32239

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end