Class: Google::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



31416
31417
31418
# File 'lib/google/apis/compute_v1/classes.rb', line 31416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


31372
31373
31374
# File 'lib/google/apis/compute_v1/classes.rb', line 31372

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31377
31378
31379
# File 'lib/google/apis/compute_v1/classes.rb', line 31377

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



31382
31383
31384
# File 'lib/google/apis/compute_v1/classes.rb', line 31382

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


31389
31390
31391
# File 'lib/google/apis/compute_v1/classes.rb', line 31389

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31399
31400
31401
# File 'lib/google/apis/compute_v1/classes.rb', line 31399

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31404
31405
31406
# File 'lib/google/apis/compute_v1/classes.rb', line 31404

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


31409
31410
31411
# File 'lib/google/apis/compute_v1/classes.rb', line 31409

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31414
31415
31416
# File 'lib/google/apis/compute_v1/classes.rb', line 31414

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31421
31422
31423
31424
31425
31426
31427
31428
31429
31430
# File 'lib/google/apis/compute_v1/classes.rb', line 31421

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end