Class: Google::Apis::ComputeV1::NetworkEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The network endpoint.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional metadata defined as annotations on the network endpoint.
-
#client_destination_port ⇒ Fixnum
Represents the port number to which PSC consumer sends packets.
-
#fqdn ⇒ String
Optional fully qualified domain name of network endpoint.
-
#instance ⇒ String
The name or a URL of VM instance of this network endpoint.
-
#ip_address ⇒ String
Optional IPv4 address of network endpoint.
-
#ipv6_address ⇒ String
Optional IPv6 address of network endpoint.
-
#port ⇒ Fixnum
Optional port number of network endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpoint
constructor
A new instance of NetworkEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpoint
Returns a new instance of NetworkEndpoint.
36029 36030 36031 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36029 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional metadata defined as annotations on the network endpoint.
Corresponds to the JSON property annotations
35975 35976 35977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35975 def annotations @annotations end |
#client_destination_port ⇒ Fixnum
Represents the port number to which PSC consumer sends packets.
Optional. Only valid for network endpoint groups created withGCE_VM_IP_PORTMAP
endpoint type.
Corresponds to the JSON property clientDestinationPort
35982 35983 35984 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35982 def client_destination_port @client_destination_port end |
#fqdn ⇒ String
Optional fully qualified domain name of network endpoint. This can only be
specified when NetworkEndpointGroup.network_endpoint_type isNON_GCP_FQDN_PORT.
Corresponds to the JSON property fqdn
35988 35989 35990 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35988 def fqdn @fqdn end |
#instance ⇒ String
The name or a URL of VM instance of this network endpoint.
Optional, the field presence depends on the network endpoint type. The
field is required for network endpoints of type GCE_VM_IP andGCE_VM_IP_PORT.
The instance must be in the same zone of network endpoint group (for zonal
NEGs) or in the zone within the region of the NEG (for regional NEGs).
If the ipAddress is specified, it must belongs to the VM
instance.
The name must be 1-63 characters long, and comply withRFC1035
or be a valid URL pointing to an existing instance.
Corresponds to the JSON property instance
36001 36002 36003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36001 def instance @instance end |
#ip_address ⇒ String
Optional IPv4 address of network endpoint. The IP address must belong to a
VM in Compute Engine (either the primary IP or as part of an aliased IP
range). If the IP address is not specified, then the primary IP address for
the VM instance in the network that the network endpoint group belongs to
will be used.
This field is redundant and need not be set for network endpoints of
typeGCE_VM_IP. If set, it must be set to the primary internal IP
address of the attached VM instance that matches the subnetwork of the NEG.
The primary internal IP address from any NIC of a multi-NIC VM instance can
be added to a NEG as long as it matches the NEG subnetwork.
Corresponds to the JSON property ipAddress
36015 36016 36017 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36015 def ip_address @ip_address end |
#ipv6_address ⇒ String
Optional IPv6 address of network endpoint.
Corresponds to the JSON property ipv6Address
36020 36021 36022 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36020 def ipv6_address @ipv6_address end |
#port ⇒ Fixnum
Optional port number of network endpoint. If not specified, the
defaultPort for the network endpoint group will be used.
This field can not be set for network endpoints of typeGCE_VM_IP.
Corresponds to the JSON property port
36027 36028 36029 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36027 def port @port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36034 36035 36036 36037 36038 36039 36040 36041 36042 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36034 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @client_destination_port = args[:client_destination_port] if args.key?(:client_destination_port) @fqdn = args[:fqdn] if args.key?(:fqdn) @instance = args[:instance] if args.key?(:instance) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @port = args[:port] if args.key?(:port) end |