Class: Google::Apis::ComputeV1::NetworkEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The network endpoint.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional metadata defined as annotations on the network endpoint.
-
#client_destination_port ⇒ Fixnum
Represents the port number to which PSC consumer sends packets.
-
#fqdn ⇒ String
Optional fully qualified domain name of network endpoint.
-
#instance ⇒ String
The name or a URL of VM instance of this network endpoint.
-
#ip_address ⇒ String
Optional IPv4 address of network endpoint.
-
#ipv6_address ⇒ String
Optional IPv6 address of network endpoint.
-
#port ⇒ Fixnum
Optional port number of network endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpoint
constructor
A new instance of NetworkEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpoint
Returns a new instance of NetworkEndpoint.
35448 35449 35450 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional metadata defined as annotations on the network endpoint.
Corresponds to the JSON property annotations
35394 35395 35396 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35394 def annotations @annotations end |
#client_destination_port ⇒ Fixnum
Represents the port number to which PSC consumer sends packets.
Optional. Only valid for network endpoint groups created withGCE_VM_IP_PORTMAP
endpoint type.
Corresponds to the JSON property clientDestinationPort
35401 35402 35403 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35401 def client_destination_port @client_destination_port end |
#fqdn ⇒ String
Optional fully qualified domain name of network endpoint. This can only be
specified when NetworkEndpointGroup.network_endpoint_type isNON_GCP_FQDN_PORT.
Corresponds to the JSON property fqdn
35407 35408 35409 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35407 def fqdn @fqdn end |
#instance ⇒ String
The name or a URL of VM instance of this network endpoint.
Optional, the field presence depends on the network endpoint type. The
field is required for network endpoints of type GCE_VM_IP andGCE_VM_IP_PORT.
The instance must be in the same zone of network endpoint group (for zonal
NEGs) or in the zone within the region of the NEG (for regional NEGs).
If the ipAddress is specified, it must belongs to the VM
instance.
The name must be 1-63 characters long, and comply withRFC1035
or be a valid URL pointing to an existing instance.
Corresponds to the JSON property instance
35420 35421 35422 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35420 def instance @instance end |
#ip_address ⇒ String
Optional IPv4 address of network endpoint. The IP address must belong to a
VM in Compute Engine (either the primary IP or as part of an aliased IP
range). If the IP address is not specified, then the primary IP address for
the VM instance in the network that the network endpoint group belongs to
will be used.
This field is redundant and need not be set for network endpoints of
typeGCE_VM_IP. If set, it must be set to the primary internal IP
address of the attached VM instance that matches the subnetwork of the NEG.
The primary internal IP address from any NIC of a multi-NIC VM instance can
be added to a NEG as long as it matches the NEG subnetwork.
Corresponds to the JSON property ipAddress
35434 35435 35436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35434 def ip_address @ip_address end |
#ipv6_address ⇒ String
Optional IPv6 address of network endpoint.
Corresponds to the JSON property ipv6Address
35439 35440 35441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35439 def ipv6_address @ipv6_address end |
#port ⇒ Fixnum
Optional port number of network endpoint. If not specified, the
defaultPort for the network endpoint group will be used.
This field can not be set for network endpoints of typeGCE_VM_IP.
Corresponds to the JSON property port
35446 35447 35448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35446 def port @port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35453 35454 35455 35456 35457 35458 35459 35460 35461 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35453 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @client_destination_port = args[:client_destination_port] if args.key?(:client_destination_port) @fqdn = args[:fqdn] if args.key?(:fqdn) @instance = args[:instance] if args.key?(:instance) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @port = args[:port] if args.key?(:port) end |