Class: Google::Apis::ComputeV1::NetworkEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The network endpoint.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Metadata defined as annotations on the network endpoint.
-
#fqdn ⇒ String
Optional fully qualified domain name of network endpoint.
-
#instance ⇒ String
The name for a specific VM instance that the IP address belongs to.
-
#ip_address ⇒ String
Optional IPv4 address of network endpoint.
-
#port ⇒ Fixnum
Optional port number of network endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpoint
constructor
A new instance of NetworkEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpoint
Returns a new instance of NetworkEndpoint.
19265 19266 19267 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Metadata defined as annotations on the network endpoint.
Corresponds to the JSON property annotations
19234 19235 19236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19234 def annotations @annotations end |
#fqdn ⇒ String
Optional fully qualified domain name of network endpoint. This can only be
specified when NetworkEndpointGroup.network_endpoint_type is NON_GCP_FQDN_PORT.
Corresponds to the JSON property fqdn
19240 19241 19242 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19240 def fqdn @fqdn end |
#instance ⇒ String
The name for a specific VM instance that the IP address belongs to. This is
required for network endpoints of type GCE_VM_IP_PORT. The instance must be in
the same zone of network endpoint group. The name must be 1-63 characters long,
and comply with RFC1035.
Corresponds to the JSON property instance
19248 19249 19250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19248 def instance @instance end |
#ip_address ⇒ String
Optional IPv4 address of network endpoint. The IP address must belong to a VM
in Compute Engine (either the primary IP or as part of an aliased IP range).
If the IP address is not specified, then the primary IP address for the VM
instance in the network that the network endpoint group belongs to will be
used.
Corresponds to the JSON property ipAddress
19257 19258 19259 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19257 def ip_address @ip_address end |
#port ⇒ Fixnum
Optional port number of network endpoint. If not specified, the defaultPort
for the network endpoint group will be used.
Corresponds to the JSON property port
19263 19264 19265 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19263 def port @port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19270 19271 19272 19273 19274 19275 19276 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19270 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @fqdn = args[:fqdn] if args.key?(:fqdn) @instance = args[:instance] if args.key?(:instance) @ip_address = args[:ip_address] if args.key?(:ip_address) @port = args[:port] if args.key?(:port) end |