Class: Google::Apis::ComputeV1::NetworkEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a collection of network endpoints. A network endpoint group (NEG) defines how a set of endpoints should be reached, whether they are reachable, and where they are located. For more information about using NEGs for different use cases, seeNetwork endpoint groups overview. Note: Use the following APIs to manage network endpoint groups:

- To manage NEGs with zonal scope (such as zonal NEGs, hybrid connectivity NEGs): zonal

API

To manage NEGs with regional scope (such as regional internet NEGs, serverless NEGs, Private Service Connect NEGs): regional

API

To manage NEGs with global scope (such as global internet NEGs):global API

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroup

Returns a new instance of NetworkEndpointGroup.



32650
32651
32652
# File 'lib/google/apis/compute_v1/classes.rb', line 32650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Metadata defined as annotations on the network endpoint group. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


32519
32520
32521
# File 'lib/google/apis/compute_v1/classes.rb', line 32519

def annotations
  @annotations
end

#app_engineGoogle::Apis::ComputeV1::NetworkEndpointGroupAppEngine

Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present. Note: App Engine service must be in the same project and located in the same region as the Serverless NEG. Corresponds to the JSON property appEngine



32529
32530
32531
# File 'lib/google/apis/compute_v1/classes.rb', line 32529

def app_engine
  @app_engine
end

#cloud_functionGoogle::Apis::ComputeV1::NetworkEndpointGroupCloudFunction

Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask. Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG. Corresponds to the JSON property cloudFunction



32537
32538
32539
# File 'lib/google/apis/compute_v1/classes.rb', line 32537

def cloud_function
  @cloud_function
end

#cloud_runGoogle::Apis::ComputeV1::NetworkEndpointGroupCloudRun

Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask. Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG. Corresponds to the JSON property cloudRun



32547
32548
32549
# File 'lib/google/apis/compute_v1/classes.rb', line 32547

def cloud_run
  @cloud_run
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


32553
32554
32555
# File 'lib/google/apis/compute_v1/classes.rb', line 32553

def creation_timestamp
  @creation_timestamp
end

#default_portFixnum

The default port used if the port number is not specified in the network endpoint. Optional. If the network endpoint type is either GCE_VM_IP,SERVERLESS or PRIVATE_SERVICE_CONNECT, this field must not be specified. Corresponds to the JSON property defaultPort

Returns:

  • (Fixnum)


32562
32563
32564
# File 'lib/google/apis/compute_v1/classes.rb', line 32562

def default_port
  @default_port
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


32568
32569
32570
# File 'lib/google/apis/compute_v1/classes.rb', line 32568

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


32575
32576
32577
# File 'lib/google/apis/compute_v1/classes.rb', line 32575

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# networkEndpointGroup for network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


32581
32582
32583
# File 'lib/google/apis/compute_v1/classes.rb', line 32581

def kind
  @kind
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


32592
32593
32594
# File 'lib/google/apis/compute_v1/classes.rb', line 32592

def name
  @name
end

#networkString

The URL of the network to which all network endpoints in the NEG belong. Uses default project network if unspecified. Corresponds to the JSON property network

Returns:

  • (String)


32598
32599
32600
# File 'lib/google/apis/compute_v1/classes.rb', line 32598

def network
  @network
end

#network_endpoint_typeString

Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT, INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. Corresponds to the JSON property networkEndpointType

Returns:

  • (String)


32605
32606
32607
# File 'lib/google/apis/compute_v1/classes.rb', line 32605

def network_endpoint_type
  @network_endpoint_type
end

#psc_dataGoogle::Apis::ComputeV1::NetworkEndpointGroupPscData

All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT. Corresponds to the JSON property pscData



32611
32612
32613
# File 'lib/google/apis/compute_v1/classes.rb', line 32611

def psc_data
  @psc_data
end

#psc_target_serviceString

The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment. An example value is: asia-northeast3-cloudkms.googleapis.com. Optional. Only valid when networkEndpointType isPRIVATE_SERVICE_CONNECT. Corresponds to the JSON property pscTargetService

Returns:

  • (String)


32619
32620
32621
# File 'lib/google/apis/compute_v1/classes.rb', line 32619

def psc_target_service
  @psc_target_service
end

#regionString

Output only. [Output Only] The URL of theregion where the network endpoint group is located. Corresponds to the JSON property region

Returns:

  • (String)


32625
32626
32627
# File 'lib/google/apis/compute_v1/classes.rb', line 32625

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32630
32631
32632
# File 'lib/google/apis/compute_v1/classes.rb', line 32630

def self_link
  @self_link
end

#sizeFixnum

Output only. [Output only] Number of network endpoints in the network endpoint group. Corresponds to the JSON property size

Returns:

  • (Fixnum)


32636
32637
32638
# File 'lib/google/apis/compute_v1/classes.rb', line 32636

def size
  @size
end

#subnetworkString

Optional URL of the subnetwork to which all network endpoints in the NEG belong. Corresponds to the JSON property subnetwork

Returns:

  • (String)


32642
32643
32644
# File 'lib/google/apis/compute_v1/classes.rb', line 32642

def subnetwork
  @subnetwork
end

#zoneString

Output only. [Output Only] The URL of thezone where the network endpoint group is located. Corresponds to the JSON property zone

Returns:

  • (String)


32648
32649
32650
# File 'lib/google/apis/compute_v1/classes.rb', line 32648

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32655
32656
32657
32658
32659
32660
32661
32662
32663
32664
32665
32666
32667
32668
32669
32670
32671
32672
32673
32674
32675
# File 'lib/google/apis/compute_v1/classes.rb', line 32655

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @app_engine = args[:app_engine] if args.key?(:app_engine)
  @cloud_function = args[:cloud_function] if args.key?(:cloud_function)
  @cloud_run = args[:cloud_run] if args.key?(:cloud_run)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_port = args[:default_port] if args.key?(:default_port)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_endpoint_type = args[:network_endpoint_type] if args.key?(:network_endpoint_type)
  @psc_data = args[:psc_data] if args.key?(:psc_data)
  @psc_target_service = args[:psc_target_service] if args.key?(:psc_target_service)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @size = args[:size] if args.key?(:size)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @zone = args[:zone] if args.key?(:zone)
end