Class: Google::Apis::ComputeV1::NetworkEndpointGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList

Returns a new instance of NetworkEndpointGroupAggregatedList.



37004
37005
37006
# File 'lib/google/apis/compute_v1/classes.rb', line 37004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36965
36966
36967
# File 'lib/google/apis/compute_v1/classes.rb', line 36965

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NetworkEndpointGroupsScopedList>

A list of NetworkEndpointGroupsScopedList resources. Corresponds to the JSON property items



36970
36971
36972
# File 'lib/google/apis/compute_v1/classes.rb', line 36970

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups. Corresponds to the JSON property kind

Returns:

  • (String)


36977
36978
36979
# File 'lib/google/apis/compute_v1/classes.rb', line 36977

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36987
36988
36989
# File 'lib/google/apis/compute_v1/classes.rb', line 36987

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36992
36993
36994
# File 'lib/google/apis/compute_v1/classes.rb', line 36992

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36997
36998
36999
# File 'lib/google/apis/compute_v1/classes.rb', line 36997

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37002
37003
37004
# File 'lib/google/apis/compute_v1/classes.rb', line 37002

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37009
37010
37011
37012
37013
37014
37015
37016
37017
# File 'lib/google/apis/compute_v1/classes.rb', line 37009

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end