Class: Google::Apis::ComputeV1::NetworkEndpointGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList

Returns a new instance of NetworkEndpointGroupAggregatedList.



36288
36289
36290
# File 'lib/google/apis/compute_v1/classes.rb', line 36288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36249
36250
36251
# File 'lib/google/apis/compute_v1/classes.rb', line 36249

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NetworkEndpointGroupsScopedList>

A list of NetworkEndpointGroupsScopedList resources. Corresponds to the JSON property items



36254
36255
36256
# File 'lib/google/apis/compute_v1/classes.rb', line 36254

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups. Corresponds to the JSON property kind

Returns:

  • (String)


36261
36262
36263
# File 'lib/google/apis/compute_v1/classes.rb', line 36261

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36271
36272
36273
# File 'lib/google/apis/compute_v1/classes.rb', line 36271

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36276
36277
36278
# File 'lib/google/apis/compute_v1/classes.rb', line 36276

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


36281
36282
36283
# File 'lib/google/apis/compute_v1/classes.rb', line 36281

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36286
36287
36288
# File 'lib/google/apis/compute_v1/classes.rb', line 36286

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36293
36294
36295
36296
36297
36298
36299
36300
36301
# File 'lib/google/apis/compute_v1/classes.rb', line 36293

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end