Class: Google::Apis::ComputeV1::NetworkEndpointGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList

Returns a new instance of NetworkEndpointGroupAggregatedList.



35693
35694
35695
# File 'lib/google/apis/compute_v1/classes.rb', line 35693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35654
35655
35656
# File 'lib/google/apis/compute_v1/classes.rb', line 35654

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NetworkEndpointGroupsScopedList>

A list of NetworkEndpointGroupsScopedList resources. Corresponds to the JSON property items



35659
35660
35661
# File 'lib/google/apis/compute_v1/classes.rb', line 35659

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups. Corresponds to the JSON property kind

Returns:

  • (String)


35666
35667
35668
# File 'lib/google/apis/compute_v1/classes.rb', line 35666

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35676
35677
35678
# File 'lib/google/apis/compute_v1/classes.rb', line 35676

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35681
35682
35683
# File 'lib/google/apis/compute_v1/classes.rb', line 35681

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35686
35687
35688
# File 'lib/google/apis/compute_v1/classes.rb', line 35686

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35691
35692
35693
# File 'lib/google/apis/compute_v1/classes.rb', line 35691

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35698
35699
35700
35701
35702
35703
35704
35705
35706
# File 'lib/google/apis/compute_v1/classes.rb', line 35698

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end