Class: Google::Apis::ComputeV1::NetworkEndpointGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::NetworkEndpointGroupsScopedList>
A list of NetworkEndpointGroupsScopedList resources.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute# networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList
constructor
A new instance of NetworkEndpointGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList
Returns a new instance of NetworkEndpointGroupAggregatedList.
19473 19474 19475 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19473 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19435 19436 19437 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19435 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::NetworkEndpointGroupsScopedList>
A list of NetworkEndpointGroupsScopedList resources.
Corresponds to the JSON property items
19440 19441 19442 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19440 def items @items end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#
networkEndpointGroupAggregatedList for aggregated lists of network endpoint
groups.
Corresponds to the JSON property kind
19447 19448 19449 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19447 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19456 19457 19458 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19456 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19461 19462 19463 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19461 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
19466 19467 19468 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19466 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19471 19472 19473 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19471 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19478 19479 19480 19481 19482 19483 19484 19485 19486 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19478 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |