Class: Google::Apis::ComputeV1::NetworkEndpointGroupAppEngine
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupAppEngine
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present. Note: App Engine service must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#service ⇒ String
Optional serving service.
-
#url_mask ⇒ String
An URL mask is one of the main components of the Cloud Function.
-
#version ⇒ String
Optional serving version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupAppEngine
constructor
A new instance of NetworkEndpointGroupAppEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupAppEngine
Returns a new instance of NetworkEndpointGroupAppEngine.
32851 32852 32853 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service ⇒ String
Optional serving service.
The service name is case-sensitive and must be 1-63
characters long.
Example value: default, my-service.
Corresponds to the JSON property service
32825 32826 32827 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32825 def service @service end |
#url_mask ⇒ String
An URL
mask is one of the main components of the Cloud Function.
A template to parse service and version fields
from a request URL. URL mask allows for routing to multiple App Engine
services without having to create multiple Network Endpoint Groups and
backend services.
For example, the request URLsfoo1-dot-appname.appspot.com/v1 andfoo1-dot-
appname.appspot.com/v2 can be backed by the same
Serverless NEG with URL maskservice = "foo1", version = "v1"
and service = "foo1", version = "v2"
respectively.
Corresponds to the JSON property urlMask
32841 32842 32843 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32841 def url_mask @url_mask end |
#version ⇒ String
Optional serving version.
The version name is case-sensitive and must be 1-100
characters long.
Example value: v1, v2.
Corresponds to the JSON property version
32849 32850 32851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32849 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32856 32857 32858 32859 32860 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32856 def update!(**args) @service = args[:service] if args.key?(:service) @url_mask = args[:url_mask] if args.key?(:url_mask) @version = args[:version] if args.key?(:version) end |