Class: Google::Apis::ComputeV1::NetworkEndpointGroupAppEngine
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupAppEngine
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present. Note: App Engine service must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#service ⇒ String
Optional serving service.
-
#url_mask ⇒ String
A template to parse service and version fields from a request URL.
-
#version ⇒ String
Optional serving version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupAppEngine
constructor
A new instance of NetworkEndpointGroupAppEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupAppEngine
Returns a new instance of NetworkEndpointGroupAppEngine.
19584 19585 19586 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service ⇒ String
Optional serving service. The service name is case-sensitive and must be 1-63
characters long. Example value: "default", "my-service".
Corresponds to the JSON property service
19565 19566 19567 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19565 def service @service end |
#url_mask ⇒ String
A template to parse service and version fields from a request URL. URL mask
allows for routing to multiple App Engine services without having to create
multiple Network Endpoint Groups and backend services. For example, the
request URLs "foo1-dot-appname.appspot.com/v1" and "foo1-dot-appname.appspot.
com/v2" can be backed by the same Serverless NEG with URL mask "-dot-appname.
appspot.com/". The URL mask will parse them to service = "foo1", version = "
v1" and service = "foo1", version = "v2" respectively.
Corresponds to the JSON property urlMask
19576 19577 19578 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19576 def url_mask @url_mask end |
#version ⇒ String
Optional serving version. The version name is case-sensitive and must be 1-100
characters long. Example value: "v1", "v2".
Corresponds to the JSON property version
19582 19583 19584 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19582 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19589 19590 19591 19592 19593 |
# File 'lib/google/apis/compute_v1/classes.rb', line 19589 def update!(**args) @service = args[:service] if args.key?(:service) @url_mask = args[:url_mask] if args.key?(:url_mask) @version = args[:version] if args.key?(:version) end |