Class: Google::Apis::ComputeV1::NetworkEndpointGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupList
constructor
A new instance of NetworkEndpointGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupList
Returns a new instance of NetworkEndpointGroupList.
37276 37277 37278 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37276 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37242 37243 37244 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37242 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
Corresponds to the JSON property items
37247 37248 37249 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37247 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupList for network endpoint group
lists.
Corresponds to the JSON property kind
37254 37255 37256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37254 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37264 37265 37266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37264 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37269 37270 37271 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37269 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
37274 37275 37276 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37274 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37281 37282 37283 37284 37285 37286 37287 37288 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37281 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |