Class: Google::Apis::ComputeV1::NetworkEndpointGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupList
constructor
A new instance of NetworkEndpointGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupList
Returns a new instance of NetworkEndpointGroupList.
36924 36925 36926 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36890 36891 36892 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36890 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
Corresponds to the JSON property items
36895 36896 36897 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36895 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupList for network endpoint group
lists.
Corresponds to the JSON property kind
36902 36903 36904 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36902 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36912 36913 36914 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36912 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36917 36918 36919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36917 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36922 36923 36924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36922 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36929 36930 36931 36932 36933 36934 36935 36936 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36929 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |