Class: Google::Apis::ComputeV1::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



36914
36915
36916
# File 'lib/google/apis/compute_v1/classes.rb', line 36914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36880
36881
36882
# File 'lib/google/apis/compute_v1/classes.rb', line 36880

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



36885
36886
36887
# File 'lib/google/apis/compute_v1/classes.rb', line 36885

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


36892
36893
36894
# File 'lib/google/apis/compute_v1/classes.rb', line 36892

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36902
36903
36904
# File 'lib/google/apis/compute_v1/classes.rb', line 36902

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36907
36908
36909
# File 'lib/google/apis/compute_v1/classes.rb', line 36907

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36912
36913
36914
# File 'lib/google/apis/compute_v1/classes.rb', line 36912

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36919
36920
36921
36922
36923
36924
36925
36926
# File 'lib/google/apis/compute_v1/classes.rb', line 36919

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end