Class: Google::Apis::ComputeV1::NetworkEndpointGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupList
constructor
A new instance of NetworkEndpointGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupList
Returns a new instance of NetworkEndpointGroupList.
36750 36751 36752 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36716 36717 36718 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36716 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
Corresponds to the JSON property items
36721 36722 36723 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36721 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupList for network endpoint group
lists.
Corresponds to the JSON property kind
36728 36729 36730 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36728 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36738 36739 36740 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36738 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36743 36744 36745 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36743 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36748 36749 36750 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36748 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36755 36756 36757 36758 36759 36760 36761 36762 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36755 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |