Class: Google::Apis::ComputeV1::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



36560
36561
36562
# File 'lib/google/apis/compute_v1/classes.rb', line 36560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36526
36527
36528
# File 'lib/google/apis/compute_v1/classes.rb', line 36526

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



36531
36532
36533
# File 'lib/google/apis/compute_v1/classes.rb', line 36531

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


36538
36539
36540
# File 'lib/google/apis/compute_v1/classes.rb', line 36538

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36548
36549
36550
# File 'lib/google/apis/compute_v1/classes.rb', line 36548

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36553
36554
36555
# File 'lib/google/apis/compute_v1/classes.rb', line 36553

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36558
36559
36560
# File 'lib/google/apis/compute_v1/classes.rb', line 36558

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36565
36566
36567
36568
36569
36570
36571
36572
# File 'lib/google/apis/compute_v1/classes.rb', line 36565

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end