Class: Google::Apis::ComputeV1::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



35965
35966
35967
# File 'lib/google/apis/compute_v1/classes.rb', line 35965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35931
35932
35933
# File 'lib/google/apis/compute_v1/classes.rb', line 35931

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



35936
35937
35938
# File 'lib/google/apis/compute_v1/classes.rb', line 35936

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


35943
35944
35945
# File 'lib/google/apis/compute_v1/classes.rb', line 35943

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35953
35954
35955
# File 'lib/google/apis/compute_v1/classes.rb', line 35953

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35958
35959
35960
# File 'lib/google/apis/compute_v1/classes.rb', line 35958

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35963
35964
35965
# File 'lib/google/apis/compute_v1/classes.rb', line 35963

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35970
35971
35972
35973
35974
35975
35976
35977
# File 'lib/google/apis/compute_v1/classes.rb', line 35970

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end