Class: Google::Apis::ComputeV1::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



32996
32997
32998
# File 'lib/google/apis/compute_v1/classes.rb', line 32996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32962
32963
32964
# File 'lib/google/apis/compute_v1/classes.rb', line 32962

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



32967
32968
32969
# File 'lib/google/apis/compute_v1/classes.rb', line 32967

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


32974
32975
32976
# File 'lib/google/apis/compute_v1/classes.rb', line 32974

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32984
32985
32986
# File 'lib/google/apis/compute_v1/classes.rb', line 32984

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32989
32990
32991
# File 'lib/google/apis/compute_v1/classes.rb', line 32989

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32994
32995
32996
# File 'lib/google/apis/compute_v1/classes.rb', line 32994

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33001
33002
33003
33004
33005
33006
33007
33008
# File 'lib/google/apis/compute_v1/classes.rb', line 33001

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end