Class: Google::Apis::ComputeV1::NetworkEndpointGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupList
constructor
A new instance of NetworkEndpointGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupList
Returns a new instance of NetworkEndpointGroupList.
32165 32166 32167 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
32131 32132 32133 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32131 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
Corresponds to the JSON property items
32136 32137 32138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32136 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupList for network endpoint group
lists.
Corresponds to the JSON property kind
32143 32144 32145 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32143 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
32153 32154 32155 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32153 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
32158 32159 32160 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32158 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
32163 32164 32165 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32163 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32170 32171 32172 32173 32174 32175 32176 32177 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32170 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |