Class: Google::Apis::ComputeV1::NetworkEndpointGroupPscData
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupPscData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.
Instance Attribute Summary collapse
-
#consumer_psc_address ⇒ String
Output only.
-
#producer_port ⇒ Fixnum
The psc producer port is used to connect PSC NEG with specific port on the PSC Producer side; should only be used for the PRIVATE_SERVICE_CONNECT NEG type Corresponds to the JSON property
producerPort. -
#psc_connection_id ⇒ Fixnum
Output only.
-
#psc_connection_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupPscData
constructor
A new instance of NetworkEndpointGroupPscData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupPscData
Returns a new instance of NetworkEndpointGroupPscData.
32282 32283 32284 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_psc_address ⇒ String
Output only. [Output Only] Address allocated from given subnetwork for PSC.
This IP
address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in
L7 PSC-XLB.
Corresponds to the JSON property consumerPscAddress
32261 32262 32263 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32261 def consumer_psc_address @consumer_psc_address end |
#producer_port ⇒ Fixnum
The psc producer port is used to connect PSC NEG with specific port on
the PSC Producer side; should only be used for the
PRIVATE_SERVICE_CONNECT NEG type
Corresponds to the JSON property producerPort
32268 32269 32270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32268 def producer_port @producer_port end |
#psc_connection_id ⇒ Fixnum
Output only. [Output Only] The PSC connection id of the PSC Network Endpoint
Group
Consumer.
Corresponds to the JSON property pscConnectionId
32275 32276 32277 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32275 def psc_connection_id @psc_connection_id end |
#psc_connection_status ⇒ String
Output only. [Output Only] The connection status of the PSC Forwarding Rule.
Corresponds to the JSON property pscConnectionStatus
32280 32281 32282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32280 def psc_connection_status @psc_connection_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32287 32288 32289 32290 32291 32292 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32287 def update!(**args) @consumer_psc_address = args[:consumer_psc_address] if args.key?(:consumer_psc_address) @producer_port = args[:producer_port] if args.key?(:producer_port) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status) end |