Class: Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointWithHealthStatus>
A list of NetworkEndpointWithHealthStatus resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints
constructor
A new instance of NetworkEndpointGroupsListNetworkEndpoints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints
Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.
37502 37503 37504 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37502 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37473 37474 37475 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37473 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointWithHealthStatus>
A list of NetworkEndpointWithHealthStatus resources.
Corresponds to the JSON property items
37478 37479 37480 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37478 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupsListNetworkEndpoints for the list
of network endpoints in the specified network endpoint group.
Corresponds to the JSON property kind
37485 37486 37487 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37485 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37495 37496 37497 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37495 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
37500 37501 37502 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37500 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37507 37508 37509 37510 37511 37512 37513 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37507 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |