Class: Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints

Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.



37150
37151
37152
# File 'lib/google/apis/compute_v1/classes.rb', line 37150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37121
37122
37123
# File 'lib/google/apis/compute_v1/classes.rb', line 37121

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkEndpointWithHealthStatus>

A list of NetworkEndpointWithHealthStatus resources. Corresponds to the JSON property items



37126
37127
37128
# File 'lib/google/apis/compute_v1/classes.rb', line 37126

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


37133
37134
37135
# File 'lib/google/apis/compute_v1/classes.rb', line 37133

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37143
37144
37145
# File 'lib/google/apis/compute_v1/classes.rb', line 37143

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37148
37149
37150
# File 'lib/google/apis/compute_v1/classes.rb', line 37148

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37155
37156
37157
37158
37159
37160
37161
# File 'lib/google/apis/compute_v1/classes.rb', line 37155

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end