Class: Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointWithHealthStatus>
A list of NetworkEndpointWithHealthStatus resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints
constructor
A new instance of NetworkEndpointGroupsListNetworkEndpoints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints
Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.
36786 36787 36788 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36757 36758 36759 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36757 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkEndpointWithHealthStatus>
A list of NetworkEndpointWithHealthStatus resources.
Corresponds to the JSON property items
36762 36763 36764 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36762 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupsListNetworkEndpoints for the list
of network endpoints in the specified network endpoint group.
Corresponds to the JSON property kind
36769 36770 36771 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36769 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36779 36780 36781 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36779 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36784 36785 36786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36784 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36791 36792 36793 36794 36795 36796 36797 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36791 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |