Class: Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints

Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.



33222
33223
33224
# File 'lib/google/apis/compute_v1/classes.rb', line 33222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33193
33194
33195
# File 'lib/google/apis/compute_v1/classes.rb', line 33193

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkEndpointWithHealthStatus>

A list of NetworkEndpointWithHealthStatus resources. Corresponds to the JSON property items



33198
33199
33200
# File 'lib/google/apis/compute_v1/classes.rb', line 33198

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


33205
33206
33207
# File 'lib/google/apis/compute_v1/classes.rb', line 33205

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33215
33216
33217
# File 'lib/google/apis/compute_v1/classes.rb', line 33215

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33220
33221
33222
# File 'lib/google/apis/compute_v1/classes.rb', line 33220

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33227
33228
33229
33230
33231
33232
33233
# File 'lib/google/apis/compute_v1/classes.rb', line 33227

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end