Class: Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints

Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.



32391
32392
32393
# File 'lib/google/apis/compute_v1/classes.rb', line 32391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32362
32363
32364
# File 'lib/google/apis/compute_v1/classes.rb', line 32362

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkEndpointWithHealthStatus>

A list of NetworkEndpointWithHealthStatus resources. Corresponds to the JSON property items



32367
32368
32369
# File 'lib/google/apis/compute_v1/classes.rb', line 32367

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


32374
32375
32376
# File 'lib/google/apis/compute_v1/classes.rb', line 32374

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32384
32385
32386
# File 'lib/google/apis/compute_v1/classes.rb', line 32384

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32389
32390
32391
# File 'lib/google/apis/compute_v1/classes.rb', line 32389

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32396
32397
32398
32399
32400
32401
32402
# File 'lib/google/apis/compute_v1/classes.rb', line 32396

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end