Class: Google::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints

Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.



19884
19885
19886
# File 'lib/google/apis/compute_v1/classes.rb', line 19884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19856
19857
19858
# File 'lib/google/apis/compute_v1/classes.rb', line 19856

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkEndpointWithHealthStatus>

A list of NetworkEndpointWithHealthStatus resources. Corresponds to the JSON property items



19861
19862
19863
# File 'lib/google/apis/compute_v1/classes.rb', line 19861

def items
  @items
end

#kindString

[Output Only] The resource type, which is always compute# networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


19868
19869
19870
# File 'lib/google/apis/compute_v1/classes.rb', line 19868

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19877
19878
19879
# File 'lib/google/apis/compute_v1/classes.rb', line 19877

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::NetworkEndpointGroupsListNetworkEndpoints::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



19882
19883
19884
# File 'lib/google/apis/compute_v1/classes.rb', line 19882

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19889
19890
19891
19892
19893
19894
19895
# File 'lib/google/apis/compute_v1/classes.rb', line 19889

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end