Class: Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



37759
37760
37761
# File 'lib/google/apis/compute_v1/classes.rb', line 37759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37720
37721
37722
# File 'lib/google/apis/compute_v1/classes.rb', line 37720

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



37725
37726
37727
# File 'lib/google/apis/compute_v1/classes.rb', line 37725

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


37732
37733
37734
# File 'lib/google/apis/compute_v1/classes.rb', line 37732

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37742
37743
37744
# File 'lib/google/apis/compute_v1/classes.rb', line 37742

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37747
37748
37749
# File 'lib/google/apis/compute_v1/classes.rb', line 37747

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


37752
37753
37754
# File 'lib/google/apis/compute_v1/classes.rb', line 37752

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37757
37758
37759
# File 'lib/google/apis/compute_v1/classes.rb', line 37757

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37764
37765
37766
37767
37768
37769
37770
37771
37772
# File 'lib/google/apis/compute_v1/classes.rb', line 37764

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end