Class: Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::FirewallPoliciesScopedList>
A list of FirewallPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList
constructor
A new instance of NetworkFirewallPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList
Returns a new instance of NetworkFirewallPolicyAggregatedList.
37232 37233 37234 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37232 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37193 37194 37195 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37193 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::FirewallPoliciesScopedList>
A list of FirewallPoliciesScopedList resources.
Corresponds to the JSON property items
37198 37199 37200 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37198 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkFirewallPoliciesAggregatedList for lists of
network firewall policies.
Corresponds to the JSON property kind
37205 37206 37207 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37205 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37215 37216 37217 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37215 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37220 37221 37222 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37220 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
37225 37226 37227 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37225 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
37230 37231 37232 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37230 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37237 37238 37239 37240 37241 37242 37243 37244 37245 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37237 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |