Class: Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



37233
37234
37235
# File 'lib/google/apis/compute_v1/classes.rb', line 37233

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37194
37195
37196
# File 'lib/google/apis/compute_v1/classes.rb', line 37194

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



37199
37200
37201
# File 'lib/google/apis/compute_v1/classes.rb', line 37199

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


37206
37207
37208
# File 'lib/google/apis/compute_v1/classes.rb', line 37206

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37216
37217
37218
# File 'lib/google/apis/compute_v1/classes.rb', line 37216

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37221
37222
37223
# File 'lib/google/apis/compute_v1/classes.rb', line 37221

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


37226
37227
37228
# File 'lib/google/apis/compute_v1/classes.rb', line 37226

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37231
37232
37233
# File 'lib/google/apis/compute_v1/classes.rb', line 37231

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37238
37239
37240
37241
37242
37243
37244
37245
37246
# File 'lib/google/apis/compute_v1/classes.rb', line 37238

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end