Class: Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::FirewallPoliciesScopedList>
A list of FirewallPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList
constructor
A new instance of NetworkFirewallPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList
Returns a new instance of NetworkFirewallPolicyAggregatedList.
32648 32649 32650 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32648 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
32609 32610 32611 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32609 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::FirewallPoliciesScopedList>
A list of FirewallPoliciesScopedList resources.
Corresponds to the JSON property items
32614 32615 32616 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32614 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkFirewallPoliciesAggregatedList for lists of
network firewall policies.
Corresponds to the JSON property kind
32621 32622 32623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32621 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
32631 32632 32633 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32631 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
32636 32637 32638 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32636 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
32641 32642 32643 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32641 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkFirewallPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
32646 32647 32648 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32646 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32653 32654 32655 32656 32657 32658 32659 32660 32661 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32653 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |