Class: Google::Apis::ComputeV1::NetworkInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A network interface resource attached to an instance.
Instance Attribute Summary collapse
-
#access_configs ⇒ Array<Google::Apis::ComputeV1::AccessConfig>
An array of configurations for this interface.
-
#alias_ip_ranges ⇒ Array<Google::Apis::ComputeV1::AliasIpRange>
An array of alias IP ranges for this network interface.
-
#alias_ipv6_ranges ⇒ Array<Google::Apis::ComputeV1::AliasIpRange>
An array of alias IPv6 ranges for this network interface.
-
#enable_vpc_scoped_dns ⇒ Boolean
(also: #enable_vpc_scoped_dns?)
Optional.
-
#fingerprint ⇒ String
Fingerprint hash of contents stored in this network interface.
-
#igmp_query ⇒ String
Indicate whether igmp query is enabled on the network interface or not.
-
#internal_ipv6_prefix_length ⇒ Fixnum
The prefix length of the primary internal IPv6 range.
-
#ipv6_access_configs ⇒ Array<Google::Apis::ComputeV1::AccessConfig>
An array of IPv6 access configurations for this interface.
-
#ipv6_access_type ⇒ String
Output only.
-
#ipv6_address ⇒ String
An IPv6 internal network address for this network interface.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] The name of the network interface, which is generated by the server.
-
#network ⇒ String
URL of the VPC network resource for this instance.
-
#network_attachment ⇒ String
The URL of the network attachment that this interface should connect to in the following format: projects/
project_number/regions/region_name/networkAttachments/network_attachment_name. -
#network_ip ⇒ String
An IPv4 internal IP address to assign to the instance for this network interface.
-
#nic_type ⇒ String
The type of vNIC to be used on this interface.
-
#parent_nic_name ⇒ String
Name of the parent network interface of a dynamic network interface.
-
#queue_count ⇒ Fixnum
The networking queue count that's specified by users for the network interface.
-
#service_class_id ⇒ String
Optional.
-
#stack_type ⇒ String
The stack type for this network interface.
-
#subnetwork ⇒ String
The URL of the Subnetwork resource for this instance.
-
#vlan ⇒ Fixnum
VLAN tag of a dynamic network interface, must be an integer in the range from 2 to 255 inclusively.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterface
constructor
A new instance of NetworkInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInterface
Returns a new instance of NetworkInterface.
38039 38040 38041 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38039 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_configs ⇒ Array<Google::Apis::ComputeV1::AccessConfig>
An array of configurations for this interface. Currently, only one access
config, ONE_TO_ONE_NAT, is supported. If there are noaccessConfigs specified,
then this instance will have
no external internet access.
Corresponds to the JSON property accessConfigs
37867 37868 37869 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37867 def access_configs @access_configs end |
#alias_ip_ranges ⇒ Array<Google::Apis::ComputeV1::AliasIpRange>
An array of alias IP ranges for this network interface.
You can only specify this field for network interfaces in VPC networks.
Corresponds to the JSON property aliasIpRanges
37873 37874 37875 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37873 def alias_ip_ranges @alias_ip_ranges end |
#alias_ipv6_ranges ⇒ Array<Google::Apis::ComputeV1::AliasIpRange>
An array of alias IPv6 ranges for this network interface.
You can only specify this field for network interfaces in VPC networks.
Corresponds to the JSON property aliasIpv6Ranges
37879 37880 37881 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37879 def alias_ipv6_ranges @alias_ipv6_ranges end |
#enable_vpc_scoped_dns ⇒ Boolean Also known as: enable_vpc_scoped_dns?
Optional. If true, DNS resolution will be enabled over this interface. Only
valid
with network_attachment.
Corresponds to the JSON property enableVpcScopedDns
37886 37887 37888 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37886 def enable_vpc_scoped_dns @enable_vpc_scoped_dns end |
#fingerprint ⇒ String
Fingerprint hash of contents stored in this network interface.
This field will be ignored when inserting an Instance or
adding a NetworkInterface. An up-to-date
fingerprint must be provided in order to update theNetworkInterface. The
request will fail with error400 Bad Request if the fingerprint is not provided,
or412 Precondition Failed if the fingerprint is out of date.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
37898 37899 37900 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37898 def fingerprint @fingerprint end |
#igmp_query ⇒ String
Indicate whether igmp query is enabled on the network interface
or not. If enabled, also indicates the version of IGMP supported.
Corresponds to the JSON property igmpQuery
37904 37905 37906 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37904 def igmp_query @igmp_query end |
#internal_ipv6_prefix_length ⇒ Fixnum
The prefix length of the primary internal IPv6 range.
Corresponds to the JSON property internalIpv6PrefixLength
37909 37910 37911 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37909 def internal_ipv6_prefix_length @internal_ipv6_prefix_length end |
#ipv6_access_configs ⇒ Array<Google::Apis::ComputeV1::AccessConfig>
An array of IPv6 access configurations for this interface. Currently, only
one IPv6 access config, DIRECT_IPV6, is supported. If there
is no ipv6AccessConfig specified, then this instance will
have no external IPv6 Internet access.
Corresponds to the JSON property ipv6AccessConfigs
37917 37918 37919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37917 def ipv6_access_configs @ipv6_access_configs end |
#ipv6_access_type ⇒ String
Output only. [Output Only] One of EXTERNAL, INTERNAL to indicate whether the
IP can be
accessed from the Internet. This field is always inherited from its
subnetwork.
Valid only if stackType is IPV4_IPV6.
Corresponds to the JSON property ipv6AccessType
37926 37927 37928 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37926 def ipv6_access_type @ipv6_access_type end |
#ipv6_address ⇒ String
An IPv6 internal network address for this network interface. To
use a static internal IP address, it must be unused and in the same region
as the instance's zone. If not specified, Google Cloud will automatically
assign an internal IPv6 address from the instance's subnetwork.
Corresponds to the JSON property ipv6Address
37934 37935 37936 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37934 def ipv6_address @ipv6_address end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
networkInterface for network interfaces.
Corresponds to the JSON property kind
37940 37941 37942 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37940 def kind @kind end |
#name ⇒ String
[Output Only] The name of the network interface, which is generated by the
server. For a VM, the network interface uses the nicN naming
format. Where N is a value between 0 and7. The default interface value is nic0.
Corresponds to the JSON property name
37947 37948 37949 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37947 def name @name end |
#network ⇒ String
URL of the VPC network resource for this instance. When creating an instance, if neither the network nor the subnetwork is specified, the default network global/networks/default is used. If the selected project doesn't have the default network, you must specify a network or subnet. If the network is not specified but the subnetwork is specified, the network is inferred. If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/global/networks/ network
- projects/project/global/networks/network
- global/networks/default
Corresponds to the JSON property
network
37965 37966 37967 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37965 def network @network end |
#network_attachment ⇒ String
The URL of the network attachment that this interface should connect
to in the following format:
projects/project_number/regions/region_name/networkAttachments/
network_attachment_name.
Corresponds to the JSON property networkAttachment
37973 37974 37975 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37973 def @network_attachment end |
#network_ip ⇒ String
An IPv4 internal IP address to assign to the instance for this network
interface. If not specified by the user, an unused internal IP is
assigned by the system.
Corresponds to the JSON property networkIP
37980 37981 37982 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37980 def network_ip @network_ip end |
#nic_type ⇒ String
The type of vNIC to be used on this interface. This may be gVNIC or
VirtioNet.
Corresponds to the JSON property nicType
37986 37987 37988 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37986 def nic_type @nic_type end |
#parent_nic_name ⇒ String
Name of the parent network interface of a dynamic network interface.
Corresponds to the JSON property parentNicName
37991 37992 37993 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37991 def parent_nic_name @parent_nic_name end |
#queue_count ⇒ Fixnum
The networking queue count that's specified by users for the network
interface. Both Rx and Tx queues will be set to this number. It'll be empty
if not specified by the users.
Corresponds to the JSON property queueCount
37998 37999 38000 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37998 def queue_count @queue_count end |
#service_class_id ⇒ String
Optional. Producer Service's Service class Id for the region of this network
interface. Can only be used with network_attachment. It is not possible to
use on its own however, network_attachment can be used without
service_class_id.
Corresponds to the JSON property serviceClassId
38006 38007 38008 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38006 def service_class_id @service_class_id end |
#stack_type ⇒ String
The stack type for this network interface. To assign only IPv4 addresses,
use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, useIPV4_IPV6. If not
specified, IPV4_ONLY is used.
This field can be both set at instance creation and update network
interface operations.
Corresponds to the JSON property stackType
38015 38016 38017 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38015 def stack_type @stack_type end |
#subnetwork ⇒ String
The URL of the Subnetwork resource for this instance. If the network resource is inlegacy mode, do not specify this field. If the network is in auto subnet mode, specifying the subnetwork is optional. If the network is in custom subnet mode, specifying the subnetwork is required. If you specify this field, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ subnetworks/subnetwork
- regions/region/subnetworks/subnetwork
Corresponds to the JSON property
subnetwork
38031 38032 38033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38031 def subnetwork @subnetwork end |
#vlan ⇒ Fixnum
VLAN tag of a dynamic network interface, must be an integer in the range
from 2 to 255 inclusively.
Corresponds to the JSON property vlan
38037 38038 38039 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38037 def vlan @vlan end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38044 38045 38046 38047 38048 38049 38050 38051 38052 38053 38054 38055 38056 38057 38058 38059 38060 38061 38062 38063 38064 38065 38066 38067 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38044 def update!(**args) @access_configs = args[:access_configs] if args.key?(:access_configs) @alias_ip_ranges = args[:alias_ip_ranges] if args.key?(:alias_ip_ranges) @alias_ipv6_ranges = args[:alias_ipv6_ranges] if args.key?(:alias_ipv6_ranges) @enable_vpc_scoped_dns = args[:enable_vpc_scoped_dns] if args.key?(:enable_vpc_scoped_dns) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @igmp_query = args[:igmp_query] if args.key?(:igmp_query) @internal_ipv6_prefix_length = args[:internal_ipv6_prefix_length] if args.key?(:internal_ipv6_prefix_length) @ipv6_access_configs = args[:ipv6_access_configs] if args.key?(:ipv6_access_configs) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_attachment = args[:network_attachment] if args.key?(:network_attachment) @network_ip = args[:network_ip] if args.key?(:network_ip) @nic_type = args[:nic_type] if args.key?(:nic_type) @parent_nic_name = args[:parent_nic_name] if args.key?(:parent_nic_name) @queue_count = args[:queue_count] if args.key?(:queue_count) @service_class_id = args[:service_class_id] if args.key?(:service_class_id) @stack_type = args[:stack_type] if args.key?(:stack_type) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @vlan = args[:vlan] if args.key?(:vlan) end |