Class: Google::Apis::ComputeV1::NetworkInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A network interface resource attached to an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkInterface

Returns a new instance of NetworkInterface.



37291
37292
37293
# File 'lib/google/apis/compute_v1/classes.rb', line 37291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_configsArray<Google::Apis::ComputeV1::AccessConfig>

An array of configurations for this interface. Currently, only one access config, ONE_TO_ONE_NAT, is supported. If there are noaccessConfigs specified, then this instance will have no external internet access. Corresponds to the JSON property accessConfigs



37125
37126
37127
# File 'lib/google/apis/compute_v1/classes.rb', line 37125

def access_configs
  @access_configs
end

#alias_ip_rangesArray<Google::Apis::ComputeV1::AliasIpRange>

An array of alias IP ranges for this network interface. You can only specify this field for network interfaces in VPC networks. Corresponds to the JSON property aliasIpRanges



37131
37132
37133
# File 'lib/google/apis/compute_v1/classes.rb', line 37131

def alias_ip_ranges
  @alias_ip_ranges
end

#enable_vpc_scoped_dnsBoolean Also known as: enable_vpc_scoped_dns?

Optional. If true, DNS resolution will be enabled over this interface. Only valid with network_attachment. Corresponds to the JSON property enableVpcScopedDns

Returns:

  • (Boolean)


37138
37139
37140
# File 'lib/google/apis/compute_v1/classes.rb', line 37138

def enable_vpc_scoped_dns
  @enable_vpc_scoped_dns
end

#fingerprintString

Fingerprint hash of contents stored in this network interface. This field will be ignored when inserting an Instance or adding a NetworkInterface. An up-to-date fingerprint must be provided in order to update theNetworkInterface. The request will fail with error400 Bad Request if the fingerprint is not provided, or412 Precondition Failed if the fingerprint is out of date. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


37150
37151
37152
# File 'lib/google/apis/compute_v1/classes.rb', line 37150

def fingerprint
  @fingerprint
end

#igmp_queryString

Indicate whether igmp query is enabled on the network interface or not. If enabled, also indicates the version of IGMP supported. Corresponds to the JSON property igmpQuery

Returns:

  • (String)


37156
37157
37158
# File 'lib/google/apis/compute_v1/classes.rb', line 37156

def igmp_query
  @igmp_query
end

#internal_ipv6_prefix_lengthFixnum

The prefix length of the primary internal IPv6 range. Corresponds to the JSON property internalIpv6PrefixLength

Returns:

  • (Fixnum)


37161
37162
37163
# File 'lib/google/apis/compute_v1/classes.rb', line 37161

def internal_ipv6_prefix_length
  @internal_ipv6_prefix_length
end

#ipv6_access_configsArray<Google::Apis::ComputeV1::AccessConfig>

An array of IPv6 access configurations for this interface. Currently, only one IPv6 access config, DIRECT_IPV6, is supported. If there is no ipv6AccessConfig specified, then this instance will have no external IPv6 Internet access. Corresponds to the JSON property ipv6AccessConfigs



37169
37170
37171
# File 'lib/google/apis/compute_v1/classes.rb', line 37169

def ipv6_access_configs
  @ipv6_access_configs
end

#ipv6_access_typeString

Output only. [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


37178
37179
37180
# File 'lib/google/apis/compute_v1/classes.rb', line 37178

def ipv6_access_type
  @ipv6_access_type
end

#ipv6_addressString

An IPv6 internal network address for this network interface. To use a static internal IP address, it must be unused and in the same region as the instance's zone. If not specified, Google Cloud will automatically assign an internal IPv6 address from the instance's subnetwork. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


37186
37187
37188
# File 'lib/google/apis/compute_v1/classes.rb', line 37186

def ipv6_address
  @ipv6_address
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# networkInterface for network interfaces. Corresponds to the JSON property kind

Returns:

  • (String)


37192
37193
37194
# File 'lib/google/apis/compute_v1/classes.rb', line 37192

def kind
  @kind
end

#nameString

[Output Only] The name of the network interface, which is generated by the server. For a VM, the network interface uses the nicN naming format. Where N is a value between 0 and7. The default interface value is nic0. Corresponds to the JSON property name

Returns:

  • (String)


37199
37200
37201
# File 'lib/google/apis/compute_v1/classes.rb', line 37199

def name
  @name
end

#networkString

URL of the VPC network resource for this instance. When creating an instance, if neither the network nor the subnetwork is specified, the default network global/networks/default is used. If the selected project doesn't have the default network, you must specify a network or subnet. If the network is not specified but the subnetwork is specified, the network is inferred. If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs:

Returns:

  • (String)


37217
37218
37219
# File 'lib/google/apis/compute_v1/classes.rb', line 37217

def network
  @network
end

#network_attachmentString

The URL of the network attachment that this interface should connect to in the following format: projects/project_number/regions/region_name/networkAttachments/ network_attachment_name. Corresponds to the JSON property networkAttachment

Returns:

  • (String)


37225
37226
37227
# File 'lib/google/apis/compute_v1/classes.rb', line 37225

def network_attachment
  @network_attachment
end

#network_ipString

An IPv4 internal IP address to assign to the instance for this network interface. If not specified by the user, an unused internal IP is assigned by the system. Corresponds to the JSON property networkIP

Returns:

  • (String)


37232
37233
37234
# File 'lib/google/apis/compute_v1/classes.rb', line 37232

def network_ip
  @network_ip
end

#nic_typeString

The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. Corresponds to the JSON property nicType

Returns:

  • (String)


37238
37239
37240
# File 'lib/google/apis/compute_v1/classes.rb', line 37238

def nic_type
  @nic_type
end

#parent_nic_nameString

Name of the parent network interface of a dynamic network interface. Corresponds to the JSON property parentNicName

Returns:

  • (String)


37243
37244
37245
# File 'lib/google/apis/compute_v1/classes.rb', line 37243

def parent_nic_name
  @parent_nic_name
end

#queue_countFixnum

The networking queue count that's specified by users for the network interface. Both Rx and Tx queues will be set to this number. It'll be empty if not specified by the users. Corresponds to the JSON property queueCount

Returns:

  • (Fixnum)


37250
37251
37252
# File 'lib/google/apis/compute_v1/classes.rb', line 37250

def queue_count
  @queue_count
end

#service_class_idString

Optional. Producer Service's Service class Id for the region of this network interface. Can only be used with network_attachment. It is not possible to use on its own however, network_attachment can be used without service_class_id. Corresponds to the JSON property serviceClassId

Returns:

  • (String)


37258
37259
37260
# File 'lib/google/apis/compute_v1/classes.rb', line 37258

def service_class_id
  @service_class_id
end

#stack_typeString

The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, useIPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. Corresponds to the JSON property stackType

Returns:

  • (String)


37267
37268
37269
# File 'lib/google/apis/compute_v1/classes.rb', line 37267

def stack_type
  @stack_type
end

#subnetworkString

The URL of the Subnetwork resource for this instance. If the network resource is inlegacy mode, do not specify this field. If the network is in auto subnet mode, specifying the subnetwork is optional. If the network is in custom subnet mode, specifying the subnetwork is required. If you specify this field, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:

Returns:

  • (String)


37283
37284
37285
# File 'lib/google/apis/compute_v1/classes.rb', line 37283

def subnetwork
  @subnetwork
end

#vlanFixnum

VLAN tag of a dynamic network interface, must be an integer in the range from 2 to 255 inclusively. Corresponds to the JSON property vlan

Returns:

  • (Fixnum)


37289
37290
37291
# File 'lib/google/apis/compute_v1/classes.rb', line 37289

def vlan
  @vlan
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37296
37297
37298
37299
37300
37301
37302
37303
37304
37305
37306
37307
37308
37309
37310
37311
37312
37313
37314
37315
37316
37317
37318
# File 'lib/google/apis/compute_v1/classes.rb', line 37296

def update!(**args)
  @access_configs = args[:access_configs] if args.key?(:access_configs)
  @alias_ip_ranges = args[:alias_ip_ranges] if args.key?(:alias_ip_ranges)
  @enable_vpc_scoped_dns = args[:enable_vpc_scoped_dns] if args.key?(:enable_vpc_scoped_dns)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @igmp_query = args[:igmp_query] if args.key?(:igmp_query)
  @internal_ipv6_prefix_length = args[:internal_ipv6_prefix_length] if args.key?(:internal_ipv6_prefix_length)
  @ipv6_access_configs = args[:ipv6_access_configs] if args.key?(:ipv6_access_configs)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_attachment = args[:network_attachment] if args.key?(:network_attachment)
  @network_ip = args[:network_ip] if args.key?(:network_ip)
  @nic_type = args[:nic_type] if args.key?(:nic_type)
  @parent_nic_name = args[:parent_nic_name] if args.key?(:parent_nic_name)
  @queue_count = args[:queue_count] if args.key?(:queue_count)
  @service_class_id = args[:service_class_id] if args.key?(:service_class_id)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @vlan = args[:vlan] if args.key?(:vlan)
end