Class: Google::Apis::ComputeV1::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Network>
A list of Network resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkList
Returns a new instance of NetworkList.
38098 38099 38100 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38065 38066 38067 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38065 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Network>
A list of Network resources.
Corresponds to the JSON property items
38070 38071 38072 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38070 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#networkList for
lists of networks.
Corresponds to the JSON property kind
38076 38077 38078 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38076 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38086 38087 38088 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38086 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38091 38092 38093 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38091 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38096 38097 38098 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38096 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38103 38104 38105 38106 38107 38108 38109 38110 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38103 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |