Class: Google::Apis::ComputeV1::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



37746
37747
37748
# File 'lib/google/apis/compute_v1/classes.rb', line 37746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37713
37714
37715
# File 'lib/google/apis/compute_v1/classes.rb', line 37713

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Network>

A list of Network resources. Corresponds to the JSON property items



37718
37719
37720
# File 'lib/google/apis/compute_v1/classes.rb', line 37718

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


37724
37725
37726
# File 'lib/google/apis/compute_v1/classes.rb', line 37724

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37734
37735
37736
# File 'lib/google/apis/compute_v1/classes.rb', line 37734

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37739
37740
37741
# File 'lib/google/apis/compute_v1/classes.rb', line 37739

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37744
37745
37746
# File 'lib/google/apis/compute_v1/classes.rb', line 37744

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37751
37752
37753
37754
37755
37756
37757
37758
# File 'lib/google/apis/compute_v1/classes.rb', line 37751

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end