Class: Google::Apis::ComputeV1::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Network>
A list of Network resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkList
Returns a new instance of NetworkList.
37736 37737 37738 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37703 37704 37705 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37703 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Network>
A list of Network resources.
Corresponds to the JSON property items
37708 37709 37710 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37708 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#networkList for
lists of networks.
Corresponds to the JSON property kind
37714 37715 37716 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37714 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37724 37725 37726 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37724 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37729 37730 37731 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37729 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
37734 37735 37736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37734 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37741 37742 37743 37744 37745 37746 37747 37748 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37741 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |