Class: Google::Apis::ComputeV1::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



37571
37572
37573
# File 'lib/google/apis/compute_v1/classes.rb', line 37571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37538
37539
37540
# File 'lib/google/apis/compute_v1/classes.rb', line 37538

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Network>

A list of Network resources. Corresponds to the JSON property items



37543
37544
37545
# File 'lib/google/apis/compute_v1/classes.rb', line 37543

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


37549
37550
37551
# File 'lib/google/apis/compute_v1/classes.rb', line 37549

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37559
37560
37561
# File 'lib/google/apis/compute_v1/classes.rb', line 37559

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37564
37565
37566
# File 'lib/google/apis/compute_v1/classes.rb', line 37564

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37569
37570
37571
# File 'lib/google/apis/compute_v1/classes.rb', line 37569

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37576
37577
37578
37579
37580
37581
37582
37583
# File 'lib/google/apis/compute_v1/classes.rb', line 37576

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end