Class: Google::Apis::ComputeV1::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



37361
37362
37363
# File 'lib/google/apis/compute_v1/classes.rb', line 37361

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37328
37329
37330
# File 'lib/google/apis/compute_v1/classes.rb', line 37328

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Network>

A list of Network resources. Corresponds to the JSON property items



37333
37334
37335
# File 'lib/google/apis/compute_v1/classes.rb', line 37333

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


37339
37340
37341
# File 'lib/google/apis/compute_v1/classes.rb', line 37339

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37349
37350
37351
# File 'lib/google/apis/compute_v1/classes.rb', line 37349

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37354
37355
37356
# File 'lib/google/apis/compute_v1/classes.rb', line 37354

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37359
37360
37361
# File 'lib/google/apis/compute_v1/classes.rb', line 37359

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37366
37367
37368
37369
37370
37371
37372
37373
# File 'lib/google/apis/compute_v1/classes.rb', line 37366

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end