Class: Google::Apis::ComputeV1::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Network>
A list of Network resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkList
Returns a new instance of NetworkList.
20256 20257 20258 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20224 20225 20226 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20224 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Network>
A list of Network resources.
Corresponds to the JSON property items
20229 20230 20231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20229 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#networkList for lists of
networks.
Corresponds to the JSON property kind
20235 20236 20237 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20235 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20244 20245 20246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20244 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20249 20250 20251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20249 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
20254 20255 20256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20254 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20261 20262 20263 20264 20265 20266 20267 20268 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20261 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |