Class: Google::Apis::ComputeV1::NetworkPeeringConnectionStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkPeeringConnectionStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings.
Instance Attribute Summary collapse
-
#consensus_state ⇒ Google::Apis::ComputeV1::NetworkPeeringConnectionStatusConsensusState
The status of update/delete for a consensus peering connection.
-
#traffic_configuration ⇒ Google::Apis::ComputeV1::NetworkPeeringConnectionStatusTrafficConfiguration
The active connectivity settings for the peering connection based on the settings of the network peerings.
-
#update_strategy ⇒ String
The update strategy determines the update/delete semantics for this peering connection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPeeringConnectionStatus
constructor
A new instance of NetworkPeeringConnectionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPeeringConnectionStatus
Returns a new instance of NetworkPeeringConnectionStatus.
34080 34081 34082 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consensus_state ⇒ Google::Apis::ComputeV1::NetworkPeeringConnectionStatusConsensusState
The status of update/delete for a consensus peering connection. Only set
when connection_status.update_strategy isCONSENSUS or a network peering is
proposing to update the
strategy to CONSENSUS.
Corresponds to the JSON property consensusState
34066 34067 34068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34066 def consensus_state @consensus_state end |
#traffic_configuration ⇒ Google::Apis::ComputeV1::NetworkPeeringConnectionStatusTrafficConfiguration
The active connectivity settings for the peering connection based on the
settings of the network peerings.
Corresponds to the JSON property trafficConfiguration
34072 34073 34074 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34072 def traffic_configuration @traffic_configuration end |
#update_strategy ⇒ String
The update strategy determines the update/delete semantics for this
peering connection.
Corresponds to the JSON property updateStrategy
34078 34079 34080 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34078 def update_strategy @update_strategy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34085 34086 34087 34088 34089 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34085 def update!(**args) @consensus_state = args[:consensus_state] if args.key?(:consensus_state) @traffic_configuration = args[:traffic_configuration] if args.key?(:traffic_configuration) @update_strategy = args[:update_strategy] if args.key?(:update_strategy) end |