Class: Google::Apis::ComputeV1::NetworkPeeringConnectionStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeeringConnectionStatus

Returns a new instance of NetworkPeeringConnectionStatus.



33243
33244
33245
# File 'lib/google/apis/compute_v1/classes.rb', line 33243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consensus_stateGoogle::Apis::ComputeV1::NetworkPeeringConnectionStatusConsensusState

The status of update/delete for a consensus peering connection. Only set when connection_status.update_strategy isCONSENSUS or a network peering is proposing to update the strategy to CONSENSUS. Corresponds to the JSON property consensusState



33229
33230
33231
# File 'lib/google/apis/compute_v1/classes.rb', line 33229

def consensus_state
  @consensus_state
end

#traffic_configurationGoogle::Apis::ComputeV1::NetworkPeeringConnectionStatusTrafficConfiguration

The active connectivity settings for the peering connection based on the settings of the network peerings. Corresponds to the JSON property trafficConfiguration



33235
33236
33237
# File 'lib/google/apis/compute_v1/classes.rb', line 33235

def traffic_configuration
  @traffic_configuration
end

#update_strategyString

The update strategy determines the update/delete semantics for this peering connection. Corresponds to the JSON property updateStrategy

Returns:

  • (String)


33241
33242
33243
# File 'lib/google/apis/compute_v1/classes.rb', line 33241

def update_strategy
  @update_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33248
33249
33250
33251
33252
# File 'lib/google/apis/compute_v1/classes.rb', line 33248

def update!(**args)
  @consensus_state = args[:consensus_state] if args.key?(:consensus_state)
  @traffic_configuration = args[:traffic_configuration] if args.key?(:traffic_configuration)
  @update_strategy = args[:update_strategy] if args.key?(:update_strategy)
end