Class: Google::Apis::ComputeV1::NetworkPeeringConnectionStatusTrafficConfiguration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeeringConnectionStatusTrafficConfiguration

Returns a new instance of NetworkPeeringConnectionStatusTrafficConfiguration.



37926
37927
37928
# File 'lib/google/apis/compute_v1/classes.rb', line 37926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_custom_routes_to_peerBoolean Also known as: export_custom_routes_to_peer?

Whether custom routes are being exported to the peer network. Corresponds to the JSON property exportCustomRoutesToPeer

Returns:

  • (Boolean)


37897
37898
37899
# File 'lib/google/apis/compute_v1/classes.rb', line 37897

def export_custom_routes_to_peer
  @export_custom_routes_to_peer
end

#export_subnet_routes_with_public_ip_to_peerBoolean Also known as: export_subnet_routes_with_public_ip_to_peer?

Whether subnet routes with public IP ranges are being exported to the peer network. Corresponds to the JSON property exportSubnetRoutesWithPublicIpToPeer

Returns:

  • (Boolean)


37904
37905
37906
# File 'lib/google/apis/compute_v1/classes.rb', line 37904

def export_subnet_routes_with_public_ip_to_peer
  @export_subnet_routes_with_public_ip_to_peer
end

#import_custom_routes_from_peerBoolean Also known as: import_custom_routes_from_peer?

Whether custom routes are being imported from the peer network. Corresponds to the JSON property importCustomRoutesFromPeer

Returns:

  • (Boolean)


37910
37911
37912
# File 'lib/google/apis/compute_v1/classes.rb', line 37910

def import_custom_routes_from_peer
  @import_custom_routes_from_peer
end

#import_subnet_routes_with_public_ip_from_peerBoolean Also known as: import_subnet_routes_with_public_ip_from_peer?

Whether subnet routes with public IP ranges are being imported from the peer network. Corresponds to the JSON property importSubnetRoutesWithPublicIpFromPeer

Returns:

  • (Boolean)


37917
37918
37919
# File 'lib/google/apis/compute_v1/classes.rb', line 37917

def import_subnet_routes_with_public_ip_from_peer
  @import_subnet_routes_with_public_ip_from_peer
end

#stack_typeString

Which IP version(s) of traffic and routes are being imported or exported between peer networks. Corresponds to the JSON property stackType

Returns:

  • (String)


37924
37925
37926
# File 'lib/google/apis/compute_v1/classes.rb', line 37924

def stack_type
  @stack_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37931
37932
37933
37934
37935
37936
37937
# File 'lib/google/apis/compute_v1/classes.rb', line 37931

def update!(**args)
  @export_custom_routes_to_peer = args[:export_custom_routes_to_peer] if args.key?(:export_custom_routes_to_peer)
  @export_subnet_routes_with_public_ip_to_peer = args[:export_subnet_routes_with_public_ip_to_peer] if args.key?(:export_subnet_routes_with_public_ip_to_peer)
  @import_custom_routes_from_peer = args[:import_custom_routes_from_peer] if args.key?(:import_custom_routes_from_peer)
  @import_subnet_routes_with_public_ip_from_peer = args[:import_subnet_routes_with_public_ip_from_peer] if args.key?(:import_subnet_routes_with_public_ip_from_peer)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
end