Class: Google::Apis::ComputeV1::NetworkPeeringConnectionStatusTrafficConfiguration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeeringConnectionStatusTrafficConfiguration

Returns a new instance of NetworkPeeringConnectionStatusTrafficConfiguration.



34156
34157
34158
# File 'lib/google/apis/compute_v1/classes.rb', line 34156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_custom_routes_to_peerBoolean Also known as: export_custom_routes_to_peer?

Whether custom routes are being exported to the peer network. Corresponds to the JSON property exportCustomRoutesToPeer

Returns:

  • (Boolean)


34127
34128
34129
# File 'lib/google/apis/compute_v1/classes.rb', line 34127

def export_custom_routes_to_peer
  @export_custom_routes_to_peer
end

#export_subnet_routes_with_public_ip_to_peerBoolean Also known as: export_subnet_routes_with_public_ip_to_peer?

Whether subnet routes with public IP ranges are being exported to the peer network. Corresponds to the JSON property exportSubnetRoutesWithPublicIpToPeer

Returns:

  • (Boolean)


34134
34135
34136
# File 'lib/google/apis/compute_v1/classes.rb', line 34134

def export_subnet_routes_with_public_ip_to_peer
  @export_subnet_routes_with_public_ip_to_peer
end

#import_custom_routes_from_peerBoolean Also known as: import_custom_routes_from_peer?

Whether custom routes are being imported from the peer network. Corresponds to the JSON property importCustomRoutesFromPeer

Returns:

  • (Boolean)


34140
34141
34142
# File 'lib/google/apis/compute_v1/classes.rb', line 34140

def import_custom_routes_from_peer
  @import_custom_routes_from_peer
end

#import_subnet_routes_with_public_ip_from_peerBoolean Also known as: import_subnet_routes_with_public_ip_from_peer?

Whether subnet routes with public IP ranges are being imported from the peer network. Corresponds to the JSON property importSubnetRoutesWithPublicIpFromPeer

Returns:

  • (Boolean)


34147
34148
34149
# File 'lib/google/apis/compute_v1/classes.rb', line 34147

def import_subnet_routes_with_public_ip_from_peer
  @import_subnet_routes_with_public_ip_from_peer
end

#stack_typeString

Which IP version(s) of traffic and routes are being imported or exported between peer networks. Corresponds to the JSON property stackType

Returns:

  • (String)


34154
34155
34156
# File 'lib/google/apis/compute_v1/classes.rb', line 34154

def stack_type
  @stack_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34161
34162
34163
34164
34165
34166
34167
# File 'lib/google/apis/compute_v1/classes.rb', line 34161

def update!(**args)
  @export_custom_routes_to_peer = args[:export_custom_routes_to_peer] if args.key?(:export_custom_routes_to_peer)
  @export_subnet_routes_with_public_ip_to_peer = args[:export_subnet_routes_with_public_ip_to_peer] if args.key?(:export_subnet_routes_with_public_ip_to_peer)
  @import_custom_routes_from_peer = args[:import_custom_routes_from_peer] if args.key?(:import_custom_routes_from_peer)
  @import_subnet_routes_with_public_ip_from_peer = args[:import_subnet_routes_with_public_ip_from_peer] if args.key?(:import_subnet_routes_with_public_ip_from_peer)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
end