Class: Google::Apis::ComputeV1::NetworkProfileNetworkFeatures
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkProfileNetworkFeatures
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#address_purposes ⇒ Array<String>
Specifies what address purposes are supported.
-
#allow_address_creation ⇒ String
Specifies whether address creation is allowed.
-
#allow_alias_ip_ranges ⇒ String
Specifies whether alias IP ranges (and secondary address ranges) are allowed.
-
#allow_auto_mode_subnet ⇒ String
Specifies whether auto mode subnet creation is allowed.
-
#allow_class_d_firewalls ⇒ String
Specifies whether firewalls for Class D address ranges are supported.
-
#allow_cloud_nat ⇒ String
Specifies whether cloud NAT creation is allowed.
-
#allow_cloud_router ⇒ String
Specifies whether cloud router creation is allowed.
-
#allow_default_nic_attachment ⇒ String
Specifies whether default NIC attachment is allowed.
-
#allow_external_ip_access ⇒ String
Specifies whether VMs are allowed to have external IP access on network interfaces connected to this VPC.
-
#allow_firewall_policy ⇒ String
Specifies whether firewall policy can be attached to the network.
-
#allow_interconnect ⇒ String
Specifies whether Cloud Interconnect creation is allowed.
-
#allow_ip_forwarding ⇒ String
Specifies whether IP forwarding is allowed.
-
#allow_load_balancing ⇒ String
Specifies whether cloud load balancing is allowed.
-
#allow_multi_nic_in_same_network ⇒ String
Specifies whether multi-nic in the same network is allowed.
-
#allow_multi_nic_in_same_subnetwork ⇒ String
Specifies whether multi-nic in the same subnetwork is allowed.
-
#allow_multicast ⇒ String
Specifies whether multicast is allowed.
-
#allow_ncc ⇒ String
Specifies whether NCC is allowed.
-
#allow_network_migration ⇒ String
Specifies whether VM network migration is allowed.
-
#allow_packet_mirroring ⇒ String
Specifies whether Packet Mirroring 1.0 is supported.
-
#allow_private_google_access ⇒ String
Specifies whether private Google access is allowed.
-
#allow_psc ⇒ String
Specifies whether PSC creation is allowed.
-
#allow_same_network_unicast ⇒ String
Specifies whether unicast within the same network is allowed.
-
#allow_static_routes ⇒ String
Specifies whether static route creation is allowed.
-
#allow_sub_interfaces ⇒ String
Specifies whether sub interfaces are allowed.
-
#allow_subnetwork_creation ⇒ String
Specifies whether subnetwork creation is allowed.
-
#allow_vpc_firewall_rules ⇒ String
Specifies whether VPC firewall rules can be created under the network.
-
#allow_vpc_peering ⇒ String
Specifies whether VPC peering is allowed.
-
#allow_vpn ⇒ String
Specifies whether VPN creation is allowed.
-
#firewall_policy_types ⇒ Array<String>
Corresponds to the JSON property
firewallPolicyTypes. -
#interface_types ⇒ Array<String>
If set, limits the interface types that the network supports.
-
#multicast ⇒ String
Specifies which type of multicast is supported.
-
#predefined_network_internal_ipv6_range ⇒ String
Specifies a predefined internal IPv6 range for the network.
-
#predefined_subnetwork_ranges ⇒ Array<Google::Apis::ComputeV1::NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>
Predefined subnetwork ranges for the network.
-
#subnet_purposes ⇒ Array<String>
Specifies which subnetwork purposes are supported.
-
#subnet_stack_types ⇒ Array<String>
Specifies which subnetwork stack types are supported.
-
#subnetwork_purposes ⇒ Array<String>
Output only.
-
#subnetwork_stack_types ⇒ Array<String>
Output only.
-
#unicast ⇒ String
Specifies which type of unicast is supported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfileNetworkFeatures
constructor
A new instance of NetworkProfileNetworkFeatures.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfileNetworkFeatures
Returns a new instance of NetworkProfileNetworkFeatures.
38049 38050 38051 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_purposes ⇒ Array<String>
Specifies what address purposes are supported. If empty, all address
purposes are supported.
Corresponds to the JSON property addressPurposes
37859 37860 37861 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37859 def address_purposes @address_purposes end |
#allow_address_creation ⇒ String
Specifies whether address creation is allowed.
Corresponds to the JSON property allowAddressCreation
37864 37865 37866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37864 def allow_address_creation @allow_address_creation end |
#allow_alias_ip_ranges ⇒ String
Specifies whether alias IP ranges (and secondary address ranges) are
allowed.
Corresponds to the JSON property allowAliasIpRanges
37870 37871 37872 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37870 def allow_alias_ip_ranges @allow_alias_ip_ranges end |
#allow_auto_mode_subnet ⇒ String
Specifies whether auto mode subnet creation is allowed.
Corresponds to the JSON property allowAutoModeSubnet
37875 37876 37877 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37875 def allow_auto_mode_subnet @allow_auto_mode_subnet end |
#allow_class_d_firewalls ⇒ String
Specifies whether firewalls for Class D address ranges are supported.
Corresponds to the JSON property allowClassDFirewalls
37880 37881 37882 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37880 def allow_class_d_firewalls @allow_class_d_firewalls end |
#allow_cloud_nat ⇒ String
Specifies whether cloud NAT creation is allowed.
Corresponds to the JSON property allowCloudNat
37885 37886 37887 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37885 def allow_cloud_nat @allow_cloud_nat end |
#allow_cloud_router ⇒ String
Specifies whether cloud router creation is allowed.
Corresponds to the JSON property allowCloudRouter
37890 37891 37892 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37890 def allow_cloud_router @allow_cloud_router end |
#allow_default_nic_attachment ⇒ String
Specifies whether default NIC attachment is allowed.
Corresponds to the JSON property allowDefaultNicAttachment
37895 37896 37897 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37895 def @allow_default_nic_attachment end |
#allow_external_ip_access ⇒ String
Specifies whether VMs are allowed to have external IP access on network
interfaces connected to this VPC.
Corresponds to the JSON property allowExternalIpAccess
37901 37902 37903 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37901 def allow_external_ip_access @allow_external_ip_access end |
#allow_firewall_policy ⇒ String
Specifies whether firewall policy can be attached to the network.
Corresponds to the JSON property allowFirewallPolicy
37906 37907 37908 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37906 def allow_firewall_policy @allow_firewall_policy end |
#allow_interconnect ⇒ String
Specifies whether Cloud Interconnect creation is allowed.
Corresponds to the JSON property allowInterconnect
37911 37912 37913 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37911 def allow_interconnect @allow_interconnect end |
#allow_ip_forwarding ⇒ String
Specifies whether IP forwarding is allowed.
Corresponds to the JSON property allowIpForwarding
37916 37917 37918 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37916 def allow_ip_forwarding @allow_ip_forwarding end |
#allow_load_balancing ⇒ String
Specifies whether cloud load balancing is allowed.
Corresponds to the JSON property allowLoadBalancing
37921 37922 37923 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37921 def allow_load_balancing @allow_load_balancing end |
#allow_multi_nic_in_same_network ⇒ String
Specifies whether multi-nic in the same network is allowed.
Corresponds to the JSON property allowMultiNicInSameNetwork
37926 37927 37928 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37926 def allow_multi_nic_in_same_network @allow_multi_nic_in_same_network end |
#allow_multi_nic_in_same_subnetwork ⇒ String
Specifies whether multi-nic in the same subnetwork is allowed.
Corresponds to the JSON property allowMultiNicInSameSubnetwork
37931 37932 37933 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37931 def allow_multi_nic_in_same_subnetwork @allow_multi_nic_in_same_subnetwork end |
#allow_multicast ⇒ String
Specifies whether multicast is allowed.
Corresponds to the JSON property allowMulticast
37936 37937 37938 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37936 def allow_multicast @allow_multicast end |
#allow_ncc ⇒ String
Specifies whether NCC is allowed.
Corresponds to the JSON property allowNcc
37941 37942 37943 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37941 def allow_ncc @allow_ncc end |
#allow_network_migration ⇒ String
Specifies whether VM network migration is allowed.
Corresponds to the JSON property allowNetworkMigration
37946 37947 37948 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37946 def allow_network_migration @allow_network_migration end |
#allow_packet_mirroring ⇒ String
Specifies whether Packet Mirroring 1.0 is supported.
Corresponds to the JSON property allowPacketMirroring
37951 37952 37953 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37951 def allow_packet_mirroring @allow_packet_mirroring end |
#allow_private_google_access ⇒ String
Specifies whether private Google access is allowed.
Corresponds to the JSON property allowPrivateGoogleAccess
37956 37957 37958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37956 def allow_private_google_access @allow_private_google_access end |
#allow_psc ⇒ String
Specifies whether PSC creation is allowed.
Corresponds to the JSON property allowPsc
37961 37962 37963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37961 def allow_psc @allow_psc end |
#allow_same_network_unicast ⇒ String
Specifies whether unicast within the same network is allowed.
Corresponds to the JSON property allowSameNetworkUnicast
37966 37967 37968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37966 def allow_same_network_unicast @allow_same_network_unicast end |
#allow_static_routes ⇒ String
Specifies whether static route creation is allowed.
Corresponds to the JSON property allowStaticRoutes
37971 37972 37973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37971 def allow_static_routes @allow_static_routes end |
#allow_sub_interfaces ⇒ String
Specifies whether sub interfaces are allowed.
Corresponds to the JSON property allowSubInterfaces
37976 37977 37978 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37976 def allow_sub_interfaces @allow_sub_interfaces end |
#allow_subnetwork_creation ⇒ String
Specifies whether subnetwork creation is allowed.
Corresponds to the JSON property allowSubnetworkCreation
37981 37982 37983 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37981 def allow_subnetwork_creation @allow_subnetwork_creation end |
#allow_vpc_firewall_rules ⇒ String
Specifies whether VPC firewall rules can be created under the network.
Corresponds to the JSON property allowVpcFirewallRules
37986 37987 37988 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37986 def allow_vpc_firewall_rules @allow_vpc_firewall_rules end |
#allow_vpc_peering ⇒ String
Specifies whether VPC peering is allowed.
Corresponds to the JSON property allowVpcPeering
37991 37992 37993 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37991 def allow_vpc_peering @allow_vpc_peering end |
#allow_vpn ⇒ String
Specifies whether VPN creation is allowed.
Corresponds to the JSON property allowVpn
37996 37997 37998 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37996 def allow_vpn @allow_vpn end |
#firewall_policy_types ⇒ Array<String>
Corresponds to the JSON property firewallPolicyTypes
38001 38002 38003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38001 def firewall_policy_types @firewall_policy_types end |
#interface_types ⇒ Array<String>
If set, limits the interface types that the network supports. If
empty, all interface types are supported.
Corresponds to the JSON property interfaceTypes
38007 38008 38009 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38007 def interface_types @interface_types end |
#multicast ⇒ String
Specifies which type of multicast is supported.
Corresponds to the JSON property multicast
38012 38013 38014 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38012 def multicast @multicast end |
#predefined_network_internal_ipv6_range ⇒ String
Specifies a predefined internal IPv6 range for the network.
Corresponds to the JSON property predefinedNetworkInternalIpv6Range
38017 38018 38019 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38017 def predefined_network_internal_ipv6_range @predefined_network_internal_ipv6_range end |
#predefined_subnetwork_ranges ⇒ Array<Google::Apis::ComputeV1::NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>
Predefined subnetwork ranges for the network.
Corresponds to the JSON property predefinedSubnetworkRanges
38022 38023 38024 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38022 def predefined_subnetwork_ranges @predefined_subnetwork_ranges end |
#subnet_purposes ⇒ Array<String>
Specifies which subnetwork purposes are supported.
Corresponds to the JSON property subnetPurposes
38027 38028 38029 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38027 def subnet_purposes @subnet_purposes end |
#subnet_stack_types ⇒ Array<String>
Specifies which subnetwork stack types are supported.
Corresponds to the JSON property subnetStackTypes
38032 38033 38034 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38032 def subnet_stack_types @subnet_stack_types end |
#subnetwork_purposes ⇒ Array<String>
Output only. Specifies which subnetwork purposes are supported.
Corresponds to the JSON property subnetworkPurposes
38037 38038 38039 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38037 def subnetwork_purposes @subnetwork_purposes end |
#subnetwork_stack_types ⇒ Array<String>
Output only. Specifies which subnetwork stack types are supported.
Corresponds to the JSON property subnetworkStackTypes
38042 38043 38044 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38042 def subnetwork_stack_types @subnetwork_stack_types end |
#unicast ⇒ String
Specifies which type of unicast is supported.
Corresponds to the JSON property unicast
38047 38048 38049 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38047 def unicast @unicast end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38054 38055 38056 38057 38058 38059 38060 38061 38062 38063 38064 38065 38066 38067 38068 38069 38070 38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 38081 38082 38083 38084 38085 38086 38087 38088 38089 38090 38091 38092 38093 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38054 def update!(**args) @address_purposes = args[:address_purposes] if args.key?(:address_purposes) @allow_address_creation = args[:allow_address_creation] if args.key?(:allow_address_creation) @allow_alias_ip_ranges = args[:allow_alias_ip_ranges] if args.key?(:allow_alias_ip_ranges) @allow_auto_mode_subnet = args[:allow_auto_mode_subnet] if args.key?(:allow_auto_mode_subnet) @allow_class_d_firewalls = args[:allow_class_d_firewalls] if args.key?(:allow_class_d_firewalls) @allow_cloud_nat = args[:allow_cloud_nat] if args.key?(:allow_cloud_nat) @allow_cloud_router = args[:allow_cloud_router] if args.key?(:allow_cloud_router) @allow_default_nic_attachment = args[:allow_default_nic_attachment] if args.key?(:allow_default_nic_attachment) @allow_external_ip_access = args[:allow_external_ip_access] if args.key?(:allow_external_ip_access) @allow_firewall_policy = args[:allow_firewall_policy] if args.key?(:allow_firewall_policy) @allow_interconnect = args[:allow_interconnect] if args.key?(:allow_interconnect) @allow_ip_forwarding = args[:allow_ip_forwarding] if args.key?(:allow_ip_forwarding) @allow_load_balancing = args[:allow_load_balancing] if args.key?(:allow_load_balancing) @allow_multi_nic_in_same_network = args[:allow_multi_nic_in_same_network] if args.key?(:allow_multi_nic_in_same_network) @allow_multi_nic_in_same_subnetwork = args[:allow_multi_nic_in_same_subnetwork] if args.key?(:allow_multi_nic_in_same_subnetwork) @allow_multicast = args[:allow_multicast] if args.key?(:allow_multicast) @allow_ncc = args[:allow_ncc] if args.key?(:allow_ncc) @allow_network_migration = args[:allow_network_migration] if args.key?(:allow_network_migration) @allow_packet_mirroring = args[:allow_packet_mirroring] if args.key?(:allow_packet_mirroring) @allow_private_google_access = args[:allow_private_google_access] if args.key?(:allow_private_google_access) @allow_psc = args[:allow_psc] if args.key?(:allow_psc) @allow_same_network_unicast = args[:allow_same_network_unicast] if args.key?(:allow_same_network_unicast) @allow_static_routes = args[:allow_static_routes] if args.key?(:allow_static_routes) @allow_sub_interfaces = args[:allow_sub_interfaces] if args.key?(:allow_sub_interfaces) @allow_subnetwork_creation = args[:allow_subnetwork_creation] if args.key?(:allow_subnetwork_creation) @allow_vpc_firewall_rules = args[:allow_vpc_firewall_rules] if args.key?(:allow_vpc_firewall_rules) @allow_vpc_peering = args[:allow_vpc_peering] if args.key?(:allow_vpc_peering) @allow_vpn = args[:allow_vpn] if args.key?(:allow_vpn) @firewall_policy_types = args[:firewall_policy_types] if args.key?(:firewall_policy_types) @interface_types = args[:interface_types] if args.key?(:interface_types) @multicast = args[:multicast] if args.key?(:multicast) @predefined_network_internal_ipv6_range = args[:predefined_network_internal_ipv6_range] if args.key?(:predefined_network_internal_ipv6_range) @predefined_subnetwork_ranges = args[:predefined_subnetwork_ranges] if args.key?(:predefined_subnetwork_ranges) @subnet_purposes = args[:subnet_purposes] if args.key?(:subnet_purposes) @subnet_stack_types = args[:subnet_stack_types] if args.key?(:subnet_stack_types) @subnetwork_purposes = args[:subnetwork_purposes] if args.key?(:subnetwork_purposes) @subnetwork_stack_types = args[:subnetwork_stack_types] if args.key?(:subnetwork_stack_types) @unicast = args[:unicast] if args.key?(:unicast) end |