Class: Google::Apis::ComputeV1::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



38948
38949
38950
# File 'lib/google/apis/compute_v1/classes.rb', line 38948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


38902
38903
38904
# File 'lib/google/apis/compute_v1/classes.rb', line 38902

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38907
38908
38909
# File 'lib/google/apis/compute_v1/classes.rb', line 38907

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



38912
38913
38914
# File 'lib/google/apis/compute_v1/classes.rb', line 38912

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


38918
38919
38920
# File 'lib/google/apis/compute_v1/classes.rb', line 38918

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38930
38931
38932
# File 'lib/google/apis/compute_v1/classes.rb', line 38930

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38935
38936
38937
# File 'lib/google/apis/compute_v1/classes.rb', line 38935

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38941
38942
38943
# File 'lib/google/apis/compute_v1/classes.rb', line 38941

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38946
38947
38948
# File 'lib/google/apis/compute_v1/classes.rb', line 38946

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38953
38954
38955
38956
38957
38958
38959
38960
38961
38962
# File 'lib/google/apis/compute_v1/classes.rb', line 38953

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end