Class: Google::Apis::ComputeV1::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
38586 38587 38588 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
38540 38541 38542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38540 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38545 38546 38547 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38545 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
38550 38551 38552 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38550 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
38556 38557 38558 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38556 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38568 38569 38570 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38568 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38573 38574 38575 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38573 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
38579 38580 38581 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38579 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38584 38585 38586 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38584 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38591 38592 38593 38594 38595 38596 38597 38598 38599 38600 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38591 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |