Class: Google::Apis::ComputeV1::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



38421
38422
38423
# File 'lib/google/apis/compute_v1/classes.rb', line 38421

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


38375
38376
38377
# File 'lib/google/apis/compute_v1/classes.rb', line 38375

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38380
38381
38382
# File 'lib/google/apis/compute_v1/classes.rb', line 38380

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



38385
38386
38387
# File 'lib/google/apis/compute_v1/classes.rb', line 38385

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


38391
38392
38393
# File 'lib/google/apis/compute_v1/classes.rb', line 38391

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38403
38404
38405
# File 'lib/google/apis/compute_v1/classes.rb', line 38403

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38408
38409
38410
# File 'lib/google/apis/compute_v1/classes.rb', line 38408

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38414
38415
38416
# File 'lib/google/apis/compute_v1/classes.rb', line 38414

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38419
38420
38421
# File 'lib/google/apis/compute_v1/classes.rb', line 38419

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38426
38427
38428
38429
38430
38431
38432
38433
38434
38435
# File 'lib/google/apis/compute_v1/classes.rb', line 38426

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end