Class: Google::Apis::ComputeV1::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
38422 38423 38424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38422 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
38376 38377 38378 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38376 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38381 38382 38383 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38381 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
38386 38387 38388 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38386 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
38392 38393 38394 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38392 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38404 38405 38406 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38404 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38409 38410 38411 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38409 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
38415 38416 38417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38415 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38420 38421 38422 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38420 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38427 38428 38429 38430 38431 38432 38433 38434 38435 38436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38427 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |