Class: Google::Apis::ComputeV1::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



38211
38212
38213
# File 'lib/google/apis/compute_v1/classes.rb', line 38211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


38165
38166
38167
# File 'lib/google/apis/compute_v1/classes.rb', line 38165

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38170
38171
38172
# File 'lib/google/apis/compute_v1/classes.rb', line 38170

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



38175
38176
38177
# File 'lib/google/apis/compute_v1/classes.rb', line 38175

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


38181
38182
38183
# File 'lib/google/apis/compute_v1/classes.rb', line 38181

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38193
38194
38195
# File 'lib/google/apis/compute_v1/classes.rb', line 38193

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38198
38199
38200
# File 'lib/google/apis/compute_v1/classes.rb', line 38198

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38204
38205
38206
# File 'lib/google/apis/compute_v1/classes.rb', line 38204

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38209
38210
38211
# File 'lib/google/apis/compute_v1/classes.rb', line 38209

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38216
38217
38218
38219
38220
38221
38222
38223
38224
38225
# File 'lib/google/apis/compute_v1/classes.rb', line 38216

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end