Class: Google::Apis::ComputeV1::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
37630 37631 37632 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
37584 37585 37586 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37584 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37589 37590 37591 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37589 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
37594 37595 37596 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37594 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
37600 37601 37602 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37600 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37612 37613 37614 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37612 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37617 37618 37619 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37617 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
37623 37624 37625 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37623 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
37628 37629 37630 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37628 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37635 37636 37637 37638 37639 37640 37641 37642 37643 37644 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37635 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |