Class: Google::Apis::ComputeV1::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
34652 34653 34654 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
34606 34607 34608 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34606 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
34611 34612 34613 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34611 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
34616 34617 34618 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34616 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
34622 34623 34624 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34622 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
34634 34635 34636 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34634 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
34639 34640 34641 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34639 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
34645 34646 34647 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34645 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
34650 34651 34652 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34650 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34657 34658 34659 34660 34661 34662 34663 34664 34665 34666 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34657 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |