Class: Google::Apis::ComputeV1::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



33815
33816
33817
# File 'lib/google/apis/compute_v1/classes.rb', line 33815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33769
33770
33771
# File 'lib/google/apis/compute_v1/classes.rb', line 33769

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33774
33775
33776
# File 'lib/google/apis/compute_v1/classes.rb', line 33774

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



33779
33780
33781
# File 'lib/google/apis/compute_v1/classes.rb', line 33779

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


33785
33786
33787
# File 'lib/google/apis/compute_v1/classes.rb', line 33785

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33797
33798
33799
# File 'lib/google/apis/compute_v1/classes.rb', line 33797

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33802
33803
33804
# File 'lib/google/apis/compute_v1/classes.rb', line 33802

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33808
33809
33810
# File 'lib/google/apis/compute_v1/classes.rb', line 33808

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33813
33814
33815
# File 'lib/google/apis/compute_v1/classes.rb', line 33813

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33820
33821
33822
33823
33824
33825
33826
33827
33828
33829
# File 'lib/google/apis/compute_v1/classes.rb', line 33820

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end