Class: Google::Apis::ComputeV1::NetworkRoutingConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkRoutingConfig

Returns a new instance of NetworkRoutingConfig.



39085
39086
39087
# File 'lib/google/apis/compute_v1/classes.rb', line 39085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgp_always_compare_medBoolean Also known as: bgp_always_compare_med?

Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm. Corresponds to the JSON property bgpAlwaysCompareMed

Returns:

  • (Boolean)


39046
39047
39048
# File 'lib/google/apis/compute_v1/classes.rb', line 39046

def bgp_always_compare_med
  @bgp_always_compare_med
end

#bgp_best_path_selection_modeString

The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. Corresponds to the JSON property bgpBestPathSelectionMode

Returns:

  • (String)


39054
39055
39056
# File 'lib/google/apis/compute_v1/classes.rb', line 39054

def bgp_best_path_selection_mode
  @bgp_best_path_selection_mode
end

#bgp_inter_region_costString

Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT orADD_COST_TO_MED. Corresponds to the JSON property bgpInterRegionCost

Returns:

  • (String)


39061
39062
39063
# File 'lib/google/apis/compute_v1/classes.rb', line 39061

def bgp_inter_region_cost
  @bgp_inter_region_cost
end

#effective_bgp_always_compare_medBoolean Also known as: effective_bgp_always_compare_med?

Output only. [Output Only] Effective value of the bgp_always_compare_med field. Corresponds to the JSON property effectiveBgpAlwaysCompareMed

Returns:

  • (Boolean)


39067
39068
39069
# File 'lib/google/apis/compute_v1/classes.rb', line 39067

def effective_bgp_always_compare_med
  @effective_bgp_always_compare_med
end

#effective_bgp_inter_region_costString

Output only. [Output Only] Effective value of the bgp_inter_region_cost field. Corresponds to the JSON property effectiveBgpInterRegionCost

Returns:

  • (String)


39074
39075
39076
# File 'lib/google/apis/compute_v1/classes.rb', line 39074

def effective_bgp_inter_region_cost
  @effective_bgp_inter_region_cost
end

#routing_modeString

The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. Corresponds to the JSON property routingMode

Returns:

  • (String)


39083
39084
39085
# File 'lib/google/apis/compute_v1/classes.rb', line 39083

def routing_mode
  @routing_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39090
39091
39092
39093
39094
39095
39096
39097
# File 'lib/google/apis/compute_v1/classes.rb', line 39090

def update!(**args)
  @bgp_always_compare_med = args[:bgp_always_compare_med] if args.key?(:bgp_always_compare_med)
  @bgp_best_path_selection_mode = args[:bgp_best_path_selection_mode] if args.key?(:bgp_best_path_selection_mode)
  @bgp_inter_region_cost = args[:bgp_inter_region_cost] if args.key?(:bgp_inter_region_cost)
  @effective_bgp_always_compare_med = args[:effective_bgp_always_compare_med] if args.key?(:effective_bgp_always_compare_med)
  @effective_bgp_inter_region_cost = args[:effective_bgp_inter_region_cost] if args.key?(:effective_bgp_inter_region_cost)
  @routing_mode = args[:routing_mode] if args.key?(:routing_mode)
end