Class: Google::Apis::ComputeV1::NodeGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, readSole-tenant nodes.
Instance Attribute Summary collapse
-
#autoscaling_policy ⇒ Google::Apis::ComputeV1::NodeGroupAutoscalingPolicy
Specifies how autoscaling should behave.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Corresponds to the JSON property
fingerprintNOTE: Values are automatically base64 encoded/decoded in the client library. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#location_hint ⇒ String
An opaque location hint used to place the Node close to other resources.
-
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events.
-
#maintenance_policy ⇒ String
Specifies how to handle instances when a node in the group undergoes maintenance.
-
#maintenance_window ⇒ Google::Apis::ComputeV1::NodeGroupMaintenanceWindow
Time window specified for daily maintenance operations.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#node_template ⇒ String
URL of the node template to create the node group from.
-
#self_link ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#size ⇒ Fixnum
Output only.
-
#status ⇒ String
Corresponds to the JSON property
status. -
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroup
constructor
A new instance of NodeGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroup
Returns a new instance of NodeGroup.
39433 39434 39435 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39433 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_policy ⇒ Google::Apis::ComputeV1::NodeGroupAutoscalingPolicy
Specifies how autoscaling should behave.
Corresponds to the JSON property autoscalingPolicy
39327 39328 39329 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39327 def autoscaling_policy @autoscaling_policy end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
39333 39334 39335 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39333 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
39339 39340 39341 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39339 def description @description end |
#fingerprint ⇒ String
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
39345 39346 39347 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39345 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
39352 39353 39354 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39352 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#nodeGroup
for node group.
Corresponds to the JSON property kind
39358 39359 39360 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39358 def kind @kind end |
#location_hint ⇒ String
An opaque location hint used to place the Node close to other
resources.
This field is for use by internal tools that use the public API.
The location hint here on the NodeGroup overrides any location_hint
present in the NodeTemplate.
Corresponds to the JSON property locationHint
39367 39368 39369 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39367 def location_hint @location_hint end |
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events. The accepted values
are: AS_NEEDED and RECURRENT.
Corresponds to the JSON property maintenanceInterval
39373 39374 39375 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39373 def maintenance_interval @maintenance_interval end |
#maintenance_policy ⇒ String
Specifies how to handle instances when a node in the group undergoes
maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or
MIGRATE_WITHIN_NODE_GROUP.
The default value is DEFAULT. For more information, see
Maintenance policies.
Corresponds to the JSON property maintenancePolicy
39382 39383 39384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39382 def maintenance_policy @maintenance_policy end |
#maintenance_window ⇒ Google::Apis::ComputeV1::NodeGroupMaintenanceWindow
Time window specified for daily maintenance operations. GCE's internal
maintenance will be performed within this window.
Corresponds to the JSON property maintenanceWindow
39388 39389 39390 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39388 def maintenance_window @maintenance_window end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
39400 39401 39402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39400 def name @name end |
#node_template ⇒ String
URL of the node template to create the node group from.
Corresponds to the JSON property nodeTemplate
39405 39406 39407 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39405 def node_template @node_template end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
39410 39411 39412 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39410 def self_link @self_link end |
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
39415 39416 39417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39415 def share_settings @share_settings end |
#size ⇒ Fixnum
Output only. [Output Only] The total number of nodes in the node group.
Corresponds to the JSON property size
39420 39421 39422 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39420 def size @size end |
#status ⇒ String
Corresponds to the JSON property status
39425 39426 39427 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39425 def status @status end |
#zone ⇒ String
Output only. [Output Only] The name of the zone where the node group resides,
such as us-central1-a.
Corresponds to the JSON property zone
39431 39432 39433 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39431 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39438 39439 39440 39441 39442 39443 39444 39445 39446 39447 39448 39449 39450 39451 39452 39453 39454 39455 39456 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39438 def update!(**args) @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @location_hint = args[:location_hint] if args.key?(:location_hint) @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @name = args[:name] if args.key?(:name) @node_template = args[:node_template] if args.key?(:node_template) @self_link = args[:self_link] if args.key?(:self_link) @share_settings = args[:share_settings] if args.key?(:share_settings) @size = args[:size] if args.key?(:size) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |