Class: Google::Apis::ComputeV1::NodeGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, read Sole-tenant nodes.
Instance Attribute Summary collapse
-
#autoscaling_policy ⇒ Google::Apis::ComputeV1::NodeGroupAutoscalingPolicy
Specifies how autoscaling should behave.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Corresponds to the JSON property
fingerprintNOTE: Values are automatically base64 encoded/decoded in the client library. -
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] The type of the resource.
-
#location_hint ⇒ String
An opaque location hint used to place the Node close to other resources.
-
#maintenance_policy ⇒ String
Specifies how to handle instances when a node in the group undergoes maintenance.
-
#maintenance_window ⇒ Google::Apis::ComputeV1::NodeGroupMaintenanceWindow
Time window specified for daily maintenance operations.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#node_template ⇒ String
URL of the node template to create the node group from.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#size ⇒ Fixnum
[Output Only] The total number of nodes in the node group.
-
#status ⇒ String
Corresponds to the JSON property
status. -
#zone ⇒ String
[Output Only] The name of the zone where the node group resides, such as us- central1-a.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroup
constructor
A new instance of NodeGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroup
Returns a new instance of NodeGroup.
20743 20744 20745 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_policy ⇒ Google::Apis::ComputeV1::NodeGroupAutoscalingPolicy
Specifies how autoscaling should behave.
Corresponds to the JSON property autoscalingPolicy
20654 20655 20656 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20654 def autoscaling_policy @autoscaling_policy end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
20659 20660 20661 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20659 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
20665 20666 20667 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20665 def description @description end |
#fingerprint ⇒ String
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
20671 20672 20673 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20671 def fingerprint @fingerprint end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
20677 20678 20679 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20677 def id @id end |
#kind ⇒ String
[Output Only] The type of the resource. Always compute#nodeGroup for node
group.
Corresponds to the JSON property kind
20683 20684 20685 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20683 def kind @kind end |
#location_hint ⇒ String
An opaque location hint used to place the Node close to other resources. This
field is for use by internal tools that use the public API. The location hint
here on the NodeGroup overrides any location_hint present in the NodeTemplate.
Corresponds to the JSON property locationHint
20690 20691 20692 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20690 def location_hint @location_hint end |
#maintenance_policy ⇒ String
Specifies how to handle instances when a node in the group undergoes
maintenance. Set to one of: DEFAULT, RESTART_IN_PLACE, or
MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information,
see Maintenance policies.
Corresponds to the JSON property maintenancePolicy
20698 20699 20700 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20698 def maintenance_policy @maintenance_policy end |
#maintenance_window ⇒ Google::Apis::ComputeV1::NodeGroupMaintenanceWindow
Time window specified for daily maintenance operations. GCE's internal
maintenance will be performed within this window.
Corresponds to the JSON property maintenanceWindow
20704 20705 20706 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20704 def maintenance_window @maintenance_window end |
#name ⇒ String
The name of the resource, provided by the client when initially creating the
resource. The resource name must be 1-63 characters long, and comply with
RFC1035. Specifically, the name must be 1-63 characters long and match the
regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be a
dash, lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
20715 20716 20717 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20715 def name @name end |
#node_template ⇒ String
URL of the node template to create the node group from.
Corresponds to the JSON property nodeTemplate
20720 20721 20722 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20720 def node_template @node_template end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
20725 20726 20727 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20725 def self_link @self_link end |
#size ⇒ Fixnum
[Output Only] The total number of nodes in the node group.
Corresponds to the JSON property size
20730 20731 20732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20730 def size @size end |
#status ⇒ String
Corresponds to the JSON property status
20735 20736 20737 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20735 def status @status end |
#zone ⇒ String
[Output Only] The name of the zone where the node group resides, such as us-
central1-a.
Corresponds to the JSON property zone
20741 20742 20743 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20741 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 20760 20761 20762 20763 20764 |
# File 'lib/google/apis/compute_v1/classes.rb', line 20748 def update!(**args) @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @location_hint = args[:location_hint] if args.key?(:location_hint) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @name = args[:name] if args.key?(:name) @node_template = args[:node_template] if args.key?(:node_template) @self_link = args[:self_link] if args.key?(:self_link) @size = args[:size] if args.key?(:size) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |