Class: Google::Apis::ComputeV1::NodeGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroupAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAggregatedList
constructor
A new instance of NodeGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAggregatedList
Returns a new instance of NodeGroupAggregatedList.
39153 39154 39155 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39114 39115 39116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39114 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
Corresponds to the JSON property items
39119 39120 39121 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39119 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeGroupAggregatedList for aggregated lists of node
groups.
Corresponds to the JSON property kind
39126 39127 39128 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39126 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39136 39137 39138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39136 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39141 39142 39143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39141 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
39146 39147 39148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39146 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39151 39152 39153 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39151 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39158 39159 39160 39161 39162 39163 39164 39165 39166 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39158 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |