Class: Google::Apis::ComputeV1::NodeGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroupAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAggregatedList
constructor
A new instance of NodeGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAggregatedList
Returns a new instance of NodeGroupAggregatedList.
38978 38979 38980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38939 38940 38941 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38939 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
Corresponds to the JSON property items
38944 38945 38946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38944 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeGroupAggregatedList for aggregated lists of node
groups.
Corresponds to the JSON property kind
38951 38952 38953 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38951 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38961 38962 38963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38961 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38966 38967 38968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38966 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
38971 38972 38973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38971 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38976 38977 38978 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38976 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38983 38984 38985 38986 38987 38988 38989 38990 38991 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38983 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |