Class: Google::Apis::ComputeV1::NodeGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupAggregatedList

Returns a new instance of NodeGroupAggregatedList.



38782
38783
38784
# File 'lib/google/apis/compute_v1/classes.rb', line 38782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38743
38744
38745
# File 'lib/google/apis/compute_v1/classes.rb', line 38743

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NodeGroupsScopedList>

A list of NodeGroupsScopedList resources. Corresponds to the JSON property items



38748
38749
38750
# File 'lib/google/apis/compute_v1/classes.rb', line 38748

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeGroupAggregatedList for aggregated lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


38755
38756
38757
# File 'lib/google/apis/compute_v1/classes.rb', line 38755

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38765
38766
38767
# File 'lib/google/apis/compute_v1/classes.rb', line 38765

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38770
38771
38772
# File 'lib/google/apis/compute_v1/classes.rb', line 38770

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38775
38776
38777
# File 'lib/google/apis/compute_v1/classes.rb', line 38775

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NodeGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38780
38781
38782
# File 'lib/google/apis/compute_v1/classes.rb', line 38780

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38787
38788
38789
38790
38791
38792
38793
38794
38795
# File 'lib/google/apis/compute_v1/classes.rb', line 38787

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end