Class: Google::Apis::ComputeV1::NodeGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroupAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAggregatedList
constructor
A new instance of NodeGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAggregatedList
Returns a new instance of NodeGroupAggregatedList.
38168 38169 38170 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38129 38130 38131 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38129 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
Corresponds to the JSON property items
38134 38135 38136 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38134 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeGroupAggregatedList for aggregated lists of node
groups.
Corresponds to the JSON property kind
38141 38142 38143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38141 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38151 38152 38153 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38151 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38156 38157 38158 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38156 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
38161 38162 38163 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38161 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38166 38167 38168 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38166 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38173 38174 38175 38176 38177 38178 38179 38180 38181 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38173 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |