Class: Google::Apis::ComputeV1::NodeGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupAggregatedList

Returns a new instance of NodeGroupAggregatedList.



34353
34354
34355
# File 'lib/google/apis/compute_v1/classes.rb', line 34353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34314
34315
34316
# File 'lib/google/apis/compute_v1/classes.rb', line 34314

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NodeGroupsScopedList>

A list of NodeGroupsScopedList resources. Corresponds to the JSON property items



34319
34320
34321
# File 'lib/google/apis/compute_v1/classes.rb', line 34319

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeGroupAggregatedList for aggregated lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


34326
34327
34328
# File 'lib/google/apis/compute_v1/classes.rb', line 34326

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34336
34337
34338
# File 'lib/google/apis/compute_v1/classes.rb', line 34336

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34341
34342
34343
# File 'lib/google/apis/compute_v1/classes.rb', line 34341

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


34346
34347
34348
# File 'lib/google/apis/compute_v1/classes.rb', line 34346

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NodeGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34351
34352
34353
# File 'lib/google/apis/compute_v1/classes.rb', line 34351

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34358
34359
34360
34361
34362
34363
34364
34365
34366
# File 'lib/google/apis/compute_v1/classes.rb', line 34358

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end