Class: Google::Apis::ComputeV1::NodeGroupAutoscalingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroupAutoscalingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#max_nodes ⇒ Fixnum
The maximum number of nodes that the group should have.
-
#min_nodes ⇒ Fixnum
The minimum number of nodes that the group should have.
-
#mode ⇒ String
The autoscaling mode.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAutoscalingPolicy
constructor
A new instance of NodeGroupAutoscalingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAutoscalingPolicy
Returns a new instance of NodeGroupAutoscalingPolicy.
39261 39262 39263 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_nodes ⇒ Fixnum
The maximum number of nodes that the group should have. Must be set if
autoscaling is enabled. Maximum value allowed is 100.
Corresponds to the JSON property maxNodes
39247 39248 39249 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39247 def max_nodes @max_nodes end |
#min_nodes ⇒ Fixnum
The minimum number of nodes that the group should have.
Corresponds to the JSON property minNodes
39252 39253 39254 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39252 def min_nodes @min_nodes end |
#mode ⇒ String
The autoscaling mode. Set to one of: ON, OFF,
or ONLY_SCALE_OUT. For more information, see
Autoscaler modes.
Corresponds to the JSON property mode
39259 39260 39261 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39259 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39266 39267 39268 39269 39270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39266 def update!(**args) @max_nodes = args[:max_nodes] if args.key?(:max_nodes) @min_nodes = args[:min_nodes] if args.key?(:min_nodes) @mode = args[:mode] if args.key?(:mode) end |