Class: Google::Apis::ComputeV1::NodeGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of nodeGroups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NodeGroup>
A list of NodeGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupList
constructor
A new instance of NodeGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupList
Returns a new instance of NodeGroupList.
39313 39314 39315 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39280 39281 39282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39280 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NodeGroup>
A list of NodeGroup resources.
Corresponds to the JSON property items
39285 39286 39287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39285 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeGroupList
for lists of node groups.
Corresponds to the JSON property kind
39291 39292 39293 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39291 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39301 39302 39303 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39301 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39306 39307 39308 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39306 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NodeGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39311 39312 39313 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39311 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39318 39319 39320 39321 39322 39323 39324 39325 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39318 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |