Class: Google::Apis::ComputeV1::NodeGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of nodeGroups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupList

Returns a new instance of NodeGroupList.



39303
39304
39305
# File 'lib/google/apis/compute_v1/classes.rb', line 39303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39270
39271
39272
# File 'lib/google/apis/compute_v1/classes.rb', line 39270

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NodeGroup>

A list of NodeGroup resources. Corresponds to the JSON property items



39275
39276
39277
# File 'lib/google/apis/compute_v1/classes.rb', line 39275

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


39281
39282
39283
# File 'lib/google/apis/compute_v1/classes.rb', line 39281

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39291
39292
39293
# File 'lib/google/apis/compute_v1/classes.rb', line 39291

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39296
39297
39298
# File 'lib/google/apis/compute_v1/classes.rb', line 39296

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NodeGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39301
39302
39303
# File 'lib/google/apis/compute_v1/classes.rb', line 39301

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39308
39309
39310
39311
39312
39313
39314
39315
# File 'lib/google/apis/compute_v1/classes.rb', line 39308

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end