Class: Google::Apis::ComputeV1::NodeGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of nodeGroups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupList

Returns a new instance of NodeGroupList.



39139
39140
39141
# File 'lib/google/apis/compute_v1/classes.rb', line 39139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39106
39107
39108
# File 'lib/google/apis/compute_v1/classes.rb', line 39106

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NodeGroup>

A list of NodeGroup resources. Corresponds to the JSON property items



39111
39112
39113
# File 'lib/google/apis/compute_v1/classes.rb', line 39111

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


39117
39118
39119
# File 'lib/google/apis/compute_v1/classes.rb', line 39117

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39127
39128
39129
# File 'lib/google/apis/compute_v1/classes.rb', line 39127

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39132
39133
39134
# File 'lib/google/apis/compute_v1/classes.rb', line 39132

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NodeGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39137
39138
39139
# File 'lib/google/apis/compute_v1/classes.rb', line 39137

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39144
39145
39146
39147
39148
39149
39150
39151
# File 'lib/google/apis/compute_v1/classes.rb', line 39144

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end