Class: Google::Apis::ComputeV1::NodeGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of nodeGroups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupList

Returns a new instance of NodeGroupList.



38942
38943
38944
# File 'lib/google/apis/compute_v1/classes.rb', line 38942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38909
38910
38911
# File 'lib/google/apis/compute_v1/classes.rb', line 38909

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NodeGroup>

A list of NodeGroup resources. Corresponds to the JSON property items



38914
38915
38916
# File 'lib/google/apis/compute_v1/classes.rb', line 38914

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


38920
38921
38922
# File 'lib/google/apis/compute_v1/classes.rb', line 38920

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38930
38931
38932
# File 'lib/google/apis/compute_v1/classes.rb', line 38930

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38935
38936
38937
# File 'lib/google/apis/compute_v1/classes.rb', line 38935

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NodeGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38940
38941
38942
# File 'lib/google/apis/compute_v1/classes.rb', line 38940

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38947
38948
38949
38950
38951
38952
38953
38954
# File 'lib/google/apis/compute_v1/classes.rb', line 38947

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end