Class: Google::Apis::ComputeV1::NodeGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of nodeGroups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NodeGroup>
A list of NodeGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupList
constructor
A new instance of NodeGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupList
Returns a new instance of NodeGroupList.
38328 38329 38330 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38295 38296 38297 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38295 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NodeGroup>
A list of NodeGroup resources.
Corresponds to the JSON property items
38300 38301 38302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38300 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeGroupList
for lists of node groups.
Corresponds to the JSON property kind
38306 38307 38308 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38306 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38316 38317 38318 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38316 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38321 38322 38323 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38321 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NodeGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38326 38327 38328 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38326 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38333 38334 38335 38336 38337 38338 38339 38340 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38333 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |