Class: Google::Apis::ComputeV1::NodeGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of nodeGroups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupList

Returns a new instance of NodeGroupList.



34513
34514
34515
# File 'lib/google/apis/compute_v1/classes.rb', line 34513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34480
34481
34482
# File 'lib/google/apis/compute_v1/classes.rb', line 34480

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NodeGroup>

A list of NodeGroup resources. Corresponds to the JSON property items



34485
34486
34487
# File 'lib/google/apis/compute_v1/classes.rb', line 34485

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


34491
34492
34493
# File 'lib/google/apis/compute_v1/classes.rb', line 34491

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34501
34502
34503
# File 'lib/google/apis/compute_v1/classes.rb', line 34501

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34506
34507
34508
# File 'lib/google/apis/compute_v1/classes.rb', line 34506

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NodeGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34511
34512
34513
# File 'lib/google/apis/compute_v1/classes.rb', line 34511

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34518
34519
34520
34521
34522
34523
34524
34525
# File 'lib/google/apis/compute_v1/classes.rb', line 34518

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end