Class: Google::Apis::ComputeV1::NodeGroupMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupMaintenanceWindow

Returns a new instance of NodeGroupMaintenanceWindow.



39033
39034
39035
# File 'lib/google/apis/compute_v1/classes.rb', line 39033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maintenance_durationGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maintenanceDuration



39024
39025
39026
# File 'lib/google/apis/compute_v1/classes.rb', line 39024

def maintenance_duration
  @maintenance_duration
end

#start_timeString

Start time of the window. This must be in UTC format that resolves to one of 00:00, 04:00, 08:00,12:00, 16:00, or 20:00. For example, both 13:00-5 and 08:00 are valid. Corresponds to the JSON property startTime

Returns:

  • (String)


39031
39032
39033
# File 'lib/google/apis/compute_v1/classes.rb', line 39031

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39038
39039
39040
39041
# File 'lib/google/apis/compute_v1/classes.rb', line 39038

def update!(**args)
  @maintenance_duration = args[:maintenance_duration] if args.key?(:maintenance_duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end