Class: Google::Apis::ComputeV1::NodeGroupMaintenanceWindow
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeGroupMaintenanceWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window.
Instance Attribute Summary collapse
-
#maintenance_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#start_time ⇒ String
Start time of the window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupMaintenanceWindow
constructor
A new instance of NodeGroupMaintenanceWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupMaintenanceWindow
Returns a new instance of NodeGroupMaintenanceWindow.
35455 35456 35457 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#maintenance_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maintenanceDuration
35446 35447 35448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35446 def maintenance_duration @maintenance_duration end |
#start_time ⇒ String
Start time of the window. This must be in UTC format that resolves to one
of 00:00, 04:00, 08:00,12:00, 16:00, or 20:00. For
example, both 13:00-5 and 08:00 are valid.
Corresponds to the JSON property startTime
35453 35454 35455 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35453 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35460 35461 35462 35463 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35460 def update!(**args) @maintenance_duration = args[:maintenance_duration] if args.key?(:maintenance_duration) @start_time = args[:start_time] if args.key?(:start_time) end |