Class: Google::Apis::ComputeV1::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



39433
39434
39435
# File 'lib/google/apis/compute_v1/classes.rb', line 39433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39398
39399
39400
# File 'lib/google/apis/compute_v1/classes.rb', line 39398

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



39403
39404
39405
# File 'lib/google/apis/compute_v1/classes.rb', line 39403

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute. nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


39410
39411
39412
# File 'lib/google/apis/compute_v1/classes.rb', line 39410

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39421
39422
39423
# File 'lib/google/apis/compute_v1/classes.rb', line 39421

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39426
39427
39428
# File 'lib/google/apis/compute_v1/classes.rb', line 39426

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NodeGroupsListNodes::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



39431
39432
39433
# File 'lib/google/apis/compute_v1/classes.rb', line 39431

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39438
39439
39440
39441
39442
39443
39444
39445
# File 'lib/google/apis/compute_v1/classes.rb', line 39438

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end