Class: Google::Apis::ComputeV1::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



39237
39238
39239
# File 'lib/google/apis/compute_v1/classes.rb', line 39237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39202
39203
39204
# File 'lib/google/apis/compute_v1/classes.rb', line 39202

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



39207
39208
39209
# File 'lib/google/apis/compute_v1/classes.rb', line 39207

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute. nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


39214
39215
39216
# File 'lib/google/apis/compute_v1/classes.rb', line 39214

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39225
39226
39227
# File 'lib/google/apis/compute_v1/classes.rb', line 39225

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39230
39231
39232
# File 'lib/google/apis/compute_v1/classes.rb', line 39230

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NodeGroupsListNodes::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



39235
39236
39237
# File 'lib/google/apis/compute_v1/classes.rb', line 39235

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39242
39243
39244
39245
39246
39247
39248
39249
# File 'lib/google/apis/compute_v1/classes.rb', line 39242

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end