Class: Google::Apis::ComputeV1::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



21224
21225
21226
# File 'lib/google/apis/compute_v1/classes.rb', line 21224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21192
21193
21194
# File 'lib/google/apis/compute_v1/classes.rb', line 21192

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



21197
21198
21199
# File 'lib/google/apis/compute_v1/classes.rb', line 21197

def items
  @items
end

#kindString

[Output Only] The resource type, which is always compute.nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


21203
21204
21205
# File 'lib/google/apis/compute_v1/classes.rb', line 21203

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21212
21213
21214
# File 'lib/google/apis/compute_v1/classes.rb', line 21212

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21217
21218
21219
# File 'lib/google/apis/compute_v1/classes.rb', line 21217

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NodeGroupsListNodes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21222
21223
21224
# File 'lib/google/apis/compute_v1/classes.rb', line 21222

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21229
21230
21231
21232
21233
21234
21235
21236
# File 'lib/google/apis/compute_v1/classes.rb', line 21229

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end