Class: Google::Apis::ComputeV1::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



40388
40389
40390
# File 'lib/google/apis/compute_v1/classes.rb', line 40388

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40349
40350
40351
# File 'lib/google/apis/compute_v1/classes.rb', line 40349

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



40354
40355
40356
# File 'lib/google/apis/compute_v1/classes.rb', line 40354

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


40361
40362
40363
# File 'lib/google/apis/compute_v1/classes.rb', line 40361

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40371
40372
40373
# File 'lib/google/apis/compute_v1/classes.rb', line 40371

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40376
40377
40378
# File 'lib/google/apis/compute_v1/classes.rb', line 40376

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40381
40382
40383
# File 'lib/google/apis/compute_v1/classes.rb', line 40381

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40386
40387
40388
# File 'lib/google/apis/compute_v1/classes.rb', line 40386

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40393
40394
40395
40396
40397
40398
40399
40400
40401
# File 'lib/google/apis/compute_v1/classes.rb', line 40393

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end