Class: Google::Apis::ComputeV1::NodeTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateAggregatedList
constructor
A new instance of NodeTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateAggregatedList
Returns a new instance of NodeTemplateAggregatedList.
40026 40027 40028 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39987 39988 39989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39987 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
Corresponds to the JSON property items
39992 39993 39994 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39992 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeTemplateAggregatedList for aggregated lists of
node templates.
Corresponds to the JSON property kind
39999 40000 40001 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39999 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40009 40010 40011 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40009 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40014 40015 40016 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40014 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
40019 40020 40021 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40019 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40024 40025 40026 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40024 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40031 40032 40033 40034 40035 40036 40037 40038 40039 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40031 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |