Class: Google::Apis::ComputeV1::NodeTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateAggregatedList
constructor
A new instance of NodeTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateAggregatedList
Returns a new instance of NodeTemplateAggregatedList.
39861 39862 39863 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39822 39823 39824 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39822 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
Corresponds to the JSON property items
39827 39828 39829 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39827 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeTemplateAggregatedList for aggregated lists of
node templates.
Corresponds to the JSON property kind
39834 39835 39836 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39834 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39844 39845 39846 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39844 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39849 39850 39851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39849 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
39854 39855 39856 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39854 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39859 39860 39861 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39859 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39866 39867 39868 39869 39870 39871 39872 39873 39874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39866 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |