Class: Google::Apis::ComputeV1::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



39862
39863
39864
# File 'lib/google/apis/compute_v1/classes.rb', line 39862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39823
39824
39825
# File 'lib/google/apis/compute_v1/classes.rb', line 39823

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



39828
39829
39830
# File 'lib/google/apis/compute_v1/classes.rb', line 39828

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


39835
39836
39837
# File 'lib/google/apis/compute_v1/classes.rb', line 39835

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39845
39846
39847
# File 'lib/google/apis/compute_v1/classes.rb', line 39845

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39850
39851
39852
# File 'lib/google/apis/compute_v1/classes.rb', line 39850

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39855
39856
39857
# File 'lib/google/apis/compute_v1/classes.rb', line 39855

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39860
39861
39862
# File 'lib/google/apis/compute_v1/classes.rb', line 39860

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39867
39868
39869
39870
39871
39872
39873
39874
39875
# File 'lib/google/apis/compute_v1/classes.rb', line 39867

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end