Class: Google::Apis::ComputeV1::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



39665
39666
39667
# File 'lib/google/apis/compute_v1/classes.rb', line 39665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39626
39627
39628
# File 'lib/google/apis/compute_v1/classes.rb', line 39626

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



39631
39632
39633
# File 'lib/google/apis/compute_v1/classes.rb', line 39631

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


39638
39639
39640
# File 'lib/google/apis/compute_v1/classes.rb', line 39638

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39648
39649
39650
# File 'lib/google/apis/compute_v1/classes.rb', line 39648

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39653
39654
39655
# File 'lib/google/apis/compute_v1/classes.rb', line 39653

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39658
39659
39660
# File 'lib/google/apis/compute_v1/classes.rb', line 39658

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39663
39664
39665
# File 'lib/google/apis/compute_v1/classes.rb', line 39663

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39670
39671
39672
39673
39674
39675
39676
39677
39678
# File 'lib/google/apis/compute_v1/classes.rb', line 39670

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end