Class: Google::Apis::ComputeV1::NodeTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateAggregatedList
constructor
A new instance of NodeTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateAggregatedList
Returns a new instance of NodeTemplateAggregatedList.
36073 36074 36075 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36073 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36034 36035 36036 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36034 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
Corresponds to the JSON property items
36039 36040 36041 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36039 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeTemplateAggregatedList for aggregated lists of
node templates.
Corresponds to the JSON property kind
36046 36047 36048 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36046 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36056 36057 36058 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36056 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36061 36062 36063 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36061 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
36066 36067 36068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36066 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36071 36072 36073 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36071 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36078 36079 36080 36081 36082 36083 36084 36085 36086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36078 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |