Class: Google::Apis::ComputeV1::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



21586
21587
21588
# File 'lib/google/apis/compute_v1/classes.rb', line 21586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21549
21550
21551
# File 'lib/google/apis/compute_v1/classes.rb', line 21549

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



21554
21555
21556
# File 'lib/google/apis/compute_v1/classes.rb', line 21554

def items
  @items
end

#kindString

[Output Only] Type of resource.Always compute#nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


21560
21561
21562
# File 'lib/google/apis/compute_v1/classes.rb', line 21560

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21569
21570
21571
# File 'lib/google/apis/compute_v1/classes.rb', line 21569

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21574
21575
21576
# File 'lib/google/apis/compute_v1/classes.rb', line 21574

def self_link
  @self_link
end

#unreachablesArray<String>

[Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21579
21580
21581
# File 'lib/google/apis/compute_v1/classes.rb', line 21579

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21584
21585
21586
# File 'lib/google/apis/compute_v1/classes.rb', line 21584

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21591
21592
21593
21594
21595
21596
21597
21598
21599
# File 'lib/google/apis/compute_v1/classes.rb', line 21591

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end