Class: Google::Apis::ComputeV1::NodeTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of node templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NodeTemplate>
A list of NodeTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateList
constructor
A new instance of NodeTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateList
Returns a new instance of NodeTemplateList.
40526 40527 40528 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40493 40494 40495 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40493 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NodeTemplate>
A list of NodeTemplate resources.
Corresponds to the JSON property items
40498 40499 40500 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40498 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeTemplateList
for lists of node templates.
Corresponds to the JSON property kind
40504 40505 40506 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40504 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40514 40515 40516 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40514 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40519 40520 40521 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40519 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40524 40525 40526 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40524 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40531 40532 40533 40534 40535 40536 40537 40538 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40531 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |