Class: Google::Apis::ComputeV1::NodeTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of node templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateList

Returns a new instance of NodeTemplateList.



40162
40163
40164
# File 'lib/google/apis/compute_v1/classes.rb', line 40162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40129
40130
40131
# File 'lib/google/apis/compute_v1/classes.rb', line 40129

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NodeTemplate>

A list of NodeTemplate resources. Corresponds to the JSON property items



40134
40135
40136
# File 'lib/google/apis/compute_v1/classes.rb', line 40134

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


40140
40141
40142
# File 'lib/google/apis/compute_v1/classes.rb', line 40140

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40150
40151
40152
# File 'lib/google/apis/compute_v1/classes.rb', line 40150

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40155
40156
40157
# File 'lib/google/apis/compute_v1/classes.rb', line 40155

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NodeTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40160
40161
40162
# File 'lib/google/apis/compute_v1/classes.rb', line 40160

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40167
40168
40169
40170
40171
40172
40173
40174
# File 'lib/google/apis/compute_v1/classes.rb', line 40167

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end