Class: Google::Apis::ComputeV1::NodeTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of node templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateList

Returns a new instance of NodeTemplateList.



39988
39989
39990
# File 'lib/google/apis/compute_v1/classes.rb', line 39988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39955
39956
39957
# File 'lib/google/apis/compute_v1/classes.rb', line 39955

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NodeTemplate>

A list of NodeTemplate resources. Corresponds to the JSON property items



39960
39961
39962
# File 'lib/google/apis/compute_v1/classes.rb', line 39960

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


39966
39967
39968
# File 'lib/google/apis/compute_v1/classes.rb', line 39966

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39976
39977
39978
# File 'lib/google/apis/compute_v1/classes.rb', line 39976

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39981
39982
39983
# File 'lib/google/apis/compute_v1/classes.rb', line 39981

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NodeTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39986
39987
39988
# File 'lib/google/apis/compute_v1/classes.rb', line 39986

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39993
39994
39995
39996
39997
39998
39999
40000
# File 'lib/google/apis/compute_v1/classes.rb', line 39993

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end