Class: Google::Apis::ComputeV1::NodeTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of node templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NodeTemplate>
A list of NodeTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateList
constructor
A new instance of NodeTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateList
Returns a new instance of NodeTemplateList.
39791 39792 39793 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39758 39759 39760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39758 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NodeTemplate>
A list of NodeTemplate resources.
Corresponds to the JSON property items
39763 39764 39765 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39763 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeTemplateList
for lists of node templates.
Corresponds to the JSON property kind
39769 39770 39771 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39769 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39779 39780 39781 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39779 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39784 39785 39786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39784 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39789 39790 39791 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39789 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39796 39797 39798 39799 39800 39801 39802 39803 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39796 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |