Class: Google::Apis::ComputeV1::NodeTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of node templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NodeTemplate>
A list of NodeTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateList
constructor
A new instance of NodeTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateList
Returns a new instance of NodeTemplateList.
35362 35363 35364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35329 35330 35331 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35329 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NodeTemplate>
A list of NodeTemplate resources.
Corresponds to the JSON property items
35334 35335 35336 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35334 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeTemplateList
for lists of node templates.
Corresponds to the JSON property kind
35340 35341 35342 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35340 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35350 35351 35352 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35350 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35355 35356 35357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35355 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NodeTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35360 35361 35362 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35360 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35367 35368 35369 35370 35371 35372 35373 35374 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35367 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |