Class: Google::Apis::ComputeV1::NodeTemplatesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplatesScopedList

Returns a new instance of NodeTemplatesScopedList.



40645
40646
40647
# File 'lib/google/apis/compute_v1/classes.rb', line 40645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#node_templatesArray<Google::Apis::ComputeV1::NodeTemplate>

[Output Only] A list of node templates contained in this scope. Corresponds to the JSON property nodeTemplates



40637
40638
40639
# File 'lib/google/apis/compute_v1/classes.rb', line 40637

def node_templates
  @node_templates
end

#warningGoogle::Apis::ComputeV1::NodeTemplatesScopedList::Warning

[Output Only] An informational warning that appears when the node templates list is empty. Corresponds to the JSON property warning



40643
40644
40645
# File 'lib/google/apis/compute_v1/classes.rb', line 40643

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40650
40651
40652
40653
# File 'lib/google/apis/compute_v1/classes.rb', line 40650

def update!(**args)
  @node_templates = args[:node_templates] if args.key?(:node_templates)
  @warning = args[:warning] if args.key?(:warning)
end