Class: Google::Apis::ComputeV1::NodeTemplatesScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeTemplatesScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#node_templates ⇒ Array<Google::Apis::ComputeV1::NodeTemplate>
[Output Only] A list of node templates contained in this scope.
-
#warning ⇒ Google::Apis::ComputeV1::NodeTemplatesScopedList::Warning
[Output Only] An informational warning that appears when the node templates list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplatesScopedList
constructor
A new instance of NodeTemplatesScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplatesScopedList
Returns a new instance of NodeTemplatesScopedList.
40118 40119 40120 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#node_templates ⇒ Array<Google::Apis::ComputeV1::NodeTemplate>
[Output Only] A list of node templates contained in this scope.
Corresponds to the JSON property nodeTemplates
40110 40111 40112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40110 def node_templates @node_templates end |
#warning ⇒ Google::Apis::ComputeV1::NodeTemplatesScopedList::Warning
[Output Only] An informational warning that appears when the node templates
list is empty.
Corresponds to the JSON property warning
40116 40117 40118 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40116 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40123 40124 40125 40126 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40123 def update!(**args) @node_templates = args[:node_templates] if args.key?(:node_templates) @warning = args[:warning] if args.key?(:warning) end |