Class: Google::Apis::ComputeV1::NodeType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NodeType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.
Instance Attribute Summary collapse
-
#cpu_platform ⇒ String
[Output Only] The CPU platform used by this node type.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional textual description of the resource.
-
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the node type.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#local_ssd_gb ⇒ Fixnum
[Output Only] Local SSD available to the node type, defined in GB.
-
#max_vms ⇒ Fixnum
Output only.
-
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the node type, defined in MB.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#self_link ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeType
constructor
A new instance of NodeType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeType
Returns a new instance of NodeType.
35656 35657 35658 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpu_platform ⇒ String
[Output Only] The CPU platform used by this node type.
Corresponds to the JSON property cpuPlatform
35587 35588 35589 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35587 def cpu_platform @cpu_platform end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
35593 35594 35595 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35593 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
35598 35599 35600 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35598 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional textual description of the resource.
Corresponds to the JSON property description
35603 35604 35605 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35603 def description @description end |
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the node
type.
Corresponds to the JSON property guestCpus
35609 35610 35611 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35609 def guest_cpus @guest_cpus end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
35615 35616 35617 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35615 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#nodeType
for node types.
Corresponds to the JSON property kind
35621 35622 35623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35621 def kind @kind end |
#local_ssd_gb ⇒ Fixnum
[Output Only] Local SSD available to the node type, defined in GB.
Corresponds to the JSON property localSsdGb
35626 35627 35628 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35626 def local_ssd_gb @local_ssd_gb end |
#max_vms ⇒ Fixnum
Output only. [Output Only] Maximum number of VMs that can be created for this
node type.
Corresponds to the JSON property maxVms
35632 35633 35634 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35632 def max_vms @max_vms end |
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the node type,
defined in MB.
Corresponds to the JSON property memoryMb
35638 35639 35640 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35638 def memory_mb @memory_mb end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
35643 35644 35645 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35643 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
35648 35649 35650 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35648 def self_link @self_link end |
#zone ⇒ String
Output only. [Output Only] The name of the zone where the node type resides,
such as us-central1-a.
Corresponds to the JSON property zone
35654 35655 35656 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35654 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35661 35662 35663 35664 35665 35666 35667 35668 35669 35670 35671 35672 35673 35674 35675 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35661 def update!(**args) @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb) @max_vms = args[:max_vms] if args.key?(:max_vms) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @zone = args[:zone] if args.key?(:zone) end |