Class: Google::Apis::ComputeV1::NodeType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information read Node types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeType

Returns a new instance of NodeType.



21977
21978
21979
# File 'lib/google/apis/compute_v1/classes.rb', line 21977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpu_platformString

[Output Only] The CPU platform used by this node type. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


21917
21918
21919
# File 'lib/google/apis/compute_v1/classes.rb', line 21917

def cpu_platform
  @cpu_platform
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


21922
21923
21924
# File 'lib/google/apis/compute_v1/classes.rb', line 21922

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeV1::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



21927
21928
21929
# File 'lib/google/apis/compute_v1/classes.rb', line 21927

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


21932
21933
21934
# File 'lib/google/apis/compute_v1/classes.rb', line 21932

def description
  @description
end

#guest_cpusFixnum

[Output Only] The number of virtual CPUs that are available to the node type. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


21937
21938
21939
# File 'lib/google/apis/compute_v1/classes.rb', line 21937

def guest_cpus
  @guest_cpus
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


21943
21944
21945
# File 'lib/google/apis/compute_v1/classes.rb', line 21943

def id
  @id
end

#kindString

[Output Only] The type of the resource. Always compute#nodeType for node types. Corresponds to the JSON property kind

Returns:

  • (String)


21948
21949
21950
# File 'lib/google/apis/compute_v1/classes.rb', line 21948

def kind
  @kind
end

#local_ssd_gbFixnum

[Output Only] Local SSD available to the node type, defined in GB. Corresponds to the JSON property localSsdGb

Returns:

  • (Fixnum)


21953
21954
21955
# File 'lib/google/apis/compute_v1/classes.rb', line 21953

def local_ssd_gb
  @local_ssd_gb
end

#memory_mbFixnum

[Output Only] The amount of physical memory available to the node type, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


21959
21960
21961
# File 'lib/google/apis/compute_v1/classes.rb', line 21959

def memory_mb
  @memory_mb
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


21964
21965
21966
# File 'lib/google/apis/compute_v1/classes.rb', line 21964

def name
  @name
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21969
21970
21971
# File 'lib/google/apis/compute_v1/classes.rb', line 21969

def self_link
  @self_link
end

#zoneString

[Output Only] The name of the zone where the node type resides, such as us- central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


21975
21976
21977
# File 'lib/google/apis/compute_v1/classes.rb', line 21975

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
# File 'lib/google/apis/compute_v1/classes.rb', line 21982

def update!(**args)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @zone = args[:zone] if args.key?(:zone)
end