Class: Google::Apis::ComputeV1::NotificationEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a notification endpoint. A notification endpoint resource defines an endpoint to receive notifications when there are status changes detected by the associated health check service. For more information, see Health checks overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpoint

Returns a new instance of NotificationEndpoint.



40722
40723
40724
# File 'lib/google/apis/compute_v1/classes.rb', line 40722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


40670
40671
40672
# File 'lib/google/apis/compute_v1/classes.rb', line 40670

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


40676
40677
40678
# File 'lib/google/apis/compute_v1/classes.rb', line 40676

def description
  @description
end

#grpc_settingsGoogle::Apis::ComputeV1::NotificationEndpointGrpcSettings

Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint. Corresponds to the JSON property grpcSettings



40682
40683
40684
# File 'lib/google/apis/compute_v1/classes.rb', line 40682

def grpc_settings
  @grpc_settings
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


40689
40690
40691
# File 'lib/google/apis/compute_v1/classes.rb', line 40689

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


40695
40696
40697
# File 'lib/google/apis/compute_v1/classes.rb', line 40695

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


40706
40707
40708
# File 'lib/google/apis/compute_v1/classes.rb', line 40706

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the notification endpoint resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


40715
40716
40717
# File 'lib/google/apis/compute_v1/classes.rb', line 40715

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40720
40721
40722
# File 'lib/google/apis/compute_v1/classes.rb', line 40720

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40727
40728
40729
40730
40731
40732
40733
40734
40735
40736
# File 'lib/google/apis/compute_v1/classes.rb', line 40727

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @grpc_settings = args[:grpc_settings] if args.key?(:grpc_settings)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end