Class: Google::Apis::ComputeV1::NotificationEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NotificationEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a notification endpoint. A notification endpoint resource defines an endpoint to receive notifications when there are status changes detected by the associated health check service. For more information, see Health checks overview.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#grpc_settings ⇒ Google::Apis::ComputeV1::NotificationEndpointGrpcSettings
Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint.
-
#id ⇒ Fixnum
[Output Only] A unique identifier for this resource type.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
[Output Only] URL of the region where the notification endpoint resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpoint
constructor
A new instance of NotificationEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpoint
Returns a new instance of NotificationEndpoint.
22390 22391 22392 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
22341 22342 22343 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22341 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
22347 22348 22349 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22347 def description @description end |
#grpc_settings ⇒ Google::Apis::ComputeV1::NotificationEndpointGrpcSettings
Represents a gRPC setting that describes one gRPC notification endpoint and
the retry duration attempting to send notification to this endpoint.
Corresponds to the JSON property grpcSettings
22353 22354 22355 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22353 def grpc_settings @grpc_settings end |
#id ⇒ Fixnum
[Output Only] A unique identifier for this resource type. The server generates
this identifier.
Corresponds to the JSON property id
22359 22360 22361 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22359 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#notificationEndpoint for
notification endpoints.
Corresponds to the JSON property kind
22365 22366 22367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22365 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
22375 22376 22377 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22375 def name @name end |
#region ⇒ String
[Output Only] URL of the region where the notification endpoint resides. This
field applies only to the regional resource. You must specify this field as
part of the HTTP request URL. It is not settable as a field in the request
body.
Corresponds to the JSON property region
22383 22384 22385 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22383 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
22388 22389 22390 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22388 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22395 22396 22397 22398 22399 22400 22401 22402 22403 22404 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22395 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @grpc_settings = args[:grpc_settings] if args.key?(:grpc_settings) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |