Class: Google::Apis::ComputeV1::NotificationEndpointGrpcSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NotificationEndpointGrpcSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint.
Instance Attribute Summary collapse
-
#authority ⇒ String
Optional.
-
#endpoint ⇒ String
Endpoint to which gRPC notifications are sent.
-
#payload_name ⇒ String
Optional.
-
#resend_interval ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#retry_duration_sec ⇒ Fixnum
How much time (in seconds) is spent attempting notification retries until a successful response is received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpointGrpcSettings
constructor
A new instance of NotificationEndpointGrpcSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpointGrpcSettings
Returns a new instance of NotificationEndpointGrpcSettings.
36153 36154 36155 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authority ⇒ String
Optional. If specified, this field is used to set the authority header by
the sender of notifications. See
https://tools.ietf.org/html/rfc7540#section-8.1.2.3
Corresponds to the JSON property authority
36124 36125 36126 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36124 def @authority end |
#endpoint ⇒ String
Endpoint to which gRPC notifications are sent. This must be a valid
gRPCLB DNS name.
Corresponds to the JSON property endpoint
36130 36131 36132 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36130 def endpoint @endpoint end |
#payload_name ⇒ String
Optional. If specified, this field is used to populate the "name" field
in gRPC requests.
Corresponds to the JSON property payloadName
36136 36137 36138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36136 def payload_name @payload_name end |
#resend_interval ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property resendInterval
36144 36145 36146 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36144 def resend_interval @resend_interval end |
#retry_duration_sec ⇒ Fixnum
How much time (in seconds) is spent attempting notification retries
until a successful response is received. Default is 30s. Limit is 20m
(1200s). Must be a positive number.
Corresponds to the JSON property retryDurationSec
36151 36152 36153 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36151 def retry_duration_sec @retry_duration_sec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36158 36159 36160 36161 36162 36163 36164 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36158 def update!(**args) @authority = args[:authority] if args.key?(:authority) @endpoint = args[:endpoint] if args.key?(:endpoint) @payload_name = args[:payload_name] if args.key?(:payload_name) @resend_interval = args[:resend_interval] if args.key?(:resend_interval) @retry_duration_sec = args[:retry_duration_sec] if args.key?(:retry_duration_sec) end |