Class: Google::Apis::ComputeV1::NotificationEndpointList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NotificationEndpointList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NotificationEndpoint>
A list of NotificationEndpoint resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpointList
constructor
A new instance of NotificationEndpointList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpointList
Returns a new instance of NotificationEndpointList.
41501 41502 41503 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
41468 41469 41470 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41468 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NotificationEndpoint>
A list of NotificationEndpoint resources.
Corresponds to the JSON property items
41473 41474 41475 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41473 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
notificationEndpoint for notification endpoints.
Corresponds to the JSON property kind
41479 41480 41481 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41479 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41489 41490 41491 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41489 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41494 41495 41496 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41494 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41499 41500 41501 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41499 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41506 41507 41508 41509 41510 41511 41512 41513 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41506 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |