Class: Google::Apis::ComputeV1::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



41137
41138
41139
# File 'lib/google/apis/compute_v1/classes.rb', line 41137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41104
41105
41106
# File 'lib/google/apis/compute_v1/classes.rb', line 41104

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



41109
41110
41111
# File 'lib/google/apis/compute_v1/classes.rb', line 41109

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


41115
41116
41117
# File 'lib/google/apis/compute_v1/classes.rb', line 41115

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41125
41126
41127
# File 'lib/google/apis/compute_v1/classes.rb', line 41125

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41130
41131
41132
# File 'lib/google/apis/compute_v1/classes.rb', line 41130

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41135
41136
41137
# File 'lib/google/apis/compute_v1/classes.rb', line 41135

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41142
41143
41144
41145
41146
41147
41148
41149
# File 'lib/google/apis/compute_v1/classes.rb', line 41142

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end