Class: Google::Apis::ComputeV1::NotificationEndpointList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NotificationEndpointList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NotificationEndpoint>
A list of NotificationEndpoint resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpointList
constructor
A new instance of NotificationEndpointList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpointList
Returns a new instance of NotificationEndpointList.
41127 41128 41129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41127 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
41094 41095 41096 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41094 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NotificationEndpoint>
A list of NotificationEndpoint resources.
Corresponds to the JSON property items
41099 41100 41101 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41099 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
notificationEndpoint for notification endpoints.
Corresponds to the JSON property kind
41105 41106 41107 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41105 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41115 41116 41117 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41115 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41120 41121 41122 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41120 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41125 41126 41127 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41125 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41132 41133 41134 41135 41136 41137 41138 41139 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41132 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |