Class: Google::Apis::ComputeV1::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



40962
40963
40964
# File 'lib/google/apis/compute_v1/classes.rb', line 40962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40929
40930
40931
# File 'lib/google/apis/compute_v1/classes.rb', line 40929

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



40934
40935
40936
# File 'lib/google/apis/compute_v1/classes.rb', line 40934

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


40940
40941
40942
# File 'lib/google/apis/compute_v1/classes.rb', line 40940

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40950
40951
40952
# File 'lib/google/apis/compute_v1/classes.rb', line 40950

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40955
40956
40957
# File 'lib/google/apis/compute_v1/classes.rb', line 40955

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40960
40961
40962
# File 'lib/google/apis/compute_v1/classes.rb', line 40960

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40967
40968
40969
40970
40971
40972
40973
40974
# File 'lib/google/apis/compute_v1/classes.rb', line 40967

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end