Class: Google::Apis::ComputeV1::NotificationEndpointList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NotificationEndpointList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NotificationEndpoint>
A list of NotificationEndpoint resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpointList
constructor
A new instance of NotificationEndpointList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpointList
Returns a new instance of NotificationEndpointList.
40752 40753 40754 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40719 40720 40721 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40719 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NotificationEndpoint>
A list of NotificationEndpoint resources.
Corresponds to the JSON property items
40724 40725 40726 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40724 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
notificationEndpoint for notification endpoints.
Corresponds to the JSON property kind
40730 40731 40732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40730 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40740 40741 40742 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40740 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40745 40746 40747 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40745 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40750 40751 40752 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40750 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40757 40758 40759 40760 40761 40762 40763 40764 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40757 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |