Class: Google::Apis::ComputeV1::NotificationEndpointList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NotificationEndpointList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::NotificationEndpoint>
A list of NotificationEndpoint resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpointList
constructor
A new instance of NotificationEndpointList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpointList
Returns a new instance of NotificationEndpointList.
40152 40153 40154 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40152 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40119 40120 40121 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40119 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::NotificationEndpoint>
A list of NotificationEndpoint resources.
Corresponds to the JSON property items
40124 40125 40126 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40124 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
notificationEndpoint for notification endpoints.
Corresponds to the JSON property kind
40130 40131 40132 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40130 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40140 40141 40142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40140 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40145 40146 40147 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40145 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40150 40151 40152 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40150 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40157 40158 40159 40160 40161 40162 40163 40164 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40157 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |