Class: Google::Apis::ComputeV1::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



36207
36208
36209
# File 'lib/google/apis/compute_v1/classes.rb', line 36207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36174
36175
36176
# File 'lib/google/apis/compute_v1/classes.rb', line 36174

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



36179
36180
36181
# File 'lib/google/apis/compute_v1/classes.rb', line 36179

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


36185
36186
36187
# File 'lib/google/apis/compute_v1/classes.rb', line 36185

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36195
36196
36197
# File 'lib/google/apis/compute_v1/classes.rb', line 36195

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36200
36201
36202
# File 'lib/google/apis/compute_v1/classes.rb', line 36200

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36205
36206
36207
# File 'lib/google/apis/compute_v1/classes.rb', line 36205

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36212
36213
36214
36215
36216
36217
36218
36219
# File 'lib/google/apis/compute_v1/classes.rb', line 36212

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end