Class: Google::Apis::ComputeV1::Operation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Operation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents an Operation resource. Google Compute Engine has three Operation resources:
- Global
- Regional
Zonal You can use an operation resource to manage asynchronous API requests. For more information, readHandling API responses. Operations can be global, regional or zonal.
For global operations, use the
globalOperationsresource.For regional operations, use the
regionOperationsresource.For zonal operations, use the
zoneOperationsresource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period.
Defined Under Namespace
Instance Attribute Summary collapse
-
#client_operation_id ⇒ String
[Output Only] The value of
requestIdif you provided it in the request. -
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
-
#description ⇒ String
[Output Only] A textual description of the operation, which is set when the operation is created.
-
#end_time ⇒ String
[Output Only] The time that this operation was completed.
-
#error ⇒ Google::Apis::ComputeV1::Operation::Error
[Output Only] If errors are generated during processing of the operation, this field will be populated.
-
#get_version_operation_metadata ⇒ Google::Apis::ComputeV1::GetVersionOperationMetadata
Corresponds to the JSON property
getVersionOperationMetadata. -
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as
NOT FOUND. -
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error status code that was returned.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation.
-
#insert_time ⇒ String
[Output Only] The time that this operation was requested.
-
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::ComputeV1::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property
instancesBulkInsertOperationMetadata. -
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the operation.
-
#operation_group_id ⇒ String
Output only.
-
#operation_type ⇒ String
[Output Only] The type of operation, such as
insert,update, ordelete, and so on. -
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100.
-
#region ⇒ String
[Output Only] The URL of the region where the operation resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::ComputeV1::SetCommonInstanceMetadataOperationMetadata
Output only.
-
#start_time ⇒ String
[Output Only] The time that this operation was started by the server.
-
#status ⇒ String
[Output Only] The status of the operation, which can be one of the following:
PENDING,RUNNING, orDONE. -
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the operation.
-
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation of the target resource.
-
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies.
-
#user ⇒ String
[Output Only] User who requested the operation, for example:
user@example.comoralice_smith_identifier (global/workforcePools/example-com-us-employees). -
#warnings ⇒ Array<Google::Apis::ComputeV1::Operation::Warning>
[Output Only] If warning messages are generated during processing of the operation, this field will be populated.
-
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
41338 41339 41340 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_operation_id ⇒ String
[Output Only] The value of requestId if you provided it in the request.
Not present otherwise.
Corresponds to the JSON property clientOperationId
41171 41172 41173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41171 def client_operation_id @client_operation_id end |
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
Corresponds to the JSON property creationTimestamp
41176 41177 41178 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41176 def @creation_timestamp end |
#description ⇒ String
[Output Only] A textual description of the operation, which is
set when the operation is created.
Corresponds to the JSON property description
41182 41183 41184 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41182 def description @description end |
#end_time ⇒ String
[Output Only] The time that this operation was completed. This value is
inRFC3339
text format.
Corresponds to the JSON property endTime
41189 41190 41191 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41189 def end_time @end_time end |
#error ⇒ Google::Apis::ComputeV1::Operation::Error
[Output Only] If errors are generated during processing of the operation,
this field will be populated.
Corresponds to the JSON property error
41195 41196 41197 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41195 def error @error end |
#get_version_operation_metadata ⇒ Google::Apis::ComputeV1::GetVersionOperationMetadata
Corresponds to the JSON property getVersionOperationMetadata
41200 41201 41202 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41200 def @get_version_operation_metadata end |
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error
message that was returned, such as NOT FOUND.
Corresponds to the JSON property httpErrorMessage
41206 41207 41208 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41206 def @http_error_message end |
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error
status code that was returned. For example, a 404 means the
resource was not found.
Corresponds to the JSON property httpErrorStatusCode
41213 41214 41215 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41213 def http_error_status_code @http_error_status_code end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation. This identifier is
defined by the server.
Corresponds to the JSON property id
41219 41220 41221 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41219 def id @id end |
#insert_time ⇒ String
[Output Only] The time that this operation was requested.
This value is inRFC3339
text format.
Corresponds to the JSON property insertTime
41226 41227 41228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41226 def insert_time @insert_time end |
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::ComputeV1::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property instancesBulkInsertOperationMetadata
41231 41232 41233 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41231 def @instances_bulk_insert_operation_metadata end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#operation
for
Operation resources.
Corresponds to the JSON property kind
41238 41239 41240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41238 def kind @kind end |
#name ⇒ String
[Output Only] Name of the operation.
Corresponds to the JSON property name
41243 41244 41245 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41243 def name @name end |
#operation_group_id ⇒ String
Output only. [Output Only] An ID that represents a group of operations, such
as when a
group of operations results from a bulkInsert API request.
Corresponds to the JSON property operationGroupId
41250 41251 41252 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41250 def operation_group_id @operation_group_id end |
#operation_type ⇒ String
[Output Only] The type of operation, such as insert,
update, or delete, and so on.
Corresponds to the JSON property operationType
41256 41257 41258 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41256 def operation_type @operation_type end |
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100.
There is no requirement that this be linear or support any granularity of
operations. This should not be used to guess when the operation will be
complete. This number should monotonically increase as the operation
progresses.
Corresponds to the JSON property progress
41265 41266 41267 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41265 def progress @progress end |
#region ⇒ String
[Output Only] The URL of the region where the operation resides. Only
applicable when performing regional operations.
Corresponds to the JSON property region
41271 41272 41273 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41271 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
41276 41277 41278 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41276 def self_link @self_link end |
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::ComputeV1::SetCommonInstanceMetadataOperationMetadata
Output only. [Output Only] If the operation is for projects.
setCommonInstanceMetadata,
this field will contain information on all underlying zonal actions and
their state.
Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata
41284 41285 41286 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41284 def @set_common_instance_metadata_operation_metadata end |
#start_time ⇒ String
[Output Only] The time that this operation was started by the server.
This value is inRFC3339
text format.
Corresponds to the JSON property startTime
41291 41292 41293 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41291 def start_time @start_time end |
#status ⇒ String
[Output Only] The status of the operation, which can be one of the
following:
PENDING, RUNNING, or DONE.
Corresponds to the JSON property status
41298 41299 41300 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41298 def status @status end |
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the
operation.
Corresponds to the JSON property statusMessage
41304 41305 41306 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41304 def @status_message end |
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation
of the target resource.
Corresponds to the JSON property targetId
41310 41311 41312 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41310 def target_id @target_id end |
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies. For
operations related to creating a snapshot, this points to the disk
that the snapshot was created from.
Corresponds to the JSON property targetLink
41317 41318 41319 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41317 def target_link @target_link end |
#user ⇒ String
[Output Only] User who requested the operation, for example:
user@example.com or
alice_smith_identifier (global/workforcePools/example-com-us-employees).
Corresponds to the JSON property user
41324 41325 41326 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41324 def user @user end |
#warnings ⇒ Array<Google::Apis::ComputeV1::Operation::Warning>
[Output Only] If warning messages are generated during processing of the
operation, this field will be populated.
Corresponds to the JSON property warnings
41330 41331 41332 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41330 def warnings @warnings end |
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides. Only
applicable when performing per-zone operations.
Corresponds to the JSON property zone
41336 41337 41338 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41336 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41343 41344 41345 41346 41347 41348 41349 41350 41351 41352 41353 41354 41355 41356 41357 41358 41359 41360 41361 41362 41363 41364 41365 41366 41367 41368 41369 41370 41371 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41343 def update!(**args) @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @get_version_operation_metadata = args[:get_version_operation_metadata] if args.key?(:get_version_operation_metadata) @http_error_message = args[:http_error_message] if args.key?(:http_error_message) @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id) @operation_type = args[:operation_type] if args.key?(:operation_type) @progress = args[:progress] if args.key?(:progress) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @target_id = args[:target_id] if args.key?(:target_id) @target_link = args[:target_link] if args.key?(:target_link) @user = args[:user] if args.key?(:user) @warnings = args[:warnings] if args.key?(:warnings) @zone = args[:zone] if args.key?(:zone) end |