Class: Google::Apis::ComputeV1::Operation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an Operation resource. Google Compute Engine has three Operation resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API requests. For more information, read Handling API responses. Operations can be global, regional or zonal. - For global operations, use the globalOperations resource. - For regional operations, use the regionOperations resource. - For zonal operations, use the zonalOperations resource. For more information, read Global, Regional, and Zonal Resources.

Defined Under Namespace

Classes: Error, Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



22736
22737
22738
# File 'lib/google/apis/compute_v1/classes.rb', line 22736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_operation_idString

[Output Only] The value of requestId if you provided it in the request. Not present otherwise. Corresponds to the JSON property clientOperationId

Returns:

  • (String)


22595
22596
22597
# File 'lib/google/apis/compute_v1/classes.rb', line 22595

def client_operation_id
  @client_operation_id
end

#creation_timestampString

[Deprecated] This field is deprecated. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


22600
22601
22602
# File 'lib/google/apis/compute_v1/classes.rb', line 22600

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] A textual description of the operation, which is set when the operation is created. Corresponds to the JSON property description

Returns:

  • (String)


22606
22607
22608
# File 'lib/google/apis/compute_v1/classes.rb', line 22606

def description
  @description
end

#end_timeString

[Output Only] The time that this operation was completed. This value is in RFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


22612
22613
22614
# File 'lib/google/apis/compute_v1/classes.rb', line 22612

def end_time
  @end_time
end

#errorGoogle::Apis::ComputeV1::Operation::Error

[Output Only] If errors are generated during processing of the operation, this field will be populated. Corresponds to the JSON property error



22618
22619
22620
# File 'lib/google/apis/compute_v1/classes.rb', line 22618

def error
  @error
end

#http_error_messageString

[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND. Corresponds to the JSON property httpErrorMessage

Returns:

  • (String)


22624
22625
22626
# File 'lib/google/apis/compute_v1/classes.rb', line 22624

def http_error_message
  @http_error_message
end

#http_error_status_codeFixnum

[Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a 404 means the resource was not found. Corresponds to the JSON property httpErrorStatusCode

Returns:

  • (Fixnum)


22631
22632
22633
# File 'lib/google/apis/compute_v1/classes.rb', line 22631

def http_error_status_code
  @http_error_status_code
end

#idFixnum

[Output Only] The unique identifier for the operation. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


22637
22638
22639
# File 'lib/google/apis/compute_v1/classes.rb', line 22637

def id
  @id
end

#insert_timeString

[Output Only] The time that this operation was requested. This value is in RFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


22643
22644
22645
# File 'lib/google/apis/compute_v1/classes.rb', line 22643

def insert_time
  @insert_time
end

#kindString

[Output Only] Type of the resource. Always compute#operation for Operation resources. Corresponds to the JSON property kind

Returns:

  • (String)


22649
22650
22651
# File 'lib/google/apis/compute_v1/classes.rb', line 22649

def kind
  @kind
end

#nameString

[Output Only] Name of the operation. Corresponds to the JSON property name

Returns:

  • (String)


22654
22655
22656
# File 'lib/google/apis/compute_v1/classes.rb', line 22654

def name
  @name
end

#operation_group_idString

[Output Only] An ID that represents a group of operations, such as when a group of operations results from a bulkInsert API request. Corresponds to the JSON property operationGroupId

Returns:

  • (String)


22660
22661
22662
# File 'lib/google/apis/compute_v1/classes.rb', line 22660

def operation_group_id
  @operation_group_id
end

#operation_typeString

[Output Only] The type of operation, such as insert, update, or delete, and so on. Corresponds to the JSON property operationType

Returns:

  • (String)


22666
22667
22668
# File 'lib/google/apis/compute_v1/classes.rb', line 22666

def operation_type
  @operation_type
end

#progressFixnum

[Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses. Corresponds to the JSON property progress

Returns:

  • (Fixnum)


22674
22675
22676
# File 'lib/google/apis/compute_v1/classes.rb', line 22674

def progress
  @progress
end

#regionString

[Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations. Corresponds to the JSON property region

Returns:

  • (String)


22680
22681
22682
# File 'lib/google/apis/compute_v1/classes.rb', line 22680

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22685
22686
22687
# File 'lib/google/apis/compute_v1/classes.rb', line 22685

def self_link
  @self_link
end

#start_timeString

[Output Only] The time that this operation was started by the server. This value is in RFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


22691
22692
22693
# File 'lib/google/apis/compute_v1/classes.rb', line 22691

def start_time
  @start_time
end

#statusString

[Output Only] The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE. Corresponds to the JSON property status

Returns:

  • (String)


22697
22698
22699
# File 'lib/google/apis/compute_v1/classes.rb', line 22697

def status
  @status
end

#status_messageString

[Output Only] An optional textual description of the current status of the operation. Corresponds to the JSON property statusMessage

Returns:

  • (String)


22703
22704
22705
# File 'lib/google/apis/compute_v1/classes.rb', line 22703

def status_message
  @status_message
end

#target_idFixnum

[Output Only] The unique target ID, which identifies a specific incarnation of the target resource. Corresponds to the JSON property targetId

Returns:

  • (Fixnum)


22709
22710
22711
# File 'lib/google/apis/compute_v1/classes.rb', line 22709

def target_id
  @target_id
end

[Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the persistent disk that the snapshot was created from. Corresponds to the JSON property targetLink

Returns:

  • (String)


22716
22717
22718
# File 'lib/google/apis/compute_v1/classes.rb', line 22716

def target_link
  @target_link
end

#userString

[Output Only] User who requested the operation, for example: user@example.com . Corresponds to the JSON property user

Returns:

  • (String)


22722
22723
22724
# File 'lib/google/apis/compute_v1/classes.rb', line 22722

def user
  @user
end

#warningsArray<Google::Apis::ComputeV1::Operation::Warning>

[Output Only] If warning messages are generated during processing of the operation, this field will be populated. Corresponds to the JSON property warnings



22728
22729
22730
# File 'lib/google/apis/compute_v1/classes.rb', line 22728

def warnings
  @warnings
end

#zoneString

[Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations. Corresponds to the JSON property zone

Returns:

  • (String)


22734
22735
22736
# File 'lib/google/apis/compute_v1/classes.rb', line 22734

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22741
22742
22743
22744
22745
22746
22747
22748
22749
22750
22751
22752
22753
22754
22755
22756
22757
22758
22759
22760
22761
22762
22763
22764
22765
22766
# File 'lib/google/apis/compute_v1/classes.rb', line 22741

def update!(**args)
  @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @http_error_message = args[:http_error_message] if args.key?(:http_error_message)
  @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_id = args[:target_id] if args.key?(:target_id)
  @target_link = args[:target_link] if args.key?(:target_link)
  @user = args[:user] if args.key?(:user)
  @warnings = args[:warnings] if args.key?(:warnings)
  @zone = args[:zone] if args.key?(:zone)
end