Class: Google::Apis::ComputeV1::Operation::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Operation::Error::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#error_details ⇒ Array<Google::Apis::ComputeV1::Operation::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
36564 36565 36566 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36564 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
36542 36543 36544 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36542 def code @code end |
#error_details ⇒ Array<Google::Apis::ComputeV1::Operation::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error
details. There is a set of defined message types to use for providing
details.The syntax depends on the error code. For example,
QuotaExceededInfo will have details when the error code is
QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
36551 36552 36553 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36551 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
This property is optional.
Corresponds to the JSON property location
36557 36558 36559 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36557 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
36562 36563 36564 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36562 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36569 36570 36571 36572 36573 36574 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36569 def update!(**args) @code = args[:code] if args.key?(:code) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |