Class: Google::Apis::ComputeV1::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



41778
41779
41780
# File 'lib/google/apis/compute_v1/classes.rb', line 41778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41739
41740
41741
# File 'lib/google/apis/compute_v1/classes.rb', line 41739

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items



41744
41745
41746
# File 'lib/google/apis/compute_v1/classes.rb', line 41744

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:

  • (String)


41751
41752
41753
# File 'lib/google/apis/compute_v1/classes.rb', line 41751

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41761
41762
41763
# File 'lib/google/apis/compute_v1/classes.rb', line 41761

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41766
41767
41768
# File 'lib/google/apis/compute_v1/classes.rb', line 41766

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


41771
41772
41773
# File 'lib/google/apis/compute_v1/classes.rb', line 41771

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::OperationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41776
41777
41778
# File 'lib/google/apis/compute_v1/classes.rb', line 41776

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41783
41784
41785
41786
41787
41788
41789
41790
41791
# File 'lib/google/apis/compute_v1/classes.rb', line 41783

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end