Class: Google::Apis::ComputeV1::OperationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::OperationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::OperationsScopedList>
[Output Only] A map of scoped operation lists.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationAggregatedList
constructor
A new instance of OperationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationAggregatedList
Returns a new instance of OperationAggregatedList.
41613 41614 41615 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41613 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
41574 41575 41576 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41574 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::OperationsScopedList>
[Output Only] A map of scoped operation lists.
Corresponds to the JSON property items
41579 41580 41581 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41579 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
operationAggregatedList
for aggregated lists of operations.
Corresponds to the JSON property kind
41586 41587 41588 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41586 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41596 41597 41598 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41596 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41601 41602 41603 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41601 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
41606 41607 41608 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41606 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41611 41612 41613 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41611 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41618 41619 41620 41621 41622 41623 41624 41625 41626 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41618 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |