Class: Google::Apis::ComputeV1::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



41417
41418
41419
# File 'lib/google/apis/compute_v1/classes.rb', line 41417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41378
41379
41380
# File 'lib/google/apis/compute_v1/classes.rb', line 41378

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items



41383
41384
41385
# File 'lib/google/apis/compute_v1/classes.rb', line 41383

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:

  • (String)


41390
41391
41392
# File 'lib/google/apis/compute_v1/classes.rb', line 41390

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41400
41401
41402
# File 'lib/google/apis/compute_v1/classes.rb', line 41400

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41405
41406
41407
# File 'lib/google/apis/compute_v1/classes.rb', line 41405

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


41410
41411
41412
# File 'lib/google/apis/compute_v1/classes.rb', line 41410

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::OperationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41415
41416
41417
# File 'lib/google/apis/compute_v1/classes.rb', line 41415

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41422
41423
41424
41425
41426
41427
41428
41429
41430
# File 'lib/google/apis/compute_v1/classes.rb', line 41422

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end