Class: Google::Apis::ComputeV1::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



40803
40804
40805
# File 'lib/google/apis/compute_v1/classes.rb', line 40803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40764
40765
40766
# File 'lib/google/apis/compute_v1/classes.rb', line 40764

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items



40769
40770
40771
# File 'lib/google/apis/compute_v1/classes.rb', line 40769

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:

  • (String)


40776
40777
40778
# File 'lib/google/apis/compute_v1/classes.rb', line 40776

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40786
40787
40788
# File 'lib/google/apis/compute_v1/classes.rb', line 40786

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40791
40792
40793
# File 'lib/google/apis/compute_v1/classes.rb', line 40791

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40796
40797
40798
# File 'lib/google/apis/compute_v1/classes.rb', line 40796

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::OperationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40801
40802
40803
# File 'lib/google/apis/compute_v1/classes.rb', line 40801

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40808
40809
40810
40811
40812
40813
40814
40815
40816
# File 'lib/google/apis/compute_v1/classes.rb', line 40808

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end