Class: Google::Apis::ComputeV1::OperationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::OperationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::OperationsScopedList>
[Output Only] A map of scoped operation lists.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationAggregatedList
constructor
A new instance of OperationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationAggregatedList
Returns a new instance of OperationAggregatedList.
22930 22931 22932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22930 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
22893 22894 22895 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22893 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::OperationsScopedList>
[Output Only] A map of scoped operation lists.
Corresponds to the JSON property items
22898 22899 22900 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22898 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#operationAggregatedList for
aggregated lists of operations.
Corresponds to the JSON property kind
22904 22905 22906 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22904 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22913 22914 22915 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22913 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22918 22919 22920 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22918 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
22923 22924 22925 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22923 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22928 22929 22930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22928 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22935 22936 22937 22938 22939 22940 22941 22942 22943 |
# File 'lib/google/apis/compute_v1/classes.rb', line 22935 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |