Class: Google::Apis::ComputeV1::OperationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::OperationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Operation resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Operation>
[Output Only] A list of Operation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::OperationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationList
constructor
A new instance of OperationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationList
Returns a new instance of OperationList.
42282 42283 42284 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
42248 42249 42250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42248 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Operation>
[Output Only] A list of Operation resources.
Corresponds to the JSON property items
42253 42254 42255 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42253 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#operations for
Operations
resource.
Corresponds to the JSON property kind
42260 42261 42262 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42260 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42270 42271 42272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42270 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42275 42276 42277 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42275 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::OperationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
42280 42281 42282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42280 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42287 42288 42289 42290 42291 42292 42293 42294 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42287 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |