Class: Google::Apis::ComputeV1::OperationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Operation resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationList

Returns a new instance of OperationList.



41918
41919
41920
# File 'lib/google/apis/compute_v1/classes.rb', line 41918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41884
41885
41886
# File 'lib/google/apis/compute_v1/classes.rb', line 41884

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Operation>

[Output Only] A list of Operation resources. Corresponds to the JSON property items



41889
41890
41891
# File 'lib/google/apis/compute_v1/classes.rb', line 41889

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#operations for Operations resource. Corresponds to the JSON property kind

Returns:

  • (String)


41896
41897
41898
# File 'lib/google/apis/compute_v1/classes.rb', line 41896

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41906
41907
41908
# File 'lib/google/apis/compute_v1/classes.rb', line 41906

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41911
41912
41913
# File 'lib/google/apis/compute_v1/classes.rb', line 41911

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::OperationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41916
41917
41918
# File 'lib/google/apis/compute_v1/classes.rb', line 41916

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41923
41924
41925
41926
41927
41928
41929
41930
# File 'lib/google/apis/compute_v1/classes.rb', line 41923

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end