Class: Google::Apis::ComputeV1::OperationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::OperationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Operation resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Operation>
[Output Only] A list of Operation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::OperationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationList
constructor
A new instance of OperationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationList
Returns a new instance of OperationList.
41906 41907 41908 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
41872 41873 41874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41872 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Operation>
[Output Only] A list of Operation resources.
Corresponds to the JSON property items
41877 41878 41879 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41877 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#operations for
Operations
resource.
Corresponds to the JSON property kind
41884 41885 41886 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41884 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41894 41895 41896 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41894 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41899 41900 41901 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41899 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::OperationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41904 41905 41906 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41904 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41911 41912 41913 41914 41915 41916 41917 41918 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41911 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |