Class: Google::Apis::ComputeV1::OperationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Operation resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationList

Returns a new instance of OperationList.



23050
23051
23052
# File 'lib/google/apis/compute_v1/classes.rb', line 23050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23018
23019
23020
# File 'lib/google/apis/compute_v1/classes.rb', line 23018

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Operation>

[Output Only] A list of Operation resources. Corresponds to the JSON property items



23023
23024
23025
# File 'lib/google/apis/compute_v1/classes.rb', line 23023

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#operations for Operations resource. Corresponds to the JSON property kind

Returns:

  • (String)


23029
23030
23031
# File 'lib/google/apis/compute_v1/classes.rb', line 23029

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23038
23039
23040
# File 'lib/google/apis/compute_v1/classes.rb', line 23038

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23043
23044
23045
# File 'lib/google/apis/compute_v1/classes.rb', line 23043

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::OperationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



23048
23049
23050
# File 'lib/google/apis/compute_v1/classes.rb', line 23048

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23055
23056
23057
23058
23059
23060
23061
23062
# File 'lib/google/apis/compute_v1/classes.rb', line 23055

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end