Class: Google::Apis::ComputeV1::OutlierDetection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OutlierDetection

Returns a new instance of OutlierDetection.



41850
41851
41852
# File 'lib/google/apis/compute_v1/classes.rb', line 41850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_ejection_timeGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property baseEjectionTime



41765
41766
41767
# File 'lib/google/apis/compute_v1/classes.rb', line 41765

def base_ejection_time
  @base_ejection_time
end

#consecutive_errorsFixnum

Number of consecutive errors before a backend endpoint is ejected from the load balancing pool. When the backend endpoint is accessed over HTTP, a 5xx return code qualifies as an error. Defaults to 5. Corresponds to the JSON property consecutiveErrors

Returns:

  • (Fixnum)


41772
41773
41774
# File 'lib/google/apis/compute_v1/classes.rb', line 41772

def consecutive_errors
  @consecutive_errors
end

#consecutive_gateway_failureFixnum

The number of consecutive gateway failures (502, 503, 504 status or connection errors that are mapped to one of those status codes) before a consecutive gateway failure ejection occurs. Defaults to 3. Corresponds to the JSON property consecutiveGatewayFailure

Returns:

  • (Fixnum)


41779
41780
41781
# File 'lib/google/apis/compute_v1/classes.rb', line 41779

def consecutive_gateway_failure
  @consecutive_gateway_failure
end

#enforcing_consecutive_errorsFixnum

The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive 5xx. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 0. Corresponds to the JSON property enforcingConsecutiveErrors

Returns:

  • (Fixnum)


41786
41787
41788
# File 'lib/google/apis/compute_v1/classes.rb', line 41786

def enforcing_consecutive_errors
  @enforcing_consecutive_errors
end

#enforcing_consecutive_gateway_failureFixnum

The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive gateway failures. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100. Corresponds to the JSON property enforcingConsecutiveGatewayFailure

Returns:

  • (Fixnum)


41794
41795
41796
# File 'lib/google/apis/compute_v1/classes.rb', line 41794

def enforcing_consecutive_gateway_failure
  @enforcing_consecutive_gateway_failure
end

#enforcing_success_rateFixnum

The percentage chance that a backend endpoint will be ejected when an outlier status is detected through success rate statistics. This setting can be used to disable ejection or to ramp it up slowly. Defaults to 100. Not supported when the backend service uses Serverless NEG. Corresponds to the JSON property enforcingSuccessRate

Returns:

  • (Fixnum)


41802
41803
41804
# File 'lib/google/apis/compute_v1/classes.rb', line 41802

def enforcing_success_rate
  @enforcing_success_rate
end

#intervalGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property interval



41810
41811
41812
# File 'lib/google/apis/compute_v1/classes.rb', line 41810

def interval
  @interval
end

#max_ejection_percentFixnum

Maximum percentage of backend endpoints in the load balancing pool for the backend service that can be ejected if the ejection conditions are met. Defaults to 50%. Corresponds to the JSON property maxEjectionPercent

Returns:

  • (Fixnum)


41817
41818
41819
# File 'lib/google/apis/compute_v1/classes.rb', line 41817

def max_ejection_percent
  @max_ejection_percent
end

#success_rate_minimum_hostsFixnum

The number of backend endpoints in the load balancing pool that must have enough request volume to detect success rate outliers. If the number of backend endpoints is fewer than this setting, outlier detection via success rate statistics is not performed for any backend endpoint in the load balancing pool. Defaults to 5. Not supported when the backend service uses Serverless NEG. Corresponds to the JSON property successRateMinimumHosts

Returns:

  • (Fixnum)


41827
41828
41829
# File 'lib/google/apis/compute_v1/classes.rb', line 41827

def success_rate_minimum_hosts
  @success_rate_minimum_hosts
end

#success_rate_request_volumeFixnum

The minimum number of total requests that must be collected in one interval (as defined by the interval duration above) to include this backend endpoint in success rate based outlier detection. If the volume is lower than this setting, outlier detection via success rate statistics is not performed for that backend endpoint. Defaults to 100. Not supported when the backend service uses Serverless NEG. Corresponds to the JSON property successRateRequestVolume

Returns:

  • (Fixnum)


41837
41838
41839
# File 'lib/google/apis/compute_v1/classes.rb', line 41837

def success_rate_request_volume
  @success_rate_request_volume
end

#success_rate_stdev_factorFixnum

This factor is used to determine the ejection threshold for success rate outlier ejection. The ejection threshold is the difference between the mean success rate, and the product of this factor and the standard deviation of the mean success rate: mean - (stdev * successRateStdevFactor). This factor is divided by a thousand to get a double. That is, if the desired factor is 1.9, the runtime value should be 1900. Defaults to 1900. Not supported when the backend service uses Serverless NEG. Corresponds to the JSON property successRateStdevFactor

Returns:

  • (Fixnum)


41848
41849
41850
# File 'lib/google/apis/compute_v1/classes.rb', line 41848

def success_rate_stdev_factor
  @success_rate_stdev_factor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41855
41856
41857
41858
41859
41860
41861
41862
41863
41864
41865
41866
41867
# File 'lib/google/apis/compute_v1/classes.rb', line 41855

def update!(**args)
  @base_ejection_time = args[:base_ejection_time] if args.key?(:base_ejection_time)
  @consecutive_errors = args[:consecutive_errors] if args.key?(:consecutive_errors)
  @consecutive_gateway_failure = args[:consecutive_gateway_failure] if args.key?(:consecutive_gateway_failure)
  @enforcing_consecutive_errors = args[:enforcing_consecutive_errors] if args.key?(:enforcing_consecutive_errors)
  @enforcing_consecutive_gateway_failure = args[:enforcing_consecutive_gateway_failure] if args.key?(:enforcing_consecutive_gateway_failure)
  @enforcing_success_rate = args[:enforcing_success_rate] if args.key?(:enforcing_success_rate)
  @interval = args[:interval] if args.key?(:interval)
  @max_ejection_percent = args[:max_ejection_percent] if args.key?(:max_ejection_percent)
  @success_rate_minimum_hosts = args[:success_rate_minimum_hosts] if args.key?(:success_rate_minimum_hosts)
  @success_rate_request_volume = args[:success_rate_request_volume] if args.key?(:success_rate_request_volume)
  @success_rate_stdev_factor = args[:success_rate_stdev_factor] if args.key?(:success_rate_stdev_factor)
end