Class: Google::Apis::ComputeV1::OutlierDetection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::OutlierDetection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.
Instance Attribute Summary collapse
-
#base_ejection_time ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#consecutive_errors ⇒ Fixnum
Number of consecutive errors before a backend endpoint is ejected from the load balancing pool.
-
#consecutive_gateway_failure ⇒ Fixnum
The number of consecutive gateway failures (502, 503, 504 status or connection errors that are mapped to one of those status codes) before a consecutive gateway failure ejection occurs.
-
#enforcing_consecutive_errors ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive 5xx.
-
#enforcing_consecutive_gateway_failure ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive gateway failures.
-
#enforcing_success_rate ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through success rate statistics.
-
#interval ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#max_ejection_percent ⇒ Fixnum
Maximum percentage of backend endpoints in the load balancing pool for the backend service that can be ejected if the ejection conditions are met.
-
#success_rate_minimum_hosts ⇒ Fixnum
The number of backend endpoints in the load balancing pool that must have enough request volume to detect success rate outliers.
-
#success_rate_request_volume ⇒ Fixnum
The minimum number of total requests that must be collected in one interval (as defined by the interval duration above) to include this backend endpoint in success rate based outlier detection.
-
#success_rate_stdev_factor ⇒ Fixnum
This factor is used to determine the ejection threshold for success rate outlier ejection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OutlierDetection
constructor
A new instance of OutlierDetection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OutlierDetection
Returns a new instance of OutlierDetection.
41236 41237 41238 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_ejection_time ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property baseEjectionTime
41151 41152 41153 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41151 def base_ejection_time @base_ejection_time end |
#consecutive_errors ⇒ Fixnum
Number of consecutive errors before a backend endpoint is ejected from the
load balancing pool. When the backend endpoint is accessed over HTTP, a 5xx
return code qualifies as an error. Defaults to 5.
Corresponds to the JSON property consecutiveErrors
41158 41159 41160 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41158 def consecutive_errors @consecutive_errors end |
#consecutive_gateway_failure ⇒ Fixnum
The number of consecutive gateway failures (502, 503, 504 status or
connection errors that are mapped to one of those status codes) before a
consecutive gateway failure ejection occurs. Defaults to 3.
Corresponds to the JSON property consecutiveGatewayFailure
41165 41166 41167 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41165 def consecutive_gateway_failure @consecutive_gateway_failure end |
#enforcing_consecutive_errors ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through consecutive 5xx. This setting can be
used to disable ejection or to ramp it up slowly. Defaults to 0.
Corresponds to the JSON property enforcingConsecutiveErrors
41172 41173 41174 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41172 def enforcing_consecutive_errors @enforcing_consecutive_errors end |
#enforcing_consecutive_gateway_failure ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through consecutive gateway failures. This
setting can be used to disable ejection or to ramp it up slowly. Defaults
to 100.
Corresponds to the JSON property enforcingConsecutiveGatewayFailure
41180 41181 41182 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41180 def enforcing_consecutive_gateway_failure @enforcing_consecutive_gateway_failure end |
#enforcing_success_rate ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through success rate statistics. This setting
can be used to disable ejection or to ramp it up slowly. Defaults to 100.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property enforcingSuccessRate
41188 41189 41190 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41188 def enforcing_success_rate @enforcing_success_rate end |
#interval ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property interval
41196 41197 41198 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41196 def interval @interval end |
#max_ejection_percent ⇒ Fixnum
Maximum percentage of backend endpoints in the load balancing pool for the
backend service that can be ejected if the ejection conditions are met.
Defaults to 50%.
Corresponds to the JSON property maxEjectionPercent
41203 41204 41205 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41203 def max_ejection_percent @max_ejection_percent end |
#success_rate_minimum_hosts ⇒ Fixnum
The number of backend endpoints in the load balancing pool that must have
enough request volume to detect success rate outliers. If the number of
backend endpoints is fewer than this setting, outlier detection via success
rate statistics is not performed for any backend endpoint in the load
balancing pool. Defaults to 5.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property successRateMinimumHosts
41213 41214 41215 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41213 def success_rate_minimum_hosts @success_rate_minimum_hosts end |
#success_rate_request_volume ⇒ Fixnum
The minimum number of total requests that must be collected in one interval
(as defined by the interval duration above) to include this backend
endpoint in success rate based outlier detection. If the volume is lower
than this setting, outlier detection via success rate statistics is not
performed for that backend endpoint. Defaults to 100.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property successRateRequestVolume
41223 41224 41225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41223 def success_rate_request_volume @success_rate_request_volume end |
#success_rate_stdev_factor ⇒ Fixnum
This factor is used to determine the ejection threshold for success rate
outlier ejection. The ejection threshold is the difference between the mean
success rate, and the product of this factor and the standard deviation of
the mean success rate: mean - (stdev * successRateStdevFactor). This factor
is divided by a thousand to get a double. That is, if the desired factor
is 1.9, the runtime value should be 1900. Defaults to 1900.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property successRateStdevFactor
41234 41235 41236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41234 def success_rate_stdev_factor @success_rate_stdev_factor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41241 41242 41243 41244 41245 41246 41247 41248 41249 41250 41251 41252 41253 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41241 def update!(**args) @base_ejection_time = args[:base_ejection_time] if args.key?(:base_ejection_time) @consecutive_errors = args[:consecutive_errors] if args.key?(:consecutive_errors) @consecutive_gateway_failure = args[:consecutive_gateway_failure] if args.key?(:consecutive_gateway_failure) @enforcing_consecutive_errors = args[:enforcing_consecutive_errors] if args.key?(:enforcing_consecutive_errors) @enforcing_consecutive_gateway_failure = args[:enforcing_consecutive_gateway_failure] if args.key?(:enforcing_consecutive_gateway_failure) @enforcing_success_rate = args[:enforcing_success_rate] if args.key?(:enforcing_success_rate) @interval = args[:interval] if args.key?(:interval) @max_ejection_percent = args[:max_ejection_percent] if args.key?(:max_ejection_percent) @success_rate_minimum_hosts = args[:success_rate_minimum_hosts] if args.key?(:success_rate_minimum_hosts) @success_rate_request_volume = args[:success_rate_request_volume] if args.key?(:success_rate_request_volume) @success_rate_stdev_factor = args[:success_rate_stdev_factor] if args.key?(:success_rate_stdev_factor) end |