Class: Google::Apis::ComputeV1::PacketMirroring
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroring
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Packet Mirroring resource. Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/ UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, see Using Packet Mirroring.
Instance Attribute Summary collapse
-
#collector_ilb ⇒ Google::Apis::ComputeV1::PacketMirroringForwardingRuleInfo
The Forwarding Rule resource of type loadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#enable ⇒ String
Indicates whether or not this packet mirroring takes effect.
-
#filter ⇒ Google::Apis::ComputeV1::PacketMirroringFilter
Filter for mirrored traffic.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#mirrored_resources ⇒ Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfo
PacketMirroring mirroredResourceInfos.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ Google::Apis::ComputeV1::PacketMirroringNetworkInfo
Specifies the mirrored VPC network.
-
#priority ⇒ Fixnum
The priority of applying this configuration.
-
#region ⇒ String
[Output Only] URI of the region where the packetMirroring resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroring
constructor
A new instance of PacketMirroring.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroring
Returns a new instance of PacketMirroring.
23470 23471 23472 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collector_ilb ⇒ Google::Apis::ComputeV1::PacketMirroringForwardingRuleInfo
The Forwarding Rule resource of type loadBalancingScheme=INTERNAL that will be
used as collector for mirrored traffic. The specified forwarding rule must
have isMirroringCollector set to true.
Corresponds to the JSON property collectorIlb
23391 23392 23393 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23391 def collector_ilb @collector_ilb end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
23396 23397 23398 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23396 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
23402 23403 23404 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23402 def description @description end |
#enable ⇒ String
Indicates whether or not this packet mirroring takes effect. If set to FALSE,
this packet mirroring policy will not be enforced on the network. The default
is TRUE.
Corresponds to the JSON property enable
23409 23410 23411 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23409 def enable @enable end |
#filter ⇒ Google::Apis::ComputeV1::PacketMirroringFilter
Filter for mirrored traffic. If unspecified, all traffic is mirrored.
Corresponds to the JSON property filter
23414 23415 23416 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23414 def filter @filter end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
23420 23421 23422 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23420 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#packetMirroring for packet
mirrorings.
Corresponds to the JSON property kind
23426 23427 23428 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23426 def kind @kind end |
#mirrored_resources ⇒ Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfo
PacketMirroring mirroredResourceInfos. MirroredResourceInfo specifies a set of
mirrored VM instances, subnetworks and/or tags for which traffic from/to all
VM instances will be mirrored.
Corresponds to the JSON property mirroredResources
23433 23434 23435 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23433 def mirrored_resources @mirrored_resources end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
23443 23444 23445 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23443 def name @name end |
#network ⇒ Google::Apis::ComputeV1::PacketMirroringNetworkInfo
Specifies the mirrored VPC network. Only packets in this network will be
mirrored. All mirrored VMs should have a NIC in the given network. All
mirrored subnetworks should belong to the given network.
Corresponds to the JSON property network
23450 23451 23452 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23450 def network @network end |
#priority ⇒ Fixnum
The priority of applying this configuration. Priority is used to break ties in
cases where there is more than one matching rule. In the case of two rules
that apply for a given Instance, the one with the lowest-numbered priority
value wins. Default value is 1000. Valid range is 0 through 65535.
Corresponds to the JSON property priority
23458 23459 23460 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23458 def priority @priority end |
#region ⇒ String
[Output Only] URI of the region where the packetMirroring resides.
Corresponds to the JSON property region
23463 23464 23465 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23463 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
23468 23469 23470 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23468 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23475 23476 23477 23478 23479 23480 23481 23482 23483 23484 23485 23486 23487 23488 23489 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23475 def update!(**args) @collector_ilb = args[:collector_ilb] if args.key?(:collector_ilb) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @enable = args[:enable] if args.key?(:enable) @filter = args[:filter] if args.key?(:filter) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @mirrored_resources = args[:mirrored_resources] if args.key?(:mirrored_resources) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @priority = args[:priority] if args.key?(:priority) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |