Class: Google::Apis::ComputeV1::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



42811
42812
42813
# File 'lib/google/apis/compute_v1/classes.rb', line 42811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42774
42775
42776
# File 'lib/google/apis/compute_v1/classes.rb', line 42774

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



42779
42780
42781
# File 'lib/google/apis/compute_v1/classes.rb', line 42779

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


42784
42785
42786
# File 'lib/google/apis/compute_v1/classes.rb', line 42784

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42794
42795
42796
# File 'lib/google/apis/compute_v1/classes.rb', line 42794

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42799
42800
42801
# File 'lib/google/apis/compute_v1/classes.rb', line 42799

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


42804
42805
42806
# File 'lib/google/apis/compute_v1/classes.rb', line 42804

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42809
42810
42811
# File 'lib/google/apis/compute_v1/classes.rb', line 42809

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42816
42817
42818
42819
42820
42821
42822
42823
42824
# File 'lib/google/apis/compute_v1/classes.rb', line 42816

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end