Class: Google::Apis::ComputeV1::PacketMirroringAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of packetMirrorings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringAggregatedList
constructor
A new instance of PacketMirroringAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringAggregatedList
Returns a new instance of PacketMirroringAggregatedList.
42459 42460 42461 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42422 42423 42424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42422 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>
A list of PacketMirroring resources.
Corresponds to the JSON property items
42427 42428 42429 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42427 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
42432 42433 42434 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42432 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42442 42443 42444 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42442 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42447 42448 42449 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42447 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
42452 42453 42454 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42452 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
42457 42458 42459 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42457 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42464 42465 42466 42467 42468 42469 42470 42471 42472 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42464 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |