Class: Google::Apis::ComputeV1::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



42282
42283
42284
# File 'lib/google/apis/compute_v1/classes.rb', line 42282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42245
42246
42247
# File 'lib/google/apis/compute_v1/classes.rb', line 42245

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



42250
42251
42252
# File 'lib/google/apis/compute_v1/classes.rb', line 42250

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


42255
42256
42257
# File 'lib/google/apis/compute_v1/classes.rb', line 42255

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42265
42266
42267
# File 'lib/google/apis/compute_v1/classes.rb', line 42265

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42270
42271
42272
# File 'lib/google/apis/compute_v1/classes.rb', line 42270

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


42275
42276
42277
# File 'lib/google/apis/compute_v1/classes.rb', line 42275

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42280
42281
42282
# File 'lib/google/apis/compute_v1/classes.rb', line 42280

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42287
42288
42289
42290
42291
42292
42293
42294
42295
# File 'lib/google/apis/compute_v1/classes.rb', line 42287

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end