Class: Google::Apis::ComputeV1::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



42072
42073
42074
# File 'lib/google/apis/compute_v1/classes.rb', line 42072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42035
42036
42037
# File 'lib/google/apis/compute_v1/classes.rb', line 42035

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



42040
42041
42042
# File 'lib/google/apis/compute_v1/classes.rb', line 42040

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


42045
42046
42047
# File 'lib/google/apis/compute_v1/classes.rb', line 42045

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42055
42056
42057
# File 'lib/google/apis/compute_v1/classes.rb', line 42055

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42060
42061
42062
# File 'lib/google/apis/compute_v1/classes.rb', line 42060

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


42065
42066
42067
# File 'lib/google/apis/compute_v1/classes.rb', line 42065

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42070
42071
42072
# File 'lib/google/apis/compute_v1/classes.rb', line 42070

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42077
42078
42079
42080
42081
42082
42083
42084
42085
# File 'lib/google/apis/compute_v1/classes.rb', line 42077

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end