Class: Google::Apis::ComputeV1::PacketMirroringAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of packetMirrorings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringAggregatedList
constructor
A new instance of PacketMirroringAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringAggregatedList
Returns a new instance of PacketMirroringAggregatedList.
41472 41473 41474 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41472 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
41435 41436 41437 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41435 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>
A list of PacketMirroring resources.
Corresponds to the JSON property items
41440 41441 41442 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41440 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
41445 41446 41447 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41445 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41455 41456 41457 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41455 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41460 41461 41462 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41460 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
41465 41466 41467 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41465 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41470 41471 41472 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41470 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41477 41478 41479 41480 41481 41482 41483 41484 41485 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41477 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |