Class: Google::Apis::ComputeV1::PacketMirroringAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of packetMirrorings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringAggregatedList
constructor
A new instance of PacketMirroringAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringAggregatedList
Returns a new instance of PacketMirroringAggregatedList.
38261 38262 38263 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38224 38225 38226 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38224 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>
A list of PacketMirroring resources.
Corresponds to the JSON property items
38229 38230 38231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38229 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
38234 38235 38236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38234 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38244 38245 38246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38244 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38249 38250 38251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38249 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
38254 38255 38256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38254 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38259 38260 38261 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38259 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38266 38267 38268 38269 38270 38271 38272 38273 38274 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38266 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |