Class: Google::Apis::ComputeV1::PacketMirroringAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of packetMirrorings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringAggregatedList
constructor
A new instance of PacketMirroringAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringAggregatedList
Returns a new instance of PacketMirroringAggregatedList.
37424 37425 37426 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37387 37388 37389 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37387 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::PacketMirroringsScopedList>
A list of PacketMirroring resources.
Corresponds to the JSON property items
37392 37393 37394 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37392 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
37397 37398 37399 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37397 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37407 37408 37409 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37407 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37412 37413 37414 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37412 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
37417 37418 37419 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37417 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
37422 37423 37424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37422 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37429 37430 37431 37432 37433 37434 37435 37436 37437 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37429 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |