Class: Google::Apis::ComputeV1::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
43006 43007 43008 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42973 42974 42975 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42973 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
42978 42979 42980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42978 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#packetMirroring
for packetMirrorings.
Corresponds to the JSON property kind
42984 42985 42986 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42984 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42994 42995 42996 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42994 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42999 43000 43001 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42999 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43004 43005 43006 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43004 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43011 43012 43013 43014 43015 43016 43017 43018 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43011 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |