Class: Google::Apis::ComputeV1::PacketMirroringList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of PacketMirroring resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringList

Returns a new instance of PacketMirroringList.



42642
42643
42644
# File 'lib/google/apis/compute_v1/classes.rb', line 42642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42609
42610
42611
# File 'lib/google/apis/compute_v1/classes.rb', line 42609

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PacketMirroring>

A list of PacketMirroring resources. Corresponds to the JSON property items



42614
42615
42616
# File 'lib/google/apis/compute_v1/classes.rb', line 42614

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#packetMirroring for packetMirrorings. Corresponds to the JSON property kind

Returns:

  • (String)


42620
42621
42622
# File 'lib/google/apis/compute_v1/classes.rb', line 42620

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42630
42631
42632
# File 'lib/google/apis/compute_v1/classes.rb', line 42630

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42635
42636
42637
# File 'lib/google/apis/compute_v1/classes.rb', line 42635

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::PacketMirroringList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42640
42641
42642
# File 'lib/google/apis/compute_v1/classes.rb', line 42640

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42647
42648
42649
42650
42651
42652
42653
42654
# File 'lib/google/apis/compute_v1/classes.rb', line 42647

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end