Class: Google::Apis::ComputeV1::PacketMirroringList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of PacketMirroring resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringList

Returns a new instance of PacketMirroringList.



42477
42478
42479
# File 'lib/google/apis/compute_v1/classes.rb', line 42477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42444
42445
42446
# File 'lib/google/apis/compute_v1/classes.rb', line 42444

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PacketMirroring>

A list of PacketMirroring resources. Corresponds to the JSON property items



42449
42450
42451
# File 'lib/google/apis/compute_v1/classes.rb', line 42449

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#packetMirroring for packetMirrorings. Corresponds to the JSON property kind

Returns:

  • (String)


42455
42456
42457
# File 'lib/google/apis/compute_v1/classes.rb', line 42455

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42465
42466
42467
# File 'lib/google/apis/compute_v1/classes.rb', line 42465

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42470
42471
42472
# File 'lib/google/apis/compute_v1/classes.rb', line 42470

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::PacketMirroringList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42475
42476
42477
# File 'lib/google/apis/compute_v1/classes.rb', line 42475

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42482
42483
42484
42485
42486
42487
42488
42489
# File 'lib/google/apis/compute_v1/classes.rb', line 42482

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end