Class: Google::Apis::ComputeV1::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
42267 42268 42269 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42234 42235 42236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42234 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
42239 42240 42241 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42239 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#packetMirroring
for packetMirrorings.
Corresponds to the JSON property kind
42245 42246 42247 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42245 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42255 42256 42257 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42255 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42260 42261 42262 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42260 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
42265 42266 42267 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42265 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42272 42273 42274 42275 42276 42277 42278 42279 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42272 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |