Class: Google::Apis::ComputeV1::PacketMirroringList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of PacketMirroring resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringList

Returns a new instance of PacketMirroringList.



41667
41668
41669
# File 'lib/google/apis/compute_v1/classes.rb', line 41667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41634
41635
41636
# File 'lib/google/apis/compute_v1/classes.rb', line 41634

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PacketMirroring>

A list of PacketMirroring resources. Corresponds to the JSON property items



41639
41640
41641
# File 'lib/google/apis/compute_v1/classes.rb', line 41639

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#packetMirroring for packetMirrorings. Corresponds to the JSON property kind

Returns:

  • (String)


41645
41646
41647
# File 'lib/google/apis/compute_v1/classes.rb', line 41645

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41655
41656
41657
# File 'lib/google/apis/compute_v1/classes.rb', line 41655

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41660
41661
41662
# File 'lib/google/apis/compute_v1/classes.rb', line 41660

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::PacketMirroringList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41665
41666
41667
# File 'lib/google/apis/compute_v1/classes.rb', line 41665

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41672
41673
41674
41675
41676
41677
41678
41679
# File 'lib/google/apis/compute_v1/classes.rb', line 41672

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end