Class: Google::Apis::ComputeV1::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
38456 38457 38458 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38423 38424 38425 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38423 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
38428 38429 38430 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38428 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#packetMirroring
for packetMirrorings.
Corresponds to the JSON property kind
38434 38435 38436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38434 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38444 38445 38446 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38444 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38449 38450 38451 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38449 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38454 38455 38456 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38454 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38461 38462 38463 38464 38465 38466 38467 38468 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38461 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |