Class: Google::Apis::ComputeV1::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
23717 23718 23719 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23717 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23685 23686 23687 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23685 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
23690 23691 23692 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23690 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#packetMirroring for
packetMirrorings.
Corresponds to the JSON property kind
23696 23697 23698 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23696 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23705 23706 23707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23705 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23710 23711 23712 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23710 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
23715 23716 23717 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23715 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23722 23723 23724 23725 23726 23727 23728 23729 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23722 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |