Class: Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfoInstanceInfo>
A set of virtual machine instances that are being mirrored.
-
#subnetworks ⇒ Array<Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfoSubnetInfo>
A set of subnetworks for which traffic from/to all VM instances will be mirrored.
-
#tags ⇒ Array<String>
A set of mirrored tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo
constructor
A new instance of PacketMirroringMirroredResourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo
Returns a new instance of PacketMirroringMirroredResourceInfo.
23822 23823 23824 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfoInstanceInfo>
A set of virtual machine instances that are being mirrored. They must live in
zones contained in the same region as this packetMirroring. Note that this
config will apply only to those network interfaces of the Instances that
belong to the network specified in this packetMirroring. You may specify a
maximum of 50 Instances.
Corresponds to the JSON property instances
23807 23808 23809 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23807 def instances @instances end |
#subnetworks ⇒ Array<Google::Apis::ComputeV1::PacketMirroringMirroredResourceInfoSubnetInfo>
A set of subnetworks for which traffic from/to all VM instances will be
mirrored. They must live in the same region as this packetMirroring. You may
specify a maximum of 5 subnetworks.
Corresponds to the JSON property subnetworks
23814 23815 23816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23814 def subnetworks @subnetworks end |
#tags ⇒ Array<String>
A set of mirrored tags. Traffic from/to all VM instances that have one or more
of these tags will be mirrored.
Corresponds to the JSON property tags
23820 23821 23822 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23820 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23827 23828 23829 23830 23831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 23827 def update!(**args) @instances = args[:instances] if args.key?(:instances) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) @tags = args[:tags] if args.key?(:tags) end |