Class: Google::Apis::ComputeV1::PathMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PathMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A matcher for the path portion of the URL. The BackendService from the longest-matched rule will serve the URL. If no rule was matched, the default service is used.
Instance Attribute Summary collapse
-
#default_custom_error_response_policy ⇒ Google::Apis::ComputeV1::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.
-
#default_route_action ⇒ Google::Apis::ComputeV1::HttpRouteAction
defaultRouteAction takes effect when none of the pathRules or routeRules match.
-
#default_service ⇒ String
The full or partial URL to the BackendService resource.
-
#default_url_redirect ⇒ Google::Apis::ComputeV1::HttpRedirectAction
Specifies settings for an HTTP redirect.
-
#description ⇒ String
An optional description of this resource.
-
#header_action ⇒ Google::Apis::ComputeV1::HttpHeaderAction
The request and response header transformations that take effect before the request is passed along to the selected backendService.
-
#name ⇒ String
The name to which this PathMatcher is referred by theHostRule.
-
#path_rules ⇒ Array<Google::Apis::ComputeV1::PathRule>
The list of path rules.
-
#route_rules ⇒ Array<Google::Apis::ComputeV1::HttpRouteRule>
The list of HTTP route rules.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PathMatcher
constructor
A new instance of PathMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PathMatcher
Returns a new instance of PathMatcher.
38854 38855 38856 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38854 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_custom_error_response_policy ⇒ Google::Apis::ComputeV1::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the
backend service or backend bucket responds with an error.
Corresponds to the JSON property defaultCustomErrorResponsePolicy
38767 38768 38769 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38767 def default_custom_error_response_policy @default_custom_error_response_policy end |
#default_route_action ⇒ Google::Apis::ComputeV1::HttpRouteAction
defaultRouteAction takes effect when none of the
pathRules or routeRules match. The load balancer
performs advanced routing actions, such as URL rewrites and
header transformations, before forwarding the request to the
selected backend.
Only one of defaultUrlRedirect, defaultService
or defaultRouteAction.weightedBackendService can be set.
URL maps for classic Application Load Balancers only support
the urlRewrite action within a path matcher'sdefaultRouteAction.
Corresponds to the JSON property defaultRouteAction
38780 38781 38782 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38780 def default_route_action @default_route_action end |
#default_service ⇒ String
The full or partial URL to the BackendService resource. This URL is used if none of the pathRules orrouteRules defined by this PathMatcher are matched. For example, the following are all valid URLs to a BackendService resource:
- https://www.googleapis.com/compute/v1/projects/project/global/ backendServices/backendService
- compute/v1/projects/project/global/backendServices/backendService
global/backendServices/backendService If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. Authorization requires one or more of the following Google IAM permissions on the specified resource default_service:
compute.backendBuckets.use
compute.backendServices.use Corresponds to the JSON property
defaultService
38807 38808 38809 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38807 def default_service @default_service end |
#default_url_redirect ⇒ Google::Apis::ComputeV1::HttpRedirectAction
Specifies settings for an HTTP redirect.
Corresponds to the JSON property defaultUrlRedirect
38812 38813 38814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38812 def default_url_redirect @default_url_redirect end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
38818 38819 38820 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38818 def description @description end |
#header_action ⇒ Google::Apis::ComputeV1::HttpHeaderAction
The request and response header transformations that take effect before
the request is passed along to the selected backendService.
Corresponds to the JSON property headerAction
38824 38825 38826 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38824 def header_action @header_action end |
#name ⇒ String
The name to which this PathMatcher is referred by theHostRule.
Corresponds to the JSON property name
38829 38830 38831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38829 def name @name end |
#path_rules ⇒ Array<Google::Apis::ComputeV1::PathRule>
The list of path rules. Use this list instead of routeRules
when routing based on simple path matching is all that's required. A path
rule can only include a wildcard character () after a
forward slash character ("/").
The order by which path rules are specified does not matter.
Matches are always done on the longest-path-first basis.
For example: a pathRule with a path /a/b/c/ will match
before /a/b/* irrespective of the order in which those paths appear in this
list.
Within a given pathMatcher, only one ofpathRules or routeRules must be set.
Corresponds to the JSON property pathRules
38843 38844 38845 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38843 def path_rules @path_rules end |
#route_rules ⇒ Array<Google::Apis::ComputeV1::HttpRouteRule>
The list of HTTP route rules. Use this list instead ofpathRules when advanced
route matching and routing actions are
desired. routeRules are evaluated in order of priority, from
the lowest to highest number.
Within a given pathMatcher, you can set only one ofpathRules or routeRules.
Corresponds to the JSON property routeRules
38852 38853 38854 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38852 def route_rules @route_rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38859 38860 38861 38862 38863 38864 38865 38866 38867 38868 38869 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38859 def update!(**args) @default_custom_error_response_policy = args[:default_custom_error_response_policy] if args.key?(:default_custom_error_response_policy) @default_route_action = args[:default_route_action] if args.key?(:default_route_action) @default_service = args[:default_service] if args.key?(:default_service) @default_url_redirect = args[:default_url_redirect] if args.key?(:default_url_redirect) @description = args[:description] if args.key?(:description) @header_action = args[:header_action] if args.key?(:header_action) @name = args[:name] if args.key?(:name) @path_rules = args[:path_rules] if args.key?(:path_rules) @route_rules = args[:route_rules] if args.key?(:route_rules) end |