Class: Google::Apis::ComputeV1::PathRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A path-matching rule for a URL. If matched, will use the specifiedBackendService to handle the traffic arriving at this URL.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PathRule

Returns a new instance of PathRule.



42941
42942
42943
# File 'lib/google/apis/compute_v1/classes.rb', line 42941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_error_response_policyGoogle::Apis::ComputeV1::CustomErrorResponsePolicy

Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error. Corresponds to the JSON property customErrorResponsePolicy



42903
42904
42905
# File 'lib/google/apis/compute_v1/classes.rb', line 42903

def custom_error_response_policy
  @custom_error_response_policy
end

#pathsArray<String>

The list of path patterns to match. Each must start with / and the only place a * is allowed is at the end following a /. The string fed to the path matcher does not include any text after the first ? or #, and those chars are not allowed here. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


42912
42913
42914
# File 'lib/google/apis/compute_v1/classes.rb', line 42912

def paths
  @paths
end

#route_actionGoogle::Apis::ComputeV1::HttpRouteAction

In response to a matching path, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. Only one of urlRedirect, service orrouteAction.weightedBackendService can be set. URL maps for classic Application Load Balancers only support the urlRewrite action within a path rule'srouteAction. Corresponds to the JSON property routeAction



42924
42925
42926
# File 'lib/google/apis/compute_v1/classes.rb', line 42924

def route_action
  @route_action
end

#serviceString

The full or partial URL of the backend service resource to which traffic is directed if this rule is matched. If routeAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. Only one of urlRedirect, service orrouteAction.weightedBackendService can be set. Corresponds to the JSON property service

Returns:

  • (String)


42934
42935
42936
# File 'lib/google/apis/compute_v1/classes.rb', line 42934

def service
  @service
end

#url_redirectGoogle::Apis::ComputeV1::HttpRedirectAction

Specifies settings for an HTTP redirect. Corresponds to the JSON property urlRedirect



42939
42940
42941
# File 'lib/google/apis/compute_v1/classes.rb', line 42939

def url_redirect
  @url_redirect
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42946
42947
42948
42949
42950
42951
42952
# File 'lib/google/apis/compute_v1/classes.rb', line 42946

def update!(**args)
  @custom_error_response_policy = args[:custom_error_response_policy] if args.key?(:custom_error_response_policy)
  @paths = args[:paths] if args.key?(:paths)
  @route_action = args[:route_action] if args.key?(:route_action)
  @service = args[:service] if args.key?(:service)
  @url_redirect = args[:url_redirect] if args.key?(:url_redirect)
end