Class: Google::Apis::ComputeV1::PeriodicPartialMaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PeriodicPartialMaintenanceSchedule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)
Instance Attribute Summary collapse
-
#sub_type ⇒ String
The maintenance type in which the zone is during the given window.
-
#target_resource ⇒ String
The target resource that the maintenance window is for.
-
#type ⇒ String
Corresponds to the JSON property
type. -
#window_end_time ⇒ Google::Apis::ComputeV1::DateTime
Represents civil time (or occasionally physical time).
-
#window_start_time ⇒ Google::Apis::ComputeV1::DateTime
Represents civil time (or occasionally physical time).
Instance Method Summary collapse
-
#initialize(**args) ⇒ PeriodicPartialMaintenanceSchedule
constructor
A new instance of PeriodicPartialMaintenanceSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PeriodicPartialMaintenanceSchedule
Returns a new instance of PeriodicPartialMaintenanceSchedule.
43068 43069 43070 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sub_type ⇒ String
The maintenance type in which the zone is during the given window.
Corresponds to the JSON property subType
43011 43012 43013 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43011 def sub_type @sub_type end |
#target_resource ⇒ String
The target resource that the maintenance window is for.
For example, "projects/my-project/zones/us-central1-a".
Corresponds to the JSON property targetResource
43017 43018 43019 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43017 def target_resource @target_resource end |
#type ⇒ String
Corresponds to the JSON property type
43022 43023 43024 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43022 def type @type end |
#window_end_time ⇒ Google::Apis::ComputeV1::DateTime
Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:
- When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
- When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
- When neither time_zone nor utc_offset is set: a civil time on a calendar
day in local time.
The date is relative to the Proleptic Gregorian Calendar.
If year, month, or day are 0, the DateTime is considered not to have a
specific year, month, or day respectively.
This type may also be used to represent a physical time if all the date and
time fields are set and either case of the
time_offsetoneof is set. Consider usingTimestampmessage for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON propertywindowEndTime
43044 43045 43046 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43044 def window_end_time @window_end_time end |
#window_start_time ⇒ Google::Apis::ComputeV1::DateTime
Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:
- When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
- When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
- When neither time_zone nor utc_offset is set: a civil time on a calendar
day in local time.
The date is relative to the Proleptic Gregorian Calendar.
If year, month, or day are 0, the DateTime is considered not to have a
specific year, month, or day respectively.
This type may also be used to represent a physical time if all the date and
time fields are set and either case of the
time_offsetoneof is set. Consider usingTimestampmessage for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON propertywindowStartTime
43066 43067 43068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43066 def window_start_time @window_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43073 43074 43075 43076 43077 43078 43079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43073 def update!(**args) @sub_type = args[:sub_type] if args.key?(:sub_type) @target_resource = args[:target_resource] if args.key?(:target_resource) @type = args[:type] if args.key?(:type) @window_end_time = args[:window_end_time] if args.key?(:window_end_time) @window_start_time = args[:window_start_time] if args.key?(:window_start_time) end |