Class: Google::Apis::ComputeV1::PreservedState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Preserved state for a given instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreservedState

Returns a new instance of PreservedState.



43431
43432
43433
# File 'lib/google/apis/compute_v1/classes.rb', line 43431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksHash<String,Google::Apis::ComputeV1::PreservedStatePreservedDisk>

Preserved disks defined for this instance. This map is keyed with the device names of the disks. Corresponds to the JSON property disks



43412
43413
43414
# File 'lib/google/apis/compute_v1/classes.rb', line 43412

def disks
  @disks
end

#external_i_psHash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>

Preserved external IPs defined for this instance. This map is keyed with the name of the network interface. Corresponds to the JSON property externalIPs



43418
43419
43420
# File 'lib/google/apis/compute_v1/classes.rb', line 43418

def external_i_ps
  @external_i_ps
end

#internal_i_psHash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>

Preserved internal IPs defined for this instance. This map is keyed with the name of the network interface. Corresponds to the JSON property internalIPs



43424
43425
43426
# File 'lib/google/apis/compute_v1/classes.rb', line 43424

def internal_i_ps
  @internal_i_ps
end

#metadataHash<String,String>

Preserved metadata defined for this instance. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


43429
43430
43431
# File 'lib/google/apis/compute_v1/classes.rb', line 43429

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43436
43437
43438
43439
43440
43441
# File 'lib/google/apis/compute_v1/classes.rb', line 43436

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps)
  @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps)
  @metadata = args[:metadata] if args.key?(:metadata)
end