Class: Google::Apis::ComputeV1::PreservedState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreservedState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Preserved state for a given instance.
Instance Attribute Summary collapse
-
#disks ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedDisk>
Preserved disks defined for this instance.
-
#external_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>
Preserved external IPs defined for this instance.
-
#internal_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>
Preserved internal IPs defined for this instance.
-
#metadata ⇒ Hash<String,String>
Preserved metadata defined for this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedState
constructor
A new instance of PreservedState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedState
Returns a new instance of PreservedState.
43267 43268 43269 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedDisk>
Preserved disks defined for this instance.
This map is keyed with the device names of the disks.
Corresponds to the JSON property disks
43248 43249 43250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43248 def disks @disks end |
#external_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>
Preserved external IPs defined for this instance.
This map is keyed with the name of the network interface.
Corresponds to the JSON property externalIPs
43254 43255 43256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43254 def external_i_ps @external_i_ps end |
#internal_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>
Preserved internal IPs defined for this instance.
This map is keyed with the name of the network interface.
Corresponds to the JSON property internalIPs
43260 43261 43262 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43260 def internal_i_ps @internal_i_ps end |
#metadata ⇒ Hash<String,String>
Preserved metadata defined for this instance.
Corresponds to the JSON property metadata
43265 43266 43267 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43265 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43272 43273 43274 43275 43276 43277 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43272 def update!(**args) @disks = args[:disks] if args.key?(:disks) @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps) @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps) @metadata = args[:metadata] if args.key?(:metadata) end |