Class: Google::Apis::ComputeV1::PreservedState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreservedState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Preserved state for a given instance.
Instance Attribute Summary collapse
-
#disks ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedDisk>
Preserved disks defined for this instance.
-
#external_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>
Preserved external IPs defined for this instance.
-
#internal_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>
Preserved internal IPs defined for this instance.
-
#metadata ⇒ Hash<String,String>
Preserved metadata defined for this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedState
constructor
A new instance of PreservedState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedState
Returns a new instance of PreservedState.
42990 42991 42992 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedDisk>
Preserved disks defined for this instance.
This map is keyed with the device names of the disks.
Corresponds to the JSON property disks
42971 42972 42973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42971 def disks @disks end |
#external_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>
Preserved external IPs defined for this instance.
This map is keyed with the name of the network interface.
Corresponds to the JSON property externalIPs
42977 42978 42979 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42977 def external_i_ps @external_i_ps end |
#internal_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp>
Preserved internal IPs defined for this instance.
This map is keyed with the name of the network interface.
Corresponds to the JSON property internalIPs
42983 42984 42985 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42983 def internal_i_ps @internal_i_ps end |
#metadata ⇒ Hash<String,String>
Preserved metadata defined for this instance.
Corresponds to the JSON property metadata
42988 42989 42990 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42988 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42995 42996 42997 42998 42999 43000 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42995 def update!(**args) @disks = args[:disks] if args.key?(:disks) @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps) @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps) @metadata = args[:metadata] if args.key?(:metadata) end |