Class: Google::Apis::ComputeV1::PreservedStatePreservedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreservedStatePreservedDisk

Returns a new instance of PreservedStatePreservedDisk.



39205
39206
39207
# File 'lib/google/apis/compute_v1/classes.rb', line 39205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteString

These stateful disks will never be deleted during autohealing, update, instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole MIG is deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted. Corresponds to the JSON property autoDelete

Returns:

  • (String)


39190
39191
39192
# File 'lib/google/apis/compute_v1/classes.rb', line 39190

def auto_delete
  @auto_delete
end

#modeString

The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode. Corresponds to the JSON property mode

Returns:

  • (String)


39197
39198
39199
# File 'lib/google/apis/compute_v1/classes.rb', line 39197

def mode
  @mode
end

#sourceString

The URL of the disk resource that is stateful and should be attached to the VM instance. Corresponds to the JSON property source

Returns:

  • (String)


39203
39204
39205
# File 'lib/google/apis/compute_v1/classes.rb', line 39203

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39210
39211
39212
39213
39214
# File 'lib/google/apis/compute_v1/classes.rb', line 39210

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @mode = args[:mode] if args.key?(:mode)
  @source = args[:source] if args.key?(:source)
end