Class: Google::Apis::ComputeV1::PreservedStatePreservedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreservedStatePreservedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful disks will never be deleted during autohealing, update, instance recreate operations.
-
#mode ⇒ String
The mode in which to attach this disk, either READ_WRITE or READ_ONLY.
-
#source ⇒ String
The URL of the disk resource that is stateful and should be attached to the VM instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedStatePreservedDisk
constructor
A new instance of PreservedStatePreservedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedStatePreservedDisk
Returns a new instance of PreservedStatePreservedDisk.
24366 24367 24368 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24366 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful disks will never be deleted during autohealing, update,
instance recreate operations. This flag is used to configure if the disk
should be deleted after it is no longer used by the group, e.g. when the given
instance or the whole MIG is deleted. Note: disks attached in READ_ONLY mode
cannot be auto-deleted.
Corresponds to the JSON property autoDelete
24352 24353 24354 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24352 def auto_delete @auto_delete end |
#mode ⇒ String
The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If not
specified, the default is to attach the disk in READ_WRITE mode.
Corresponds to the JSON property mode
24358 24359 24360 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24358 def mode @mode end |
#source ⇒ String
The URL of the disk resource that is stateful and should be attached to the VM
instance.
Corresponds to the JSON property source
24364 24365 24366 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24364 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24371 24372 24373 24374 24375 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24371 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @mode = args[:mode] if args.key?(:mode) @source = args[:source] if args.key?(:source) end |