Class: Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
-
#ip_address ⇒ Google::Apis::ComputeV1::PreservedStatePreservedNetworkIpIpAddress
Ip address representation Corresponds to the JSON property
ipAddress.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedStatePreservedNetworkIp
constructor
A new instance of PreservedStatePreservedNetworkIp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedStatePreservedNetworkIp
Returns a new instance of PreservedStatePreservedNetworkIp.
42446 42447 42448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing,
update or VM instance recreate operations.
This flag is used to configure if the IP reservation should be deleted
after it is no longer used by the group, e.g. when the given instance
or the whole group is deleted.
Corresponds to the JSON property autoDelete
42439 42440 42441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42439 def auto_delete @auto_delete end |
#ip_address ⇒ Google::Apis::ComputeV1::PreservedStatePreservedNetworkIpIpAddress
Ip address representation
Corresponds to the JSON property ipAddress
42444 42445 42446 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42444 def ip_address @ip_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42451 42452 42453 42454 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42451 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @ip_address = args[:ip_address] if args.key?(:ip_address) end |