Class: Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreservedStatePreservedNetworkIp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
-
#ip_address ⇒ Google::Apis::ComputeV1::PreservedStatePreservedNetworkIpIpAddress
Ip address representation Corresponds to the JSON property
ipAddress.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedStatePreservedNetworkIp
constructor
A new instance of PreservedStatePreservedNetworkIp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedStatePreservedNetworkIp
Returns a new instance of PreservedStatePreservedNetworkIp.
38398 38399 38400 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing,
update or VM instance recreate operations.
This flag is used to configure if the IP reservation should be deleted
after it is no longer used by the group, e.g. when the given instance
or the whole group is deleted.
Corresponds to the JSON property autoDelete
38391 38392 38393 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38391 def auto_delete @auto_delete end |
#ip_address ⇒ Google::Apis::ComputeV1::PreservedStatePreservedNetworkIpIpAddress
Ip address representation
Corresponds to the JSON property ipAddress
38396 38397 38398 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38396 def ip_address @ip_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38403 38404 38405 38406 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38403 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @ip_address = args[:ip_address] if args.key?(:ip_address) end |