Class: Google::Apis::ComputeV1::PreviewFeatureList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureList

Returns a new instance of PreviewFeatureList.



43491
43492
43493
# File 'lib/google/apis/compute_v1/classes.rb', line 43491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


43453
43454
43455
# File 'lib/google/apis/compute_v1/classes.rb', line 43453

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43458
43459
43460
# File 'lib/google/apis/compute_v1/classes.rb', line 43458

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PreviewFeature>

A list of PreviewFeature resources. Corresponds to the JSON property items



43463
43464
43465
# File 'lib/google/apis/compute_v1/classes.rb', line 43463

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43473
43474
43475
# File 'lib/google/apis/compute_v1/classes.rb', line 43473

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43478
43479
43480
# File 'lib/google/apis/compute_v1/classes.rb', line 43478

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


43484
43485
43486
# File 'lib/google/apis/compute_v1/classes.rb', line 43484

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::PreviewFeatureList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43489
43490
43491
# File 'lib/google/apis/compute_v1/classes.rb', line 43489

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43496
43497
43498
43499
43500
43501
43502
43503
43504
# File 'lib/google/apis/compute_v1/classes.rb', line 43496

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end