Class: Google::Apis::ComputeV1::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
43491 43492 43493 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43491 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
43453 43454 43455 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43453 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43458 43459 43460 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43458 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
43463 43464 43465 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43463 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43473 43474 43475 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43473 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43478 43479 43480 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43478 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
43484 43485 43486 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43484 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43489 43490 43491 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43489 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43496 43497 43498 43499 43500 43501 43502 43503 43504 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43496 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |