Class: Google::Apis::ComputeV1::PreviewFeatureList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureList

Returns a new instance of PreviewFeatureList.



43214
43215
43216
# File 'lib/google/apis/compute_v1/classes.rb', line 43214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


43176
43177
43178
# File 'lib/google/apis/compute_v1/classes.rb', line 43176

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43181
43182
43183
# File 'lib/google/apis/compute_v1/classes.rb', line 43181

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PreviewFeature>

A list of PreviewFeature resources. Corresponds to the JSON property items



43186
43187
43188
# File 'lib/google/apis/compute_v1/classes.rb', line 43186

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43196
43197
43198
# File 'lib/google/apis/compute_v1/classes.rb', line 43196

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43201
43202
43203
# File 'lib/google/apis/compute_v1/classes.rb', line 43201

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


43207
43208
43209
# File 'lib/google/apis/compute_v1/classes.rb', line 43207

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::PreviewFeatureList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43212
43213
43214
# File 'lib/google/apis/compute_v1/classes.rb', line 43212

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43219
43220
43221
43222
43223
43224
43225
43226
43227
# File 'lib/google/apis/compute_v1/classes.rb', line 43219

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end