Class: Google::Apis::ComputeV1::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
42600 42601 42602 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
42562 42563 42564 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42562 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42567 42568 42569 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42567 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
42572 42573 42574 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42572 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42582 42583 42584 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42582 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42587 42588 42589 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42587 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
42593 42594 42595 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42593 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
42598 42599 42600 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42598 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42605 42606 42607 42608 42609 42610 42611 42612 42613 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42605 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |