Class: Google::Apis::ComputeV1::PreviewFeatureList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureList

Returns a new instance of PreviewFeatureList.



39389
39390
39391
# File 'lib/google/apis/compute_v1/classes.rb', line 39389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


39351
39352
39353
# File 'lib/google/apis/compute_v1/classes.rb', line 39351

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39356
39357
39358
# File 'lib/google/apis/compute_v1/classes.rb', line 39356

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PreviewFeature>

A list of PreviewFeature resources. Corresponds to the JSON property items



39361
39362
39363
# File 'lib/google/apis/compute_v1/classes.rb', line 39361

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39371
39372
39373
# File 'lib/google/apis/compute_v1/classes.rb', line 39371

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39376
39377
39378
# File 'lib/google/apis/compute_v1/classes.rb', line 39376

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39382
39383
39384
# File 'lib/google/apis/compute_v1/classes.rb', line 39382

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::PreviewFeatureList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39387
39388
39389
# File 'lib/google/apis/compute_v1/classes.rb', line 39387

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39394
39395
39396
39397
39398
39399
39400
39401
39402
# File 'lib/google/apis/compute_v1/classes.rb', line 39394

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end