Class: Google::Apis::ComputeV1::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
39389 39390 39391 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
39351 39352 39353 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39351 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39356 39357 39358 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39356 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
39361 39362 39363 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39361 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39371 39372 39373 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39371 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39376 39377 39378 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39376 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
39382 39383 39384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39382 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39387 39388 39389 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39387 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39394 39395 39396 39397 39398 39399 39400 39401 39402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39394 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |