Class: Google::Apis::ComputeV1::PreviewFeatureStatusReleaseStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PreviewFeatureStatusReleaseStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] The release status of the feature.
Instance Attribute Summary collapse
-
#stage ⇒ String
Output only.
-
#update_date ⇒ Google::Apis::ComputeV1::Date
Represents a whole or partial calendar date, such as a birthday.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureStatusReleaseStatus
constructor
A new instance of PreviewFeatureStatusReleaseStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureStatusReleaseStatus
Returns a new instance of PreviewFeatureStatusReleaseStatus.
39582 39583 39584 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#stage ⇒ String
Output only. [Output Only] The stage of the feature.
Corresponds to the JSON property stage
39563 39564 39565 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39563 def stage @stage end |
#update_date ⇒ Google::Apis::ComputeV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:
- A full date, with non-zero year, month, and day values.
- A month and day, with a zero year (for example, an anniversary).
- A year on its own, with a zero month and a zero day.
- A year and month, with a zero day (for example, a credit card expiration date). Related types:
- google.type.TimeOfDay
- google.type.DateTime
- google.protobuf.Timestamp
Corresponds to the JSON property
updateDate
39580 39581 39582 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39580 def update_date @update_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39587 39588 39589 39590 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39587 def update!(**args) @stage = args[:stage] if args.key?(:stage) @update_date = args[:update_date] if args.key?(:update_date) end |