Class: Google::Apis::ComputeV1::Project

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Project

Returns a new instance of Project.



43792
43793
43794
# File 'lib/google/apis/compute_v1/classes.rb', line 43792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_armor_tierString

Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to beCA_STANDARD. Corresponds to the JSON property cloudArmorTier

Returns:

  • (String)


43708
43709
43710
# File 'lib/google/apis/compute_v1/classes.rb', line 43708

def cloud_armor_tier
  @cloud_armor_tier
end

#common_instance_metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property commonInstanceMetadata



43713
43714
43715
# File 'lib/google/apis/compute_v1/classes.rb', line 43713

def 
  @common_instance_metadata
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


43719
43720
43721
# File 'lib/google/apis/compute_v1/classes.rb', line 43719

def creation_timestamp
  @creation_timestamp
end

#default_network_tierString

This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Corresponds to the JSON property defaultNetworkTier

Returns:

  • (String)


43727
43728
43729
# File 'lib/google/apis/compute_v1/classes.rb', line 43727

def default_network_tier
  @default_network_tier
end

#default_service_accountString

[Output Only] Default service account used by VMs running in this project. Corresponds to the JSON property defaultServiceAccount

Returns:

  • (String)


43732
43733
43734
# File 'lib/google/apis/compute_v1/classes.rb', line 43732

def 
  @default_service_account
end

#descriptionString

An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


43737
43738
43739
# File 'lib/google/apis/compute_v1/classes.rb', line 43737

def description
  @description
end

#enabled_featuresArray<String>

An optional list of restricted features enabled for use on this project. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


43742
43743
43744
# File 'lib/google/apis/compute_v1/classes.rb', line 43742

def enabled_features
  @enabled_features
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources. Corresponds to the JSON property id

Returns:

  • (Fixnum)


43749
43750
43751
# File 'lib/google/apis/compute_v1/classes.rb', line 43749

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#project for projects. Corresponds to the JSON property kind

Returns:

  • (String)


43755
43756
43757
# File 'lib/google/apis/compute_v1/classes.rb', line 43755

def kind
  @kind
end

#nameString

The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine. Corresponds to the JSON property name

Returns:

  • (String)


43761
43762
43763
# File 'lib/google/apis/compute_v1/classes.rb', line 43761

def name
  @name
end

#quotasArray<Google::Apis::ComputeV1::Quota>

[Output Only] Quotas assigned to this project. Corresponds to the JSON property quotas

Returns:



43766
43767
43768
# File 'lib/google/apis/compute_v1/classes.rb', line 43766

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43771
43772
43773
# File 'lib/google/apis/compute_v1/classes.rb', line 43771

def self_link
  @self_link
end

#usage_export_locationGoogle::Apis::ComputeV1::UsageExportLocation

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix. Corresponds to the JSON property usageExportLocation



43777
43778
43779
# File 'lib/google/apis/compute_v1/classes.rb', line 43777

def usage_export_location
  @usage_export_location
end

#vm_dns_settingString

Output only. [Output Only] Default internal DNS setting used by VMs running in this project. Corresponds to the JSON property vmDnsSetting

Returns:

  • (String)


43783
43784
43785
# File 'lib/google/apis/compute_v1/classes.rb', line 43783

def vm_dns_setting
  @vm_dns_setting
end

#xpn_project_statusString

[Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Corresponds to the JSON property xpnProjectStatus

Returns:

  • (String)


43790
43791
43792
# File 'lib/google/apis/compute_v1/classes.rb', line 43790

def xpn_project_status
  @xpn_project_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43797
43798
43799
43800
43801
43802
43803
43804
43805
43806
43807
43808
43809
43810
43811
43812
43813
# File 'lib/google/apis/compute_v1/classes.rb', line 43797

def update!(**args)
  @cloud_armor_tier = args[:cloud_armor_tier] if args.key?(:cloud_armor_tier)
  @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier)
  @default_service_account = args[:default_service_account] if args.key?(:default_service_account)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location)
  @vm_dns_setting = args[:vm_dns_setting] if args.key?(:vm_dns_setting)
  @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status)
end