Class: Google::Apis::ComputeV1::Project
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Project
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.
Instance Attribute Summary collapse
-
#cloud_armor_tier ⇒ String
Output only.
-
#common_instance_metadata ⇒ Google::Apis::ComputeV1::Metadata
A metadata key/value entry.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_network_tier ⇒ String
This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD.
-
#default_service_account ⇒ String
[Output Only] Default service account used by VMs running in this project.
-
#description ⇒ String
An optional textual description of the resource.
-
#enabled_features ⇒ Array<String>
An optional list of restricted features enabled for use on this project.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The project ID.
-
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this project.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#usage_export_location ⇒ Google::Apis::ComputeV1::UsageExportLocation
The location in Cloud Storage and naming method of the daily usage report.
-
#vm_dns_setting ⇒ String
Output only.
-
#xpn_project_status ⇒ String
[Output Only] The role this project has in a shared VPC configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Project
constructor
A new instance of Project.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Project
Returns a new instance of Project.
42901 42902 42903 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_armor_tier ⇒ String
Output only. [Output Only] The Cloud Armor tier for this project. It can be
one of the
following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
If this field is not specified, it is assumed to beCA_STANDARD.
Corresponds to the JSON property cloudArmorTier
42817 42818 42819 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42817 def cloud_armor_tier @cloud_armor_tier end |
#common_instance_metadata ⇒ Google::Apis::ComputeV1::Metadata
A metadata key/value entry.
Corresponds to the JSON property commonInstanceMetadata
42822 42823 42824 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42822 def @common_instance_metadata end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
42828 42829 42830 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42828 def @creation_timestamp end |
#default_network_tier ⇒ String
This signifies the default network tier used for configuring resources of
the project and can only take the following values:PREMIUM, STANDARD.
Initially the default network
tier is PREMIUM.
Corresponds to the JSON property defaultNetworkTier
42836 42837 42838 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42836 def default_network_tier @default_network_tier end |
#default_service_account ⇒ String
[Output Only] Default service account used by VMs running in this project.
Corresponds to the JSON property defaultServiceAccount
42841 42842 42843 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42841 def default_service_account @default_service_account end |
#description ⇒ String
An optional textual description of the resource.
Corresponds to the JSON property description
42846 42847 42848 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42846 def description @description end |
#enabled_features ⇒ Array<String>
An optional list of restricted features enabled for use on this project.
Corresponds to the JSON property enabledFeatures
42851 42852 42853 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42851 def enabled_features @enabled_features end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server. This is not the project ID, and is
just a unique ID used by Compute Engine to identify resources.
Corresponds to the JSON property id
42858 42859 42860 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42858 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#project for
projects.
Corresponds to the JSON property kind
42864 42865 42866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42864 def kind @kind end |
#name ⇒ String
The project ID. For example: my-example-project. Use the
project ID to make requests to Compute Engine.
Corresponds to the JSON property name
42870 42871 42872 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42870 def name @name end |
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this project.
Corresponds to the JSON property quotas
42875 42876 42877 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42875 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
42880 42881 42882 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42880 def self_link @self_link end |
#usage_export_location ⇒ Google::Apis::ComputeV1::UsageExportLocation
The location in Cloud Storage and naming method of the daily usage
report. Contains bucket_name and report_name prefix.
Corresponds to the JSON property usageExportLocation
42886 42887 42888 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42886 def usage_export_location @usage_export_location end |
#vm_dns_setting ⇒ String
Output only. [Output Only] Default internal DNS setting used by VMs running in
this project.
Corresponds to the JSON property vmDnsSetting
42892 42893 42894 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42892 def vm_dns_setting @vm_dns_setting end |
#xpn_project_status ⇒ String
[Output Only] The role this project has in a shared VPC configuration.
Currently, only projects with the host role, which is specified by the
value HOST, are differentiated.
Corresponds to the JSON property xpnProjectStatus
42899 42900 42901 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42899 def xpn_project_status @xpn_project_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42906 42907 42908 42909 42910 42911 42912 42913 42914 42915 42916 42917 42918 42919 42920 42921 42922 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42906 def update!(**args) @cloud_armor_tier = args[:cloud_armor_tier] if args.key?(:cloud_armor_tier) @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier) @default_service_account = args[:default_service_account] if args.key?(:default_service_account) @description = args[:description] if args.key?(:description) @enabled_features = args[:enabled_features] if args.key?(:enabled_features) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location) @vm_dns_setting = args[:vm_dns_setting] if args.key?(:vm_dns_setting) @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status) end |