Class: Google::Apis::ComputeV1::Project

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Project

Returns a new instance of Project.



24457
24458
24459
# File 'lib/google/apis/compute_v1/classes.rb', line 24457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_instance_metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property commonInstanceMetadata



24387
24388
24389
# File 'lib/google/apis/compute_v1/classes.rb', line 24387

def 
  @common_instance_metadata
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


24392
24393
24394
# File 'lib/google/apis/compute_v1/classes.rb', line 24392

def creation_timestamp
  @creation_timestamp
end

#default_network_tierString

This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Corresponds to the JSON property defaultNetworkTier

Returns:

  • (String)


24399
24400
24401
# File 'lib/google/apis/compute_v1/classes.rb', line 24399

def default_network_tier
  @default_network_tier
end

#default_service_accountString

[Output Only] Default service account used by VMs running in this project. Corresponds to the JSON property defaultServiceAccount

Returns:

  • (String)


24404
24405
24406
# File 'lib/google/apis/compute_v1/classes.rb', line 24404

def 
  @default_service_account
end

#descriptionString

An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


24409
24410
24411
# File 'lib/google/apis/compute_v1/classes.rb', line 24409

def description
  @description
end

#enabled_featuresArray<String>

Restricted features enabled for use on this project. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


24414
24415
24416
# File 'lib/google/apis/compute_v1/classes.rb', line 24414

def enabled_features
  @enabled_features
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources. Corresponds to the JSON property id

Returns:

  • (Fixnum)


24421
24422
24423
# File 'lib/google/apis/compute_v1/classes.rb', line 24421

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#project for projects. Corresponds to the JSON property kind

Returns:

  • (String)


24426
24427
24428
# File 'lib/google/apis/compute_v1/classes.rb', line 24426

def kind
  @kind
end

#nameString

The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine. Corresponds to the JSON property name

Returns:

  • (String)


24432
24433
24434
# File 'lib/google/apis/compute_v1/classes.rb', line 24432

def name
  @name
end

#quotasArray<Google::Apis::ComputeV1::Quota>

[Output Only] Quotas assigned to this project. Corresponds to the JSON property quotas

Returns:



24437
24438
24439
# File 'lib/google/apis/compute_v1/classes.rb', line 24437

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24442
24443
24444
# File 'lib/google/apis/compute_v1/classes.rb', line 24442

def self_link
  @self_link
end

#usage_export_locationGoogle::Apis::ComputeV1::UsageExportLocation

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix. Corresponds to the JSON property usageExportLocation



24448
24449
24450
# File 'lib/google/apis/compute_v1/classes.rb', line 24448

def usage_export_location
  @usage_export_location
end

#xpn_project_statusString

[Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Corresponds to the JSON property xpnProjectStatus

Returns:

  • (String)


24455
24456
24457
# File 'lib/google/apis/compute_v1/classes.rb', line 24455

def xpn_project_status
  @xpn_project_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24462
24463
24464
24465
24466
24467
24468
24469
24470
24471
24472
24473
24474
24475
24476
# File 'lib/google/apis/compute_v1/classes.rb', line 24462

def update!(**args)
  @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier)
  @default_service_account = args[:default_service_account] if args.key?(:default_service_account)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location)
  @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status)
end