Class: Google::Apis::ComputeV1::ProjectsGetXpnResources

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectsGetXpnResources

Returns a new instance of ProjectsGetXpnResources.



42991
42992
42993
# File 'lib/google/apis/compute_v1/classes.rb', line 42991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# projectsGetXpnResources for lists of service resources (a.k.a service projects) Corresponds to the JSON property kind

Returns:

  • (String)


42972
42973
42974
# File 'lib/google/apis/compute_v1/classes.rb', line 42972

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42983
42984
42985
# File 'lib/google/apis/compute_v1/classes.rb', line 42983

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::ComputeV1::XpnResourceId>

Service resources (a.k.a service projects) attached to this project as their shared VPC host. Corresponds to the JSON property resources



42989
42990
42991
# File 'lib/google/apis/compute_v1/classes.rb', line 42989

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42996
42997
42998
42999
43000
# File 'lib/google/apis/compute_v1/classes.rb', line 42996

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
end