Class: Google::Apis::ComputeV1::ProjectsGetXpnResources
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ProjectsGetXpnResources
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#resources ⇒ Array<Google::Apis::ComputeV1::XpnResourceId>
Service resources (a.k.a service projects) attached to this project as their shared VPC host.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectsGetXpnResources
constructor
A new instance of ProjectsGetXpnResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectsGetXpnResources
Returns a new instance of ProjectsGetXpnResources.
24542 24543 24544 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
[Output Only] Type of resource. Always compute#projectsGetXpnResources for
lists of service resources (a.k.a service projects)
Corresponds to the JSON property kind
24525 24526 24527 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24525 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
24534 24535 24536 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24534 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::ComputeV1::XpnResourceId>
Service resources (a.k.a service projects) attached to this project as their
shared VPC host.
Corresponds to the JSON property resources
24540 24541 24542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24540 def resources @resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24547 24548 24549 24550 24551 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24547 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) end |