Class: Google::Apis::ComputeV1::ProjectsListXpnHostsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectsListXpnHostsRequest

Returns a new instance of ProjectsListXpnHostsRequest.



43904
43905
43906
# File 'lib/google/apis/compute_v1/classes.rb', line 43904

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#organizationString

Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project. Corresponds to the JSON property organization

Returns:

  • (String)


43902
43903
43904
# File 'lib/google/apis/compute_v1/classes.rb', line 43902

def organization
  @organization
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43909
43910
43911
# File 'lib/google/apis/compute_v1/classes.rb', line 43909

def update!(**args)
  @organization = args[:organization] if args.key?(:organization)
end