Class: Google::Apis::ComputeV1::ProjectsListXpnHostsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectsListXpnHostsRequest

Returns a new instance of ProjectsListXpnHostsRequest.



39803
39804
39805
# File 'lib/google/apis/compute_v1/classes.rb', line 39803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#organizationString

Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project. Corresponds to the JSON property organization

Returns:

  • (String)


39801
39802
39803
# File 'lib/google/apis/compute_v1/classes.rb', line 39801

def organization
  @organization
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39808
39809
39810
# File 'lib/google/apis/compute_v1/classes.rb', line 39808

def update!(**args)
  @organization = args[:organization] if args.key?(:organization)
end