Class: Google::Apis::ComputeV1::ProjectsListXpnHostsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ProjectsListXpnHostsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
constructor
A new instance of ProjectsListXpnHostsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
Returns a new instance of ProjectsListXpnHostsRequest.
38966 38967 38968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to
list shared VPC host projects. If not specified, the organization will be
inferred from the project.
Corresponds to the JSON property organization
38964 38965 38966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38964 def organization @organization end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38971 38972 38973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38971 def update!(**args) @organization = args[:organization] if args.key?(:organization) end |