Class: Google::Apis::ComputeV1::ProjectsListXpnHostsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ProjectsListXpnHostsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
constructor
A new instance of ProjectsListXpnHostsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
Returns a new instance of ProjectsListXpnHostsRequest.
24565 24566 24567 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to list
shared VPC host projects. If not specified, the organization will be inferred
from the project.
Corresponds to the JSON property organization
24563 24564 24565 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24563 def organization @organization end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24570 24571 24572 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24570 def update!(**args) @organization = args[:organization] if args.key?(:organization) end |