Class: Google::Apis::ComputeV1::PublicAdvertisedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefix

Returns a new instance of PublicAdvertisedPrefix.



39974
39975
39976
# File 'lib/google/apis/compute_v1/classes.rb', line 39974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byoip_api_versionString

Output only. [Output Only] The version of BYOIP API. Corresponds to the JSON property byoipApiVersion

Returns:

  • (String)


39860
39861
39862
# File 'lib/google/apis/compute_v1/classes.rb', line 39860

def byoip_api_version
  @byoip_api_version
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


39866
39867
39868
# File 'lib/google/apis/compute_v1/classes.rb', line 39866

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


39872
39873
39874
# File 'lib/google/apis/compute_v1/classes.rb', line 39872

def description
  @description
end

#dns_verification_ipString

The address to be used for reverse DNS verification. Corresponds to the JSON property dnsVerificationIp

Returns:

  • (String)


39877
39878
39879
# File 'lib/google/apis/compute_v1/classes.rb', line 39877

def dns_verification_ip
  @dns_verification_ip
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-date fingerprint must be provided in order to update thePublicAdvertisedPrefix, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a PublicAdvertisedPrefix. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


39890
39891
39892
# File 'lib/google/apis/compute_v1/classes.rb', line 39890

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


39897
39898
39899
# File 'lib/google/apis/compute_v1/classes.rb', line 39897

def id
  @id
end

#ip_cidr_rangeString

The address range, in CIDR format, represented by this public advertised prefix. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


39903
39904
39905
# File 'lib/google/apis/compute_v1/classes.rb', line 39903

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

The internet access type for IPv6 Public Advertised Prefixes. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


39908
39909
39910
# File 'lib/google/apis/compute_v1/classes.rb', line 39908

def ipv6_access_type
  @ipv6_access_type
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


39914
39915
39916
# File 'lib/google/apis/compute_v1/classes.rb', line 39914

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


39925
39926
39927
# File 'lib/google/apis/compute_v1/classes.rb', line 39925

def name
  @name
end

#pdp_scopeString

Specifies how child public delegated prefix will be scoped. It could be one of following values:

  • REGIONAL: The public delegated prefix is regional only. The provisioning will take a few minutes.
  • GLOBAL: The public delegated prefix is global only. The provisioning will take ~4 weeks.
  • GLOBAL_AND_REGIONAL [output only]: The public delegated prefixes is BYOIP V1 legacy prefix. This is output only value and no longer supported in BYOIP V2. Corresponds to the JSON property pdpScope

Returns:

  • (String)


39940
39941
39942
# File 'lib/google/apis/compute_v1/classes.rb', line 39940

def pdp_scope
  @pdp_scope
end

#public_delegated_prefixsArray<Google::Apis::ComputeV1::PublicAdvertisedPrefixPublicDelegatedPrefix>

Output only. [Output Only] The list of public delegated prefixes that exist for this public advertised prefix. Corresponds to the JSON property publicDelegatedPrefixs



39947
39948
39949
# File 'lib/google/apis/compute_v1/classes.rb', line 39947

def public_delegated_prefixs
  @public_delegated_prefixs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39952
39953
39954
# File 'lib/google/apis/compute_v1/classes.rb', line 39952

def self_link
  @self_link
end

#shared_secretString

[Output Only] The shared secret to be used for reverse DNS verification. Corresponds to the JSON property sharedSecret

Returns:

  • (String)


39957
39958
39959
# File 'lib/google/apis/compute_v1/classes.rb', line 39957

def shared_secret
  @shared_secret
end

#statusString

The status of the public advertised prefix. Possible values include:

  • INITIAL: RPKI validation is complete.
  • PTR_CONFIGURED: User has configured the PTR.
  • VALIDATED: Reverse DNS lookup is successful.
  • REVERSE_DNS_LOOKUP_FAILED: Reverse DNS lookup failed.
  • PREFIX_CONFIGURATION_IN_PROGRESS: The prefix is being configured.
  • PREFIX_CONFIGURATION_COMPLETE: The prefix is fully configured.
  • PREFIX_REMOVAL_IN_PROGRESS: The prefix is being removed. Corresponds to the JSON property status

Returns:

  • (String)


39972
39973
39974
# File 'lib/google/apis/compute_v1/classes.rb', line 39972

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39979
39980
39981
39982
39983
39984
39985
39986
39987
39988
39989
39990
39991
39992
39993
39994
39995
# File 'lib/google/apis/compute_v1/classes.rb', line 39979

def update!(**args)
  @byoip_api_version = args[:byoip_api_version] if args.key?(:byoip_api_version)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @dns_verification_ip = args[:dns_verification_ip] if args.key?(:dns_verification_ip)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @pdp_scope = args[:pdp_scope] if args.key?(:pdp_scope)
  @public_delegated_prefixs = args[:public_delegated_prefixs] if args.key?(:public_delegated_prefixs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @shared_secret = args[:shared_secret] if args.key?(:shared_secret)
  @status = args[:status] if args.key?(:status)
end