Class: Google::Apis::ComputeV1::PublicAdvertisedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixList

Returns a new instance of PublicAdvertisedPrefixList.



44316
44317
44318
# File 'lib/google/apis/compute_v1/classes.rb', line 44316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44283
44284
44285
# File 'lib/google/apis/compute_v1/classes.rb', line 44283

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PublicAdvertisedPrefix>

A list of PublicAdvertisedPrefix resources. Corresponds to the JSON property items



44288
44289
44290
# File 'lib/google/apis/compute_v1/classes.rb', line 44288

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


44294
44295
44296
# File 'lib/google/apis/compute_v1/classes.rb', line 44294

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44304
44305
44306
# File 'lib/google/apis/compute_v1/classes.rb', line 44304

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44309
44310
44311
# File 'lib/google/apis/compute_v1/classes.rb', line 44309

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::PublicAdvertisedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44314
44315
44316
# File 'lib/google/apis/compute_v1/classes.rb', line 44314

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44321
44322
44323
44324
44325
44326
44327
44328
# File 'lib/google/apis/compute_v1/classes.rb', line 44321

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end