Class: Google::Apis::ComputeV1::PublicAdvertisedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicAdvertisedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixList
constructor
A new instance of PublicAdvertisedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixList
Returns a new instance of PublicAdvertisedPrefixList.
43863 43864 43865 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43830 43831 43832 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43830 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
Corresponds to the JSON property items
43835 43836 43837 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43835 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicAdvertisedPrefix for public advertised prefixes.
Corresponds to the JSON property kind
43841 43842 43843 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43841 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43851 43852 43853 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43851 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43856 43857 43858 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43856 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43861 43862 43863 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43861 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43868 43869 43870 43871 43872 43873 43874 43875 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43868 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |