Class: Google::Apis::ComputeV1::PublicAdvertisedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixList

Returns a new instance of PublicAdvertisedPrefixList.



43849
43850
43851
# File 'lib/google/apis/compute_v1/classes.rb', line 43849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43816
43817
43818
# File 'lib/google/apis/compute_v1/classes.rb', line 43816

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PublicAdvertisedPrefix>

A list of PublicAdvertisedPrefix resources. Corresponds to the JSON property items



43821
43822
43823
# File 'lib/google/apis/compute_v1/classes.rb', line 43821

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


43827
43828
43829
# File 'lib/google/apis/compute_v1/classes.rb', line 43827

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43837
43838
43839
# File 'lib/google/apis/compute_v1/classes.rb', line 43837

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43842
43843
43844
# File 'lib/google/apis/compute_v1/classes.rb', line 43842

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::PublicAdvertisedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43847
43848
43849
# File 'lib/google/apis/compute_v1/classes.rb', line 43847

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43854
43855
43856
43857
43858
43859
43860
43861
# File 'lib/google/apis/compute_v1/classes.rb', line 43854

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end