Class: Google::Apis::ComputeV1::PublicAdvertisedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicAdvertisedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixList
constructor
A new instance of PublicAdvertisedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixList
Returns a new instance of PublicAdvertisedPrefixList.
40038 40039 40040 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40005 40006 40007 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40005 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
Corresponds to the JSON property items
40010 40011 40012 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40010 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicAdvertisedPrefix for public advertised prefixes.
Corresponds to the JSON property kind
40016 40017 40018 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40016 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40026 40027 40028 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40026 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40031 40032 40033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40031 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40036 40037 40038 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40036 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40043 40044 40045 40046 40047 40048 40049 40050 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40043 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |