Class: Google::Apis::ComputeV1::PublicAdvertisedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicAdvertisedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixList
constructor
A new instance of PublicAdvertisedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixList
Returns a new instance of PublicAdvertisedPrefixList.
24742 24743 24744 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
24710 24711 24712 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24710 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
Corresponds to the JSON property items
24715 24716 24717 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24715 def items @items end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#publicAdvertisedPrefix for
public advertised prefixes.
Corresponds to the JSON property kind
24721 24722 24723 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24721 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
24730 24731 24732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24730 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
24735 24736 24737 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24735 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
24740 24741 24742 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24740 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24747 24748 24749 24750 24751 24752 24753 24754 |
# File 'lib/google/apis/compute_v1/classes.rb', line 24747 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |