Class: Google::Apis::ComputeV1::PublicAdvertisedPrefixPublicDelegatedPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicAdvertisedPrefixPublicDelegatedPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a CIDR range which can be used to assign addresses.
Instance Attribute Summary collapse
-
#ip_range ⇒ String
The IP address range of the public delegated prefix Corresponds to the JSON property
ipRange. -
#name ⇒ String
The name of the public delegated prefix Corresponds to the JSON property
name. -
#project ⇒ String
The project number of the public delegated prefix Corresponds to the JSON property
project. -
#region ⇒ String
The region of the public delegated prefix if it is regional.
-
#status ⇒ String
The status of the public delegated prefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix
constructor
A new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix
Returns a new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.
40156 40157 40158 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_range ⇒ String
The IP address range of the public delegated prefix
Corresponds to the JSON property ipRange
40130 40131 40132 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40130 def ip_range @ip_range end |
#name ⇒ String
The name of the public delegated prefix
Corresponds to the JSON property name
40135 40136 40137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40135 def name @name end |
#project ⇒ String
The project number of the public delegated prefix
Corresponds to the JSON property project
40140 40141 40142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40140 def project @project end |
#region ⇒ String
The region of the public delegated prefix if it is regional. If absent,
the prefix is global.
Corresponds to the JSON property region
40146 40147 40148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40146 def region @region end |
#status ⇒ String
The status of the public delegated prefix. Possible values are:
INITIALIZING: The public delegated prefix is being initialized and
addresses cannot be created yet.
ANNOUNCED: The public delegated prefix is active.
Corresponds to the JSON property status
40154 40155 40156 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40154 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40161 40162 40163 40164 40165 40166 40167 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40161 def update!(**args) @ip_range = args[:ip_range] if args.key?(:ip_range) @name = args[:name] if args.key?(:name) @project = args[:project] if args.key?(:project) @region = args[:region] if args.key?(:region) @status = args[:status] if args.key?(:status) end |