Class: Google::Apis::ComputeV1::PublicAdvertisedPrefixPublicDelegatedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a CIDR range which can be used to assign addresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix

Returns a new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.



39319
39320
39321
# File 'lib/google/apis/compute_v1/classes.rb', line 39319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_rangeString

The IP address range of the public delegated prefix Corresponds to the JSON property ipRange

Returns:

  • (String)


39293
39294
39295
# File 'lib/google/apis/compute_v1/classes.rb', line 39293

def ip_range
  @ip_range
end

#nameString

The name of the public delegated prefix Corresponds to the JSON property name

Returns:

  • (String)


39298
39299
39300
# File 'lib/google/apis/compute_v1/classes.rb', line 39298

def name
  @name
end

#projectString

The project number of the public delegated prefix Corresponds to the JSON property project

Returns:

  • (String)


39303
39304
39305
# File 'lib/google/apis/compute_v1/classes.rb', line 39303

def project
  @project
end

#regionString

The region of the public delegated prefix if it is regional. If absent, the prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


39309
39310
39311
# File 'lib/google/apis/compute_v1/classes.rb', line 39309

def region
  @region
end

#statusString

The status of the public delegated prefix. Possible values are: INITIALIZING: The public delegated prefix is being initialized and addresses cannot be created yet. ANNOUNCED: The public delegated prefix is active. Corresponds to the JSON property status

Returns:

  • (String)


39317
39318
39319
# File 'lib/google/apis/compute_v1/classes.rb', line 39317

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39324
39325
39326
39327
39328
39329
39330
# File 'lib/google/apis/compute_v1/classes.rb', line 39324

def update!(**args)
  @ip_range = args[:ip_range] if args.key?(:ip_range)
  @name = args[:name] if args.key?(:name)
  @project = args[:project] if args.key?(:project)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end