Class: Google::Apis::ComputeV1::PublicAdvertisedPrefixPublicDelegatedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a CIDR range which can be used to assign addresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix

Returns a new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.



24853
24854
24855
# File 'lib/google/apis/compute_v1/classes.rb', line 24853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_rangeString

The IP address range of the public delegated prefix Corresponds to the JSON property ipRange

Returns:

  • (String)


24828
24829
24830
# File 'lib/google/apis/compute_v1/classes.rb', line 24828

def ip_range
  @ip_range
end

#nameString

The name of the public delegated prefix Corresponds to the JSON property name

Returns:

  • (String)


24833
24834
24835
# File 'lib/google/apis/compute_v1/classes.rb', line 24833

def name
  @name
end

#projectString

The project number of the public delegated prefix Corresponds to the JSON property project

Returns:

  • (String)


24838
24839
24840
# File 'lib/google/apis/compute_v1/classes.rb', line 24838

def project
  @project
end

#regionString

The region of the public delegated prefix if it is regional. If absent, the prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


24844
24845
24846
# File 'lib/google/apis/compute_v1/classes.rb', line 24844

def region
  @region
end

#statusString

The status of the public delegated prefix. Possible values are: INITIALIZING: The public delegated prefix is being initialized and addresses cannot be created yet. ANNOUNCED: The public delegated prefix is active. Corresponds to the JSON property status

Returns:

  • (String)


24851
24852
24853
# File 'lib/google/apis/compute_v1/classes.rb', line 24851

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24858
24859
24860
24861
24862
24863
24864
# File 'lib/google/apis/compute_v1/classes.rb', line 24858

def update!(**args)
  @ip_range = args[:ip_range] if args.key?(:ip_range)
  @name = args[:name] if args.key?(:name)
  @project = args[:project] if args.key?(:project)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end