Class: Google::Apis::ComputeV1::PublicDelegatedPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicDelegatedPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A PublicDelegatedPrefix resource represents an IP block within a PublicAdvertisedPrefix that is configured within a single cloud scope (global or region). IPs in the block can be allocated to resources within that scope. Public delegated prefixes may be further broken up into smaller IP blocks in the same scope as the parent block.
Instance Attribute Summary collapse
-
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this public delegated prefix.
-
#byoip_api_version ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#enable_enhanced_ipv4_allocation ⇒ Boolean
(also: #enable_enhanced_ipv4_allocation?)
Output only.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this public delegated prefix.
-
#ipv6_access_type ⇒ String
Output only.
-
#is_live_migration ⇒ Boolean
(also: #is_live_migration?)
If true, the prefix will be live migrated.
-
#kind ⇒ String
Output only.
-
#mode ⇒ String
The public delegated prefix mode for IPv6 only.
-
#name ⇒ String
Name of the resource.
-
#parent_prefix ⇒ String
The URL of parent prefix.
-
#public_delegated_sub_prefixs ⇒ Array<Google::Apis::ComputeV1::PublicDelegatedPrefixPublicDelegatedSubPrefix>
The list of sub public delegated prefixes that exist for this public delegated prefix.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#status ⇒ String
[Output Only] The status of the public delegated prefix, which can be one of following values:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefix
constructor
A new instance of PublicDelegatedPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefix
Returns a new instance of PublicDelegatedPrefix.
44578 44579 44580 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44578 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this public delegated prefix.
This field is optional and cannot be set for prefixes in DELEGATION mode.
It cannot be set for IPv4 prefixes either, and it always defaults to 32.
Corresponds to the JSON property allocatablePrefixLength
44449 44450 44451 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44449 def allocatable_prefix_length @allocatable_prefix_length end |
#byoip_api_version ⇒ String
Output only. [Output Only] The version of BYOIP API.
Corresponds to the JSON property byoipApiVersion
44454 44455 44456 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44454 def byoip_api_version @byoip_api_version end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
44460 44461 44462 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44460 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
44466 44467 44468 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44466 def description @description end |
#enable_enhanced_ipv4_allocation ⇒ Boolean Also known as: enable_enhanced_ipv4_allocation?
Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations.
Applicable for IPv4 PDPs only.
Corresponds to the JSON property enableEnhancedIpv4Allocation
44472 44473 44474 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44472 def enable_enhanced_ipv4_allocation @enable_enhanced_ipv4_allocation end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a new PublicDelegatedPrefix. An up-to-date
fingerprint must be provided in order to update thePublicDelegatedPrefix,
otherwise the request will fail with
error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a PublicDelegatedPrefix.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
44486 44487 44488 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44486 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
44493 44494 44495 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44493 def id @id end |
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this public
delegated prefix.
Corresponds to the JSON property ipCidrRange
44499 44500 44501 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44499 def ip_cidr_range @ip_cidr_range end |
#ipv6_access_type ⇒ String
Output only. [Output Only] The internet access type for IPv6 Public Delegated
Prefixes.
Inherited from parent prefix.
Corresponds to the JSON property ipv6AccessType
44506 44507 44508 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44506 def ipv6_access_type @ipv6_access_type end |
#is_live_migration ⇒ Boolean Also known as: is_live_migration?
If true, the prefix will be live migrated.
Corresponds to the JSON property isLiveMigration
44511 44512 44513 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44511 def is_live_migration @is_live_migration end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefix for public delegated prefixes.
Corresponds to the JSON property kind
44518 44519 44520 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44518 def kind @kind end |
#mode ⇒ String
The public delegated prefix mode for IPv6 only.
Corresponds to the JSON property mode
44523 44524 44525 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44523 def mode @mode end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
44534 44535 44536 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44534 def name @name end |
#parent_prefix ⇒ String
The URL of parent prefix. Either PublicAdvertisedPrefix or
PublicDelegatedPrefix.
Corresponds to the JSON property parentPrefix
44540 44541 44542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44540 def parent_prefix @parent_prefix end |
#public_delegated_sub_prefixs ⇒ Array<Google::Apis::ComputeV1::PublicDelegatedPrefixPublicDelegatedSubPrefix>
The list of sub public delegated prefixes that exist for this public
delegated prefix.
Corresponds to the JSON property publicDelegatedSubPrefixs
44546 44547 44548 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44546 def public_delegated_sub_prefixs @public_delegated_sub_prefixs end |
#region ⇒ String
Output only. [Output Only] URL of the region where the public delegated prefix
resides.
This field applies only to the region resource. You must specify this
field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
44555 44556 44557 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44555 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
44560 44561 44562 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44560 def self_link @self_link end |
#status ⇒ String
[Output Only] The status of the public delegated prefix, which can be one of following values:
INITIALIZINGThe public delegated prefix is being initialized and addresses cannot be created yet.READY_TO_ANNOUNCEThe public delegated prefix is a live migration prefix and is active.ANNOUNCEDThe public delegated prefix is announced and ready to use.DELETINGThe public delegated prefix is being deprovsioned.ACTIVEThe public delegated prefix is ready to use. Corresponds to the JSON propertystatus
44576 44577 44578 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44576 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44583 44584 44585 44586 44587 44588 44589 44590 44591 44592 44593 44594 44595 44596 44597 44598 44599 44600 44601 44602 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44583 def update!(**args) @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length) @byoip_api_version = args[:byoip_api_version] if args.key?(:byoip_api_version) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @is_live_migration = args[:is_live_migration] if args.key?(:is_live_migration) @kind = args[:kind] if args.key?(:kind) @mode = args[:mode] if args.key?(:mode) @name = args[:name] if args.key?(:name) @parent_prefix = args[:parent_prefix] if args.key?(:parent_prefix) @public_delegated_sub_prefixs = args[:public_delegated_sub_prefixs] if args.key?(:public_delegated_sub_prefixs) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) end |