Class: Google::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::PublicDelegatedPrefixesScopedList>
A list of PublicDelegatedPrefixesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList
constructor
A new instance of PublicDelegatedPrefixAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList
Returns a new instance of PublicDelegatedPrefixAggregatedList.
44210 44211 44212 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
44171 44172 44173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44171 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::PublicDelegatedPrefixesScopedList>
A list of PublicDelegatedPrefixesScopedList resources.
Corresponds to the JSON property items
44176 44177 44178 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44176 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefixAggregatedList for aggregated
lists of public delegated prefixes.
Corresponds to the JSON property kind
44183 44184 44185 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44183 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
44193 44194 44195 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44193 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
44198 44199 44200 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44198 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
44203 44204 44205 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44203 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
44208 44209 44210 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44208 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44215 44216 44217 44218 44219 44220 44221 44222 44223 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44215 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |