Class: Google::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::PublicDelegatedPrefixesScopedList>
A list of PublicDelegatedPrefixesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList
constructor
A new instance of PublicDelegatedPrefixAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList
Returns a new instance of PublicDelegatedPrefixAggregatedList.
43596 43597 43598 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43596 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43557 43558 43559 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43557 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::PublicDelegatedPrefixesScopedList>
A list of PublicDelegatedPrefixesScopedList resources.
Corresponds to the JSON property items
43562 43563 43564 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43562 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefixAggregatedList for aggregated
lists of public delegated prefixes.
Corresponds to the JSON property kind
43569 43570 43571 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43569 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43579 43580 43581 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43579 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43584 43585 43586 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43584 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
43589 43590 43591 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43589 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::PublicDelegatedPrefixAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43594 43595 43596 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43594 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43601 43602 43603 43604 43605 43606 43607 43608 43609 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43601 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |