Class: Google::Apis::ComputeV1::PublicDelegatedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicDelegatedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::PublicDelegatedPrefix>
A list of PublicDelegatedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::PublicDelegatedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixList
constructor
A new instance of PublicDelegatedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixList
Returns a new instance of PublicDelegatedPrefixList.
44790 44791 44792 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
44756 44757 44758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44756 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::PublicDelegatedPrefix>
A list of PublicDelegatedPrefix resources.
Corresponds to the JSON property items
44761 44762 44763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44761 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefixList for public delegated
prefixes.
Corresponds to the JSON property kind
44768 44769 44770 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44768 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
44778 44779 44780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44778 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
44783 44784 44785 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44783 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::PublicDelegatedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
44788 44789 44790 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44788 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44795 44796 44797 44798 44799 44800 44801 44802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44795 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |