Class: Google::Apis::ComputeV1::PublicDelegatedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixList

Returns a new instance of PublicDelegatedPrefixList.



43723
43724
43725
# File 'lib/google/apis/compute_v1/classes.rb', line 43723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43689
43690
43691
# File 'lib/google/apis/compute_v1/classes.rb', line 43689

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PublicDelegatedPrefix>

A list of PublicDelegatedPrefix resources. Corresponds to the JSON property items



43694
43695
43696
# File 'lib/google/apis/compute_v1/classes.rb', line 43694

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixList for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


43701
43702
43703
# File 'lib/google/apis/compute_v1/classes.rb', line 43701

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43711
43712
43713
# File 'lib/google/apis/compute_v1/classes.rb', line 43711

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43716
43717
43718
# File 'lib/google/apis/compute_v1/classes.rb', line 43716

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::PublicDelegatedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43721
43722
43723
# File 'lib/google/apis/compute_v1/classes.rb', line 43721

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43728
43729
43730
43731
43732
43733
43734
43735
# File 'lib/google/apis/compute_v1/classes.rb', line 43728

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end