Class: Google::Apis::ComputeV1::PublicDelegatedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixList

Returns a new instance of PublicDelegatedPrefixList.



39675
39676
39677
# File 'lib/google/apis/compute_v1/classes.rb', line 39675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39641
39642
39643
# File 'lib/google/apis/compute_v1/classes.rb', line 39641

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PublicDelegatedPrefix>

A list of PublicDelegatedPrefix resources. Corresponds to the JSON property items



39646
39647
39648
# File 'lib/google/apis/compute_v1/classes.rb', line 39646

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixList for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


39653
39654
39655
# File 'lib/google/apis/compute_v1/classes.rb', line 39653

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39663
39664
39665
# File 'lib/google/apis/compute_v1/classes.rb', line 39663

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39668
39669
39670
# File 'lib/google/apis/compute_v1/classes.rb', line 39668

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::PublicDelegatedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39673
39674
39675
# File 'lib/google/apis/compute_v1/classes.rb', line 39673

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39680
39681
39682
39683
39684
39685
39686
39687
# File 'lib/google/apis/compute_v1/classes.rb', line 39680

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end