Class: Google::Apis::ComputeV1::PublicDelegatedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixList

Returns a new instance of PublicDelegatedPrefixList.



25152
25153
25154
# File 'lib/google/apis/compute_v1/classes.rb', line 25152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25120
25121
25122
# File 'lib/google/apis/compute_v1/classes.rb', line 25120

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::PublicDelegatedPrefix>

A list of PublicDelegatedPrefix resources. Corresponds to the JSON property items



25125
25126
25127
# File 'lib/google/apis/compute_v1/classes.rb', line 25125

def items
  @items
end

#kindString

[Output Only] Type of the resource. Always compute#publicDelegatedPrefixList for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


25131
25132
25133
# File 'lib/google/apis/compute_v1/classes.rb', line 25131

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25140
25141
25142
# File 'lib/google/apis/compute_v1/classes.rb', line 25140

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25145
25146
25147
# File 'lib/google/apis/compute_v1/classes.rb', line 25145

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::PublicDelegatedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25150
25151
25152
# File 'lib/google/apis/compute_v1/classes.rb', line 25150

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25157
25158
25159
25160
25161
25162
25163
25164
# File 'lib/google/apis/compute_v1/classes.rb', line 25157

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end