Class: Google::Apis::ComputeV1::PublicDelegatedPrefixPublicDelegatedSubPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicDelegatedPrefixPublicDelegatedSubPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a sub PublicDelegatedPrefix.
Instance Attribute Summary collapse
-
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this PublicDelegatedSubPrefix.
-
#delegatee_project ⇒ String
Name of the project scoping this PublicDelegatedSubPrefix.
-
#description ⇒ String
An optional description of this resource.
-
#enable_enhanced_ipv4_allocation ⇒ Boolean
(also: #enable_enhanced_ipv4_allocation?)
Output only.
-
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this sub public delegated prefix.
-
#ipv6_access_type ⇒ String
Output only.
-
#is_address ⇒ Boolean
(also: #is_address?)
Whether the sub prefix is delegated to create Address resources in the delegatee project.
-
#mode ⇒ String
The PublicDelegatedSubPrefix mode for IPv6 only.
-
#name ⇒ String
The name of the sub public delegated prefix.
-
#region ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix
constructor
A new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix
Returns a new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.
44767 44768 44769 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44767 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this PublicDelegatedSubPrefix.
Corresponds to the JSON property allocatablePrefixLength
44705 44706 44707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44705 def allocatable_prefix_length @allocatable_prefix_length end |
#delegatee_project ⇒ String
Name of the project scoping this PublicDelegatedSubPrefix.
Corresponds to the JSON property delegateeProject
44710 44711 44712 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44710 def delegatee_project @delegatee_project end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
44716 44717 44718 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44716 def description @description end |
#enable_enhanced_ipv4_allocation ⇒ Boolean Also known as: enable_enhanced_ipv4_allocation?
Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations.
Applicable for IPv4 PDPs only.
Corresponds to the JSON property enableEnhancedIpv4Allocation
44722 44723 44724 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44722 def enable_enhanced_ipv4_allocation @enable_enhanced_ipv4_allocation end |
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this sub public
delegated prefix.
Corresponds to the JSON property ipCidrRange
44729 44730 44731 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44729 def ip_cidr_range @ip_cidr_range end |
#ipv6_access_type ⇒ String
Output only. [Output Only] The internet access type for IPv6 Public Delegated
Sub
Prefixes. Inherited from parent prefix.
Corresponds to the JSON property ipv6AccessType
44736 44737 44738 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44736 def ipv6_access_type @ipv6_access_type end |
#is_address ⇒ Boolean Also known as: is_address?
Whether the sub prefix is delegated to create Address resources in the
delegatee project.
Corresponds to the JSON property isAddress
44742 44743 44744 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44742 def is_address @is_address end |
#mode ⇒ String
The PublicDelegatedSubPrefix mode for IPv6 only.
Corresponds to the JSON property mode
44748 44749 44750 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44748 def mode @mode end |
#name ⇒ String
The name of the sub public delegated prefix.
Corresponds to the JSON property name
44753 44754 44755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44753 def name @name end |
#region ⇒ String
Output only. [Output Only] The region of the sub public delegated prefix if it
is
regional. If absent, the sub prefix is global.
Corresponds to the JSON property region
44760 44761 44762 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44760 def region @region end |
#status ⇒ String
Output only. [Output Only] The status of the sub public delegated prefix.
Corresponds to the JSON property status
44765 44766 44767 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44765 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44772 44773 44774 44775 44776 44777 44778 44779 44780 44781 44782 44783 44784 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44772 def update!(**args) @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length) @delegatee_project = args[:delegatee_project] if args.key?(:delegatee_project) @description = args[:description] if args.key?(:description) @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @is_address = args[:is_address] if args.key?(:is_address) @mode = args[:mode] if args.key?(:mode) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @status = args[:status] if args.key?(:status) end |