Class: Google::Apis::ComputeV1::PublicDelegatedPrefixPublicDelegatedSubPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a sub PublicDelegatedPrefix.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix

Returns a new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.



44491
44492
44493
# File 'lib/google/apis/compute_v1/classes.rb', line 44491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocatable_prefix_lengthFixnum

The allocatable prefix length supported by this PublicDelegatedSubPrefix. Corresponds to the JSON property allocatablePrefixLength

Returns:

  • (Fixnum)


44429
44430
44431
# File 'lib/google/apis/compute_v1/classes.rb', line 44429

def allocatable_prefix_length
  @allocatable_prefix_length
end

#delegatee_projectString

Name of the project scoping this PublicDelegatedSubPrefix. Corresponds to the JSON property delegateeProject

Returns:

  • (String)


44434
44435
44436
# File 'lib/google/apis/compute_v1/classes.rb', line 44434

def delegatee_project
  @delegatee_project
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


44440
44441
44442
# File 'lib/google/apis/compute_v1/classes.rb', line 44440

def description
  @description
end

#enable_enhanced_ipv4_allocationBoolean Also known as: enable_enhanced_ipv4_allocation?

Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only. Corresponds to the JSON property enableEnhancedIpv4Allocation

Returns:

  • (Boolean)


44446
44447
44448
# File 'lib/google/apis/compute_v1/classes.rb', line 44446

def enable_enhanced_ipv4_allocation
  @enable_enhanced_ipv4_allocation
end

#ip_cidr_rangeString

The IP address range, in CIDR format, represented by this sub public delegated prefix. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


44453
44454
44455
# File 'lib/google/apis/compute_v1/classes.rb', line 44453

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub Prefixes. Inherited from parent prefix. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


44460
44461
44462
# File 'lib/google/apis/compute_v1/classes.rb', line 44460

def ipv6_access_type
  @ipv6_access_type
end

#is_addressBoolean Also known as: is_address?

Whether the sub prefix is delegated to create Address resources in the delegatee project. Corresponds to the JSON property isAddress

Returns:

  • (Boolean)


44466
44467
44468
# File 'lib/google/apis/compute_v1/classes.rb', line 44466

def is_address
  @is_address
end

#modeString

The PublicDelegatedSubPrefix mode for IPv6 only. Corresponds to the JSON property mode

Returns:

  • (String)


44472
44473
44474
# File 'lib/google/apis/compute_v1/classes.rb', line 44472

def mode
  @mode
end

#nameString

The name of the sub public delegated prefix. Corresponds to the JSON property name

Returns:

  • (String)


44477
44478
44479
# File 'lib/google/apis/compute_v1/classes.rb', line 44477

def name
  @name
end

#regionString

Output only. [Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


44484
44485
44486
# File 'lib/google/apis/compute_v1/classes.rb', line 44484

def region
  @region
end

#statusString

Output only. [Output Only] The status of the sub public delegated prefix. Corresponds to the JSON property status

Returns:

  • (String)


44489
44490
44491
# File 'lib/google/apis/compute_v1/classes.rb', line 44489

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44496
44497
44498
44499
44500
44501
44502
44503
44504
44505
44506
44507
44508
# File 'lib/google/apis/compute_v1/classes.rb', line 44496

def update!(**args)
  @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length)
  @delegatee_project = args[:delegatee_project] if args.key?(:delegatee_project)
  @description = args[:description] if args.key?(:description)
  @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @is_address = args[:is_address] if args.key?(:is_address)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end