Class: Google::Apis::ComputeV1::PublicDelegatedPrefixPublicDelegatedSubPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PublicDelegatedPrefixPublicDelegatedSubPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a sub PublicDelegatedPrefix.
Instance Attribute Summary collapse
-
#delegatee_project ⇒ String
Name of the project scoping this PublicDelegatedSubPrefix.
-
#description ⇒ String
An optional description of this resource.
-
#ip_cidr_range ⇒ String
The IPv4 address range, in CIDR format, represented by this sub public delegated prefix.
-
#is_address ⇒ Boolean
(also: #is_address?)
Whether the sub prefix is delegated to create Address resources in the delegatee project.
-
#name ⇒ String
The name of the sub public delegated prefix.
-
#region ⇒ String
[Output Only] The region of the sub public delegated prefix if it is regional.
-
#status ⇒ String
[Output Only] The status of the sub public delegated prefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix
constructor
A new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix
Returns a new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.
25275 25276 25277 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delegatee_project ⇒ String
Name of the project scoping this PublicDelegatedSubPrefix.
Corresponds to the JSON property delegateeProject
25238 25239 25240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25238 def delegatee_project @delegatee_project end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
25244 25245 25246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25244 def description @description end |
#ip_cidr_range ⇒ String
The IPv4 address range, in CIDR format, represented by this sub public
delegated prefix.
Corresponds to the JSON property ipCidrRange
25250 25251 25252 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25250 def ip_cidr_range @ip_cidr_range end |
#is_address ⇒ Boolean Also known as: is_address?
Whether the sub prefix is delegated to create Address resources in the
delegatee project.
Corresponds to the JSON property isAddress
25256 25257 25258 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25256 def is_address @is_address end |
#name ⇒ String
The name of the sub public delegated prefix.
Corresponds to the JSON property name
25262 25263 25264 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25262 def name @name end |
#region ⇒ String
[Output Only] The region of the sub public delegated prefix if it is regional.
If absent, the sub prefix is global.
Corresponds to the JSON property region
25268 25269 25270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25268 def region @region end |
#status ⇒ String
[Output Only] The status of the sub public delegated prefix.
Corresponds to the JSON property status
25273 25274 25275 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25273 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25280 25281 25282 25283 25284 25285 25286 25287 25288 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25280 def update!(**args) @delegatee_project = args[:delegatee_project] if args.key?(:delegatee_project) @description = args[:description] if args.key?(:description) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @is_address = args[:is_address] if args.key?(:is_address) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @status = args[:status] if args.key?(:status) end |