Class: Google::Apis::ComputeV1::Reference

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a reference to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reference

Returns a new instance of Reference.



45167
45168
45169
# File 'lib/google/apis/compute_v1/classes.rb', line 45167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of the resource. Always compute#reference for references. Corresponds to the JSON property kind

Returns:

  • (String)


45146
45147
45148
# File 'lib/google/apis/compute_v1/classes.rb', line 45146

def kind
  @kind
end

#reference_typeString

A description of the reference type with no implied semantics. Possible values include:

  1. MEMBER_OF Corresponds to the JSON property referenceType

Returns:

  • (String)


45155
45156
45157
# File 'lib/google/apis/compute_v1/classes.rb', line 45155

def reference_type
  @reference_type
end

#referrerString

URL of the resource which refers to the target. Corresponds to the JSON property referrer

Returns:

  • (String)


45160
45161
45162
# File 'lib/google/apis/compute_v1/classes.rb', line 45160

def referrer
  @referrer
end

#targetString

URL of the resource to which this reference points. Corresponds to the JSON property target

Returns:

  • (String)


45165
45166
45167
# File 'lib/google/apis/compute_v1/classes.rb', line 45165

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45172
45173
45174
45175
45176
45177
# File 'lib/google/apis/compute_v1/classes.rb', line 45172

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @reference_type = args[:reference_type] if args.key?(:reference_type)
  @referrer = args[:referrer] if args.key?(:referrer)
  @target = args[:target] if args.key?(:target)
end