Class: Google::Apis::ComputeV1::Reference

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a reference to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reference

Returns a new instance of Reference.



45002
45003
45004
# File 'lib/google/apis/compute_v1/classes.rb', line 45002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of the resource. Always compute#reference for references. Corresponds to the JSON property kind

Returns:

  • (String)


44981
44982
44983
# File 'lib/google/apis/compute_v1/classes.rb', line 44981

def kind
  @kind
end

#reference_typeString

A description of the reference type with no implied semantics. Possible values include:

  1. MEMBER_OF Corresponds to the JSON property referenceType

Returns:

  • (String)


44990
44991
44992
# File 'lib/google/apis/compute_v1/classes.rb', line 44990

def reference_type
  @reference_type
end

#referrerString

URL of the resource which refers to the target. Corresponds to the JSON property referrer

Returns:

  • (String)


44995
44996
44997
# File 'lib/google/apis/compute_v1/classes.rb', line 44995

def referrer
  @referrer
end

#targetString

URL of the resource to which this reference points. Corresponds to the JSON property target

Returns:

  • (String)


45000
45001
45002
# File 'lib/google/apis/compute_v1/classes.rb', line 45000

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45007
45008
45009
45010
45011
45012
# File 'lib/google/apis/compute_v1/classes.rb', line 45007

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @reference_type = args[:reference_type] if args.key?(:reference_type)
  @referrer = args[:referrer] if args.key?(:referrer)
  @target = args[:target] if args.key?(:target)
end