Class: Google::Apis::ComputeV1::Reference
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Reference
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reference to a resource.
Instance Attribute Summary collapse
-
#kind ⇒ String
Output only.
-
#reference_type ⇒ String
A description of the reference type with no implied semantics.
-
#referrer ⇒ String
URL of the resource which refers to the target.
-
#target ⇒ String
URL of the resource to which this reference points.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reference
constructor
A new instance of Reference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reference
Returns a new instance of Reference.
45003 45004 45005 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#reference
for references.
Corresponds to the JSON property kind
44982 44983 44984 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44982 def kind @kind end |
#reference_type ⇒ String
A description of the reference type with no implied semantics. Possible values include:
- MEMBER_OF
Corresponds to the JSON property
referenceType
44991 44992 44993 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44991 def reference_type @reference_type end |
#referrer ⇒ String
URL of the resource which refers to the target.
Corresponds to the JSON property referrer
44996 44997 44998 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44996 def referrer @referrer end |
#target ⇒ String
URL of the resource to which this reference points.
Corresponds to the JSON property target
45001 45002 45003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45001 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45008 45009 45010 45011 45012 45013 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45008 def update!(**args) @kind = args[:kind] if args.key?(:kind) @reference_type = args[:reference_type] if args.key?(:reference_type) @referrer = args[:referrer] if args.key?(:referrer) @target = args[:target] if args.key?(:target) end |