Class: Google::Apis::ComputeV1::Reference

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a reference to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reference

Returns a new instance of Reference.



44712
44713
44714
# File 'lib/google/apis/compute_v1/classes.rb', line 44712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of the resource. Always compute#reference for references. Corresponds to the JSON property kind

Returns:

  • (String)


44691
44692
44693
# File 'lib/google/apis/compute_v1/classes.rb', line 44691

def kind
  @kind
end

#reference_typeString

A description of the reference type with no implied semantics. Possible values include:

  1. MEMBER_OF Corresponds to the JSON property referenceType

Returns:

  • (String)


44700
44701
44702
# File 'lib/google/apis/compute_v1/classes.rb', line 44700

def reference_type
  @reference_type
end

#referrerString

URL of the resource which refers to the target. Corresponds to the JSON property referrer

Returns:

  • (String)


44705
44706
44707
# File 'lib/google/apis/compute_v1/classes.rb', line 44705

def referrer
  @referrer
end

#targetString

URL of the resource to which this reference points. Corresponds to the JSON property target

Returns:

  • (String)


44710
44711
44712
# File 'lib/google/apis/compute_v1/classes.rb', line 44710

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44717
44718
44719
44720
44721
44722
# File 'lib/google/apis/compute_v1/classes.rb', line 44717

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @reference_type = args[:reference_type] if args.key?(:reference_type)
  @referrer = args[:referrer] if args.key?(:referrer)
  @target = args[:target] if args.key?(:target)
end