Class: Google::Apis::ComputeV1::Reference

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a reference to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reference

Returns a new instance of Reference.



44112
44113
44114
# File 'lib/google/apis/compute_v1/classes.rb', line 44112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of the resource. Always compute#reference for references. Corresponds to the JSON property kind

Returns:

  • (String)


44091
44092
44093
# File 'lib/google/apis/compute_v1/classes.rb', line 44091

def kind
  @kind
end

#reference_typeString

A description of the reference type with no implied semantics. Possible values include:

  1. MEMBER_OF Corresponds to the JSON property referenceType

Returns:

  • (String)


44100
44101
44102
# File 'lib/google/apis/compute_v1/classes.rb', line 44100

def reference_type
  @reference_type
end

#referrerString

URL of the resource which refers to the target. Corresponds to the JSON property referrer

Returns:

  • (String)


44105
44106
44107
# File 'lib/google/apis/compute_v1/classes.rb', line 44105

def referrer
  @referrer
end

#targetString

URL of the resource to which this reference points. Corresponds to the JSON property target

Returns:

  • (String)


44110
44111
44112
# File 'lib/google/apis/compute_v1/classes.rb', line 44110

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44117
44118
44119
44120
44121
44122
# File 'lib/google/apis/compute_v1/classes.rb', line 44117

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @reference_type = args[:reference_type] if args.key?(:reference_type)
  @referrer = args[:referrer] if args.key?(:referrer)
  @target = args[:target] if args.key?(:target)
end