Class: Google::Apis::ComputeV1::Reference
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Reference
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reference to a resource.
Instance Attribute Summary collapse
-
#kind ⇒ String
Output only.
-
#reference_type ⇒ String
A description of the reference type with no implied semantics.
-
#referrer ⇒ String
URL of the resource which refers to the target.
-
#target ⇒ String
URL of the resource to which this reference points.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reference
constructor
A new instance of Reference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reference
Returns a new instance of Reference.
40064 40065 40066 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#reference
for references.
Corresponds to the JSON property kind
40043 40044 40045 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40043 def kind @kind end |
#reference_type ⇒ String
A description of the reference type with no implied semantics. Possible values include:
- MEMBER_OF
Corresponds to the JSON property
referenceType
40052 40053 40054 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40052 def reference_type @reference_type end |
#referrer ⇒ String
URL of the resource which refers to the target.
Corresponds to the JSON property referrer
40057 40058 40059 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40057 def referrer @referrer end |
#target ⇒ String
URL of the resource to which this reference points.
Corresponds to the JSON property target
40062 40063 40064 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40062 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40069 40070 40071 40072 40073 40074 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40069 def update!(**args) @kind = args[:kind] if args.key?(:kind) @reference_type = args[:reference_type] if args.key?(:reference_type) @referrer = args[:referrer] if args.key?(:referrer) @target = args[:target] if args.key?(:target) end |