Class: Google::Apis::ComputeV1::Region
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Region
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Region resource. A region is a geographical area where a resource is located. For more information, readRegions and Zones.
Defined Under Namespace
Classes: QuotaStatusWarning
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#quota_status_warning ⇒ Google::Apis::ComputeV1::Region::QuotaStatusWarning
Output only.
-
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this region.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
-
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of resource URLs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Region
constructor
A new instance of Region.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Region
Returns a new instance of Region.
44199 44200 44201 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
44136 44137 44138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44136 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
44141 44142 44143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44141 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
44146 44147 44148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44146 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
44152 44153 44154 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44152 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#region for
regions.
Corresponds to the JSON property kind
44158 44159 44160 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44158 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
44163 44164 44165 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44163 def name @name end |
#quota_status_warning ⇒ Google::Apis::ComputeV1::Region::QuotaStatusWarning
Output only. [Output Only] Warning of fetching the quotas field for this
region. This
field is populated only if fetching of the quotas field fails.
Corresponds to the JSON property quotaStatusWarning
44170 44171 44172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44170 def quota_status_warning @quota_status_warning end |
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this region.
Corresponds to the JSON property quotas
44175 44176 44177 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44175 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
44180 44181 44182 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44180 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
Corresponds to the JSON property status
44185 44186 44187 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44185 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
44190 44191 44192 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44190 def supports_pzs @supports_pzs end |
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of
resource URLs.
Corresponds to the JSON property zones
44197 44198 44199 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44197 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44204 44205 44206 44207 44208 44209 44210 44211 44212 44213 44214 44215 44216 44217 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44204 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @quota_status_warning = args[:quota_status_warning] if args.key?(:quota_status_warning) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) @zones = args[:zones] if args.key?(:zones) end |