Class: Google::Apis::ComputeV1::Region
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Region
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Region resource. A region is a geographical area where a resource is located. For more information, readRegions and Zones.
Defined Under Namespace
Classes: QuotaStatusWarning
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#quota_status_warning ⇒ Google::Apis::ComputeV1::Region::QuotaStatusWarning
Output only.
-
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this region.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
-
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of resource URLs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Region
constructor
A new instance of Region.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Region
Returns a new instance of Region.
40151 40152 40153 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
40088 40089 40090 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40088 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
40093 40094 40095 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40093 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
40098 40099 40100 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40098 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
40104 40105 40106 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40104 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#region for
regions.
Corresponds to the JSON property kind
40110 40111 40112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40110 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
40115 40116 40117 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40115 def name @name end |
#quota_status_warning ⇒ Google::Apis::ComputeV1::Region::QuotaStatusWarning
Output only. [Output Only] Warning of fetching the quotas field for this
region. This
field is populated only if fetching of the quotas field fails.
Corresponds to the JSON property quotaStatusWarning
40122 40123 40124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40122 def quota_status_warning @quota_status_warning end |
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this region.
Corresponds to the JSON property quotas
40127 40128 40129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40127 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
40132 40133 40134 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40132 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
Corresponds to the JSON property status
40137 40138 40139 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40137 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
40142 40143 40144 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40142 def supports_pzs @supports_pzs end |
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of
resource URLs.
Corresponds to the JSON property zones
40149 40150 40151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40149 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40156 40157 40158 40159 40160 40161 40162 40163 40164 40165 40166 40167 40168 40169 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40156 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @quota_status_warning = args[:quota_status_warning] if args.key?(:quota_status_warning) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) @zones = args[:zones] if args.key?(:zones) end |