Class: Google::Apis::ComputeV1::RegionAddressesMoveRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionAddressesMoveRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional destination address description if intended to be different from the source.
-
#destination_address ⇒ String
The URL of the destination address to move to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionAddressesMoveRequest
constructor
A new instance of RegionAddressesMoveRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionAddressesMoveRequest
Returns a new instance of RegionAddressesMoveRequest.
40266 40267 40268 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional destination address description if intended to be different
from the source.
Corresponds to the JSON property description
40252 40253 40254 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40252 def description @description end |
#destination_address ⇒ String
The URL of the destination address to move to. This can be a full or partial URL. For example, the following are all valid URLs to a address:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ addresses/address
- projects/project/regions/region/addresses/address
Note that destination project must be different from the source project. So/
regions/region/addresses/address is not valid partial url.
Corresponds to the JSON property
destinationAddress
40264 40265 40266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40264 def destination_address @destination_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40271 40272 40273 40274 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40271 def update!(**args) @description = args[:description] if args.key?(:description) @destination_address = args[:destination_address] if args.key?(:destination_address) end |