Class: Google::Apis::ComputeV1::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



45419
45420
45421
# File 'lib/google/apis/compute_v1/classes.rb', line 45419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45387
45388
45389
# File 'lib/google/apis/compute_v1/classes.rb', line 45387

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



45392
45393
45394
# File 'lib/google/apis/compute_v1/classes.rb', line 45392

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


45397
45398
45399
# File 'lib/google/apis/compute_v1/classes.rb', line 45397

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45407
45408
45409
# File 'lib/google/apis/compute_v1/classes.rb', line 45407

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45412
45413
45414
# File 'lib/google/apis/compute_v1/classes.rb', line 45412

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45417
45418
45419
# File 'lib/google/apis/compute_v1/classes.rb', line 45417

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45424
45425
45426
45427
45428
45429
45430
45431
# File 'lib/google/apis/compute_v1/classes.rb', line 45424

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end