Class: Google::Apis::ComputeV1::RegionAutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionAutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of autoscalers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionAutoscalerList
constructor
A new instance of RegionAutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionAutoscalerList
Returns a new instance of RegionAutoscalerList.
45255 45256 45257 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
45223 45224 45225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45223 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
45228 45229 45230 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45228 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
45233 45234 45235 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45233 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45243 45244 45245 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45243 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
45248 45249 45250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45248 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45253 45254 45255 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45253 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45260 45261 45262 45263 45264 45265 45266 45267 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45260 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |