Class: Google::Apis::ComputeV1::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



44978
44979
44980
# File 'lib/google/apis/compute_v1/classes.rb', line 44978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44946
44947
44948
# File 'lib/google/apis/compute_v1/classes.rb', line 44946

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



44951
44952
44953
# File 'lib/google/apis/compute_v1/classes.rb', line 44951

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


44956
44957
44958
# File 'lib/google/apis/compute_v1/classes.rb', line 44956

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44966
44967
44968
# File 'lib/google/apis/compute_v1/classes.rb', line 44966

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44971
44972
44973
# File 'lib/google/apis/compute_v1/classes.rb', line 44971

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44976
44977
44978
# File 'lib/google/apis/compute_v1/classes.rb', line 44976

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44983
44984
44985
44986
44987
44988
44989
44990
# File 'lib/google/apis/compute_v1/classes.rb', line 44983

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end