Class: Google::Apis::ComputeV1::RegionAutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionAutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of autoscalers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionAutoscalerList
constructor
A new instance of RegionAutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionAutoscalerList
Returns a new instance of RegionAutoscalerList.
44978 44979 44980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
44946 44947 44948 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44946 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
44951 44952 44953 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44951 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
44956 44957 44958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44956 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
44966 44967 44968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44966 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
44971 44972 44973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44971 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
44976 44977 44978 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44976 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44983 44984 44985 44986 44987 44988 44989 44990 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44983 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |