Class: Google::Apis::ComputeV1::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



44364
44365
44366
# File 'lib/google/apis/compute_v1/classes.rb', line 44364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44332
44333
44334
# File 'lib/google/apis/compute_v1/classes.rb', line 44332

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



44337
44338
44339
# File 'lib/google/apis/compute_v1/classes.rb', line 44337

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


44342
44343
44344
# File 'lib/google/apis/compute_v1/classes.rb', line 44342

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44352
44353
44354
# File 'lib/google/apis/compute_v1/classes.rb', line 44352

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44357
44358
44359
# File 'lib/google/apis/compute_v1/classes.rb', line 44357

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44362
44363
44364
# File 'lib/google/apis/compute_v1/classes.rb', line 44362

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44369
44370
44371
44372
44373
44374
44375
44376
# File 'lib/google/apis/compute_v1/classes.rb', line 44369

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end