Class: Google::Apis::ComputeV1::RegionDiskUpdateKmsKeyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionDiskUpdateKmsKeyRequest

Returns a new instance of RegionDiskUpdateKmsKeyRequest.



44592
44593
44594
# File 'lib/google/apis/compute_v1/classes.rb', line 44592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Optional. The new KMS key to replace the current one on the disk. If empty, the disk will be re-encrypted using the primary version of the disk's current KMS key. The KMS key can be provided in the following formats:

  • projects/project_id/locations/location/keyRings/key_ring/cryptoKeys/key Where project is the project ID or project number. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


44590
44591
44592
# File 'lib/google/apis/compute_v1/classes.rb', line 44590

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44597
44598
44599
# File 'lib/google/apis/compute_v1/classes.rb', line 44597

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end