Class: Google::Apis::ComputeV1::RegionInstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupList

Returns a new instance of RegionInstanceGroupList.



45633
45634
45635
# File 'lib/google/apis/compute_v1/classes.rb', line 45633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45600
45601
45602
# File 'lib/google/apis/compute_v1/classes.rb', line 45600

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



45605
45606
45607
# File 'lib/google/apis/compute_v1/classes.rb', line 45605

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


45610
45611
45612
# File 'lib/google/apis/compute_v1/classes.rb', line 45610

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45621
45622
45623
# File 'lib/google/apis/compute_v1/classes.rb', line 45621

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45626
45627
45628
# File 'lib/google/apis/compute_v1/classes.rb', line 45626

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



45631
45632
45633
# File 'lib/google/apis/compute_v1/classes.rb', line 45631

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45638
45639
45640
45641
45642
45643
45644
45645
# File 'lib/google/apis/compute_v1/classes.rb', line 45638

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end