Class: Google::Apis::ComputeV1::RegionInstanceGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of InstanceGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroup>
A list of InstanceGroup resources.
-
#kind ⇒ String
The resource type.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupList
constructor
A new instance of RegionInstanceGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupList
Returns a new instance of RegionInstanceGroupList.
25871 25872 25873 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25840 25841 25842 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25840 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroup>
A list of InstanceGroup resources.
Corresponds to the JSON property items
25845 25846 25847 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25845 def items @items end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
25850 25851 25852 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25850 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25859 25860 25861 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25859 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25864 25865 25866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25864 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
25869 25870 25871 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25869 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25876 25877 25878 25879 25880 25881 25882 25883 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25876 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |