Class: Google::Apis::ComputeV1::RegionInstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupManagerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of managed instance groups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
A list of InstanceGroupManager resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagerList
constructor
A new instance of RegionInstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagerList
Returns a new instance of RegionInstanceGroupManagerList.
46307 46308 46309 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46273 46274 46275 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46273 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
A list of InstanceGroupManager resources.
Corresponds to the JSON property items
46278 46279 46280 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46278 def items @items end |
#kind ⇒ String
Output only. The resource type, which is always compute#
instanceGroupManagerList for a
list of managed instance groups that exist in th regional scope.
Corresponds to the JSON property kind
46285 46286 46287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46285 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46295 46296 46297 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46295 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46300 46301 46302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46300 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
46305 46306 46307 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46305 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46312 46313 46314 46315 46316 46317 46318 46319 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46312 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |