Class: Google::Apis::ComputeV1::RegionInstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerList

Returns a new instance of RegionInstanceGroupManagerList.



45778
45779
45780
# File 'lib/google/apis/compute_v1/classes.rb', line 45778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45744
45745
45746
# File 'lib/google/apis/compute_v1/classes.rb', line 45744

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



45749
45750
45751
# File 'lib/google/apis/compute_v1/classes.rb', line 45749

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups that exist in th regional scope. Corresponds to the JSON property kind

Returns:

  • (String)


45756
45757
45758
# File 'lib/google/apis/compute_v1/classes.rb', line 45756

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45766
45767
45768
# File 'lib/google/apis/compute_v1/classes.rb', line 45766

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45771
45772
45773
# File 'lib/google/apis/compute_v1/classes.rb', line 45771

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



45776
45777
45778
# File 'lib/google/apis/compute_v1/classes.rb', line 45776

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45783
45784
45785
45786
45787
45788
45789
45790
# File 'lib/google/apis/compute_v1/classes.rb', line 45783

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end