Class: Google::Apis::ComputeV1::RegionInstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerList

Returns a new instance of RegionInstanceGroupManagerList.



45502
45503
45504
# File 'lib/google/apis/compute_v1/classes.rb', line 45502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45468
45469
45470
# File 'lib/google/apis/compute_v1/classes.rb', line 45468

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



45473
45474
45475
# File 'lib/google/apis/compute_v1/classes.rb', line 45473

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups that exist in th regional scope. Corresponds to the JSON property kind

Returns:

  • (String)


45480
45481
45482
# File 'lib/google/apis/compute_v1/classes.rb', line 45480

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45490
45491
45492
# File 'lib/google/apis/compute_v1/classes.rb', line 45490

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45495
45496
45497
# File 'lib/google/apis/compute_v1/classes.rb', line 45495

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



45500
45501
45502
# File 'lib/google/apis/compute_v1/classes.rb', line 45500

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45507
45508
45509
45510
45511
45512
45513
45514
# File 'lib/google/apis/compute_v1/classes.rb', line 45507

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end