Class: Google::Apis::ComputeV1::RegionInstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupManagerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of managed instance groups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
A list of InstanceGroupManager resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagerList
constructor
A new instance of RegionInstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagerList
Returns a new instance of RegionInstanceGroupManagerList.
41651 41652 41653 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
41616 41617 41618 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41616 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
A list of InstanceGroupManager resources.
Corresponds to the JSON property items
41621 41622 41623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41621 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is always
compute#instanceGroupManagerList for a list of managed instance groups that
exist in th regional scope.
Corresponds to the JSON property kind
41628 41629 41630 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41628 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41639 41640 41641 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41639 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41644 41645 41646 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41644 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
41649 41650 41651 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41649 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41656 41657 41658 41659 41660 41661 41662 41663 |
# File 'lib/google/apis/compute_v1/classes.rb', line 41656 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |