Class: Google::Apis::ComputeV1::RegionInstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupManagerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of managed instance groups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
A list of InstanceGroupManager resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagerList
constructor
A new instance of RegionInstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagerList
Returns a new instance of RegionInstanceGroupManagerList.
40814 40815 40816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40814 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
40779 40780 40781 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40779 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
A list of InstanceGroupManager resources.
Corresponds to the JSON property items
40784 40785 40786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40784 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is always
compute#instanceGroupManagerList for a list of managed instance groups that
exist in th regional scope.
Corresponds to the JSON property kind
40791 40792 40793 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40791 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40802 40803 40804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40802 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40807 40808 40809 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40807 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
40812 40813 40814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40812 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40819 40820 40821 40822 40823 40824 40825 40826 |
# File 'lib/google/apis/compute_v1/classes.rb', line 40819 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |