Class: Google::Apis::ComputeV1::RegionInstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupManagerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of managed instance groups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
A list of InstanceGroupManager resources.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups that exist in th regional scope.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagerList
constructor
A new instance of RegionInstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagerList
Returns a new instance of RegionInstanceGroupManagerList.
26010 26011 26012 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25977 25978 25979 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25977 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroupManager>
A list of InstanceGroupManager resources.
Corresponds to the JSON property items
25982 25983 25984 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25982 def items @items end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#
instanceGroupManagerList for a list of managed instance groups that exist in
th regional scope.
Corresponds to the JSON property kind
25989 25990 25991 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25989 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25998 25999 26000 |
# File 'lib/google/apis/compute_v1/classes.rb', line 25998 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
26003 26004 26005 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26003 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26008 26009 26010 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26008 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26015 26016 26017 26018 26019 26020 26021 26022 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26015 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |