Class: Google::Apis::ComputeV1::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



46100
46101
46102
# File 'lib/google/apis/compute_v1/classes.rb', line 46100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


46055
46056
46057
# File 'lib/google/apis/compute_v1/classes.rb', line 46055

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46060
46061
46062
# File 'lib/google/apis/compute_v1/classes.rb', line 46060

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



46065
46066
46067
# File 'lib/google/apis/compute_v1/classes.rb', line 46065

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


46072
46073
46074
# File 'lib/google/apis/compute_v1/classes.rb', line 46072

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46082
46083
46084
# File 'lib/google/apis/compute_v1/classes.rb', line 46082

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46087
46088
46089
# File 'lib/google/apis/compute_v1/classes.rb', line 46087

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46093
46094
46095
# File 'lib/google/apis/compute_v1/classes.rb', line 46093

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



46098
46099
46100
# File 'lib/google/apis/compute_v1/classes.rb', line 46098

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46105
46106
46107
46108
46109
46110
46111
46112
46113
46114
# File 'lib/google/apis/compute_v1/classes.rb', line 46105

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end