Class: Google::Apis::ComputeV1::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



45936
45937
45938
# File 'lib/google/apis/compute_v1/classes.rb', line 45936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


45891
45892
45893
# File 'lib/google/apis/compute_v1/classes.rb', line 45891

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45896
45897
45898
# File 'lib/google/apis/compute_v1/classes.rb', line 45896

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



45901
45902
45903
# File 'lib/google/apis/compute_v1/classes.rb', line 45901

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


45908
45909
45910
# File 'lib/google/apis/compute_v1/classes.rb', line 45908

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45918
45919
45920
# File 'lib/google/apis/compute_v1/classes.rb', line 45918

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45923
45924
45925
# File 'lib/google/apis/compute_v1/classes.rb', line 45923

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


45929
45930
45931
# File 'lib/google/apis/compute_v1/classes.rb', line 45929

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



45934
45935
45936
# File 'lib/google/apis/compute_v1/classes.rb', line 45934

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45941
45942
45943
45944
45945
45946
45947
45948
45949
45950
# File 'lib/google/apis/compute_v1/classes.rb', line 45941

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end