Class: Google::Apis::ComputeV1::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



45645
45646
45647
# File 'lib/google/apis/compute_v1/classes.rb', line 45645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


45600
45601
45602
# File 'lib/google/apis/compute_v1/classes.rb', line 45600

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45605
45606
45607
# File 'lib/google/apis/compute_v1/classes.rb', line 45605

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



45610
45611
45612
# File 'lib/google/apis/compute_v1/classes.rb', line 45610

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


45617
45618
45619
# File 'lib/google/apis/compute_v1/classes.rb', line 45617

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45627
45628
45629
# File 'lib/google/apis/compute_v1/classes.rb', line 45627

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45632
45633
45634
# File 'lib/google/apis/compute_v1/classes.rb', line 45632

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


45638
45639
45640
# File 'lib/google/apis/compute_v1/classes.rb', line 45638

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



45643
45644
45645
# File 'lib/google/apis/compute_v1/classes.rb', line 45643

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45650
45651
45652
45653
45654
45655
45656
45657
45658
45659
# File 'lib/google/apis/compute_v1/classes.rb', line 45650

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end