Class: Google::Apis::ComputeV1::RegionInstanceGroupManagersDeleteInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersDeleteInstancesRequest

Returns a new instance of RegionInstanceGroupManagersDeleteInstancesRequest.



41905
41906
41907
# File 'lib/google/apis/compute_v1/classes.rb', line 41905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<String>

The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME]. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


41891
41892
41893
# File 'lib/google/apis/compute_v1/classes.rb', line 41891

def instances
  @instances
end

#skip_instances_on_validation_errorBoolean Also known as: skip_instances_on_validation_error?

Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned. If this field is set to false and such an instance is specified in the request, the operation fails. The operation always fails if the request contains a malformed instance URL or a reference to an instance that exists in a zone or region other than the group's zone or region. Corresponds to the JSON property skipInstancesOnValidationError

Returns:

  • (Boolean)


41902
41903
41904
# File 'lib/google/apis/compute_v1/classes.rb', line 41902

def skip_instances_on_validation_error
  @skip_instances_on_validation_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41910
41911
41912
41913
# File 'lib/google/apis/compute_v1/classes.rb', line 41910

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @skip_instances_on_validation_error = args[:skip_instances_on_validation_error] if args.key?(:skip_instances_on_validation_error)
end