Class: Google::Apis::ComputeV1::RegionInstanceGroupManagersListInstanceConfigsResp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupManagersListInstanceConfigsResp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::ComputeV1::PerInstanceConfig>
[Output Only] The list of PerInstanceConfig.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagersListInstanceConfigsResp::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagersListInstanceConfigsResp
constructor
A new instance of RegionInstanceGroupManagersListInstanceConfigsResp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagersListInstanceConfigsResp
Returns a new instance of RegionInstanceGroupManagersListInstanceConfigsResp.
26304 26305 26306 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::ComputeV1::PerInstanceConfig>
[Output Only] The list of PerInstanceConfig.
Corresponds to the JSON property items
26288 26289 26290 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26288 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26297 26298 26299 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26297 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::RegionInstanceGroupManagersListInstanceConfigsResp::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26302 26303 26304 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26302 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26309 26310 26311 26312 26313 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26309 def update!(**args) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |