Class: Google::Apis::ComputeV1::RegionInstanceGroupManagersListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstancesResponse

Returns a new instance of RegionInstanceGroupManagersListInstancesResponse.



46064
46065
46066
# File 'lib/google/apis/compute_v1/classes.rb', line 46064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#managed_instancesArray<Google::Apis::ComputeV1::ManagedInstance>

A list of managed instances. Corresponds to the JSON property managedInstances



46051
46052
46053
# File 'lib/google/apis/compute_v1/classes.rb', line 46051

def managed_instances
  @managed_instances
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46062
46063
46064
# File 'lib/google/apis/compute_v1/classes.rb', line 46062

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46069
46070
46071
46072
# File 'lib/google/apis/compute_v1/classes.rb', line 46069

def update!(**args)
  @managed_instances = args[:managed_instances] if args.key?(:managed_instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end