Class: Google::Apis::ComputeV1::RegionInstanceGroupManagersListInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupManagersListInstancesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#managed_instances ⇒ Array<Google::Apis::ComputeV1::ManagedInstance>
A list of managed instances.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagersListInstancesResponse
constructor
A new instance of RegionInstanceGroupManagersListInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagersListInstancesResponse
Returns a new instance of RegionInstanceGroupManagersListInstancesResponse.
26398 26399 26400 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#managed_instances ⇒ Array<Google::Apis::ComputeV1::ManagedInstance>
A list of managed instances.
Corresponds to the JSON property managedInstances
26387 26388 26389 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26387 def managed_instances @managed_instances end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26396 26397 26398 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26396 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26403 26404 26405 26406 |
# File 'lib/google/apis/compute_v1/classes.rb', line 26403 def update!(**args) @managed_instances = args[:managed_instances] if args.key?(:managed_instances) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |