Class: Google::Apis::ComputeV1::RegionInstanceGroupManagersSetTargetPoolsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupManagersSetTargetPoolsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Fingerprint of the target pools information, which is a hash of the contents.
-
#target_pools ⇒ Array<String>
The URL of all TargetPool resources to which instances in theinstanceGroup field are added.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagersSetTargetPoolsRequest
constructor
A new instance of RegionInstanceGroupManagersSetTargetPoolsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagersSetTargetPoolsRequest
Returns a new instance of RegionInstanceGroupManagersSetTargetPoolsRequest.
46134 46135 46136 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Fingerprint of the target pools information, which is a hash of the
contents. This field is used for optimistic locking when you update the
target pool entries. This field is optional.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
46125 46126 46127 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46125 def fingerprint @fingerprint end |
#target_pools ⇒ Array<String>
The URL of all TargetPool resources to which instances in theinstanceGroup
field are added. The target pools automatically
apply to all of the instances in the managed instance group.
Corresponds to the JSON property targetPools
46132 46133 46134 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46132 def target_pools @target_pools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46139 46140 46141 46142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46139 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @target_pools = args[:target_pools] if args.key?(:target_pools) end |