Class: Google::Apis::ComputeV1::RegionInstanceGroupManagersSetTargetPoolsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersSetTargetPoolsRequest

Returns a new instance of RegionInstanceGroupManagersSetTargetPoolsRequest.



46120
46121
46122
# File 'lib/google/apis/compute_v1/classes.rb', line 46120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

Fingerprint of the target pools information, which is a hash of the contents. This field is used for optimistic locking when you update the target pool entries. This field is optional. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


46111
46112
46113
# File 'lib/google/apis/compute_v1/classes.rb', line 46111

def fingerprint
  @fingerprint
end

#target_poolsArray<String>

The URL of all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


46118
46119
46120
# File 'lib/google/apis/compute_v1/classes.rb', line 46118

def target_pools
  @target_pools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46125
46126
46127
46128
# File 'lib/google/apis/compute_v1/classes.rb', line 46125

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
end