Class: Google::Apis::ComputeV1::RegionInstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstances

Returns a new instance of RegionInstanceGroupsListInstances.



47087
47088
47089
# File 'lib/google/apis/compute_v1/classes.rb', line 47087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47054
47055
47056
# File 'lib/google/apis/compute_v1/classes.rb', line 47054

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



47059
47060
47061
# File 'lib/google/apis/compute_v1/classes.rb', line 47059

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


47064
47065
47066
# File 'lib/google/apis/compute_v1/classes.rb', line 47064

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47075
47076
47077
# File 'lib/google/apis/compute_v1/classes.rb', line 47075

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47080
47081
47082
# File 'lib/google/apis/compute_v1/classes.rb', line 47080

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



47085
47086
47087
# File 'lib/google/apis/compute_v1/classes.rb', line 47085

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47092
47093
47094
47095
47096
47097
47098
47099
# File 'lib/google/apis/compute_v1/classes.rb', line 47092

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end