Class: Google::Apis::ComputeV1::RegionInstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstances

Returns a new instance of RegionInstanceGroupsListInstances.



46723
46724
46725
# File 'lib/google/apis/compute_v1/classes.rb', line 46723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46690
46691
46692
# File 'lib/google/apis/compute_v1/classes.rb', line 46690

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



46695
46696
46697
# File 'lib/google/apis/compute_v1/classes.rb', line 46695

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


46700
46701
46702
# File 'lib/google/apis/compute_v1/classes.rb', line 46700

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46711
46712
46713
# File 'lib/google/apis/compute_v1/classes.rb', line 46711

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46716
46717
46718
# File 'lib/google/apis/compute_v1/classes.rb', line 46716

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



46721
46722
46723
# File 'lib/google/apis/compute_v1/classes.rb', line 46721

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46728
46729
46730
46731
46732
46733
46734
46735
# File 'lib/google/apis/compute_v1/classes.rb', line 46728

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end