Class: Google::Apis::ComputeV1::RegionInstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstances

Returns a new instance of RegionInstanceGroupsListInstances.



26517
26518
26519
# File 'lib/google/apis/compute_v1/classes.rb', line 26517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26486
26487
26488
# File 'lib/google/apis/compute_v1/classes.rb', line 26486

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



26491
26492
26493
# File 'lib/google/apis/compute_v1/classes.rb', line 26491

def items
  @items
end

#kindString

The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


26496
26497
26498
# File 'lib/google/apis/compute_v1/classes.rb', line 26496

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26505
26506
26507
# File 'lib/google/apis/compute_v1/classes.rb', line 26505

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26510
26511
26512
# File 'lib/google/apis/compute_v1/classes.rb', line 26510

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionInstanceGroupsListInstances::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



26515
26516
26517
# File 'lib/google/apis/compute_v1/classes.rb', line 26515

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26522
26523
26524
26525
26526
26527
26528
26529
# File 'lib/google/apis/compute_v1/classes.rb', line 26522

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end