Class: Google::Apis::ComputeV1::RegionInstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstancesRequest

Returns a new instance of RegionInstanceGroupsListInstancesRequest.



46826
46827
46828
# File 'lib/google/apis/compute_v1/classes.rb', line 46826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_stateString

Instances in which state should be returned. Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances. Corresponds to the JSON property instanceState

Returns:

  • (String)


46816
46817
46818
# File 'lib/google/apis/compute_v1/classes.rb', line 46816

def instance_state
  @instance_state
end

#port_nameString

Name of port user is interested in. It is optional. If it is set, only information about this ports will be returned. If it is not set, all the named ports will be returned. Always lists all instances. Corresponds to the JSON property portName

Returns:

  • (String)


46824
46825
46826
# File 'lib/google/apis/compute_v1/classes.rb', line 46824

def port_name
  @port_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46831
46832
46833
46834
# File 'lib/google/apis/compute_v1/classes.rb', line 46831

def update!(**args)
  @instance_state = args[:instance_state] if args.key?(:instance_state)
  @port_name = args[:port_name] if args.key?(:port_name)
end