Class: Google::Apis::ComputeV1::RegionInstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstancesRequest

Returns a new instance of RegionInstanceGroupsListInstancesRequest.



45775
45776
45777
# File 'lib/google/apis/compute_v1/classes.rb', line 45775

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_stateString

Instances in which state should be returned. Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances. Corresponds to the JSON property instanceState

Returns:

  • (String)


45765
45766
45767
# File 'lib/google/apis/compute_v1/classes.rb', line 45765

def instance_state
  @instance_state
end

#port_nameString

Name of port user is interested in. It is optional. If it is set, only information about this ports will be returned. If it is not set, all the named ports will be returned. Always lists all instances. Corresponds to the JSON property portName

Returns:

  • (String)


45773
45774
45775
# File 'lib/google/apis/compute_v1/classes.rb', line 45773

def port_name
  @port_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45780
45781
45782
45783
# File 'lib/google/apis/compute_v1/classes.rb', line 45780

def update!(**args)
  @instance_state = args[:instance_state] if args.key?(:instance_state)
  @port_name = args[:port_name] if args.key?(:port_name)
end