Class: Google::Apis::ComputeV1::RegionInstanceGroupsSetNamedPortsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupsSetNamedPortsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeV1::NamedPort>
The list of named ports to set for this instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupsSetNamedPortsRequest
constructor
A new instance of RegionInstanceGroupsSetNamedPortsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupsSetNamedPortsRequest
Returns a new instance of RegionInstanceGroupsSetNamedPortsRequest.
47222 47223 47224 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47222 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
Use this optional property to prevent conflicts when multiple users change
the named ports settings concurrently. Obtain the fingerprint with
theinstanceGroups.get
method. Then, include the fingerprint in your request to ensure that you
do not overwrite changes that were applied from another
concurrent request.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
47215 47216 47217 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47215 def fingerprint @fingerprint end |
#named_ports ⇒ Array<Google::Apis::ComputeV1::NamedPort>
The list of named ports to set for this instance group.
Corresponds to the JSON property namedPorts
47220 47221 47222 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47220 def named_ports @named_ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47227 47228 47229 47230 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47227 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @named_ports = args[:named_ports] if args.key?(:named_ports) end |