Class: Google::Apis::ComputeV1::RegionInstanceGroupsSetNamedPortsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsSetNamedPortsRequest

Returns a new instance of RegionInstanceGroupsSetNamedPortsRequest.



46417
46418
46419
# File 'lib/google/apis/compute_v1/classes.rb', line 46417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with theinstanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


46410
46411
46412
# File 'lib/google/apis/compute_v1/classes.rb', line 46410

def fingerprint
  @fingerprint
end

#named_portsArray<Google::Apis::ComputeV1::NamedPort>

The list of named ports to set for this instance group. Corresponds to the JSON property namedPorts



46415
46416
46417
# File 'lib/google/apis/compute_v1/classes.rb', line 46415

def named_ports
  @named_ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46422
46423
46424
46425
# File 'lib/google/apis/compute_v1/classes.rb', line 46422

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
end