Class: Google::Apis::ComputeV1::RegionList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of region resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Region>
A list of Region resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RegionList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionList
constructor
A new instance of RegionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionList
Returns a new instance of RegionList.
47285 47286 47287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47252 47253 47254 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47252 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Region>
A list of Region resources.
Corresponds to the JSON property items
47257 47258 47259 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47257 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#regionList for
lists of regions.
Corresponds to the JSON property kind
47263 47264 47265 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47263 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47273 47274 47275 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47273 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47278 47279 47280 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47278 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RegionList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47283 47284 47285 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47283 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47290 47291 47292 47293 47294 47295 47296 47297 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47290 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |