Class: Google::Apis::ComputeV1::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



46921
46922
46923
# File 'lib/google/apis/compute_v1/classes.rb', line 46921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46888
46889
46890
# File 'lib/google/apis/compute_v1/classes.rb', line 46888

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Region>

A list of Region resources. Corresponds to the JSON property items



46893
46894
46895
# File 'lib/google/apis/compute_v1/classes.rb', line 46893

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


46899
46900
46901
# File 'lib/google/apis/compute_v1/classes.rb', line 46899

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46909
46910
46911
# File 'lib/google/apis/compute_v1/classes.rb', line 46909

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46914
46915
46916
# File 'lib/google/apis/compute_v1/classes.rb', line 46914

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46919
46920
46921
# File 'lib/google/apis/compute_v1/classes.rb', line 46919

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46926
46927
46928
46929
46930
46931
46932
46933
# File 'lib/google/apis/compute_v1/classes.rb', line 46926

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end