Class: Google::Apis::ComputeV1::RegionList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of region resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Region>
A list of Region resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RegionList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionList
constructor
A new instance of RegionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionList
Returns a new instance of RegionList.
46468 46469 46470 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46435 46436 46437 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46435 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Region>
A list of Region resources.
Corresponds to the JSON property items
46440 46441 46442 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46440 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#regionList for
lists of regions.
Corresponds to the JSON property kind
46446 46447 46448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46446 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46456 46457 46458 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46456 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46461 46462 46463 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46461 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RegionList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46466 46467 46468 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46466 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46473 46474 46475 46476 46477 46478 46479 46480 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46473 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |