Class: Google::Apis::ComputeV1::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



42478
42479
42480
# File 'lib/google/apis/compute_v1/classes.rb', line 42478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42445
42446
42447
# File 'lib/google/apis/compute_v1/classes.rb', line 42445

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Region>

A list of Region resources. Corresponds to the JSON property items



42450
42451
42452
# File 'lib/google/apis/compute_v1/classes.rb', line 42450

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


42456
42457
42458
# File 'lib/google/apis/compute_v1/classes.rb', line 42456

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42466
42467
42468
# File 'lib/google/apis/compute_v1/classes.rb', line 42466

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42471
42472
42473
# File 'lib/google/apis/compute_v1/classes.rb', line 42471

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42476
42477
42478
# File 'lib/google/apis/compute_v1/classes.rb', line 42476

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42483
42484
42485
42486
42487
42488
42489
42490
# File 'lib/google/apis/compute_v1/classes.rb', line 42483

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end