Class: Google::Apis::ComputeV1::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



26693
26694
26695
# File 'lib/google/apis/compute_v1/classes.rb', line 26693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


26662
26663
26664
# File 'lib/google/apis/compute_v1/classes.rb', line 26662

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Region>

A list of Region resources. Corresponds to the JSON property items



26667
26668
26669
# File 'lib/google/apis/compute_v1/classes.rb', line 26667

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


26672
26673
26674
# File 'lib/google/apis/compute_v1/classes.rb', line 26672

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26681
26682
26683
# File 'lib/google/apis/compute_v1/classes.rb', line 26681

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


26686
26687
26688
# File 'lib/google/apis/compute_v1/classes.rb', line 26686

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



26691
26692
26693
# File 'lib/google/apis/compute_v1/classes.rb', line 26691

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26698
26699
26700
26701
26702
26703
26704
26705
# File 'lib/google/apis/compute_v1/classes.rb', line 26698

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end