Class: Google::Apis::ComputeV1::RegionSetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionSetLabelsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#label_fingerprint ⇒ String
The fingerprint of the previous set of labels for this resource, used to detect conflicts.
-
#labels ⇒ Hash<String,String>
The labels to set for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionSetLabelsRequest
constructor
A new instance of RegionSetLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionSetLabelsRequest
Returns a new instance of RegionSetLabelsRequest.
47511 47512 47513 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47511 def initialize(**args) update!(**args) end |
Instance Attribute Details
#label_fingerprint ⇒ String
The fingerprint of the previous set of labels for this resource,
used to detect conflicts. The fingerprint is initially generated by Compute
Engine and changes after every request to modify or update labels. You must
always provide an up-to-date fingerprint hash in order to update or change
labels. Make a get() request to the resource to get the latest
fingerprint.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
47504 47505 47506 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47504 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
The labels to set for this resource.
Corresponds to the JSON property labels
47509 47510 47511 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47509 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47516 47517 47518 47519 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47516 def update!(**args) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) end |