Class: Google::Apis::ComputeV1::ReliabilityRisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a ReliabilityRisk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReliabilityRisk

Returns a new instance of ReliabilityRisk.



47752
47753
47754
# File 'lib/google/apis/compute_v1/classes.rb', line 47752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


47705
47706
47707
# File 'lib/google/apis/compute_v1/classes.rb', line 47705

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional textual description of the resource; provided when the resource is created. Corresponds to the JSON property description

Returns:

  • (String)


47711
47712
47713
# File 'lib/google/apis/compute_v1/classes.rb', line 47711

def description
  @description
end

#detailsGoogle::Apis::ComputeV1::RiskDetails

Detailed insights and metrics about a detected reliability risk. Corresponds to the JSON property details



47716
47717
47718
# File 'lib/google/apis/compute_v1/classes.rb', line 47716

def details
  @details
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


47722
47723
47724
# File 'lib/google/apis/compute_v1/classes.rb', line 47722

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Always compute#reliabilityRisk for reliability risks. Corresponds to the JSON property kind

Returns:

  • (String)


47728
47729
47730
# File 'lib/google/apis/compute_v1/classes.rb', line 47728

def kind
  @kind
end

#nameString

Name of the resource. The name must be 1-63 characters long and comply with RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


47734
47735
47736
# File 'lib/google/apis/compute_v1/classes.rb', line 47734

def name
  @name
end

#recommendationGoogle::Apis::ComputeV1::RiskRecommendation

Recommendation for mitigating a reliability risk, including a reference URL. Corresponds to the JSON property recommendation



47739
47740
47741
# File 'lib/google/apis/compute_v1/classes.rb', line 47739

def recommendation
  @recommendation
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47744
47745
47746
# File 'lib/google/apis/compute_v1/classes.rb', line 47744

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


47750
47751
47752
# File 'lib/google/apis/compute_v1/classes.rb', line 47750

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47757
47758
47759
47760
47761
47762
47763
47764
47765
47766
47767
# File 'lib/google/apis/compute_v1/classes.rb', line 47757

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @details = args[:details] if args.key?(:details)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @recommendation = args[:recommendation] if args.key?(:recommendation)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end