Class: Google::Apis::ComputeV1::ReliabilityRisksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReliabilityRisksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response message for the List method of ReliabilityRisksService.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
[Output Only] An ETag of the resource.
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ReliabilityRisk>
A list of ReliabilityRisk resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisksListResponse
constructor
A new instance of ReliabilityRisksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisksListResponse
Returns a new instance of ReliabilityRisksListResponse.
47827 47828 47829 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
[Output Only] An ETag of the resource.
Corresponds to the JSON property etag
47789 47790 47791 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47789 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47794 47795 47796 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47794 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ReliabilityRisk>
A list of ReliabilityRisk resources.
Corresponds to the JSON property items
47799 47800 47801 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47799 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47809 47810 47811 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47809 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47814 47815 47816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47814 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
47820 47821 47822 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47820 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47825 47826 47827 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47825 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47832 47833 47834 47835 47836 47837 47838 47839 47840 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47832 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |