Class: Google::Apis::ComputeV1::ReliabilityRisksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response message for the List method of ReliabilityRisksService.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReliabilityRisksListResponse

Returns a new instance of ReliabilityRisksListResponse.



47815
47816
47817
# File 'lib/google/apis/compute_v1/classes.rb', line 47815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

[Output Only] An ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


47777
47778
47779
# File 'lib/google/apis/compute_v1/classes.rb', line 47777

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47782
47783
47784
# File 'lib/google/apis/compute_v1/classes.rb', line 47782

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReliabilityRisk>

A list of ReliabilityRisk resources. Corresponds to the JSON property items



47787
47788
47789
# File 'lib/google/apis/compute_v1/classes.rb', line 47787

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47797
47798
47799
# File 'lib/google/apis/compute_v1/classes.rb', line 47797

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47802
47803
47804
# File 'lib/google/apis/compute_v1/classes.rb', line 47802

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47808
47809
47810
# File 'lib/google/apis/compute_v1/classes.rb', line 47808

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ReliabilityRisksListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47813
47814
47815
# File 'lib/google/apis/compute_v1/classes.rb', line 47813

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47820
47821
47822
47823
47824
47825
47826
47827
47828
# File 'lib/google/apis/compute_v1/classes.rb', line 47820

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end