Class: Google::Apis::ComputeV1::Reservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a reservation resource. A reservation ensures that capacity is held in a specific zone even if the reserved VMs are not running. For more information, read Reserving zonal resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reservation

Returns a new instance of Reservation.



47398
47399
47400
# File 'lib/google/apis/compute_v1/classes.rb', line 47398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_deployment_controlGoogle::Apis::ComputeV1::ReservationAdvancedDeploymentControl

Advance control for cluster management, applicable only to DENSE deployment type reservations. Corresponds to the JSON property advancedDeploymentControl



47214
47215
47216
# File 'lib/google/apis/compute_v1/classes.rb', line 47214

def advanced_deployment_control
  @advanced_deployment_control
end

#aggregate_reservationGoogle::Apis::ComputeV1::AllocationAggregateReservation

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation. Corresponds to the JSON property aggregateReservation



47221
47222
47223
# File 'lib/google/apis/compute_v1/classes.rb', line 47221

def aggregate_reservation
  @aggregate_reservation
end

#commitmentString

Output only. [Output Only] Full or partial URL to a parent commitment. This field displays for reservations that are tied to a commitment. Corresponds to the JSON property commitment

Returns:

  • (String)


47228
47229
47230
# File 'lib/google/apis/compute_v1/classes.rb', line 47228

def commitment
  @commitment
end

#confidential_compute_typeString

Corresponds to the JSON property confidentialComputeType

Returns:

  • (String)


47233
47234
47235
# File 'lib/google/apis/compute_v1/classes.rb', line 47233

def confidential_compute_type
  @confidential_compute_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


47239
47240
47241
# File 'lib/google/apis/compute_v1/classes.rb', line 47239

def creation_timestamp
  @creation_timestamp
end

#delete_after_durationGoogle::Apis::ComputeV1::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property deleteAfterDuration



47247
47248
47249
# File 'lib/google/apis/compute_v1/classes.rb', line 47247

def delete_after_duration
  @delete_after_duration
end

#delete_at_timeString

Absolute time in future when the reservation will be auto-deleted by Compute Engine. Timestamp is represented inRFC3339 text format. Corresponds to the JSON property deleteAtTime

Returns:

  • (String)


47254
47255
47256
# File 'lib/google/apis/compute_v1/classes.rb', line 47254

def delete_at_time
  @delete_at_time
end

#deployment_typeString

Specifies the deployment strategy for this reservation. Corresponds to the JSON property deploymentType

Returns:

  • (String)


47259
47260
47261
# File 'lib/google/apis/compute_v1/classes.rb', line 47259

def deployment_type
  @deployment_type
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


47265
47266
47267
# File 'lib/google/apis/compute_v1/classes.rb', line 47265

def description
  @description
end

#early_access_maintenanceString

Indicates the early access maintenance for the reservation. If this field is absent or set to NO_EARLY_ACCESS, the reservation is not enrolled in early access maintenance and the standard notice applies. Corresponds to the JSON property earlyAccessMaintenance

Returns:

  • (String)


47272
47273
47274
# File 'lib/google/apis/compute_v1/classes.rb', line 47272

def early_access_maintenance
  @early_access_maintenance
end

#enable_emergent_maintenanceBoolean Also known as: enable_emergent_maintenance?

Indicates whether Compute Engine allows unplanned maintenance for your VMs; for example, to fix hardware errors. Corresponds to the JSON property enableEmergentMaintenance

Returns:

  • (Boolean)


47278
47279
47280
# File 'lib/google/apis/compute_v1/classes.rb', line 47278

def enable_emergent_maintenance
  @enable_emergent_maintenance
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


47286
47287
47288
# File 'lib/google/apis/compute_v1/classes.rb', line 47286

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#reservations for reservations. Corresponds to the JSON property kind

Returns:

  • (String)


47292
47293
47294
# File 'lib/google/apis/compute_v1/classes.rb', line 47292

def kind
  @kind
end

#linked_commitmentsArray<String>

Output only. [Output Only] Full or partial URL to parent commitments. This field displays for reservations that are tied to multiple commitments. Corresponds to the JSON property linkedCommitments

Returns:

  • (Array<String>)


47299
47300
47301
# File 'lib/google/apis/compute_v1/classes.rb', line 47299

def linked_commitments
  @linked_commitments
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


47311
47312
47313
# File 'lib/google/apis/compute_v1/classes.rb', line 47311

def name
  @name
end

#paramsGoogle::Apis::ComputeV1::ReservationParams

Additional reservation params. Corresponds to the JSON property params



47316
47317
47318
# File 'lib/google/apis/compute_v1/classes.rb', line 47316

def params
  @params
end

#protection_tierString

Protection tier for the workload which specifies the workload expectations in the event of infrastructure failures at data center (e.g. power and/or cooling failures). Corresponds to the JSON property protectionTier

Returns:

  • (String)


47323
47324
47325
# File 'lib/google/apis/compute_v1/classes.rb', line 47323

def protection_tier
  @protection_tier
end

#reservation_sharing_policyGoogle::Apis::ComputeV1::AllocationReservationSharingPolicy

Specify the reservation sharing policy. If unspecified, the reservation will not be shared with Google Cloud managed services. Corresponds to the JSON property reservationSharingPolicy



47329
47330
47331
# File 'lib/google/apis/compute_v1/classes.rb', line 47329

def reservation_sharing_policy
  @reservation_sharing_policy
end

#resource_policiesHash<String,String>

Resource policies to be added to this reservation. The key is defined by user, and the value is resource policy url. This is to define placement policy with reservation. Corresponds to the JSON property resourcePolicies

Returns:

  • (Hash<String,String>)


47336
47337
47338
# File 'lib/google/apis/compute_v1/classes.rb', line 47336

def resource_policies
  @resource_policies
end

#resource_statusGoogle::Apis::ComputeV1::AllocationResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property resourceStatus



47341
47342
47343
# File 'lib/google/apis/compute_v1/classes.rb', line 47341

def resource_status
  @resource_status
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


47346
47347
47348
# File 'lib/google/apis/compute_v1/classes.rb', line 47346

def satisfies_pzs
  @satisfies_pzs
end

#scheduling_typeString

The type of maintenance for the reservation. Corresponds to the JSON property schedulingType

Returns:

  • (String)


47352
47353
47354
# File 'lib/google/apis/compute_v1/classes.rb', line 47352

def scheduling_type
  @scheduling_type
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47358
47359
47360
# File 'lib/google/apis/compute_v1/classes.rb', line 47358

def self_link
  @self_link
end

#share_settingsGoogle::Apis::ComputeV1::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



47363
47364
47365
# File 'lib/google/apis/compute_v1/classes.rb', line 47363

def share_settings
  @share_settings
end

#specific_reservationGoogle::Apis::ComputeV1::AllocationSpecificSkuReservation

This reservation type allows to pre allocate specific instance configuration. Corresponds to the JSON property specificReservation



47369
47370
47371
# File 'lib/google/apis/compute_v1/classes.rb', line 47369

def specific_reservation
  @specific_reservation
end

#specific_reservation_requiredBoolean Also known as: specific_reservation_required?

Indicates whether the reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from this reservation. Corresponds to the JSON property specificReservationRequired

Returns:

  • (Boolean)


47376
47377
47378
# File 'lib/google/apis/compute_v1/classes.rb', line 47376

def specific_reservation_required
  @specific_reservation_required
end

#statusString

Output only. [Output Only] The status of the reservation.

  • CREATING: Reservation resources are being allocated.
  • READY: Reservation resources have been allocated, and the reservation is ready for use.
  • DELETING: Reservation deletion is in progress.
  • UPDATING: Reservation update is in progress. Corresponds to the JSON property status

Returns:

  • (String)


47390
47391
47392
# File 'lib/google/apis/compute_v1/classes.rb', line 47390

def status
  @status
end

#zoneString

Zone in which the reservation resides. A zone must be provided if the reservation is created within a commitment. Corresponds to the JSON property zone

Returns:

  • (String)


47396
47397
47398
# File 'lib/google/apis/compute_v1/classes.rb', line 47396

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47403
47404
47405
47406
47407
47408
47409
47410
47411
47412
47413
47414
47415
47416
47417
47418
47419
47420
47421
47422
47423
47424
47425
47426
47427
47428
47429
47430
47431
47432
# File 'lib/google/apis/compute_v1/classes.rb', line 47403

def update!(**args)
  @advanced_deployment_control = args[:advanced_deployment_control] if args.key?(:advanced_deployment_control)
  @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation)
  @commitment = args[:commitment] if args.key?(:commitment)
  @confidential_compute_type = args[:confidential_compute_type] if args.key?(:confidential_compute_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @delete_after_duration = args[:delete_after_duration] if args.key?(:delete_after_duration)
  @delete_at_time = args[:delete_at_time] if args.key?(:delete_at_time)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @early_access_maintenance = args[:early_access_maintenance] if args.key?(:early_access_maintenance)
  @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @linked_commitments = args[:linked_commitments] if args.key?(:linked_commitments)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @protection_tier = args[:protection_tier] if args.key?(:protection_tier)
  @reservation_sharing_policy = args[:reservation_sharing_policy] if args.key?(:reservation_sharing_policy)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_reservation = args[:specific_reservation] if args.key?(:specific_reservation)
  @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end