Class: Google::Apis::ComputeV1::Reservation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Reservation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reservation resource. A reservation ensures that capacity is held in a specific zone even if the reserved VMs are not running. For more information, read Reserving zonal resources.
Instance Attribute Summary collapse
-
#advanced_deployment_control ⇒ Google::Apis::ComputeV1::ReservationAdvancedDeploymentControl
Advance control for cluster management, applicable only to DENSE deployment type reservations.
-
#aggregate_reservation ⇒ Google::Apis::ComputeV1::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs.
-
#commitment ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#delete_after_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#delete_at_time ⇒ String
Absolute time in future when the reservation will be auto-deleted by Compute Engine.
-
#deployment_type ⇒ String
Specifies the deployment strategy for this reservation.
-
#description ⇒ String
An optional description of this resource.
-
#enable_emergent_maintenance ⇒ Boolean
(also: #enable_emergent_maintenance?)
Indicates whether Compute Engine allows unplanned maintenance for your VMs; for example, to fix hardware errors.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#linked_commitments ⇒ Array<String>
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#protection_tier ⇒ String
Protection tier for the workload which specifies the workload expectations in the event of infrastructure failures at data center (e.g. power and/or cooling failures).
-
#reservation_sharing_policy ⇒ Google::Apis::ComputeV1::AllocationReservationSharingPolicy
Specify the reservation sharing policy.
-
#resource_policies ⇒ Hash<String,String>
Resource policies to be added to this reservation.
-
#resource_status ⇒ Google::Apis::ComputeV1::AllocationResourceStatus
[Output Only] Contains output only fields.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#scheduling_type ⇒ String
The type of maintenance for the reservation.
-
#self_link ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#specific_reservation ⇒ Google::Apis::ComputeV1::AllocationSpecificSkuReservation
This reservation type allows to pre allocate specific instance configuration.
-
#specific_reservation_required ⇒ Boolean
(also: #specific_reservation_required?)
Indicates whether the reservation can be consumed by VMs with affinity for "any" reservation.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Zone in which the reservation resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reservation
constructor
A new instance of Reservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reservation
Returns a new instance of Reservation.
42251 42252 42253 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_deployment_control ⇒ Google::Apis::ComputeV1::ReservationAdvancedDeploymentControl
Advance control for cluster management, applicable only to DENSE deployment
type reservations.
Corresponds to the JSON property advancedDeploymentControl
42084 42085 42086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42084 def advanced_deployment_control @advanced_deployment_control end |
#aggregate_reservation ⇒ Google::Apis::ComputeV1::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total
count of CPUs) and can account for multiple instance SKUs. In other words,
one can create instances of varying shapes against this reservation.
Corresponds to the JSON property aggregateReservation
42091 42092 42093 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42091 def aggregate_reservation @aggregate_reservation end |
#commitment ⇒ String
Output only. [Output Only] Full or partial URL to a parent commitment. This
field
displays for reservations that are tied to a commitment.
Corresponds to the JSON property commitment
42098 42099 42100 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42098 def commitment @commitment end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
42104 42105 42106 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42104 def @creation_timestamp end |
#delete_after_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property deleteAfterDuration
42112 42113 42114 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42112 def delete_after_duration @delete_after_duration end |
#delete_at_time ⇒ String
Absolute time in future when the reservation will be
auto-deleted by Compute Engine. Timestamp is represented inRFC3339 text
format.
Corresponds to the JSON property deleteAtTime
42119 42120 42121 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42119 def delete_at_time @delete_at_time end |
#deployment_type ⇒ String
Specifies the deployment strategy for this reservation.
Corresponds to the JSON property deploymentType
42124 42125 42126 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42124 def deployment_type @deployment_type end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
42130 42131 42132 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42130 def description @description end |
#enable_emergent_maintenance ⇒ Boolean Also known as: enable_emergent_maintenance?
Indicates whether Compute Engine allows unplanned maintenance for your VMs;
for example, to fix hardware errors.
Corresponds to the JSON property enableEmergentMaintenance
42136 42137 42138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42136 def enable_emergent_maintenance @enable_emergent_maintenance end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
42144 42145 42146 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42144 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#reservations
for reservations.
Corresponds to the JSON property kind
42150 42151 42152 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42150 def kind @kind end |
#linked_commitments ⇒ Array<String>
Output only. [Output Only] Full or partial URL to parent commitments. This
field
displays for reservations that are tied to multiple commitments.
Corresponds to the JSON property linkedCommitments
42157 42158 42159 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42157 def linked_commitments @linked_commitments end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
42169 42170 42171 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42169 def name @name end |
#protection_tier ⇒ String
Protection tier for the workload which specifies the workload expectations
in the event of infrastructure failures at data center (e.g. power
and/or cooling failures).
Corresponds to the JSON property protectionTier
42176 42177 42178 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42176 def protection_tier @protection_tier end |
#reservation_sharing_policy ⇒ Google::Apis::ComputeV1::AllocationReservationSharingPolicy
Specify the reservation sharing policy. If unspecified, the reservation
will not be shared with Google Cloud managed services.
Corresponds to the JSON property reservationSharingPolicy
42182 42183 42184 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42182 def reservation_sharing_policy @reservation_sharing_policy end |
#resource_policies ⇒ Hash<String,String>
Resource policies to be added to this reservation. The key is defined by
user, and the value is resource policy url. This is to define placement
policy with reservation.
Corresponds to the JSON property resourcePolicies
42189 42190 42191 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42189 def resource_policies @resource_policies end |
#resource_status ⇒ Google::Apis::ComputeV1::AllocationResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property resourceStatus
42194 42195 42196 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42194 def resource_status @resource_status end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
42199 42200 42201 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42199 def satisfies_pzs @satisfies_pzs end |
#scheduling_type ⇒ String
The type of maintenance for the reservation.
Corresponds to the JSON property schedulingType
42205 42206 42207 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42205 def scheduling_type @scheduling_type end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
42211 42212 42213 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42211 def self_link @self_link end |
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
42216 42217 42218 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42216 def share_settings @share_settings end |
#specific_reservation ⇒ Google::Apis::ComputeV1::AllocationSpecificSkuReservation
This reservation type allows to pre allocate specific instance
configuration.
Corresponds to the JSON property specificReservation
42222 42223 42224 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42222 def specific_reservation @specific_reservation end |
#specific_reservation_required ⇒ Boolean Also known as: specific_reservation_required?
Indicates whether the reservation can be consumed by VMs with affinity
for "any" reservation. If the field is set, then only VMs that target
the reservation by name can consume from this reservation.
Corresponds to the JSON property specificReservationRequired
42229 42230 42231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42229 def specific_reservation_required @specific_reservation_required end |
#status ⇒ String
Output only. [Output Only] The status of the reservation.
- CREATING: Reservation resources are being allocated.
- READY: Reservation resources have been allocated, and the reservation is ready for use.
- DELETING: Reservation deletion is in progress.
- UPDATING: Reservation update is in progress.
Corresponds to the JSON property
status
42243 42244 42245 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42243 def status @status end |
#zone ⇒ String
Zone in which the reservation resides. A zone must be provided if the
reservation is created within a commitment.
Corresponds to the JSON property zone
42249 42250 42251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42249 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42256 42257 42258 42259 42260 42261 42262 42263 42264 42265 42266 42267 42268 42269 42270 42271 42272 42273 42274 42275 42276 42277 42278 42279 42280 42281 42282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42256 def update!(**args) @advanced_deployment_control = args[:advanced_deployment_control] if args.key?(:advanced_deployment_control) @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation) @commitment = args[:commitment] if args.key?(:commitment) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @delete_after_duration = args[:delete_after_duration] if args.key?(:delete_after_duration) @delete_at_time = args[:delete_at_time] if args.key?(:delete_at_time) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @description = args[:description] if args.key?(:description) @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @linked_commitments = args[:linked_commitments] if args.key?(:linked_commitments) @name = args[:name] if args.key?(:name) @protection_tier = args[:protection_tier] if args.key?(:protection_tier) @reservation_sharing_policy = args[:reservation_sharing_policy] if args.key?(:reservation_sharing_policy) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @resource_status = args[:resource_status] if args.key?(:resource_status) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type) @self_link = args[:self_link] if args.key?(:self_link) @share_settings = args[:share_settings] if args.key?(:share_settings) @specific_reservation = args[:specific_reservation] if args.key?(:specific_reservation) @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |