Class: Google::Apis::ComputeV1::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



48271
48272
48273
# File 'lib/google/apis/compute_v1/classes.rb', line 48271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48234
48235
48236
# File 'lib/google/apis/compute_v1/classes.rb', line 48234

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



48239
48240
48241
# File 'lib/google/apis/compute_v1/classes.rb', line 48239

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


48244
48245
48246
# File 'lib/google/apis/compute_v1/classes.rb', line 48244

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48254
48255
48256
# File 'lib/google/apis/compute_v1/classes.rb', line 48254

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48259
48260
48261
# File 'lib/google/apis/compute_v1/classes.rb', line 48259

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48264
48265
48266
# File 'lib/google/apis/compute_v1/classes.rb', line 48264

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48269
48270
48271
# File 'lib/google/apis/compute_v1/classes.rb', line 48269

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48276
48277
48278
48279
48280
48281
48282
48283
48284
# File 'lib/google/apis/compute_v1/classes.rb', line 48276

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end