Class: Google::Apis::ComputeV1::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



47715
47716
47717
# File 'lib/google/apis/compute_v1/classes.rb', line 47715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47678
47679
47680
# File 'lib/google/apis/compute_v1/classes.rb', line 47678

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



47683
47684
47685
# File 'lib/google/apis/compute_v1/classes.rb', line 47683

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


47688
47689
47690
# File 'lib/google/apis/compute_v1/classes.rb', line 47688

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47698
47699
47700
# File 'lib/google/apis/compute_v1/classes.rb', line 47698

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47703
47704
47705
# File 'lib/google/apis/compute_v1/classes.rb', line 47703

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47708
47709
47710
# File 'lib/google/apis/compute_v1/classes.rb', line 47708

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47713
47714
47715
# File 'lib/google/apis/compute_v1/classes.rb', line 47713

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47720
47721
47722
47723
47724
47725
47726
47727
47728
# File 'lib/google/apis/compute_v1/classes.rb', line 47720

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end