Class: Google::Apis::ComputeV1::ReservationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ReservationsScopedList>
A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationAggregatedList
constructor
A new instance of ReservationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationAggregatedList
Returns a new instance of ReservationAggregatedList.
47715 47716 47717 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47678 47679 47680 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47678 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ReservationsScopedList>
A list of Allocation resources.
Corresponds to the JSON property items
47683 47684 47685 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47683 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
47688 47689 47690 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47688 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47698 47699 47700 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47698 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47703 47704 47705 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47703 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
47708 47709 47710 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47708 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47713 47714 47715 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47713 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47720 47721 47722 47723 47724 47725 47726 47727 47728 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47720 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |