Class: Google::Apis::ComputeV1::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



47703
47704
47705
# File 'lib/google/apis/compute_v1/classes.rb', line 47703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47666
47667
47668
# File 'lib/google/apis/compute_v1/classes.rb', line 47666

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



47671
47672
47673
# File 'lib/google/apis/compute_v1/classes.rb', line 47671

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


47676
47677
47678
# File 'lib/google/apis/compute_v1/classes.rb', line 47676

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47686
47687
47688
# File 'lib/google/apis/compute_v1/classes.rb', line 47686

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47691
47692
47693
# File 'lib/google/apis/compute_v1/classes.rb', line 47691

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47696
47697
47698
# File 'lib/google/apis/compute_v1/classes.rb', line 47696

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47701
47702
47703
# File 'lib/google/apis/compute_v1/classes.rb', line 47701

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47708
47709
47710
47711
47712
47713
47714
47715
47716
# File 'lib/google/apis/compute_v1/classes.rb', line 47708

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end