Class: Google::Apis::ComputeV1::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



46652
46653
46654
# File 'lib/google/apis/compute_v1/classes.rb', line 46652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46615
46616
46617
# File 'lib/google/apis/compute_v1/classes.rb', line 46615

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



46620
46621
46622
# File 'lib/google/apis/compute_v1/classes.rb', line 46620

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


46625
46626
46627
# File 'lib/google/apis/compute_v1/classes.rb', line 46625

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46635
46636
46637
# File 'lib/google/apis/compute_v1/classes.rb', line 46635

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46640
46641
46642
# File 'lib/google/apis/compute_v1/classes.rb', line 46640

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46645
46646
46647
# File 'lib/google/apis/compute_v1/classes.rb', line 46645

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46650
46651
46652
# File 'lib/google/apis/compute_v1/classes.rb', line 46650

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46657
46658
46659
46660
46661
46662
46663
46664
46665
# File 'lib/google/apis/compute_v1/classes.rb', line 46657

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end