Class: Google::Apis::ComputeV1::ReservationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ReservationsScopedList>
A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationAggregatedList
constructor
A new instance of ReservationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationAggregatedList
Returns a new instance of ReservationAggregatedList.
43240 43241 43242 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43240 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43203 43204 43205 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43203 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ReservationsScopedList>
A list of Allocation resources.
Corresponds to the JSON property items
43208 43209 43210 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43208 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
43213 43214 43215 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43213 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43223 43224 43225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43223 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43228 43229 43230 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43228 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
43233 43234 43235 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43233 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43238 43239 43240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43238 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43245 43246 43247 43248 43249 43250 43251 43252 43253 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43245 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |