Class: Google::Apis::ComputeV1::ReservationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ReservationsScopedList>
A list of Allocation resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationAggregatedList
constructor
A new instance of ReservationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationAggregatedList
Returns a new instance of ReservationAggregatedList.
27190 27191 27192 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27190 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
27154 27155 27156 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27154 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ReservationsScopedList>
A list of Allocation resources.
Corresponds to the JSON property items
27159 27160 27161 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27159 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
27164 27165 27166 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27164 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
27173 27174 27175 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27173 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
27178 27179 27180 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27178 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
27183 27184 27185 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27183 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
27188 27189 27190 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27188 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27195 27196 27197 27198 27199 27200 27201 27202 27203 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27195 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |