Class: Google::Apis::ComputeV1::ReservationBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reservation block resource.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeV1::ReservationBlockHealthInfo
Health information for the reservation block.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationBlockPhysicalTopology
Output only.
-
#reservation_maintenance ⇒ Google::Apis::ComputeV1::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#reservation_sub_block_count ⇒ Fixnum
Output only.
-
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlock
constructor
A new instance of ReservationBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlock
Returns a new instance of ReservationBlock.
48459 48460 48461 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. [Output Only] The number of resources that are allocated in this
reservation block.
Corresponds to the JSON property count
48365 48366 48367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48365 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
48370 48371 48372 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48370 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeV1::ReservationBlockHealthInfo
Health information for the reservation block.
Corresponds to the JSON property healthInfo
48375 48376 48377 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48375 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
48382 48383 48384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48382 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation block.
Corresponds to the JSON property inUseCount
48389 48390 48391 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48389 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
48396 48397 48398 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48396 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationBlock for reservation blocks.
Corresponds to the JSON property kind
48402 48403 48404 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48402 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation block generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
48410 48411 48412 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48410 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation block.
Corresponds to the JSON property physicalTopology
48415 48416 48417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48415 def physical_topology @physical_topology end |
#reservation_maintenance ⇒ Google::Apis::ComputeV1::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
48420 48421 48422 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48420 def reservation_maintenance @reservation_maintenance end |
#reservation_sub_block_count ⇒ Fixnum
Output only. [Output Only] The number of reservation subBlocks associated with
this
reservation block.
Corresponds to the JSON property reservationSubBlockCount
48427 48428 48429 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48427 def reservation_sub_block_count @reservation_sub_block_count end |
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only. [Output Only] The number of in-use reservation subBlocks
associated with
this reservation block. If at least one VM is running on a subBlock, it is
considered in-use.
Corresponds to the JSON property reservationSubBlockInUseCount
48435 48436 48437 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48435 def reservation_sub_block_in_use_count @reservation_sub_block_in_use_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
48441 48442 48443 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48441 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
48447 48448 48449 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48447 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation block.
Corresponds to the JSON property status
48452 48453 48454 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48452 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation block resides.
Corresponds to the JSON property zone
48457 48458 48459 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48457 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48464 48465 48466 48467 48468 48469 48470 48471 48472 48473 48474 48475 48476 48477 48478 48479 48480 48481 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48464 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count) @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |