Class: Google::Apis::ComputeV1::ReservationBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reservation block resource.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeV1::ReservationBlockHealthInfo
Health information for the reservation block.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationBlockPhysicalTopology
Output only.
-
#reservation_maintenance ⇒ Google::Apis::ComputeV1::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#reservation_sub_block_count ⇒ Fixnum
Output only.
-
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlock
constructor
A new instance of ReservationBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlock
Returns a new instance of ReservationBlock.
47891 47892 47893 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. [Output Only] The number of resources that are allocated in this
reservation block.
Corresponds to the JSON property count
47797 47798 47799 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47797 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
47802 47803 47804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47802 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeV1::ReservationBlockHealthInfo
Health information for the reservation block.
Corresponds to the JSON property healthInfo
47807 47808 47809 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47807 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
47814 47815 47816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47814 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation block.
Corresponds to the JSON property inUseCount
47821 47822 47823 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47821 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
47828 47829 47830 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47828 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationBlock for reservation blocks.
Corresponds to the JSON property kind
47834 47835 47836 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47834 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation block generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
47842 47843 47844 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47842 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation block.
Corresponds to the JSON property physicalTopology
47847 47848 47849 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47847 def physical_topology @physical_topology end |
#reservation_maintenance ⇒ Google::Apis::ComputeV1::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
47852 47853 47854 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47852 def reservation_maintenance @reservation_maintenance end |
#reservation_sub_block_count ⇒ Fixnum
Output only. [Output Only] The number of reservation subBlocks associated with
this
reservation block.
Corresponds to the JSON property reservationSubBlockCount
47859 47860 47861 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47859 def reservation_sub_block_count @reservation_sub_block_count end |
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only. [Output Only] The number of in-use reservation subBlocks
associated with
this reservation block. If at least one VM is running on a subBlock, it is
considered in-use.
Corresponds to the JSON property reservationSubBlockInUseCount
47867 47868 47869 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47867 def reservation_sub_block_in_use_count @reservation_sub_block_in_use_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
47873 47874 47875 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47873 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
47879 47880 47881 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47879 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation block.
Corresponds to the JSON property status
47884 47885 47886 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47884 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation block resides.
Corresponds to the JSON property zone
47889 47890 47891 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47889 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47896 47897 47898 47899 47900 47901 47902 47903 47904 47905 47906 47907 47908 47909 47910 47911 47912 47913 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47896 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count) @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |