Class: Google::Apis::ComputeV1::ReservationBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a reservation block resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlock

Returns a new instance of ReservationBlock.



47726
47727
47728
# File 'lib/google/apis/compute_v1/classes.rb', line 47726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#block_health_infoGoogle::Apis::ComputeV1::ReservationBlockHealthInfo

Health information for the reservation block. Corresponds to the JSON property blockHealthInfo



47631
47632
47633
# File 'lib/google/apis/compute_v1/classes.rb', line 47631

def block_health_info
  @block_health_info
end

#countFixnum

Output only. [Output Only] The number of resources that are allocated in this reservation block. Corresponds to the JSON property count

Returns:

  • (Fixnum)


47637
47638
47639
# File 'lib/google/apis/compute_v1/classes.rb', line 47637

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


47642
47643
47644
# File 'lib/google/apis/compute_v1/classes.rb', line 47642

def creation_timestamp
  @creation_timestamp
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


47649
47650
47651
# File 'lib/google/apis/compute_v1/classes.rb', line 47649

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation block. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


47656
47657
47658
# File 'lib/google/apis/compute_v1/classes.rb', line 47656

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


47663
47664
47665
# File 'lib/google/apis/compute_v1/classes.rb', line 47663

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationBlock for reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


47669
47670
47671
# File 'lib/google/apis/compute_v1/classes.rb', line 47669

def kind
  @kind
end

#nameString

Output only. [Output Only] The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


47677
47678
47679
# File 'lib/google/apis/compute_v1/classes.rb', line 47677

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeV1::ReservationBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation block. Corresponds to the JSON property physicalTopology



47682
47683
47684
# File 'lib/google/apis/compute_v1/classes.rb', line 47682

def physical_topology
  @physical_topology
end

#reservation_maintenanceGoogle::Apis::ComputeV1::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationMaintenance



47687
47688
47689
# File 'lib/google/apis/compute_v1/classes.rb', line 47687

def reservation_maintenance
  @reservation_maintenance
end

#reservation_sub_block_countFixnum

Output only. [Output Only] The number of reservation subBlocks associated with this reservation block. Corresponds to the JSON property reservationSubBlockCount

Returns:

  • (Fixnum)


47694
47695
47696
# File 'lib/google/apis/compute_v1/classes.rb', line 47694

def reservation_sub_block_count
  @reservation_sub_block_count
end

#reservation_sub_block_in_use_countFixnum

Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use. Corresponds to the JSON property reservationSubBlockInUseCount

Returns:

  • (Fixnum)


47702
47703
47704
# File 'lib/google/apis/compute_v1/classes.rb', line 47702

def reservation_sub_block_in_use_count
  @reservation_sub_block_in_use_count
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47708
47709
47710
# File 'lib/google/apis/compute_v1/classes.rb', line 47708

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


47714
47715
47716
# File 'lib/google/apis/compute_v1/classes.rb', line 47714

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation block. Corresponds to the JSON property status

Returns:

  • (String)


47719
47720
47721
# File 'lib/google/apis/compute_v1/classes.rb', line 47719

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation block resides. Corresponds to the JSON property zone

Returns:

  • (String)


47724
47725
47726
# File 'lib/google/apis/compute_v1/classes.rb', line 47724

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47731
47732
47733
47734
47735
47736
47737
47738
47739
47740
47741
47742
47743
47744
47745
47746
47747
47748
# File 'lib/google/apis/compute_v1/classes.rb', line 47731

def update!(**args)
  @block_health_info = args[:block_health_info] if args.key?(:block_health_info)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance)
  @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count)
  @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end