Class: Google::Apis::ComputeV1::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



47801
47802
47803
# File 'lib/google/apis/compute_v1/classes.rb', line 47801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


47789
47790
47791
# File 'lib/google/apis/compute_v1/classes.rb', line 47789

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


47794
47795
47796
# File 'lib/google/apis/compute_v1/classes.rb', line 47794

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeV1::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



47799
47800
47801
# File 'lib/google/apis/compute_v1/classes.rb', line 47799

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47806
47807
47808
47809
47810
# File 'lib/google/apis/compute_v1/classes.rb', line 47806

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end