Class: Google::Apis::ComputeV1::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



47525
47526
47527
# File 'lib/google/apis/compute_v1/classes.rb', line 47525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


47513
47514
47515
# File 'lib/google/apis/compute_v1/classes.rb', line 47513

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


47518
47519
47520
# File 'lib/google/apis/compute_v1/classes.rb', line 47518

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeV1::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



47523
47524
47525
# File 'lib/google/apis/compute_v1/classes.rb', line 47523

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47530
47531
47532
47533
47534
# File 'lib/google/apis/compute_v1/classes.rb', line 47530

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end