Class: Google::Apis::ComputeV1::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



46915
46916
46917
# File 'lib/google/apis/compute_v1/classes.rb', line 46915

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


46903
46904
46905
# File 'lib/google/apis/compute_v1/classes.rb', line 46903

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


46908
46909
46910
# File 'lib/google/apis/compute_v1/classes.rb', line 46908

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeV1::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



46913
46914
46915
# File 'lib/google/apis/compute_v1/classes.rb', line 46913

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46920
46921
46922
46923
46924
# File 'lib/google/apis/compute_v1/classes.rb', line 46920

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end