Class: Google::Apis::ComputeV1::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



42652
42653
42654
# File 'lib/google/apis/compute_v1/classes.rb', line 42652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


42640
42641
42642
# File 'lib/google/apis/compute_v1/classes.rb', line 42640

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


42645
42646
42647
# File 'lib/google/apis/compute_v1/classes.rb', line 42645

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeV1::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



42650
42651
42652
# File 'lib/google/apis/compute_v1/classes.rb', line 42650

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42657
42658
42659
42660
42661
# File 'lib/google/apis/compute_v1/classes.rb', line 42657

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end