Class: Google::Apis::ComputeV1::ReservationBlockPhysicalTopologyInstancePhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The PhysicalHostTopology of the instance within a Block resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopologyInstancePhysicalHostTopology

Returns a new instance of ReservationBlockPhysicalTopologyInstancePhysicalHostTopology.



48023
48024
48025
# File 'lib/google/apis/compute_v1/classes.rb', line 48023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Host hash for a given instance Corresponds to the JSON property host

Returns:

  • (String)


48016
48017
48018
# File 'lib/google/apis/compute_v1/classes.rb', line 48016

def host
  @host
end

#sub_blockString

Sub block hash for a given instance Corresponds to the JSON property subBlock

Returns:

  • (String)


48021
48022
48023
# File 'lib/google/apis/compute_v1/classes.rb', line 48021

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48028
48029
48030
48031
# File 'lib/google/apis/compute_v1/classes.rb', line 48028

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end