Class: Google::Apis::ComputeV1::ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The PhysicalHostTopology of the instance within a Block resource.
Instance Attribute Summary collapse
-
#host ⇒ String
Host hash for a given instance Corresponds to the JSON property
host. -
#sub_block ⇒ String
Sub block hash for a given instance Corresponds to the JSON property
subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
constructor
A new instance of ReservationBlockPhysicalTopologyInstancePhysicalHostTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlockPhysicalTopologyInstancePhysicalHostTopology
Returns a new instance of ReservationBlockPhysicalTopologyInstancePhysicalHostTopology.
47568 47569 47570 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47568 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Host hash for a given instance
Corresponds to the JSON property host
47561 47562 47563 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47561 def host @host end |
#sub_block ⇒ String
Sub block hash for a given instance
Corresponds to the JSON property subBlock
47566 47567 47568 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47566 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47573 47574 47575 47576 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47573 def update!(**args) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |