Class: Google::Apis::ComputeV1::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



48105
48106
48107
# File 'lib/google/apis/compute_v1/classes.rb', line 48105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48072
48073
48074
# File 'lib/google/apis/compute_v1/classes.rb', line 48072

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



48077
48078
48079
# File 'lib/google/apis/compute_v1/classes.rb', line 48077

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


48083
48084
48085
# File 'lib/google/apis/compute_v1/classes.rb', line 48083

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48093
48094
48095
# File 'lib/google/apis/compute_v1/classes.rb', line 48093

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48098
48099
48100
# File 'lib/google/apis/compute_v1/classes.rb', line 48098

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



48103
48104
48105
# File 'lib/google/apis/compute_v1/classes.rb', line 48103

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48110
48111
48112
48113
48114
48115
48116
48117
# File 'lib/google/apis/compute_v1/classes.rb', line 48110

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end