Class: Google::Apis::ComputeV1::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



47928
47929
47930
# File 'lib/google/apis/compute_v1/classes.rb', line 47928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47895
47896
47897
# File 'lib/google/apis/compute_v1/classes.rb', line 47895

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



47900
47901
47902
# File 'lib/google/apis/compute_v1/classes.rb', line 47900

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


47906
47907
47908
# File 'lib/google/apis/compute_v1/classes.rb', line 47906

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47916
47917
47918
# File 'lib/google/apis/compute_v1/classes.rb', line 47916

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47921
47922
47923
# File 'lib/google/apis/compute_v1/classes.rb', line 47921

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



47926
47927
47928
# File 'lib/google/apis/compute_v1/classes.rb', line 47926

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47933
47934
47935
47936
47937
47938
47939
47940
# File 'lib/google/apis/compute_v1/classes.rb', line 47933

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end