Class: Google::Apis::ComputeV1::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



47638
47639
47640
# File 'lib/google/apis/compute_v1/classes.rb', line 47638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47605
47606
47607
# File 'lib/google/apis/compute_v1/classes.rb', line 47605

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



47610
47611
47612
# File 'lib/google/apis/compute_v1/classes.rb', line 47610

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


47616
47617
47618
# File 'lib/google/apis/compute_v1/classes.rb', line 47616

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47626
47627
47628
# File 'lib/google/apis/compute_v1/classes.rb', line 47626

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47631
47632
47633
# File 'lib/google/apis/compute_v1/classes.rb', line 47631

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



47636
47637
47638
# File 'lib/google/apis/compute_v1/classes.rb', line 47636

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47643
47644
47645
47646
47647
47648
47649
47650
# File 'lib/google/apis/compute_v1/classes.rb', line 47643

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end