Class: Google::Apis::ComputeV1::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



42779
42780
42781
# File 'lib/google/apis/compute_v1/classes.rb', line 42779

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42746
42747
42748
# File 'lib/google/apis/compute_v1/classes.rb', line 42746

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



42751
42752
42753
# File 'lib/google/apis/compute_v1/classes.rb', line 42751

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


42757
42758
42759
# File 'lib/google/apis/compute_v1/classes.rb', line 42757

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42767
42768
42769
# File 'lib/google/apis/compute_v1/classes.rb', line 42767

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42772
42773
42774
# File 'lib/google/apis/compute_v1/classes.rb', line 42772

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



42777
42778
42779
# File 'lib/google/apis/compute_v1/classes.rb', line 42777

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42784
42785
42786
42787
42788
42789
42790
42791
# File 'lib/google/apis/compute_v1/classes.rb', line 42784

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end