Class: Google::Apis::ComputeV1::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
48231 48232 48233 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
48198 48199 48200 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48198 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
48203 48204 48205 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48203 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
48209 48210 48211 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48209 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48219 48220 48221 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48219 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48224 48225 48226 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48224 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
48229 48230 48231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48229 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48236 48237 48238 48239 48240 48241 48242 48243 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48236 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |