Class: Google::Apis::ComputeV1::ReservationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationList

Returns a new instance of ReservationList.



48219
48220
48221
# File 'lib/google/apis/compute_v1/classes.rb', line 48219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48186
48187
48188
# File 'lib/google/apis/compute_v1/classes.rb', line 48186

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Reservation>

[Output Only] A list of Allocation resources. Corresponds to the JSON property items



48191
48192
48193
# File 'lib/google/apis/compute_v1/classes.rb', line 48191

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#reservationsList for listsof reservations Corresponds to the JSON property kind

Returns:

  • (String)


48197
48198
48199
# File 'lib/google/apis/compute_v1/classes.rb', line 48197

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48207
48208
48209
# File 'lib/google/apis/compute_v1/classes.rb', line 48207

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48212
48213
48214
# File 'lib/google/apis/compute_v1/classes.rb', line 48212

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48217
48218
48219
# File 'lib/google/apis/compute_v1/classes.rb', line 48217

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48224
48225
48226
48227
48228
48229
48230
48231
# File 'lib/google/apis/compute_v1/classes.rb', line 48224

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end