Class: Google::Apis::ComputeV1::ReservationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationList

Returns a new instance of ReservationList.



48054
48055
48056
# File 'lib/google/apis/compute_v1/classes.rb', line 48054

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48021
48022
48023
# File 'lib/google/apis/compute_v1/classes.rb', line 48021

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Reservation>

[Output Only] A list of Allocation resources. Corresponds to the JSON property items



48026
48027
48028
# File 'lib/google/apis/compute_v1/classes.rb', line 48026

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#reservationsList for listsof reservations Corresponds to the JSON property kind

Returns:

  • (String)


48032
48033
48034
# File 'lib/google/apis/compute_v1/classes.rb', line 48032

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48042
48043
48044
# File 'lib/google/apis/compute_v1/classes.rb', line 48042

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48047
48048
48049
# File 'lib/google/apis/compute_v1/classes.rb', line 48047

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48052
48053
48054
# File 'lib/google/apis/compute_v1/classes.rb', line 48052

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48059
48060
48061
48062
48063
48064
48065
48066
# File 'lib/google/apis/compute_v1/classes.rb', line 48059

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end