Class: Google::Apis::ComputeV1::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
47778 47779 47780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
47745 47746 47747 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47745 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
47750 47751 47752 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47750 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
47756 47757 47758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47756 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47766 47767 47768 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47766 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47771 47772 47773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47771 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47776 47777 47778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47776 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47783 47784 47785 47786 47787 47788 47789 47790 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47783 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |