Class: Google::Apis::ComputeV1::ReservationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationList

Returns a new instance of ReservationList.



47764
47765
47766
# File 'lib/google/apis/compute_v1/classes.rb', line 47764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47731
47732
47733
# File 'lib/google/apis/compute_v1/classes.rb', line 47731

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Reservation>

[Output Only] A list of Allocation resources. Corresponds to the JSON property items



47736
47737
47738
# File 'lib/google/apis/compute_v1/classes.rb', line 47736

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#reservationsList for listsof reservations Corresponds to the JSON property kind

Returns:

  • (String)


47742
47743
47744
# File 'lib/google/apis/compute_v1/classes.rb', line 47742

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47752
47753
47754
# File 'lib/google/apis/compute_v1/classes.rb', line 47752

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47757
47758
47759
# File 'lib/google/apis/compute_v1/classes.rb', line 47757

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47762
47763
47764
# File 'lib/google/apis/compute_v1/classes.rb', line 47762

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47769
47770
47771
47772
47773
47774
47775
47776
# File 'lib/google/apis/compute_v1/classes.rb', line 47769

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end