Class: Google::Apis::ComputeV1::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
47168 47169 47170 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
47135 47136 47137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47135 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
47140 47141 47142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47140 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
47146 47147 47148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47146 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47156 47157 47158 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47156 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47161 47162 47163 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47161 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47166 47167 47168 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47166 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47173 47174 47175 47176 47177 47178 47179 47180 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47173 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |