Class: Google::Apis::ComputeV1::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
43756 43757 43758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
43723 43724 43725 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43723 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
43728 43729 43730 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43728 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
43734 43735 43736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43734 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43744 43745 43746 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43744 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43749 43750 43751 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43749 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43754 43755 43756 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43754 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43761 43762 43763 43764 43765 43766 43767 43768 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43761 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |