Class: Google::Apis::ComputeV1::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
42905 42906 42907 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42905 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
42872 42873 42874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42872 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
42877 42878 42879 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42877 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
42883 42884 42885 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42883 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42893 42894 42895 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42893 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42898 42899 42900 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42898 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
42903 42904 42905 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42903 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42910 42911 42912 42913 42914 42915 42916 42917 |
# File 'lib/google/apis/compute_v1/classes.rb', line 42910 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |