Class: Google::Apis::ComputeV1::ReservationParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Additional reservation params.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationParams

Returns a new instance of ReservationParams.



47878
47879
47880
# File 'lib/google/apis/compute_v1/classes.rb', line 47878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the reservation. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


47876
47877
47878
# File 'lib/google/apis/compute_v1/classes.rb', line 47876

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47883
47884
47885
# File 'lib/google/apis/compute_v1/classes.rb', line 47883

def update!(**args)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end