Class: Google::Apis::ComputeV1::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeV1::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
47342 47343 47344 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
47285 47286 47287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47285 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
47292 47293 47294 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47292 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
47298 47299 47300 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47298 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
47303 47304 47305 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47303 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
47308 47309 47310 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47308 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
47314 47315 47316 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47314 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
47320 47321 47322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47320 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
47325 47326 47327 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47325 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
47330 47331 47332 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47330 def state @state end |
#status ⇒ Google::Apis::ComputeV1::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
47335 47336 47337 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47335 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
47340 47341 47342 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47340 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47347 47348 47349 47350 47351 47352 47353 47354 47355 47356 47357 47358 47359 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47347 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |