Class: Google::Apis::ComputeV1::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeV1::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
43930 43931 43932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43930 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
43873 43874 43875 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43873 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
43880 43881 43882 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43880 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
43886 43887 43888 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43886 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
43891 43892 43893 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43891 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
43896 43897 43898 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43896 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
43902 43903 43904 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43902 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
43908 43909 43910 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43908 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeV1::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
43913 43914 43915 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43913 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
43918 43919 43920 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43918 def state @state end |
#status ⇒ Google::Apis::ComputeV1::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
43923 43924 43925 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43923 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
43928 43929 43930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43928 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43935 43936 43937 43938 43939 43940 43941 43942 43943 43944 43945 43946 43947 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43935 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |