Class: Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The unique identifier of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation sub-block.
-
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
-
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
constructor
A new instance of ReservationSlotPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
Returns a new instance of ReservationSlotPhysicalTopology.
49006 49007 49008 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The unique identifier of the capacity block within the cluster.
Corresponds to the JSON property block
48988 48989 48990 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48988 def block @block end |
#cluster ⇒ String
The cluster name of the reservation sub-block.
Corresponds to the JSON property cluster
48993 48994 48995 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48993 def cluster @cluster end |
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
Corresponds to the JSON property host
48998 48999 49000 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48998 def host @host end |
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity
block.
Corresponds to the JSON property subBlock
49004 49005 49006 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49004 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49011 49012 49013 49014 49015 49016 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49011 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |