Class: Google::Apis::ComputeV1::ReservationSlotPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotPhysicalTopology

Returns a new instance of ReservationSlotPhysicalTopology.



48438
48439
48440
# File 'lib/google/apis/compute_v1/classes.rb', line 48438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The unique identifier of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


48420
48421
48422
# File 'lib/google/apis/compute_v1/classes.rb', line 48420

def block
  @block
end

#clusterString

The cluster name of the reservation sub-block. Corresponds to the JSON property cluster

Returns:

  • (String)


48425
48426
48427
# File 'lib/google/apis/compute_v1/classes.rb', line 48425

def cluster
  @cluster
end

#hostString

The unique identifier of the capacity host within the capacity sub-block. Corresponds to the JSON property host

Returns:

  • (String)


48430
48431
48432
# File 'lib/google/apis/compute_v1/classes.rb', line 48430

def host
  @host
end

#sub_blockString

The unique identifier of the capacity sub-block within the capacity block. Corresponds to the JSON property subBlock

Returns:

  • (String)


48436
48437
48438
# File 'lib/google/apis/compute_v1/classes.rb', line 48436

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48443
48444
48445
48446
48447
48448
# File 'lib/google/apis/compute_v1/classes.rb', line 48443

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end