Class: Google::Apis::ComputeV1::ReservationSlotPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotPhysicalTopology

Returns a new instance of ReservationSlotPhysicalTopology.



47983
47984
47985
# File 'lib/google/apis/compute_v1/classes.rb', line 47983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The unique identifier of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


47965
47966
47967
# File 'lib/google/apis/compute_v1/classes.rb', line 47965

def block
  @block
end

#clusterString

The cluster name of the reservation sub-block. Corresponds to the JSON property cluster

Returns:

  • (String)


47970
47971
47972
# File 'lib/google/apis/compute_v1/classes.rb', line 47970

def cluster
  @cluster
end

#hostString

The unique identifier of the capacity host within the capacity sub-block. Corresponds to the JSON property host

Returns:

  • (String)


47975
47976
47977
# File 'lib/google/apis/compute_v1/classes.rb', line 47975

def host
  @host
end

#sub_blockString

The unique identifier of the capacity sub-block within the capacity block. Corresponds to the JSON property subBlock

Returns:

  • (String)


47981
47982
47983
# File 'lib/google/apis/compute_v1/classes.rb', line 47981

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47988
47989
47990
47991
47992
47993
# File 'lib/google/apis/compute_v1/classes.rb', line 47988

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end