Class: Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSlotPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The unique identifier of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation sub-block.
-
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
-
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
constructor
A new instance of ReservationSlotPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
Returns a new instance of ReservationSlotPhysicalTopology.
43975 43976 43977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43975 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The unique identifier of the capacity block within the cluster.
Corresponds to the JSON property block
43957 43958 43959 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43957 def block @block end |
#cluster ⇒ String
The cluster name of the reservation sub-block.
Corresponds to the JSON property cluster
43962 43963 43964 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43962 def cluster @cluster end |
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
Corresponds to the JSON property host
43967 43968 43969 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43967 def host @host end |
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity
block.
Corresponds to the JSON property subBlock
43973 43974 43975 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43973 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43980 43981 43982 43983 43984 43985 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43980 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |