Class: Google::Apis::ComputeV1::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation slots within a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotsListResponse

Returns a new instance of ReservationSlotsListResponse.



49128
49129
49130
# File 'lib/google/apis/compute_v1/classes.rb', line 49128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49095
49096
49097
# File 'lib/google/apis/compute_v1/classes.rb', line 49095

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationSlot>

A list of reservation slot resources. Corresponds to the JSON property items



49100
49101
49102
# File 'lib/google/apis/compute_v1/classes.rb', line 49100

def items
  @items
end

#kindString

The type of resource. Alwayscompute#reservationSlot for a list of reservation slots. Corresponds to the JSON property kind

Returns:

  • (String)


49106
49107
49108
# File 'lib/google/apis/compute_v1/classes.rb', line 49106

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49116
49117
49118
# File 'lib/google/apis/compute_v1/classes.rb', line 49116

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49121
49122
49123
# File 'lib/google/apis/compute_v1/classes.rb', line 49121

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationSlotsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



49126
49127
49128
# File 'lib/google/apis/compute_v1/classes.rb', line 49126

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49133
49134
49135
49136
49137
49138
49139
49140
# File 'lib/google/apis/compute_v1/classes.rb', line 49133

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end