Class: Google::Apis::ComputeV1::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation slots within a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotsListResponse

Returns a new instance of ReservationSlotsListResponse.



48572
48573
48574
# File 'lib/google/apis/compute_v1/classes.rb', line 48572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48539
48540
48541
# File 'lib/google/apis/compute_v1/classes.rb', line 48539

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationSlot>

A list of reservation slot resources. Corresponds to the JSON property items



48544
48545
48546
# File 'lib/google/apis/compute_v1/classes.rb', line 48544

def items
  @items
end

#kindString

The type of resource. Alwayscompute#reservationSlot for a list of reservation slots. Corresponds to the JSON property kind

Returns:

  • (String)


48550
48551
48552
# File 'lib/google/apis/compute_v1/classes.rb', line 48550

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48560
48561
48562
# File 'lib/google/apis/compute_v1/classes.rb', line 48560

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48565
48566
48567
# File 'lib/google/apis/compute_v1/classes.rb', line 48565

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationSlotsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



48570
48571
48572
# File 'lib/google/apis/compute_v1/classes.rb', line 48570

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48577
48578
48579
48580
48581
48582
48583
48584
# File 'lib/google/apis/compute_v1/classes.rb', line 48577

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end