Class: Google::Apis::ComputeV1::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
48395 48396 48397 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
48362 48363 48364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48362 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
48367 48368 48369 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48367 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
48373 48374 48375 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48373 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48383 48384 48385 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48383 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
48388 48389 48390 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48388 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
48393 48394 48395 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48393 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48400 48401 48402 48403 48404 48405 48406 48407 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48400 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |