Class: Google::Apis::ComputeV1::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
47509 47510 47511 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47476 47477 47478 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47476 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
47481 47482 47483 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47481 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
47487 47488 47489 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47487 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47497 47498 47499 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47497 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
47502 47503 47504 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47502 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
47507 47508 47509 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47507 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47514 47515 47516 47517 47518 47519 47520 47521 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47514 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |