Class: Google::Apis::ComputeV1::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
44078 44079 44080 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
44045 44046 44047 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44045 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
44050 44051 44052 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44050 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
44056 44057 44058 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44056 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
44066 44067 44068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44066 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
44071 44072 44073 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44071 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
44076 44077 44078 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44076 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44083 44084 44085 44086 44087 44088 44089 44090 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44083 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |