Class: Google::Apis::ComputeV1::ReservationSubBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSubBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a reservation subBlock resource.
Instance Attribute Summary collapse
-
#accelerator_topologies_info ⇒ Google::Apis::ComputeV1::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeV1::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationSubBlockPhysicalTopology
Output only.
-
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeV1::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlock
constructor
A new instance of ReservationSubBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlock
Returns a new instance of ReservationSubBlock.
48572 48573 48574 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topologies_info ⇒ Google::Apis::ComputeV1::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
Corresponds to the JSON property acceleratorTopologiesInfo
48487 48488 48489 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48487 def accelerator_topologies_info @accelerator_topologies_info end |
#count ⇒ Fixnum
Output only. [Output Only] The number of hosts that are allocated in this
reservation subBlock.
Corresponds to the JSON property count
48493 48494 48495 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48493 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
48498 48499 48500 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48498 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeV1::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
Corresponds to the JSON property healthInfo
48503 48504 48505 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48503 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
48510 48511 48512 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48510 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation subBlock.
Corresponds to the JSON property inUseCount
48517 48518 48519 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48517 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
48524 48525 48526 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48524 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationSubBlock for reservation subBlocks.
Corresponds to the JSON property kind
48530 48531 48532 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48530 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation subBlock generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
48538 48539 48540 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48538 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeV1::ReservationSubBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation subBlock.
Corresponds to the JSON property physicalTopology
48543 48544 48545 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48543 def physical_topology @physical_topology end |
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeV1::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationSubBlockMaintenance
48548 48549 48550 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48548 def reservation_sub_block_maintenance @reservation_sub_block_maintenance end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
48554 48555 48556 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48554 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
48560 48561 48562 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48560 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation subBlock.
Corresponds to the JSON property status
48565 48566 48567 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48565 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation subBlock resides.
Corresponds to the JSON property zone
48570 48571 48572 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48570 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48577 48578 48579 48580 48581 48582 48583 48584 48585 48586 48587 48588 48589 48590 48591 48592 48593 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48577 def update!(**args) @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |