Class: Google::Apis::ComputeV1::ReservationSubBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a reservation subBlock resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlock

Returns a new instance of ReservationSubBlock.



43082
43083
43084
# File 'lib/google/apis/compute_v1/classes.rb', line 43082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologies_infoGoogle::Apis::ComputeV1::AcceleratorTopologiesInfo

Info for accelerator topologies within a densely packed reservation. Corresponds to the JSON property acceleratorTopologiesInfo



42997
42998
42999
# File 'lib/google/apis/compute_v1/classes.rb', line 42997

def accelerator_topologies_info
  @accelerator_topologies_info
end

#countFixnum

Output only. [Output Only] The number of hosts that are allocated in this reservation subBlock. Corresponds to the JSON property count

Returns:

  • (Fixnum)


43003
43004
43005
# File 'lib/google/apis/compute_v1/classes.rb', line 43003

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


43008
43009
43010
# File 'lib/google/apis/compute_v1/classes.rb', line 43008

def creation_timestamp
  @creation_timestamp
end

#health_infoGoogle::Apis::ComputeV1::ReservationSubBlockHealthInfo

Health information for the reservation subBlock. Corresponds to the JSON property healthInfo



43013
43014
43015
# File 'lib/google/apis/compute_v1/classes.rb', line 43013

def health_info
  @health_info
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


43020
43021
43022
# File 'lib/google/apis/compute_v1/classes.rb', line 43020

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation subBlock. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


43027
43028
43029
# File 'lib/google/apis/compute_v1/classes.rb', line 43027

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


43034
43035
43036
# File 'lib/google/apis/compute_v1/classes.rb', line 43034

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationSubBlock for reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


43040
43041
43042
# File 'lib/google/apis/compute_v1/classes.rb', line 43040

def kind
  @kind
end

#nameString

Output only. [Output Only] The name of this reservation subBlock generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


43048
43049
43050
# File 'lib/google/apis/compute_v1/classes.rb', line 43048

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeV1::ReservationSubBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation subBlock. Corresponds to the JSON property physicalTopology



43053
43054
43055
# File 'lib/google/apis/compute_v1/classes.rb', line 43053

def physical_topology
  @physical_topology
end

#reservation_sub_block_maintenanceGoogle::Apis::ComputeV1::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationSubBlockMaintenance



43058
43059
43060
# File 'lib/google/apis/compute_v1/classes.rb', line 43058

def reservation_sub_block_maintenance
  @reservation_sub_block_maintenance
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43064
43065
43066
# File 'lib/google/apis/compute_v1/classes.rb', line 43064

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


43070
43071
43072
# File 'lib/google/apis/compute_v1/classes.rb', line 43070

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation subBlock. Corresponds to the JSON property status

Returns:

  • (String)


43075
43076
43077
# File 'lib/google/apis/compute_v1/classes.rb', line 43075

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation subBlock resides. Corresponds to the JSON property zone

Returns:

  • (String)


43080
43081
43082
# File 'lib/google/apis/compute_v1/classes.rb', line 43080

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
# File 'lib/google/apis/compute_v1/classes.rb', line 43087

def update!(**args)
  @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @health_info = args[:health_info] if args.key?(:health_info)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end