Class: Google::Apis::ComputeV1::ReservationSubBlockHealthInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSubBlockHealthInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Health information for the reservation subBlock.
Instance Attribute Summary collapse
-
#degraded_host_count ⇒ Fixnum
The number of degraded hosts in the reservation subBlock.
-
#degraded_infra_count ⇒ Fixnum
The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.
-
#health_status ⇒ String
The health status of the reservation subBlock.
-
#healthy_host_count ⇒ Fixnum
The number of healthy hosts in the reservation subBlock.
-
#healthy_infra_count ⇒ Fixnum
The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlockHealthInfo
constructor
A new instance of ReservationSubBlockHealthInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlockHealthInfo
Returns a new instance of ReservationSubBlockHealthInfo.
44310 44311 44312 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44310 def initialize(**args) update!(**args) end |
Instance Attribute Details
#degraded_host_count ⇒ Fixnum
The number of degraded hosts in the reservation subBlock.
Corresponds to the JSON property degradedHostCount
44286 44287 44288 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44286 def degraded_host_count @degraded_host_count end |
#degraded_infra_count ⇒ Fixnum
The number of degraded infrastructure (e.g NV link domain) in the
reservation subblock.
Corresponds to the JSON property degradedInfraCount
44292 44293 44294 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44292 def degraded_infra_count @degraded_infra_count end |
#health_status ⇒ String
The health status of the reservation subBlock.
Corresponds to the JSON property healthStatus
44297 44298 44299 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44297 def health_status @health_status end |
#healthy_host_count ⇒ Fixnum
The number of healthy hosts in the reservation subBlock.
Corresponds to the JSON property healthyHostCount
44302 44303 44304 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44302 def healthy_host_count @healthy_host_count end |
#healthy_infra_count ⇒ Fixnum
The number of healthy infrastructure (e.g NV link domain) in the
reservation subblock.
Corresponds to the JSON property healthyInfraCount
44308 44309 44310 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44308 def healthy_infra_count @healthy_infra_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44315 44316 44317 44318 44319 44320 44321 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44315 def update!(**args) @degraded_host_count = args[:degraded_host_count] if args.key?(:degraded_host_count) @degraded_infra_count = args[:degraded_infra_count] if args.key?(:degraded_infra_count) @health_status = args[:health_status] if args.key?(:health_status) @healthy_host_count = args[:healthy_host_count] if args.key?(:healthy_host_count) @healthy_infra_count = args[:healthy_infra_count] if args.key?(:healthy_infra_count) end |