Class: Google::Apis::ComputeV1::ReservationSubBlockHealthInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Health information for the reservation subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlockHealthInfo

Returns a new instance of ReservationSubBlockHealthInfo.



43137
43138
43139
# File 'lib/google/apis/compute_v1/classes.rb', line 43137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#degraded_host_countFixnum

The number of degraded hosts in the reservation subBlock. Corresponds to the JSON property degradedHostCount

Returns:

  • (Fixnum)


43113
43114
43115
# File 'lib/google/apis/compute_v1/classes.rb', line 43113

def degraded_host_count
  @degraded_host_count
end

#degraded_infra_countFixnum

The number of degraded infrastructure (e.g NV link domain) in the reservation subblock. Corresponds to the JSON property degradedInfraCount

Returns:

  • (Fixnum)


43119
43120
43121
# File 'lib/google/apis/compute_v1/classes.rb', line 43119

def degraded_infra_count
  @degraded_infra_count
end

#health_statusString

The health status of the reservation subBlock. Corresponds to the JSON property healthStatus

Returns:

  • (String)


43124
43125
43126
# File 'lib/google/apis/compute_v1/classes.rb', line 43124

def health_status
  @health_status
end

#healthy_host_countFixnum

The number of healthy hosts in the reservation subBlock. Corresponds to the JSON property healthyHostCount

Returns:

  • (Fixnum)


43129
43130
43131
# File 'lib/google/apis/compute_v1/classes.rb', line 43129

def healthy_host_count
  @healthy_host_count
end

#healthy_infra_countFixnum

The number of healthy infrastructure (e.g NV link domain) in the reservation subblock. Corresponds to the JSON property healthyInfraCount

Returns:

  • (Fixnum)


43135
43136
43137
# File 'lib/google/apis/compute_v1/classes.rb', line 43135

def healthy_infra_count
  @healthy_infra_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43142
43143
43144
43145
43146
43147
43148
# File 'lib/google/apis/compute_v1/classes.rb', line 43142

def update!(**args)
  @degraded_host_count = args[:degraded_host_count] if args.key?(:degraded_host_count)
  @degraded_infra_count = args[:degraded_infra_count] if args.key?(:degraded_infra_count)
  @health_status = args[:health_status] if args.key?(:health_status)
  @healthy_host_count = args[:healthy_host_count] if args.key?(:healthy_host_count)
  @healthy_infra_count = args[:healthy_infra_count] if args.key?(:healthy_infra_count)
end