Class: Google::Apis::ComputeV1::ReservationSubBlockPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSubBlockPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The hash of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation subBlock.
-
#sub_block ⇒ String
The hash of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlockPhysicalTopology
constructor
A new instance of ReservationSubBlockPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlockPhysicalTopology
Returns a new instance of ReservationSubBlockPhysicalTopology.
48384 48385 48386 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The hash of the capacity block within the cluster.
Corresponds to the JSON property block
48372 48373 48374 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48372 def block @block end |
#cluster ⇒ String
The cluster name of the reservation subBlock.
Corresponds to the JSON property cluster
48377 48378 48379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48377 def cluster @cluster end |
#sub_block ⇒ String
The hash of the capacity sub-block within the capacity block.
Corresponds to the JSON property subBlock
48382 48383 48384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48382 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48389 48390 48391 48392 48393 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48389 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @sub_block = args[:sub_block] if args.key?(:sub_block) end |