Class: Google::Apis::ComputeV1::ReservationSubBlockPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSubBlockPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The hash of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation subBlock.
-
#sub_block ⇒ String
The hash of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlockPhysicalTopology
constructor
A new instance of ReservationSubBlockPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlockPhysicalTopology
Returns a new instance of ReservationSubBlockPhysicalTopology.
48370 48371 48372 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48370 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The hash of the capacity block within the cluster.
Corresponds to the JSON property block
48358 48359 48360 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48358 def block @block end |
#cluster ⇒ String
The cluster name of the reservation subBlock.
Corresponds to the JSON property cluster
48363 48364 48365 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48363 def cluster @cluster end |
#sub_block ⇒ String
The hash of the capacity sub-block within the capacity block.
Corresponds to the JSON property subBlock
48368 48369 48370 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48368 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48375 48376 48377 48378 48379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48375 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @sub_block = args[:sub_block] if args.key?(:sub_block) end |