Class: Google::Apis::ComputeV1::ReservationSubBlockPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSubBlockPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The hash of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation subBlock.
-
#sub_block ⇒ String
The hash of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlockPhysicalTopology
constructor
A new instance of ReservationSubBlockPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlockPhysicalTopology
Returns a new instance of ReservationSubBlockPhysicalTopology.
43170 43171 43172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The hash of the capacity block within the cluster.
Corresponds to the JSON property block
43158 43159 43160 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43158 def block @block end |
#cluster ⇒ String
The cluster name of the reservation subBlock.
Corresponds to the JSON property cluster
43163 43164 43165 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43163 def cluster @cluster end |
#sub_block ⇒ String
The hash of the capacity sub-block within the capacity block.
Corresponds to the JSON property subBlock
43168 43169 43170 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43168 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43175 43176 43177 43178 43179 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43175 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @sub_block = args[:sub_block] if args.key?(:sub_block) end |