Class: Google::Apis::ComputeV1::ReservationSubBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSubBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of reservation subBlocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSubBlock>
A list of reservation subBlock resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationSubBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksListResponse
constructor
A new instance of ReservationSubBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksListResponse
Returns a new instance of ReservationSubBlocksListResponse.
49484 49485 49486 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49450 49451 49452 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49450 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSubBlock>
A list of reservation subBlock resources.
Corresponds to the JSON property items
49455 49456 49457 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49455 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationSubBlock for a list of
reservation
subBlocks.
Corresponds to the JSON property kind
49462 49463 49464 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49462 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49472 49473 49474 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49472 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49477 49478 49479 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49477 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationSubBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
49482 49483 49484 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49482 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49489 49490 49491 49492 49493 49494 49495 49496 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49489 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |