Class: Google::Apis::ComputeV1::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



48916
48917
48918
# File 'lib/google/apis/compute_v1/classes.rb', line 48916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48882
48883
48884
# File 'lib/google/apis/compute_v1/classes.rb', line 48882

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



48887
48888
48889
# File 'lib/google/apis/compute_v1/classes.rb', line 48887

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


48894
48895
48896
# File 'lib/google/apis/compute_v1/classes.rb', line 48894

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48904
48905
48906
# File 'lib/google/apis/compute_v1/classes.rb', line 48904

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48909
48910
48911
# File 'lib/google/apis/compute_v1/classes.rb', line 48909

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



48914
48915
48916
# File 'lib/google/apis/compute_v1/classes.rb', line 48914

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48921
48922
48923
48924
48925
48926
48927
48928
# File 'lib/google/apis/compute_v1/classes.rb', line 48921

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end