Class: Google::Apis::ComputeV1::ReservationSubBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSubBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of reservation subBlocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSubBlock>
A list of reservation subBlock resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationSubBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksListResponse
constructor
A new instance of ReservationSubBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksListResponse
Returns a new instance of ReservationSubBlocksListResponse.
48752 48753 48754 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
48718 48719 48720 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48718 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ReservationSubBlock>
A list of reservation subBlock resources.
Corresponds to the JSON property items
48723 48724 48725 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48723 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationSubBlock for a list of
reservation
subBlocks.
Corresponds to the JSON property kind
48730 48731 48732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48730 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48740 48741 48742 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48740 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48745 48746 48747 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48745 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ReservationSubBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
48750 48751 48752 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48750 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48757 48758 48759 48760 48761 48762 48763 48764 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48757 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |