Class: Google::Apis::ComputeV1::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



48475
48476
48477
# File 'lib/google/apis/compute_v1/classes.rb', line 48475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48441
48442
48443
# File 'lib/google/apis/compute_v1/classes.rb', line 48441

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



48446
48447
48448
# File 'lib/google/apis/compute_v1/classes.rb', line 48446

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


48453
48454
48455
# File 'lib/google/apis/compute_v1/classes.rb', line 48453

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48463
48464
48465
# File 'lib/google/apis/compute_v1/classes.rb', line 48463

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48468
48469
48470
# File 'lib/google/apis/compute_v1/classes.rb', line 48468

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



48473
48474
48475
# File 'lib/google/apis/compute_v1/classes.rb', line 48473

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48480
48481
48482
48483
48484
48485
48486
48487
# File 'lib/google/apis/compute_v1/classes.rb', line 48480

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end