Class: Google::Apis::ComputeV1::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



48461
48462
48463
# File 'lib/google/apis/compute_v1/classes.rb', line 48461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48427
48428
48429
# File 'lib/google/apis/compute_v1/classes.rb', line 48427

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



48432
48433
48434
# File 'lib/google/apis/compute_v1/classes.rb', line 48432

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


48439
48440
48441
# File 'lib/google/apis/compute_v1/classes.rb', line 48439

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48449
48450
48451
# File 'lib/google/apis/compute_v1/classes.rb', line 48449

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48454
48455
48456
# File 'lib/google/apis/compute_v1/classes.rb', line 48454

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



48459
48460
48461
# File 'lib/google/apis/compute_v1/classes.rb', line 48459

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48466
48467
48468
48469
48470
48471
48472
48473
# File 'lib/google/apis/compute_v1/classes.rb', line 48466

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end