Class: Google::Apis::ComputeV1::ReservationSubBlocksReportFaultyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSubBlocksReportFaultyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
-
#failure_component ⇒ String
The component that experienced the fault.
-
#fault_reasons ⇒ Array<Google::Apis::ComputeV1::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
constructor
A new instance of ReservationSubBlocksReportFaultyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
Returns a new instance of ReservationSubBlocksReportFaultyRequest.
43346 43347 43348 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
Corresponds to the JSON property disruptionSchedule
43334 43335 43336 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43334 def disruption_schedule @disruption_schedule end |
#failure_component ⇒ String
The component that experienced the fault.
Corresponds to the JSON property failureComponent
43339 43340 43341 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43339 def failure_component @failure_component end |
#fault_reasons ⇒ Array<Google::Apis::ComputeV1::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Corresponds to the JSON property faultReasons
43344 43345 43346 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43344 def fault_reasons @fault_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43351 43352 43353 43354 43355 |
# File 'lib/google/apis/compute_v1/classes.rb', line 43351 def update!(**args) @disruption_schedule = args[:disruption_schedule] if args.key?(:disruption_schedule) @failure_component = args[:failure_component] if args.key?(:failure_component) @fault_reasons = args[:fault_reasons] if args.key?(:fault_reasons) end |