Class: Google::Apis::ComputeV1::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



44545
44546
44547
# File 'lib/google/apis/compute_v1/classes.rb', line 44545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


44538
44539
44540
# File 'lib/google/apis/compute_v1/classes.rb', line 44538

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


44543
44544
44545
# File 'lib/google/apis/compute_v1/classes.rb', line 44543

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44550
44551
44552
44553
# File 'lib/google/apis/compute_v1/classes.rb', line 44550

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end