Class: Google::Apis::ComputeV1::ReservationSubBlocksReportFaultyRequestFaultReason
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationSubBlocksReportFaultyRequestFaultReason
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The reason for the fault experienced with the subBlock.
Instance Attribute Summary collapse
-
#behavior ⇒ String
The behavior of the fault experienced with the subBlock.
-
#description ⇒ String
The description of the fault experienced with the subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason
constructor
A new instance of ReservationSubBlocksReportFaultyRequestFaultReason.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason
Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.
44545 44546 44547 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#behavior ⇒ String
The behavior of the fault experienced with the subBlock.
Corresponds to the JSON property behavior
44538 44539 44540 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44538 def behavior @behavior end |
#description ⇒ String
The description of the fault experienced with the subBlock.
Corresponds to the JSON property description
44543 44544 44545 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44543 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44550 44551 44552 44553 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44550 def update!(**args) @behavior = args[:behavior] if args.key?(:behavior) @description = args[:description] if args.key?(:description) end |