Class: Google::Apis::ComputeV1::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



43372
43373
43374
# File 'lib/google/apis/compute_v1/classes.rb', line 43372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


43365
43366
43367
# File 'lib/google/apis/compute_v1/classes.rb', line 43365

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


43370
43371
43372
# File 'lib/google/apis/compute_v1/classes.rb', line 43370

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43377
43378
43379
43380
# File 'lib/google/apis/compute_v1/classes.rb', line 43377

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end