Class: Google::Apis::ComputeV1::ReservationsScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ReservationsScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#reservations ⇒ Array<Google::Apis::ComputeV1::Reservation>
A list of reservations contained in this scope.
-
#warning ⇒ Google::Apis::ComputeV1::ReservationsScopedList::Warning
Informational warning which replaces the list of reservations when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationsScopedList
constructor
A new instance of ReservationsScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationsScopedList
Returns a new instance of ReservationsScopedList.
48079 48080 48081 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48079 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reservations ⇒ Array<Google::Apis::ComputeV1::Reservation>
A list of reservations contained in this scope.
Corresponds to the JSON property reservations
48071 48072 48073 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48071 def reservations @reservations end |
#warning ⇒ Google::Apis::ComputeV1::ReservationsScopedList::Warning
Informational warning which replaces the list of reservations when
the list is empty.
Corresponds to the JSON property warning
48077 48078 48079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48077 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48084 48085 48086 48087 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48084 def update!(**args) @reservations = args[:reservations] if args.key?(:reservations) @warning = args[:warning] if args.key?(:warning) end |