Class: Google::Apis::ComputeV1::ResourcePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them toschedule persistent disk snapshots.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Corresponds to the JSON property
description. -
#disk_consistency_group_policy ⇒ Google::Apis::ComputeV1::ResourcePolicyDiskConsistencyGroupPolicy
Resource policy for disk consistency groups.
-
#group_placement_policy ⇒ Google::Apis::ComputeV1::ResourcePolicyGroupPlacementPolicy
A GroupPlacementPolicy specifies resource placement configuration.
-
#id ⇒ Fixnum
Output only.
-
#instance_schedule_policy ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicy
An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#region ⇒ String
Corresponds to the JSON property
region. -
#resource_status ⇒ Google::Apis::ComputeV1::ResourcePolicyResourceStatus
Contains output only fields.
-
#self_link ⇒ String
Output only.
-
#snapshot_schedule_policy ⇒ Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicy
A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk.
-
#status ⇒ String
Output only.
-
#workload_policy ⇒ Google::Apis::ComputeV1::ResourcePolicyWorkloadPolicy
Represents the workload policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicy
constructor
A new instance of ResourcePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicy
Returns a new instance of ResourcePolicy.
49034 49035 49036 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
48949 48950 48951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48949 def @creation_timestamp end |
#description ⇒ String
Corresponds to the JSON property description
48954 48955 48956 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48954 def description @description end |
#disk_consistency_group_policy ⇒ Google::Apis::ComputeV1::ResourcePolicyDiskConsistencyGroupPolicy
Resource policy for disk consistency groups.
Corresponds to the JSON property diskConsistencyGroupPolicy
48959 48960 48961 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48959 def disk_consistency_group_policy @disk_consistency_group_policy end |
#group_placement_policy ⇒ Google::Apis::ComputeV1::ResourcePolicyGroupPlacementPolicy
A GroupPlacementPolicy specifies resource placement configuration.
It specifies the failure bucket separation
Corresponds to the JSON property groupPlacementPolicy
48965 48966 48967 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48965 def group_placement_policy @group_placement_policy end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
48972 48973 48974 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48972 def id @id end |
#instance_schedule_policy ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicy
An InstanceSchedulePolicy specifies when and how frequent certain
operations are performed on the instance.
Corresponds to the JSON property instanceSchedulePolicy
48978 48979 48980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48978 def instance_schedule_policy @instance_schedule_policy end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
resource_policies for resource policies.
Corresponds to the JSON property kind
48984 48985 48986 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48984 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
48996 48997 48998 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48996 def name @name end |
#region ⇒ String
Corresponds to the JSON property region
49001 49002 49003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49001 def region @region end |
#resource_status ⇒ Google::Apis::ComputeV1::ResourcePolicyResourceStatus
Contains output only fields.
Use this sub-message for all output fields set on ResourcePolicy.
The internal structure of this "status" field should mimic the structure
of ResourcePolicy proto specification.
Corresponds to the JSON property resourceStatus
49009 49010 49011 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49009 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
49015 49016 49017 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49015 def self_link @self_link end |
#snapshot_schedule_policy ⇒ Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicy
A snapshot schedule policy specifies when and how frequently snapshots are
to be created for the target disk. Also specifies how many and how long
these scheduled snapshots should be retained.
Corresponds to the JSON property snapshotSchedulePolicy
49022 49023 49024 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49022 def snapshot_schedule_policy @snapshot_schedule_policy end |
#status ⇒ String
Output only. [Output Only] The status of resource policy creation.
Corresponds to the JSON property status
49027 49028 49029 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49027 def status @status end |
#workload_policy ⇒ Google::Apis::ComputeV1::ResourcePolicyWorkloadPolicy
Represents the workload policy.
Corresponds to the JSON property workloadPolicy
49032 49033 49034 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49032 def workload_policy @workload_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49039 49040 49041 49042 49043 49044 49045 49046 49047 49048 49049 49050 49051 49052 49053 49054 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49039 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disk_consistency_group_policy = args[:disk_consistency_group_policy] if args.key?(:disk_consistency_group_policy) @group_placement_policy = args[:group_placement_policy] if args.key?(:group_placement_policy) @id = args[:id] if args.key?(:id) @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @snapshot_schedule_policy = args[:snapshot_schedule_policy] if args.key?(:snapshot_schedule_policy) @status = args[:status] if args.key?(:status) @workload_policy = args[:workload_policy] if args.key?(:workload_policy) end |