Class: Google::Apis::ComputeV1::ResourcePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them to schedule persistent disk snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicy

Returns a new instance of ResourcePolicy.



27728
27729
27730
# File 'lib/google/apis/compute_v1/classes.rb', line 27728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


27657
27658
27659
# File 'lib/google/apis/compute_v1/classes.rb', line 27657

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Corresponds to the JSON property description

Returns:

  • (String)


27662
27663
27664
# File 'lib/google/apis/compute_v1/classes.rb', line 27662

def description
  @description
end

#group_placement_policyGoogle::Apis::ComputeV1::ResourcePolicyGroupPlacementPolicy

A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation as well as network locality Corresponds to the JSON property groupPlacementPolicy



27668
27669
27670
# File 'lib/google/apis/compute_v1/classes.rb', line 27668

def group_placement_policy
  @group_placement_policy
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27674
27675
27676
# File 'lib/google/apis/compute_v1/classes.rb', line 27674

def id
  @id
end

#instance_schedule_policyGoogle::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicy

An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance. Corresponds to the JSON property instanceSchedulePolicy



27680
27681
27682
# File 'lib/google/apis/compute_v1/classes.rb', line 27680

def instance_schedule_policy
  @instance_schedule_policy
end

#kindString

[Output Only] Type of the resource. Always compute#resource_policies for resource policies. Corresponds to the JSON property kind

Returns:

  • (String)


27686
27687
27688
# File 'lib/google/apis/compute_v1/classes.rb', line 27686

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


27697
27698
27699
# File 'lib/google/apis/compute_v1/classes.rb', line 27697

def name
  @name
end

#regionString

Corresponds to the JSON property region

Returns:

  • (String)


27702
27703
27704
# File 'lib/google/apis/compute_v1/classes.rb', line 27702

def region
  @region
end

#resource_statusGoogle::Apis::ComputeV1::ResourcePolicyResourceStatus

Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this "status" field should mimic the structure of ResourcePolicy proto specification. Corresponds to the JSON property resourceStatus



27709
27710
27711
# File 'lib/google/apis/compute_v1/classes.rb', line 27709

def resource_status
  @resource_status
end

[Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27714
27715
27716
# File 'lib/google/apis/compute_v1/classes.rb', line 27714

def self_link
  @self_link
end

#snapshot_schedule_policyGoogle::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicy

A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained. Corresponds to the JSON property snapshotSchedulePolicy



27721
27722
27723
# File 'lib/google/apis/compute_v1/classes.rb', line 27721

def snapshot_schedule_policy
  @snapshot_schedule_policy
end

#statusString

[Output Only] The status of resource policy creation. Corresponds to the JSON property status

Returns:

  • (String)


27726
27727
27728
# File 'lib/google/apis/compute_v1/classes.rb', line 27726

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27733
27734
27735
27736
27737
27738
27739
27740
27741
27742
27743
27744
27745
27746
# File 'lib/google/apis/compute_v1/classes.rb', line 27733

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @group_placement_policy = args[:group_placement_policy] if args.key?(:group_placement_policy)
  @id = args[:id] if args.key?(:id)
  @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @snapshot_schedule_policy = args[:snapshot_schedule_policy] if args.key?(:snapshot_schedule_policy)
  @status = args[:status] if args.key?(:status)
end