Class: Google::Apis::ComputeV1::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



50115
50116
50117
# File 'lib/google/apis/compute_v1/classes.rb', line 50115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50073
50074
50075
# File 'lib/google/apis/compute_v1/classes.rb', line 50073

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50078
50079
50080
# File 'lib/google/apis/compute_v1/classes.rb', line 50078

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



50083
50084
50085
# File 'lib/google/apis/compute_v1/classes.rb', line 50083

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


50088
50089
50090
# File 'lib/google/apis/compute_v1/classes.rb', line 50088

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50098
50099
50100
# File 'lib/google/apis/compute_v1/classes.rb', line 50098

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50103
50104
50105
# File 'lib/google/apis/compute_v1/classes.rb', line 50103

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50108
50109
50110
# File 'lib/google/apis/compute_v1/classes.rb', line 50108

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50113
50114
50115
# File 'lib/google/apis/compute_v1/classes.rb', line 50113

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50120
50121
50122
50123
50124
50125
50126
50127
50128
50129
# File 'lib/google/apis/compute_v1/classes.rb', line 50120

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end