Class: Google::Apis::ComputeV1::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



49547
49548
49549
# File 'lib/google/apis/compute_v1/classes.rb', line 49547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


49505
49506
49507
# File 'lib/google/apis/compute_v1/classes.rb', line 49505

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49510
49511
49512
# File 'lib/google/apis/compute_v1/classes.rb', line 49510

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



49515
49516
49517
# File 'lib/google/apis/compute_v1/classes.rb', line 49515

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


49520
49521
49522
# File 'lib/google/apis/compute_v1/classes.rb', line 49520

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49530
49531
49532
# File 'lib/google/apis/compute_v1/classes.rb', line 49530

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49535
49536
49537
# File 'lib/google/apis/compute_v1/classes.rb', line 49535

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


49540
49541
49542
# File 'lib/google/apis/compute_v1/classes.rb', line 49540

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49545
49546
49547
# File 'lib/google/apis/compute_v1/classes.rb', line 49545

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49552
49553
49554
49555
49556
49557
49558
49559
49560
49561
# File 'lib/google/apis/compute_v1/classes.rb', line 49552

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end