Class: Google::Apis::ComputeV1::ResourcePolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of resourcePolicies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyAggregatedList
constructor
A new instance of ResourcePolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyAggregatedList
Returns a new instance of ResourcePolicyAggregatedList.
49382 49383 49384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
49340 49341 49342 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49340 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49345 49346 49347 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49345 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
Corresponds to the JSON property items
49350 49351 49352 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49350 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
49355 49356 49357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49355 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49365 49366 49367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49365 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49370 49371 49372 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49370 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
49375 49376 49377 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49375 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
49380 49381 49382 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49380 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49387 49388 49389 49390 49391 49392 49393 49394 49395 49396 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49387 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |