Class: Google::Apis::ComputeV1::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



49092
49093
49094
# File 'lib/google/apis/compute_v1/classes.rb', line 49092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


49050
49051
49052
# File 'lib/google/apis/compute_v1/classes.rb', line 49050

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49055
49056
49057
# File 'lib/google/apis/compute_v1/classes.rb', line 49055

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



49060
49061
49062
# File 'lib/google/apis/compute_v1/classes.rb', line 49060

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


49065
49066
49067
# File 'lib/google/apis/compute_v1/classes.rb', line 49065

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49075
49076
49077
# File 'lib/google/apis/compute_v1/classes.rb', line 49075

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49080
49081
49082
# File 'lib/google/apis/compute_v1/classes.rb', line 49080

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


49085
49086
49087
# File 'lib/google/apis/compute_v1/classes.rb', line 49085

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49090
49091
49092
# File 'lib/google/apis/compute_v1/classes.rb', line 49090

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49097
49098
49099
49100
49101
49102
49103
49104
49105
49106
# File 'lib/google/apis/compute_v1/classes.rb', line 49097

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end