Class: Google::Apis::ComputeV1::ResourcePolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of resourcePolicies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyAggregatedList
constructor
A new instance of ResourcePolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyAggregatedList
Returns a new instance of ResourcePolicyAggregatedList.
45046 45047 45048 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
45004 45005 45006 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45004 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
45009 45010 45011 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45009 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
Corresponds to the JSON property items
45014 45015 45016 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45014 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
45019 45020 45021 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45019 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45029 45030 45031 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45029 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
45034 45035 45036 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45034 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
45039 45040 45041 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45039 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45044 45045 45046 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45044 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45051 45052 45053 45054 45055 45056 45057 45058 45059 45060 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45051 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |