Class: Google::Apis::ComputeV1::ResourcePolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of resourcePolicies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyAggregatedList
constructor
A new instance of ResourcePolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyAggregatedList
Returns a new instance of ResourcePolicyAggregatedList.
27797 27798 27799 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27797 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
27756 27757 27758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27756 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
27761 27762 27763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27761 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
Corresponds to the JSON property items
27766 27767 27768 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27766 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
27771 27772 27773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27771 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
27780 27781 27782 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27780 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
27785 27786 27787 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27785 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
27790 27791 27792 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27790 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
27795 27796 27797 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27795 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27802 27803 27804 27805 27806 27807 27808 27809 27810 27811 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27802 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |