Class: Google::Apis::ComputeV1::ResourcePolicyGroupPlacementPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy

Returns a new instance of ResourcePolicyGroupPlacementPolicy.



49554
49555
49556
# File 'lib/google/apis/compute_v1/classes.rb', line 49554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topology_modeString

Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Corresponds to the JSON property acceleratorTopologyMode

Returns:

  • (String)


49527
49528
49529
# File 'lib/google/apis/compute_v1/classes.rb', line 49527

def accelerator_topology_mode
  @accelerator_topology_mode
end

#availability_domain_countFixnum

The number of availability domains to spread instances across. If two instances are in different availability domain, they are not in the same low latency network. Corresponds to the JSON property availabilityDomainCount

Returns:

  • (Fixnum)


49534
49535
49536
# File 'lib/google/apis/compute_v1/classes.rb', line 49534

def availability_domain_count
  @availability_domain_count
end

#collocationString

Specifies network collocation Corresponds to the JSON property collocation

Returns:

  • (String)


49539
49540
49541
# File 'lib/google/apis/compute_v1/classes.rb', line 49539

def collocation
  @collocation
end

#gpu_topologyString

Specifies the shape of the GPU slice, in slice based GPU families eg. A4X. Corresponds to the JSON property gpuTopology

Returns:

  • (String)


49545
49546
49547
# File 'lib/google/apis/compute_v1/classes.rb', line 49545

def gpu_topology
  @gpu_topology
end

#vm_countFixnum

Number of VMs in this placement group. Google does not recommend that you use this field unless you use a compact policy and you want your policy to work only if it contains this exact number of VMs. Corresponds to the JSON property vmCount

Returns:

  • (Fixnum)


49552
49553
49554
# File 'lib/google/apis/compute_v1/classes.rb', line 49552

def vm_count
  @vm_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49559
49560
49561
49562
49563
49564
49565
# File 'lib/google/apis/compute_v1/classes.rb', line 49559

def update!(**args)
  @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode)
  @availability_domain_count = args[:availability_domain_count] if args.key?(:availability_domain_count)
  @collocation = args[:collocation] if args.key?(:collocation)
  @gpu_topology = args[:gpu_topology] if args.key?(:gpu_topology)
  @vm_count = args[:vm_count] if args.key?(:vm_count)
end