Class: Google::Apis::ComputeV1::ResourcePolicyGroupPlacementPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyGroupPlacementPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation as well as network locality
Instance Attribute Summary collapse
-
#availability_domain_count ⇒ Fixnum
The number of availability domains instances will be spread across.
-
#collocation ⇒ String
Specifies network collocation Corresponds to the JSON property
collocation. -
#vm_count ⇒ Fixnum
Number of vms in this placement group Corresponds to the JSON property
vmCount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy
constructor
A new instance of ResourcePolicyGroupPlacementPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy
Returns a new instance of ResourcePolicyGroupPlacementPolicy.
27935 27936 27937 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27935 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability_domain_count ⇒ Fixnum
The number of availability domains instances will be spread across. If two
instances are in different availability domain, they will not be put in the
same low latency network
Corresponds to the JSON property availabilityDomainCount
27923 27924 27925 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27923 def availability_domain_count @availability_domain_count end |
#collocation ⇒ String
Specifies network collocation
Corresponds to the JSON property collocation
27928 27929 27930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27928 def collocation @collocation end |
#vm_count ⇒ Fixnum
Number of vms in this placement group
Corresponds to the JSON property vmCount
27933 27934 27935 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27933 def vm_count @vm_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27940 27941 27942 27943 27944 |
# File 'lib/google/apis/compute_v1/classes.rb', line 27940 def update!(**args) @availability_domain_count = args[:availability_domain_count] if args.key?(:availability_domain_count) @collocation = args[:collocation] if args.key?(:collocation) @vm_count = args[:vm_count] if args.key?(:vm_count) end |