Class: Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
Instance Attribute Summary collapse
-
#expiration_time ⇒ String
The expiration time of the schedule.
-
#start_time ⇒ String
The start time of the schedule.
-
#time_zone ⇒ String
Specifies the time zone to be used in interpreting Schedule.schedule.
-
#vm_start_schedule ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
-
#vm_stop_schedule ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy
constructor
A new instance of ResourcePolicyInstanceSchedulePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy
Returns a new instance of ResourcePolicyInstanceSchedulePolicy.
49800 49801 49802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49800 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expiration_time ⇒ String
The expiration time of the schedule. The timestamp is an RFC3339 string.
Corresponds to the JSON property expirationTime
49776 49777 49778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49776 def expiration_time @expiration_time end |
#start_time ⇒ String
The start time of the schedule. The timestamp is an RFC3339 string.
Corresponds to the JSON property startTime
49781 49782 49783 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49781 def start_time @start_time end |
#time_zone ⇒ String
Specifies the time zone to be used in interpreting Schedule.schedule.
The value of this field must be a time zone name from the tz database:
https://wikipedia.org/wiki/Tz_database.
Corresponds to the JSON property timeZone
49788 49789 49790 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49788 def time_zone @time_zone end |
#vm_start_schedule ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Corresponds to the JSON property vmStartSchedule
49793 49794 49795 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49793 def vm_start_schedule @vm_start_schedule end |
#vm_stop_schedule ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Corresponds to the JSON property vmStopSchedule
49798 49799 49800 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49798 def vm_stop_schedule @vm_stop_schedule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49805 49806 49807 49808 49809 49810 49811 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49805 def update!(**args) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @start_time = args[:start_time] if args.key?(:start_time) @time_zone = args[:time_zone] if args.key?(:time_zone) @vm_start_schedule = args[:vm_start_schedule] if args.key?(:vm_start_schedule) @vm_stop_schedule = args[:vm_stop_schedule] if args.key?(:vm_stop_schedule) end |