Class: Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
Instance Attribute Summary collapse
-
#expiration_time ⇒ String
The expiration time of the schedule.
-
#start_time ⇒ String
The start time of the schedule.
-
#time_zone ⇒ String
Specifies the time zone to be used in interpreting Schedule.schedule.
-
#vm_start_schedule ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
-
#vm_stop_schedule ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy
constructor
A new instance of ResourcePolicyInstanceSchedulePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy
Returns a new instance of ResourcePolicyInstanceSchedulePolicy.
49636 49637 49638 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expiration_time ⇒ String
The expiration time of the schedule. The timestamp is an RFC3339 string.
Corresponds to the JSON property expirationTime
49612 49613 49614 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49612 def expiration_time @expiration_time end |
#start_time ⇒ String
The start time of the schedule. The timestamp is an RFC3339 string.
Corresponds to the JSON property startTime
49617 49618 49619 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49617 def start_time @start_time end |
#time_zone ⇒ String
Specifies the time zone to be used in interpreting Schedule.schedule.
The value of this field must be a time zone name from the tz database:
https://wikipedia.org/wiki/Tz_database.
Corresponds to the JSON property timeZone
49624 49625 49626 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49624 def time_zone @time_zone end |
#vm_start_schedule ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Corresponds to the JSON property vmStartSchedule
49629 49630 49631 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49629 def vm_start_schedule @vm_start_schedule end |
#vm_stop_schedule ⇒ Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Corresponds to the JSON property vmStopSchedule
49634 49635 49636 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49634 def vm_stop_schedule @vm_stop_schedule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49641 49642 49643 49644 49645 49646 49647 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49641 def update!(**args) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @start_time = args[:start_time] if args.key?(:start_time) @time_zone = args[:time_zone] if args.key?(:time_zone) @vm_start_schedule = args[:vm_start_schedule] if args.key?(:vm_start_schedule) @vm_stop_schedule = args[:vm_stop_schedule] if args.key?(:vm_stop_schedule) end |