Class: Google::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy

Returns a new instance of ResourcePolicyInstanceSchedulePolicy.



45299
45300
45301
# File 'lib/google/apis/compute_v1/classes.rb', line 45299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expiration_timeString

The expiration time of the schedule. The timestamp is an RFC3339 string. Corresponds to the JSON property expirationTime

Returns:

  • (String)


45275
45276
45277
# File 'lib/google/apis/compute_v1/classes.rb', line 45275

def expiration_time
  @expiration_time
end

#start_timeString

The start time of the schedule. The timestamp is an RFC3339 string. Corresponds to the JSON property startTime

Returns:

  • (String)


45280
45281
45282
# File 'lib/google/apis/compute_v1/classes.rb', line 45280

def start_time
  @start_time
end

#time_zoneString

Specifies the time zone to be used in interpreting Schedule.schedule. The value of this field must be a time zone name from the tz database: https://wikipedia.org/wiki/Tz_database. Corresponds to the JSON property timeZone

Returns:

  • (String)


45287
45288
45289
# File 'lib/google/apis/compute_v1/classes.rb', line 45287

def time_zone
  @time_zone
end

#vm_start_scheduleGoogle::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule

Schedule for an instance operation. Corresponds to the JSON property vmStartSchedule



45292
45293
45294
# File 'lib/google/apis/compute_v1/classes.rb', line 45292

def vm_start_schedule
  @vm_start_schedule
end

#vm_stop_scheduleGoogle::Apis::ComputeV1::ResourcePolicyInstanceSchedulePolicySchedule

Schedule for an instance operation. Corresponds to the JSON property vmStopSchedule



45297
45298
45299
# File 'lib/google/apis/compute_v1/classes.rb', line 45297

def vm_stop_schedule
  @vm_stop_schedule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45304
45305
45306
45307
45308
45309
45310
# File 'lib/google/apis/compute_v1/classes.rb', line 45304

def update!(**args)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @vm_start_schedule = args[:vm_start_schedule] if args.key?(:vm_start_schedule)
  @vm_stop_schedule = args[:vm_stop_schedule] if args.key?(:vm_stop_schedule)
end