Class: Google::Apis::ComputeV1::ResourcePolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyList
constructor
A new instance of ResourcePolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyList
Returns a new instance of ResourcePolicyList.
50493 50494 50495 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
50454 50455 50456 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50454 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
50460 50461 50462 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50460 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
Corresponds to the JSON property items
50465 50466 50467 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50465 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList
for listsof resourcePolicies
Corresponds to the JSON property kind
50471 50472 50473 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50471 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50481 50482 50483 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50481 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50486 50487 50488 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50486 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
50491 50492 50493 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50491 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50498 50499 50500 50501 50502 50503 50504 50505 50506 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50498 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |