Class: Google::Apis::ComputeV1::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



49879
49880
49881
# File 'lib/google/apis/compute_v1/classes.rb', line 49879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


49840
49841
49842
# File 'lib/google/apis/compute_v1/classes.rb', line 49840

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49846
49847
49848
# File 'lib/google/apis/compute_v1/classes.rb', line 49846

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



49851
49852
49853
# File 'lib/google/apis/compute_v1/classes.rb', line 49851

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


49857
49858
49859
# File 'lib/google/apis/compute_v1/classes.rb', line 49857

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49867
49868
49869
# File 'lib/google/apis/compute_v1/classes.rb', line 49867

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49872
49873
49874
# File 'lib/google/apis/compute_v1/classes.rb', line 49872

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49877
49878
49879
# File 'lib/google/apis/compute_v1/classes.rb', line 49877

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49884
49885
49886
49887
49888
49889
49890
49891
49892
# File 'lib/google/apis/compute_v1/classes.rb', line 49884

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end