Class: Google::Apis::ComputeV1::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



49714
49715
49716
# File 'lib/google/apis/compute_v1/classes.rb', line 49714

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


49675
49676
49677
# File 'lib/google/apis/compute_v1/classes.rb', line 49675

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49681
49682
49683
# File 'lib/google/apis/compute_v1/classes.rb', line 49681

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



49686
49687
49688
# File 'lib/google/apis/compute_v1/classes.rb', line 49686

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


49692
49693
49694
# File 'lib/google/apis/compute_v1/classes.rb', line 49692

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49702
49703
49704
# File 'lib/google/apis/compute_v1/classes.rb', line 49702

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49707
49708
49709
# File 'lib/google/apis/compute_v1/classes.rb', line 49707

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49712
49713
49714
# File 'lib/google/apis/compute_v1/classes.rb', line 49712

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49719
49720
49721
49722
49723
49724
49725
49726
49727
# File 'lib/google/apis/compute_v1/classes.rb', line 49719

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end