Class: Google::Apis::ComputeV1::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



49715
49716
49717
# File 'lib/google/apis/compute_v1/classes.rb', line 49715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


49676
49677
49678
# File 'lib/google/apis/compute_v1/classes.rb', line 49676

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49682
49683
49684
# File 'lib/google/apis/compute_v1/classes.rb', line 49682

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



49687
49688
49689
# File 'lib/google/apis/compute_v1/classes.rb', line 49687

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


49693
49694
49695
# File 'lib/google/apis/compute_v1/classes.rb', line 49693

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49703
49704
49705
# File 'lib/google/apis/compute_v1/classes.rb', line 49703

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49708
49709
49710
# File 'lib/google/apis/compute_v1/classes.rb', line 49708

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49713
49714
49715
# File 'lib/google/apis/compute_v1/classes.rb', line 49713

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49720
49721
49722
49723
49724
49725
49726
49727
49728
# File 'lib/google/apis/compute_v1/classes.rb', line 49720

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end