Class: Google::Apis::ComputeV1::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



45378
45379
45380
# File 'lib/google/apis/compute_v1/classes.rb', line 45378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


45339
45340
45341
# File 'lib/google/apis/compute_v1/classes.rb', line 45339

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45345
45346
45347
# File 'lib/google/apis/compute_v1/classes.rb', line 45345

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



45350
45351
45352
# File 'lib/google/apis/compute_v1/classes.rb', line 45350

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


45356
45357
45358
# File 'lib/google/apis/compute_v1/classes.rb', line 45356

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45366
45367
45368
# File 'lib/google/apis/compute_v1/classes.rb', line 45366

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45371
45372
45373
# File 'lib/google/apis/compute_v1/classes.rb', line 45371

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45376
45377
45378
# File 'lib/google/apis/compute_v1/classes.rb', line 45376

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45383
45384
45385
45386
45387
45388
45389
45390
45391
# File 'lib/google/apis/compute_v1/classes.rb', line 45383

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end