Class: Google::Apis::ComputeV1::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



44198
44199
44200
# File 'lib/google/apis/compute_v1/classes.rb', line 44198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


44159
44160
44161
# File 'lib/google/apis/compute_v1/classes.rb', line 44159

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44165
44166
44167
# File 'lib/google/apis/compute_v1/classes.rb', line 44165

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



44170
44171
44172
# File 'lib/google/apis/compute_v1/classes.rb', line 44170

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


44176
44177
44178
# File 'lib/google/apis/compute_v1/classes.rb', line 44176

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44186
44187
44188
# File 'lib/google/apis/compute_v1/classes.rb', line 44186

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44191
44192
44193
# File 'lib/google/apis/compute_v1/classes.rb', line 44191

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44196
44197
44198
# File 'lib/google/apis/compute_v1/classes.rb', line 44196

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44203
44204
44205
44206
44207
44208
44209
44210
44211
# File 'lib/google/apis/compute_v1/classes.rb', line 44203

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end