Class: Google::Apis::ComputeV1::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



28091
28092
28093
# File 'lib/google/apis/compute_v1/classes.rb', line 28091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


28053
28054
28055
# File 'lib/google/apis/compute_v1/classes.rb', line 28053

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28059
28060
28061
# File 'lib/google/apis/compute_v1/classes.rb', line 28059

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



28064
28065
28066
# File 'lib/google/apis/compute_v1/classes.rb', line 28064

def items
  @items
end

#kindString

[Output Only] Type of resource.Always compute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


28070
28071
28072
# File 'lib/google/apis/compute_v1/classes.rb', line 28070

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28079
28080
28081
# File 'lib/google/apis/compute_v1/classes.rb', line 28079

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28084
28085
28086
# File 'lib/google/apis/compute_v1/classes.rb', line 28084

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



28089
28090
28091
# File 'lib/google/apis/compute_v1/classes.rb', line 28089

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28096
28097
28098
28099
28100
28101
28102
28103
28104
# File 'lib/google/apis/compute_v1/classes.rb', line 28096

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end