Class: Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained.
Instance Attribute Summary collapse
-
#retention_policy ⇒ Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
Policy for retention of scheduled snapshots.
-
#schedule ⇒ Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicySchedule
A schedule for disks where the schedueled operations are performed.
-
#snapshot_properties ⇒ Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicySnapshotProperties
Specified snapshot properties for scheduled snapshots created by this policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicy
constructor
A new instance of ResourcePolicySnapshotSchedulePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicy
Returns a new instance of ResourcePolicySnapshotSchedulePolicy.
44358 44359 44360 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44358 def initialize(**args) update!(**args) end |
Instance Attribute Details
#retention_policy ⇒ Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
Policy for retention of scheduled snapshots.
Corresponds to the JSON property retentionPolicy
44345 44346 44347 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44345 def retention_policy @retention_policy end |
#schedule ⇒ Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicySchedule
A schedule for disks where the schedueled operations are performed.
Corresponds to the JSON property schedule
44350 44351 44352 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44350 def schedule @schedule end |
#snapshot_properties ⇒ Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicySnapshotProperties
Specified snapshot properties for scheduled snapshots created by this
policy.
Corresponds to the JSON property snapshotProperties
44356 44357 44358 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44356 def snapshot_properties @snapshot_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44363 44364 44365 44366 44367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44363 def update!(**args) @retention_policy = args[:retention_policy] if args.key?(:retention_policy) @schedule = args[:schedule] if args.key?(:schedule) @snapshot_properties = args[:snapshot_properties] if args.key?(:snapshot_properties) end |