Class: Google::Apis::ComputeV1::ResourcePolicySnapshotSchedulePolicySnapshotProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Specified snapshot properties for scheduled snapshots created by this policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicySnapshotProperties

Returns a new instance of ResourcePolicySnapshotSchedulePolicySnapshotProperties.



49085
49086
49087
# File 'lib/google/apis/compute_v1/classes.rb', line 49085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chain_nameString

Chain name that the snapshot is created in. Corresponds to the JSON property chainName

Returns:

  • (String)


49065
49066
49067
# File 'lib/google/apis/compute_v1/classes.rb', line 49065

def chain_name
  @chain_name
end

#guest_flushBoolean Also known as: guest_flush?

Indication to perform a 'guest aware' snapshot. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


49070
49071
49072
# File 'lib/google/apis/compute_v1/classes.rb', line 49070

def guest_flush
  @guest_flush
end

#labelsHash<String,String>

Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


49077
49078
49079
# File 'lib/google/apis/compute_v1/classes.rb', line 49077

def labels
  @labels
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional). Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


49083
49084
49085
# File 'lib/google/apis/compute_v1/classes.rb', line 49083

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49090
49091
49092
49093
49094
49095
# File 'lib/google/apis/compute_v1/classes.rb', line 49090

def update!(**args)
  @chain_name = args[:chain_name] if args.key?(:chain_name)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @labels = args[:labels] if args.key?(:labels)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end