Class: Google::Apis::ComputeV1::ResourcePolicyWeeklyCycleDayOfWeek
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyWeeklyCycleDayOfWeek
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#day ⇒ String
Defines a schedule that runs on specific days of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ String
Time within the window to start the operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyWeeklyCycleDayOfWeek
constructor
A new instance of ResourcePolicyWeeklyCycleDayOfWeek.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyWeeklyCycleDayOfWeek
Returns a new instance of ResourcePolicyWeeklyCycleDayOfWeek.
44511 44512 44513 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44511 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Defines a schedule that runs on specific days of the week. Specify
one or more days. The following options are available:
MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
Corresponds to the JSON property day
44496 44497 44498 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44496 def day @day end |
#duration ⇒ String
Output only. [Output only] Duration of the time window, automatically chosen
to be
smallest possible in the given scenario.
Corresponds to the JSON property duration
44503 44504 44505 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44503 def duration @duration end |
#start_time ⇒ String
Time within the window to start the operations.
It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
Corresponds to the JSON property startTime
44509 44510 44511 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44509 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44516 44517 44518 44519 44520 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44516 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |