Class: Google::Apis::ComputeV1::ResourcePolicyWorkloadPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyWorkloadPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents the workload policy.
Instance Attribute Summary collapse
-
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
-
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology.
-
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
-
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
constructor
A new instance of ResourcePolicyWorkloadPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
Returns a new instance of ResourcePolicyWorkloadPolicy.
49179 49180 49181 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49179 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have
interconnected GPUs.
Corresponds to the JSON property acceleratorTopology
49161 49162 49163 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49161 def accelerator_topology @accelerator_topology end |
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology. If not
specified, the default is AUTO_CONNECT.
Corresponds to the JSON property acceleratorTopologyMode
49167 49168 49169 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49167 def accelerator_topology_mode @accelerator_topology_mode end |
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
Corresponds to the JSON property maxTopologyDistance
49172 49173 49174 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49172 def max_topology_distance @max_topology_distance end |
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Corresponds to the JSON property type
49177 49178 49179 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49177 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49184 49185 49186 49187 49188 49189 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49184 def update!(**args) @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology) @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode) @max_topology_distance = args[:max_topology_distance] if args.key?(:max_topology_distance) @type = args[:type] if args.key?(:type) end |