Class: Google::Apis::ComputeV1::ResourcePolicyWorkloadPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourcePolicyWorkloadPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents the workload policy.
Instance Attribute Summary collapse
-
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
-
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
-
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
constructor
A new instance of ResourcePolicyWorkloadPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
Returns a new instance of ResourcePolicyWorkloadPolicy.
44543 44544 44545 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have
interconnected GPUs.
Corresponds to the JSON property acceleratorTopology
44531 44532 44533 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44531 def accelerator_topology @accelerator_topology end |
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
Corresponds to the JSON property maxTopologyDistance
44536 44537 44538 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44536 def max_topology_distance @max_topology_distance end |
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Corresponds to the JSON property type
44541 44542 44543 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44541 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44548 44549 44550 44551 44552 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44548 def update!(**args) @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology) @max_topology_distance = args[:max_topology_distance] if args.key?(:max_topology_distance) @type = args[:type] if args.key?(:type) end |