Class: Google::Apis::ComputeV1::ResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatus

Returns a new instance of ResourceStatus.



50857
50858
50859
# File 'lib/google/apis/compute_v1/classes.rb', line 50857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_instance_metadataGoogle::Apis::ComputeV1::ResourceStatusEffectiveInstanceMetadata

Effective values of predefined metadata keys for an instance. Corresponds to the JSON property effectiveInstanceMetadata



50820
50821
50822
# File 'lib/google/apis/compute_v1/classes.rb', line 50820

def 
  @effective_instance_metadata
end

#physical_hostString

Output only. [Output Only] The precise location of your instance within the zone's data center, including the block, sub-block, and host. The field is formatted as follows: blockId/subBlockId/hostId. Corresponds to the JSON property physicalHost

Returns:

  • (String)


50828
50829
50830
# File 'lib/google/apis/compute_v1/classes.rb', line 50828

def physical_host
  @physical_host
end

#physical_host_topologyGoogle::Apis::ComputeV1::ResourceStatusPhysicalHostTopology

Represents the physical host topology of the host on which the VM is running. Corresponds to the JSON property physicalHostTopology



50834
50835
50836
# File 'lib/google/apis/compute_v1/classes.rb', line 50834

def physical_host_topology
  @physical_host_topology
end

#reservation_consumption_infoGoogle::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo

Reservation consumption information that the instance is consuming from. Corresponds to the JSON property reservationConsumptionInfo



50839
50840
50841
# File 'lib/google/apis/compute_v1/classes.rb', line 50839

def reservation_consumption_info
  @reservation_consumption_info
end

#schedulingGoogle::Apis::ComputeV1::ResourceStatusScheduling

Corresponds to the JSON property scheduling



50844
50845
50846
# File 'lib/google/apis/compute_v1/classes.rb', line 50844

def scheduling
  @scheduling
end

#shutdown_detailsGoogle::Apis::ComputeV1::ResourceStatusShutdownDetails

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled. Corresponds to the JSON property shutdownDetails



50850
50851
50852
# File 'lib/google/apis/compute_v1/classes.rb', line 50850

def shutdown_details
  @shutdown_details
end

#upcoming_maintenanceGoogle::Apis::ComputeV1::UpcomingMaintenance

Upcoming Maintenance notification information. Corresponds to the JSON property upcomingMaintenance



50855
50856
50857
# File 'lib/google/apis/compute_v1/classes.rb', line 50855

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50862
50863
50864
50865
50866
50867
50868
50869
50870
# File 'lib/google/apis/compute_v1/classes.rb', line 50862

def update!(**args)
  @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata)
  @physical_host = args[:physical_host] if args.key?(:physical_host)
  @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology)
  @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end