Class: Google::Apis::ComputeV1::ResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatus

Returns a new instance of ResourceStatus.



50118
50119
50120
# File 'lib/google/apis/compute_v1/classes.rb', line 50118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_instance_metadataGoogle::Apis::ComputeV1::ResourceStatusEffectiveInstanceMetadata

Effective values of predefined metadata keys for an instance. Corresponds to the JSON property effectiveInstanceMetadata



50087
50088
50089
# File 'lib/google/apis/compute_v1/classes.rb', line 50087

def 
  @effective_instance_metadata
end

#physical_hostString

Output only. [Output Only] The precise location of your instance within the zone's data center, including the block, sub-block, and host. The field is formatted as follows: blockId/subBlockId/hostId. Corresponds to the JSON property physicalHost

Returns:

  • (String)


50095
50096
50097
# File 'lib/google/apis/compute_v1/classes.rb', line 50095

def physical_host
  @physical_host
end

#physical_host_topologyGoogle::Apis::ComputeV1::ResourceStatusPhysicalHostTopology

Represents the physical host topology of the host on which the VM is running. Corresponds to the JSON property physicalHostTopology



50101
50102
50103
# File 'lib/google/apis/compute_v1/classes.rb', line 50101

def physical_host_topology
  @physical_host_topology
end

#reservation_consumption_infoGoogle::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo

Reservation consumption information that the instance is consuming from. Corresponds to the JSON property reservationConsumptionInfo



50106
50107
50108
# File 'lib/google/apis/compute_v1/classes.rb', line 50106

def reservation_consumption_info
  @reservation_consumption_info
end

#schedulingGoogle::Apis::ComputeV1::ResourceStatusScheduling

Corresponds to the JSON property scheduling



50111
50112
50113
# File 'lib/google/apis/compute_v1/classes.rb', line 50111

def scheduling
  @scheduling
end

#upcoming_maintenanceGoogle::Apis::ComputeV1::UpcomingMaintenance

Upcoming Maintenance notification information. Corresponds to the JSON property upcomingMaintenance



50116
50117
50118
# File 'lib/google/apis/compute_v1/classes.rb', line 50116

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50123
50124
50125
50126
50127
50128
50129
50130
# File 'lib/google/apis/compute_v1/classes.rb', line 50123

def update!(**args)
  @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata)
  @physical_host = args[:physical_host] if args.key?(:physical_host)
  @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology)
  @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end