Class: Google::Apis::ComputeV1::ResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.
Instance Attribute Summary collapse
-
#effective_instance_metadata ⇒ Google::Apis::ComputeV1::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
-
#physical_host ⇒ String
Output only.
-
#physical_host_topology ⇒ Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is running.
-
#reservation_consumption_info ⇒ Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
-
#scheduling ⇒ Google::Apis::ComputeV1::ResourceStatusScheduling
Corresponds to the JSON property
scheduling. -
#upcoming_maintenance ⇒ Google::Apis::ComputeV1::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatus
constructor
A new instance of ResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatus
Returns a new instance of ResourceStatus.
45775 45776 45777 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45775 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_instance_metadata ⇒ Google::Apis::ComputeV1::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
Corresponds to the JSON property effectiveInstanceMetadata
45744 45745 45746 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45744 def @effective_instance_metadata end |
#physical_host ⇒ String
Output only. [Output Only] The precise location of your instance within the
zone's data
center, including the block, sub-block, and host. The field is formatted as
follows: blockId/subBlockId/hostId.
Corresponds to the JSON property physicalHost
45752 45753 45754 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45752 def physical_host @physical_host end |
#physical_host_topology ⇒ Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is
running.
Corresponds to the JSON property physicalHostTopology
45758 45759 45760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45758 def physical_host_topology @physical_host_topology end |
#reservation_consumption_info ⇒ Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
Corresponds to the JSON property reservationConsumptionInfo
45763 45764 45765 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45763 def reservation_consumption_info @reservation_consumption_info end |
#scheduling ⇒ Google::Apis::ComputeV1::ResourceStatusScheduling
Corresponds to the JSON property scheduling
45768 45769 45770 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45768 def scheduling @scheduling end |
#upcoming_maintenance ⇒ Google::Apis::ComputeV1::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingMaintenance
45773 45774 45775 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45773 def upcoming_maintenance @upcoming_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45780 45781 45782 45783 45784 45785 45786 45787 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45780 def update!(**args) @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata) @physical_host = args[:physical_host] if args.key?(:physical_host) @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology) @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info) @scheduling = args[:scheduling] if args.key?(:scheduling) @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance) end |