Class: Google::Apis::ComputeV1::ResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.
Instance Attribute Summary collapse
-
#effective_instance_metadata ⇒ Google::Apis::ComputeV1::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
-
#physical_host ⇒ String
Output only.
-
#physical_host_topology ⇒ Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is running.
-
#reservation_consumption_info ⇒ Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
-
#scheduling ⇒ Google::Apis::ComputeV1::ResourceStatusScheduling
Corresponds to the JSON property
scheduling. -
#upcoming_maintenance ⇒ Google::Apis::ComputeV1::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatus
constructor
A new instance of ResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatus
Returns a new instance of ResourceStatus.
44595 44596 44597 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_instance_metadata ⇒ Google::Apis::ComputeV1::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
Corresponds to the JSON property effectiveInstanceMetadata
44564 44565 44566 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44564 def @effective_instance_metadata end |
#physical_host ⇒ String
Output only. [Output Only] The precise location of your instance within the
zone's data
center, including the block, sub-block, and host. The field is formatted as
follows: blockId/subBlockId/hostId.
Corresponds to the JSON property physicalHost
44572 44573 44574 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44572 def physical_host @physical_host end |
#physical_host_topology ⇒ Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is
running.
Corresponds to the JSON property physicalHostTopology
44578 44579 44580 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44578 def physical_host_topology @physical_host_topology end |
#reservation_consumption_info ⇒ Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
Corresponds to the JSON property reservationConsumptionInfo
44583 44584 44585 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44583 def reservation_consumption_info @reservation_consumption_info end |
#scheduling ⇒ Google::Apis::ComputeV1::ResourceStatusScheduling
Corresponds to the JSON property scheduling
44588 44589 44590 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44588 def scheduling @scheduling end |
#upcoming_maintenance ⇒ Google::Apis::ComputeV1::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingMaintenance
44593 44594 44595 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44593 def upcoming_maintenance @upcoming_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44600 44601 44602 44603 44604 44605 44606 44607 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44600 def update!(**args) @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata) @physical_host = args[:physical_host] if args.key?(:physical_host) @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology) @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info) @scheduling = args[:scheduling] if args.key?(:scheduling) @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance) end |