Class: Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents the physical host topology of the host on which the VM is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology

Returns a new instance of ResourceStatusPhysicalHostTopology.



50409
50410
50411
# File 'lib/google/apis/compute_v1/classes.rb', line 50409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesGoogle::Apis::ComputeV1::ResourceStatusPhysicalHostTopologyAdditionalAttributes

Additional location information of the running instance. Corresponds to the JSON property additionalAttributes



50381
50382
50383
# File 'lib/google/apis/compute_v1/classes.rb', line 50381

def additional_attributes
  @additional_attributes
end

#blockString

[Output Only] The ID of the block in which the running instance is located. Instances within the same block experience low network latency. Corresponds to the JSON property block

Returns:

  • (String)


50387
50388
50389
# File 'lib/google/apis/compute_v1/classes.rb', line 50387

def block
  @block
end

#clusterString

[Output Only] The global name of the Compute Engine cluster where the running instance is located. Corresponds to the JSON property cluster

Returns:

  • (String)


50393
50394
50395
# File 'lib/google/apis/compute_v1/classes.rb', line 50393

def cluster
  @cluster
end

#hostString

[Output Only] The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency. Corresponds to the JSON property host

Returns:

  • (String)


50400
50401
50402
# File 'lib/google/apis/compute_v1/classes.rb', line 50400

def host
  @host
end

#subblockString

[Output Only] The ID of the sub-block in which the running instance is located. Instances in the same sub-block experience lower network latency than instances in the same block. Corresponds to the JSON property subblock

Returns:

  • (String)


50407
50408
50409
# File 'lib/google/apis/compute_v1/classes.rb', line 50407

def subblock
  @subblock
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50414
50415
50416
50417
50418
50419
50420
# File 'lib/google/apis/compute_v1/classes.rb', line 50414

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @subblock = args[:subblock] if args.key?(:subblock)
end