Class: Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents the physical host topology of the host on which the VM is running.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopologyAdditionalAttributes
Additional location information of the running instance.
-
#block ⇒ String
[Output Only] The ID of the block in which the running instance is located.
-
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the running instance is located.
-
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
-
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
constructor
A new instance of ResourceStatusPhysicalHostTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
Returns a new instance of ResourceStatusPhysicalHostTopology.
50409 50410 50411 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopologyAdditionalAttributes
Additional location information of the running instance.
Corresponds to the JSON property additionalAttributes
50381 50382 50383 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50381 def additional_attributes @additional_attributes end |
#block ⇒ String
[Output Only] The ID of the block in which the running instance is
located. Instances within the same block experience low network latency.
Corresponds to the JSON property block
50387 50388 50389 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50387 def block @block end |
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the
running instance is located.
Corresponds to the JSON property cluster
50393 50394 50395 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50393 def cluster @cluster end |
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
Instances on the same host experience the lowest possible network
latency.
Corresponds to the JSON property host
50400 50401 50402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50400 def host @host end |
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is
located. Instances in the same sub-block experience lower network latency
than instances in the same block.
Corresponds to the JSON property subblock
50407 50408 50409 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50407 def subblock @subblock end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50414 50415 50416 50417 50418 50419 50420 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50414 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @subblock = args[:subblock] if args.key?(:subblock) end |