Class: Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents the physical host topology of the host on which the VM is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology

Returns a new instance of ResourceStatusPhysicalHostTopology.



50244
50245
50246
# File 'lib/google/apis/compute_v1/classes.rb', line 50244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesGoogle::Apis::ComputeV1::ResourceStatusPhysicalHostTopologyAdditionalAttributes

Additional location information of the running instance. Corresponds to the JSON property additionalAttributes



50216
50217
50218
# File 'lib/google/apis/compute_v1/classes.rb', line 50216

def additional_attributes
  @additional_attributes
end

#blockString

[Output Only] The ID of the block in which the running instance is located. Instances within the same block experience low network latency. Corresponds to the JSON property block

Returns:

  • (String)


50222
50223
50224
# File 'lib/google/apis/compute_v1/classes.rb', line 50222

def block
  @block
end

#clusterString

[Output Only] The global name of the Compute Engine cluster where the running instance is located. Corresponds to the JSON property cluster

Returns:

  • (String)


50228
50229
50230
# File 'lib/google/apis/compute_v1/classes.rb', line 50228

def cluster
  @cluster
end

#hostString

[Output Only] The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency. Corresponds to the JSON property host

Returns:

  • (String)


50235
50236
50237
# File 'lib/google/apis/compute_v1/classes.rb', line 50235

def host
  @host
end

#subblockString

[Output Only] The ID of the sub-block in which the running instance is located. Instances in the same sub-block experience lower network latency than instances in the same block. Corresponds to the JSON property subblock

Returns:

  • (String)


50242
50243
50244
# File 'lib/google/apis/compute_v1/classes.rb', line 50242

def subblock
  @subblock
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50249
50250
50251
50252
50253
50254
50255
# File 'lib/google/apis/compute_v1/classes.rb', line 50249

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @subblock = args[:subblock] if args.key?(:subblock)
end