Class: Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents the physical host topology of the host on which the VM is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology

Returns a new instance of ResourceStatusPhysicalHostTopology.



49949
49950
49951
# File 'lib/google/apis/compute_v1/classes.rb', line 49949

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

[Output Only] The ID of the block in which the running instance is located. Instances within the same block experience low network latency. Corresponds to the JSON property block

Returns:

  • (String)


49927
49928
49929
# File 'lib/google/apis/compute_v1/classes.rb', line 49927

def block
  @block
end

#clusterString

[Output Only] The global name of the Compute Engine cluster where the running instance is located. Corresponds to the JSON property cluster

Returns:

  • (String)


49933
49934
49935
# File 'lib/google/apis/compute_v1/classes.rb', line 49933

def cluster
  @cluster
end

#hostString

[Output Only] The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency. Corresponds to the JSON property host

Returns:

  • (String)


49940
49941
49942
# File 'lib/google/apis/compute_v1/classes.rb', line 49940

def host
  @host
end

#subblockString

[Output Only] The ID of the sub-block in which the running instance is located. Instances in the same sub-block experience lower network latency than instances in the same block. Corresponds to the JSON property subblock

Returns:

  • (String)


49947
49948
49949
# File 'lib/google/apis/compute_v1/classes.rb', line 49947

def subblock
  @subblock
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49954
49955
49956
49957
49958
49959
# File 'lib/google/apis/compute_v1/classes.rb', line 49954

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @subblock = args[:subblock] if args.key?(:subblock)
end