Class: Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents the physical host topology of the host on which the VM is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology

Returns a new instance of ResourceStatusPhysicalHostTopology.



44709
44710
44711
# File 'lib/google/apis/compute_v1/classes.rb', line 44709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

[Output Only] The ID of the block in which the running instance is located. Instances within the same block experience low network latency. Corresponds to the JSON property block

Returns:

  • (String)


44687
44688
44689
# File 'lib/google/apis/compute_v1/classes.rb', line 44687

def block
  @block
end

#clusterString

[Output Only] The global name of the Compute Engine cluster where the running instance is located. Corresponds to the JSON property cluster

Returns:

  • (String)


44693
44694
44695
# File 'lib/google/apis/compute_v1/classes.rb', line 44693

def cluster
  @cluster
end

#hostString

[Output Only] The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency. Corresponds to the JSON property host

Returns:

  • (String)


44700
44701
44702
# File 'lib/google/apis/compute_v1/classes.rb', line 44700

def host
  @host
end

#subblockString

[Output Only] The ID of the sub-block in which the running instance is located. Instances in the same sub-block experience lower network latency than instances in the same block. Corresponds to the JSON property subblock

Returns:

  • (String)


44707
44708
44709
# File 'lib/google/apis/compute_v1/classes.rb', line 44707

def subblock
  @subblock
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44714
44715
44716
44717
44718
44719
# File 'lib/google/apis/compute_v1/classes.rb', line 44714

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @subblock = args[:subblock] if args.key?(:subblock)
end