Class: Google::Apis::ComputeV1::ResourceStatusPhysicalHostTopologyAdditionalAttributes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Additional location information of the running instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusPhysicalHostTopologyAdditionalAttributes

Returns a new instance of ResourceStatusPhysicalHostTopologyAdditionalAttributes.



50272
50273
50274
# File 'lib/google/apis/compute_v1/classes.rb', line 50272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topology_idsHash<String,String>

Output only. The IDs of the accelerator topologies the instance belongs to. For example The key will be topologies like "4x4", "2x2x2" and the value will be the location ID of the topologies. Corresponds to the JSON property acceleratorTopologyIds

Returns:

  • (Hash<String,String>)


50270
50271
50272
# File 'lib/google/apis/compute_v1/classes.rb', line 50270

def accelerator_topology_ids
  @accelerator_topology_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50277
50278
50279
# File 'lib/google/apis/compute_v1/classes.rb', line 50277

def update!(**args)
  @accelerator_topology_ids = args[:accelerator_topology_ids] if args.key?(:accelerator_topology_ids)
end