Class: Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Reservation consumption information that the instance is consuming from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo

Returns a new instance of ResourceStatusReservationConsumptionInfo.



45919
45920
45921
# File 'lib/google/apis/compute_v1/classes.rb', line 45919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumed_reservationString

Output only. [Output Only] The full resource name of the reservation that this instance is consuming from. Corresponds to the JSON property consumedReservation

Returns:

  • (String)


45917
45918
45919
# File 'lib/google/apis/compute_v1/classes.rb', line 45917

def consumed_reservation
  @consumed_reservation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45924
45925
45926
# File 'lib/google/apis/compute_v1/classes.rb', line 45924

def update!(**args)
  @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation)
end