Class: Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Reservation consumption information that the instance is consuming from.
Instance Attribute Summary collapse
-
#consumed_reservation ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo
constructor
A new instance of ResourceStatusReservationConsumptionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo
Returns a new instance of ResourceStatusReservationConsumptionInfo.
45919 45920 45921 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumed_reservation ⇒ String
Output only. [Output Only] The full resource name of the reservation that this
instance is consuming from.
Corresponds to the JSON property consumedReservation
45917 45918 45919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45917 def consumed_reservation @consumed_reservation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45924 45925 45926 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45924 def update!(**args) @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation) end |