Class: Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Reservation consumption information that the instance is consuming from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo

Returns a new instance of ResourceStatusReservationConsumptionInfo.



44732
44733
44734
# File 'lib/google/apis/compute_v1/classes.rb', line 44732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumed_reservationString

Output only. [Output Only] The full resource name of the reservation that this instance is consuming from. Corresponds to the JSON property consumedReservation

Returns:

  • (String)


44730
44731
44732
# File 'lib/google/apis/compute_v1/classes.rb', line 44730

def consumed_reservation
  @consumed_reservation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44737
44738
44739
# File 'lib/google/apis/compute_v1/classes.rb', line 44737

def update!(**args)
  @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation)
end