Class: Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourceStatusReservationConsumptionInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Reservation consumption information that the instance is consuming from.
Instance Attribute Summary collapse
-
#consumed_reservation ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo
constructor
A new instance of ResourceStatusReservationConsumptionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo
Returns a new instance of ResourceStatusReservationConsumptionInfo.
44732 44733 44734 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumed_reservation ⇒ String
Output only. [Output Only] The full resource name of the reservation that this
instance is consuming from.
Corresponds to the JSON property consumedReservation
44730 44731 44732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44730 def consumed_reservation @consumed_reservation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44737 44738 44739 |
# File 'lib/google/apis/compute_v1/classes.rb', line 44737 def update!(**args) @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation) end |