Class: Google::Apis::ComputeV1::ResourceStatusScheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourceStatusScheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in.
-
#graceful_shutdown_timestamp ⇒ String
Output only.
-
#termination_timestamp ⇒ String
Time in future when the instance will be terminated inRFC3339 text format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusScheduling
constructor
A new instance of ResourceStatusScheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusScheduling
Returns a new instance of ResourceStatusScheduling.
51126 51127 51128 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in. The value
must be a number between 1 and the number of availability domains
specified in the spread placement policy attached to the instance.
Corresponds to the JSON property availabilityDomain
51112 51113 51114 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51112 def availability_domain @availability_domain end |
#graceful_shutdown_timestamp ⇒ String
Output only. Specifies the timestamp, when the instance will start graceful
shutdown
process, in RFC3339 text format.
Corresponds to the JSON property gracefulShutdownTimestamp
51119 51120 51121 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51119 def @graceful_shutdown_timestamp end |
#termination_timestamp ⇒ String
Time in future when the instance will be terminated inRFC3339 text format.
Corresponds to the JSON property terminationTimestamp
51124 51125 51126 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51124 def @termination_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51131 51132 51133 51134 51135 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51131 def update!(**args) @availability_domain = args[:availability_domain] if args.key?(:availability_domain) @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp) @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp) end |