Class: Google::Apis::ComputeV1::ResourceStatusScheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusScheduling

Returns a new instance of ResourceStatusScheduling.



51080
51081
51082
# File 'lib/google/apis/compute_v1/classes.rb', line 51080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_domainFixnum

Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance. Corresponds to the JSON property availabilityDomain

Returns:

  • (Fixnum)


51066
51067
51068
# File 'lib/google/apis/compute_v1/classes.rb', line 51066

def availability_domain
  @availability_domain
end

#graceful_shutdown_timestampString

Output only. Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format. Corresponds to the JSON property gracefulShutdownTimestamp

Returns:

  • (String)


51073
51074
51075
# File 'lib/google/apis/compute_v1/classes.rb', line 51073

def graceful_shutdown_timestamp
  @graceful_shutdown_timestamp
end

#termination_timestampString

Time in future when the instance will be terminated inRFC3339 text format. Corresponds to the JSON property terminationTimestamp

Returns:

  • (String)


51078
51079
51080
# File 'lib/google/apis/compute_v1/classes.rb', line 51078

def termination_timestamp
  @termination_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51085
51086
51087
51088
51089
# File 'lib/google/apis/compute_v1/classes.rb', line 51085

def update!(**args)
  @availability_domain = args[:availability_domain] if args.key?(:availability_domain)
  @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp)
  @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp)
end