Class: Google::Apis::ComputeV1::ResourceStatusScheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusScheduling

Returns a new instance of ResourceStatusScheduling.



50007
50008
50009
# File 'lib/google/apis/compute_v1/classes.rb', line 50007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_domainFixnum

Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance. Corresponds to the JSON property availabilityDomain

Returns:

  • (Fixnum)


50005
50006
50007
# File 'lib/google/apis/compute_v1/classes.rb', line 50005

def availability_domain
  @availability_domain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50012
50013
50014
# File 'lib/google/apis/compute_v1/classes.rb', line 50012

def update!(**args)
  @availability_domain = args[:availability_domain] if args.key?(:availability_domain)
end