Class: Google::Apis::ComputeV1::ResourceStatusShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ResourceStatusShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Specifies if the instance is in PENDING_STOP state or there is a
programmed stop scheduled.
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Past timestamp indicating the beginning of current
stopStatein RFC3339 text format. -
#stop_state ⇒ String
Current stopping state of the instance.
-
#target_state ⇒ String
Target instance state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusShutdownDetails
constructor
A new instance of ResourceStatusShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusShutdownDetails
Returns a new instance of ResourceStatusShutdownDetails.
51121 51122 51123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
51103 51104 51105 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51103 def max_duration @max_duration end |
#request_timestamp ⇒ String
Past timestamp indicating the beginning of current stopState in RFC3339 text
format.
Corresponds to the JSON property requestTimestamp
51109 51110 51111 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51109 def @request_timestamp end |
#stop_state ⇒ String
Current stopping state of the instance.
Corresponds to the JSON property stopState
51114 51115 51116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51114 def stop_state @stop_state end |
#target_state ⇒ String
Target instance state.
Corresponds to the JSON property targetState
51119 51120 51121 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51119 def target_state @target_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51126 51127 51128 51129 51130 51131 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51126 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) @stop_state = args[:stop_state] if args.key?(:stop_state) @target_state = args[:target_state] if args.key?(:target_state) end |