Class: Google::Apis::ComputeV1::RiskDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Detailed insights and metrics about a detected reliability risk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RiskDetails

Returns a new instance of RiskDetails.



51163
51164
51165
# File 'lib/google/apis/compute_v1/classes.rb', line 51163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

The duration of the risk since it was detected. Corresponds to the JSON property duration

Returns:

  • (String)


51141
51142
51143
# File 'lib/google/apis/compute_v1/classes.rb', line 51141

def duration
  @duration
end

#global_dns_insightGoogle::Apis::ComputeV1::RiskDetailsGlobalDnsInsight

Detailed insights for a global DNS reliability risk. Corresponds to the JSON property globalDnsInsight



51146
51147
51148
# File 'lib/google/apis/compute_v1/classes.rb', line 51146

def global_dns_insight
  @global_dns_insight
end

#last_update_timestampString

The last time the risk was updated. Corresponds to the JSON property lastUpdateTimestamp

Returns:

  • (String)


51151
51152
51153
# File 'lib/google/apis/compute_v1/classes.rb', line 51151

def last_update_timestamp
  @last_update_timestamp
end

#severityString

The severity of the risk. Corresponds to the JSON property severity

Returns:

  • (String)


51156
51157
51158
# File 'lib/google/apis/compute_v1/classes.rb', line 51156

def severity
  @severity
end

#typeString

The type of risk. Corresponds to the JSON property type

Returns:

  • (String)


51161
51162
51163
# File 'lib/google/apis/compute_v1/classes.rb', line 51161

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51168
51169
51170
51171
51172
51173
51174
# File 'lib/google/apis/compute_v1/classes.rb', line 51168

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @global_dns_insight = args[:global_dns_insight] if args.key?(:global_dns_insight)
  @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp)
  @severity = args[:severity] if args.key?(:severity)
  @type = args[:type] if args.key?(:type)
end