Class: Google::Apis::ComputeV1::Rollout

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Rollout resource. A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



50429
50430
50431
# File 'lib/google/apis/compute_v1/classes.rb', line 50429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancellation_timeString

Output only. The timestamp at which the Rollout was cancelled. Corresponds to the JSON property cancellationTime

Returns:

  • (String)


50332
50333
50334
# File 'lib/google/apis/compute_v1/classes.rb', line 50332

def cancellation_time
  @cancellation_time
end

#completion_timeString

Output only. The timestamp at which the Rollout was completed. Corresponds to the JSON property completionTime

Returns:

  • (String)


50337
50338
50339
# File 'lib/google/apis/compute_v1/classes.rb', line 50337

def completion_time
  @completion_time
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


50343
50344
50345
# File 'lib/google/apis/compute_v1/classes.rb', line 50343

def creation_timestamp
  @creation_timestamp
end

#current_wave_numberFixnum

Output only. The number of the currently running wave. Ex. 1 Corresponds to the JSON property currentWaveNumber

Returns:

  • (Fixnum)


50349
50350
50351
# File 'lib/google/apis/compute_v1/classes.rb', line 50349

def current_wave_number
  @current_wave_number
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


50355
50356
50357
# File 'lib/google/apis/compute_v1/classes.rb', line 50355

def description
  @description
end

#etagString

Output only. etag of the Rollout Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


50361
50362
50363
# File 'lib/google/apis/compute_v1/classes.rb', line 50361

def etag
  @etag
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


50368
50369
50370
# File 'lib/google/apis/compute_v1/classes.rb', line 50368

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#rollout for rollouts. Corresponds to the JSON property kind

Returns:

  • (String)


50374
50375
50376
# File 'lib/google/apis/compute_v1/classes.rb', line 50374

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


50385
50386
50387
# File 'lib/google/apis/compute_v1/classes.rb', line 50385

def name
  @name
end

#pause_timeString

Output only. The timestamp at which the Rollout was paused. Corresponds to the JSON property pauseTime

Returns:

  • (String)


50390
50391
50392
# File 'lib/google/apis/compute_v1/classes.rb', line 50390

def pause_time
  @pause_time
end

#resume_timeString

Output only. The timestamp at which the Rollout was resumed. Corresponds to the JSON property resumeTime

Returns:

  • (String)


50395
50396
50397
# File 'lib/google/apis/compute_v1/classes.rb', line 50395

def resume_time
  @resume_time
end

#rollout_entityGoogle::Apis::ComputeV1::RolloutRolloutEntity

Specifications of the resource to roll out. Corresponds to the JSON property rolloutEntity



50400
50401
50402
# File 'lib/google/apis/compute_v1/classes.rb', line 50400

def rollout_entity
  @rollout_entity
end

#rollout_planString

Required. Rollout Plan used to model the Rollout. Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1 Corresponds to the JSON property rolloutPlan

Returns:

  • (String)


50406
50407
50408
# File 'lib/google/apis/compute_v1/classes.rb', line 50406

def rollout_plan
  @rollout_plan
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50412
50413
50414
# File 'lib/google/apis/compute_v1/classes.rb', line 50412

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


50417
50418
50419
# File 'lib/google/apis/compute_v1/classes.rb', line 50417

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. The current state of the Rollout. Corresponds to the JSON property state

Returns:

  • (String)


50422
50423
50424
# File 'lib/google/apis/compute_v1/classes.rb', line 50422

def state
  @state
end

#wave_detailsArray<Google::Apis::ComputeV1::RolloutWaveDetails>

Output only. Details about each wave of the rollout. Corresponds to the JSON property waveDetails



50427
50428
50429
# File 'lib/google/apis/compute_v1/classes.rb', line 50427

def wave_details
  @wave_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50434
50435
50436
50437
50438
50439
50440
50441
50442
50443
50444
50445
50446
50447
50448
50449
50450
50451
50452
# File 'lib/google/apis/compute_v1/classes.rb', line 50434

def update!(**args)
  @cancellation_time = args[:cancellation_time] if args.key?(:cancellation_time)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_wave_number = args[:current_wave_number] if args.key?(:current_wave_number)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @pause_time = args[:pause_time] if args.key?(:pause_time)
  @resume_time = args[:resume_time] if args.key?(:resume_time)
  @rollout_entity = args[:rollout_entity] if args.key?(:rollout_entity)
  @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @wave_details = args[:wave_details] if args.key?(:wave_details)
end