Class: Google::Apis::ComputeV1::RolloutPlanWave

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A single wave in a rollout plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWave

Returns a new instance of RolloutPlanWave.



50738
50739
50740
# File 'lib/google/apis/compute_v1/classes.rb', line 50738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of this wave of the rollout plan. Corresponds to the JSON property displayName

Returns:

  • (String)


50711
50712
50713
# File 'lib/google/apis/compute_v1/classes.rb', line 50711

def display_name
  @display_name
end

#numberFixnum

Output only. The wave number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


50716
50717
50718
# File 'lib/google/apis/compute_v1/classes.rb', line 50716

def number
  @number
end

#orchestration_optionsGoogle::Apis::ComputeV1::RolloutPlanWaveOrchestrationOptions

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern. Corresponds to the JSON property orchestrationOptions



50723
50724
50725
# File 'lib/google/apis/compute_v1/classes.rb', line 50723

def orchestration_options
  @orchestration_options
end

#selectorsArray<Google::Apis::ComputeV1::RolloutPlanWaveSelector>

Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave. Corresponds to the JSON property selectors



50731
50732
50733
# File 'lib/google/apis/compute_v1/classes.rb', line 50731

def selectors
  @selectors
end

#validationGoogle::Apis::ComputeV1::RolloutPlanWaveValidation

The validation to be performed before progressing to the next wave. Corresponds to the JSON property validation



50736
50737
50738
# File 'lib/google/apis/compute_v1/classes.rb', line 50736

def validation
  @validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50743
50744
50745
50746
50747
50748
50749
# File 'lib/google/apis/compute_v1/classes.rb', line 50743

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @number = args[:number] if args.key?(:number)
  @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options)
  @selectors = args[:selectors] if args.key?(:selectors)
  @validation = args[:validation] if args.key?(:validation)
end