Class: Google::Apis::ComputeV1::RolloutPlanWave
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutPlanWave
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A single wave in a rollout plan.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#number ⇒ Fixnum
Output only.
-
#orchestration_options ⇒ Google::Apis::ComputeV1::RolloutPlanWaveOrchestrationOptions
Options to control the pace of orchestration of a wave.
-
#selectors ⇒ Array<Google::Apis::ComputeV1::RolloutPlanWaveSelector>
Required.
-
#validation ⇒ Google::Apis::ComputeV1::RolloutPlanWaveValidation
The validation to be performed before progressing to the next wave.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWave
constructor
A new instance of RolloutPlanWave.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWave
Returns a new instance of RolloutPlanWave.
50738 50739 50740 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50738 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. The display name of this wave of the rollout plan.
Corresponds to the JSON property displayName
50711 50712 50713 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50711 def display_name @display_name end |
#number ⇒ Fixnum
Output only. The wave number.
Corresponds to the JSON property number
50716 50717 50718 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50716 def number @number end |
#orchestration_options ⇒ Google::Apis::ComputeV1::RolloutPlanWaveOrchestrationOptions
Options to control the pace of orchestration of a wave. These options are
required only if the resource being rolled out follows the Orchestrated
pattern.
Corresponds to the JSON property orchestrationOptions
50723 50724 50725 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50723 def @orchestration_options end |
#selectors ⇒ Array<Google::Apis::ComputeV1::RolloutPlanWaveSelector>
Required. The selectors for this wave. There is a logical AND between each
selector
defined in a wave, so a resource must satisfy the criteria of all the
specified selectors to be in scope for the wave.
Corresponds to the JSON property selectors
50731 50732 50733 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50731 def selectors @selectors end |
#validation ⇒ Google::Apis::ComputeV1::RolloutPlanWaveValidation
The validation to be performed before progressing to the next wave.
Corresponds to the JSON property validation
50736 50737 50738 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50736 def validation @validation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50743 50744 50745 50746 50747 50748 50749 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50743 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @number = args[:number] if args.key?(:number) @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options) @selectors = args[:selectors] if args.key?(:selectors) @validation = args[:validation] if args.key?(:validation) end |