Class: Google::Apis::ComputeV1::RolloutPlanWaveOrchestrationOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutPlanWaveOrchestrationOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.
Instance Attribute Summary collapse
-
#delays ⇒ Array<Google::Apis::ComputeV1::RolloutPlanWaveOrchestrationOptionsDelay>
Optional.
-
#max_concurrent_locations ⇒ Fixnum
Optional.
-
#max_concurrent_resources_per_location ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions
constructor
A new instance of RolloutPlanWaveOrchestrationOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions
Returns a new instance of RolloutPlanWaveOrchestrationOptions.
50613 50614 50615 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50613 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delays ⇒ Array<Google::Apis::ComputeV1::RolloutPlanWaveOrchestrationOptionsDelay>
Optional. Delays, if any, to be added between batches of projects. We allow
multiple Delays to be specified, letting users set separate delays
between batches of projects corresponding to different locations and
batches of projects corresponding to the same location.
Corresponds to the JSON property delays
50600 50601 50602 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50600 def delays @delays end |
#max_concurrent_locations ⇒ Fixnum
Optional. Maximum number of locations to be orchestrated in parallel.
Corresponds to the JSON property maxConcurrentLocations
50605 50606 50607 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50605 def max_concurrent_locations @max_concurrent_locations end |
#max_concurrent_resources_per_location ⇒ Fixnum
Optional. Maximum number of resources to be orchestrated per location in
parallel.
Corresponds to the JSON property maxConcurrentResourcesPerLocation
50611 50612 50613 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50611 def max_concurrent_resources_per_location @max_concurrent_resources_per_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50618 50619 50620 50621 50622 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50618 def update!(**args) @delays = args[:delays] if args.key?(:delays) @max_concurrent_locations = args[:max_concurrent_locations] if args.key?(:max_concurrent_locations) @max_concurrent_resources_per_location = args[:max_concurrent_resources_per_location] if args.key?(:max_concurrent_resources_per_location) end |