Class: Google::Apis::ComputeV1::RolloutPlanWaveValidation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutPlanWaveValidation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The validation to be performed before progressing to the next wave.
Instance Attribute Summary collapse
-
#time_based_validation_metadata ⇒ Google::Apis::ComputeV1::RolloutPlanWaveValidationTimeBasedValidationMetadata
Metadata required if type = "time".
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveValidation
constructor
A new instance of RolloutPlanWaveValidation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveValidation
Returns a new instance of RolloutPlanWaveValidation.
50430 50431 50432 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#time_based_validation_metadata ⇒ Google::Apis::ComputeV1::RolloutPlanWaveValidationTimeBasedValidationMetadata
Metadata required if type = "time".
Corresponds to the JSON property timeBasedValidationMetadata
50415 50416 50417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50415 def @time_based_validation_metadata end |
#type ⇒ String
Required. The type of the validation. If a type of validation is associated
with
a metadata object, the appropriate metadata field mapping to the
validation type must be provided in the validation message. Possible
values are in quotes below alongside an explanation:
"manual": The system waits for an end-user approval API before
progressing to the next wave.
"time": The system waits for a user specified duration before
progressing to the next wave. TimeBasedValidation must be provided.
Corresponds to the JSON property type
50428 50429 50430 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50428 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50435 50436 50437 50438 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50435 def update!(**args) @time_based_validation_metadata = args[:time_based_validation_metadata] if args.key?(:time_based_validation_metadata) @type = args[:type] if args.key?(:type) end |