Class: Google::Apis::ComputeV1::RolloutPlanWaveValidationTimeBasedValidationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutPlanWaveValidationTimeBasedValidationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Metadata required if type = "time".
Instance Attribute Summary collapse
-
#wait_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata
constructor
A new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata
Returns a new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.
50960 50961 50962 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#wait_duration ⇒ String
Optional. The duration that the system waits in between waves. This wait
starts
after all changes in the wave are rolled out.
Corresponds to the JSON property waitDuration
50958 50959 50960 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50958 def wait_duration @wait_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50965 50966 50967 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50965 def update!(**args) @wait_duration = args[:wait_duration] if args.key?(:wait_duration) end |