Class: Google::Apis::ComputeV1::RolloutPlanWaveValidationTimeBasedValidationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Metadata required if type = "time".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata

Returns a new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.



50948
50949
50950
# File 'lib/google/apis/compute_v1/classes.rb', line 50948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#wait_durationString

Optional. The duration that the system waits in between waves. This wait starts after all changes in the wave are rolled out. Corresponds to the JSON property waitDuration

Returns:

  • (String)


50946
50947
50948
# File 'lib/google/apis/compute_v1/classes.rb', line 50946

def wait_duration
  @wait_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50953
50954
50955
# File 'lib/google/apis/compute_v1/classes.rb', line 50953

def update!(**args)
  @wait_duration = args[:wait_duration] if args.key?(:wait_duration)
end