Class: Google::Apis::ComputeV1::RolloutPlanWaveValidationTimeBasedValidationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Metadata required if type = "time".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata

Returns a new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.



50783
50784
50785
# File 'lib/google/apis/compute_v1/classes.rb', line 50783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#wait_durationString

Optional. The duration that the system waits in between waves. This wait starts after all changes in the wave are rolled out. Corresponds to the JSON property waitDuration

Returns:

  • (String)


50781
50782
50783
# File 'lib/google/apis/compute_v1/classes.rb', line 50781

def wait_duration
  @wait_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50788
50789
50790
# File 'lib/google/apis/compute_v1/classes.rb', line 50788

def update!(**args)
  @wait_duration = args[:wait_duration] if args.key?(:wait_duration)
end