Class: Google::Apis::ComputeV1::RolloutPlansListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutPlansListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of RolloutPlan resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::RolloutPlan>
A list of RolloutPlan resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlansListResponse
constructor
A new instance of RolloutPlansListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlansListResponse
Returns a new instance of RolloutPlansListResponse.
51015 51016 51017 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
50977 50978 50979 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50977 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50982 50983 50984 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50982 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::RolloutPlan>
A list of RolloutPlan resources.
Corresponds to the JSON property items
50987 50988 50989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50987 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50997 50998 50999 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50997 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51002 51003 51004 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51002 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
51008 51009 51010 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51008 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51013 51014 51015 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51013 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51020 51021 51022 51023 51024 51025 51026 51027 51028 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51020 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |