Class: Google::Apis::ComputeV1::RolloutPlansListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutPlansListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of RolloutPlan resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::RolloutPlan>
A list of RolloutPlan resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlansListResponse
constructor
A new instance of RolloutPlansListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlansListResponse
Returns a new instance of RolloutPlansListResponse.
51003 51004 51005 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
50965 50966 50967 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50965 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50970 50971 50972 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50970 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::RolloutPlan>
A list of RolloutPlan resources.
Corresponds to the JSON property items
50975 50976 50977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50975 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50985 50986 50987 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50985 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50990 50991 50992 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50990 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
50996 50997 50998 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50996 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51001 51002 51003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51001 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51008 51009 51010 51011 51012 51013 51014 51015 51016 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51008 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |