Class: Google::Apis::ComputeV1::RolloutPlansListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutPlansListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of RolloutPlan resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::RolloutPlan>
A list of RolloutPlan resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlansListResponse
constructor
A new instance of RolloutPlansListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlansListResponse
Returns a new instance of RolloutPlansListResponse.
50838 50839 50840 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
50800 50801 50802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50800 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50805 50806 50807 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50805 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::RolloutPlan>
A list of RolloutPlan resources.
Corresponds to the JSON property items
50810 50811 50812 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50810 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50820 50821 50822 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50820 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50825 50826 50827 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50825 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
50831 50832 50833 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50831 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
50836 50837 50838 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50836 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50843 50844 50845 50846 50847 50848 50849 50850 50851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50843 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |