Class: Google::Apis::ComputeV1::RolloutWaveDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutWaveDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Additional metadata about the status of each wave provided by the server.
Instance Attribute Summary collapse
-
#orchestrated_wave_details ⇒ Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetails
Details of the wave for products using the Orchestrated integration model.
-
#wave_display_name ⇒ String
Output only.
-
#wave_number ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutWaveDetails
constructor
A new instance of RolloutWaveDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutWaveDetails
Returns a new instance of RolloutWaveDetails.
50684 50685 50686 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#orchestrated_wave_details ⇒ Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetails
Details of the wave for products using the Orchestrated integration
model.
Corresponds to the JSON property orchestratedWaveDetails
50671 50672 50673 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50671 def orchestrated_wave_details @orchestrated_wave_details end |
#wave_display_name ⇒ String
Output only. Wave name.
Ex. wave1
Corresponds to the JSON property waveDisplayName
50677 50678 50679 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50677 def wave_display_name @wave_display_name end |
#wave_number ⇒ Fixnum
Output only. System generated number for the wave.
Corresponds to the JSON property waveNumber
50682 50683 50684 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50682 def wave_number @wave_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50689 50690 50691 50692 50693 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50689 def update!(**args) @orchestrated_wave_details = args[:orchestrated_wave_details] if args.key?(:orchestrated_wave_details) @wave_display_name = args[:wave_display_name] if args.key?(:wave_display_name) @wave_number = args[:wave_number] if args.key?(:wave_number) end |