Class: Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Details of the wave for products using the Orchestrated integration model.
Instance Attribute Summary collapse
-
#completed_resources_count ⇒ Fixnum
Output only.
-
#estimated_completion_time ⇒ String
Output only.
-
#estimated_total_resources_count ⇒ Fixnum
Output only.
-
#failed_locations ⇒ Array<String>
Output only.
-
#failed_resources_count ⇒ Fixnum
Output only.
-
#location_status ⇒ Hash<String,Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails
constructor
A new instance of RolloutWaveDetailsOrchestratedWaveDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails
Returns a new instance of RolloutWaveDetailsOrchestratedWaveDetails.
51233 51234 51235 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_resources_count ⇒ Fixnum
Output only. Resource completed so far.
Corresponds to the JSON property completedResourcesCount
51200 51201 51202 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51200 def completed_resources_count @completed_resources_count end |
#estimated_completion_time ⇒ String
Output only. Estimated timestamp at which the wave will complete. Extrapolated
from
current progress.
Corresponds to the JSON property estimatedCompletionTime
51207 51208 51209 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51207 def estimated_completion_time @estimated_completion_time end |
#estimated_total_resources_count ⇒ Fixnum
Output only. Estimated total count of resources.
Corresponds to the JSON property estimatedTotalResourcesCount
51212 51213 51214 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51212 def estimated_total_resources_count @estimated_total_resources_count end |
#failed_locations ⇒ Array<String>
Output only. Locations that failed during orchestration, and
ProgressiveRollout
stopped retrying. There may be some successful resources rolled out in
the wave as the location may have failed later in the Rollout.
Corresponds to the JSON property failedLocations
51220 51221 51222 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51220 def failed_locations @failed_locations end |
#failed_resources_count ⇒ Fixnum
Output only. Resources failed.
Corresponds to the JSON property failedResourcesCount
51225 51226 51227 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51225 def failed_resources_count @failed_resources_count end |
#location_status ⇒ Hash<String,Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>
Output only. Status of each location in the wave. Map keys (locations) must be
specified like "us-east1" or "asia-west1-a".
Corresponds to the JSON property locationStatus
51231 51232 51233 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51231 def location_status @location_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51238 51239 51240 51241 51242 51243 51244 51245 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51238 def update!(**args) @completed_resources_count = args[:completed_resources_count] if args.key?(:completed_resources_count) @estimated_completion_time = args[:estimated_completion_time] if args.key?(:estimated_completion_time) @estimated_total_resources_count = args[:estimated_total_resources_count] if args.key?(:estimated_total_resources_count) @failed_locations = args[:failed_locations] if args.key?(:failed_locations) @failed_resources_count = args[:failed_resources_count] if args.key?(:failed_resources_count) @location_status = args[:location_status] if args.key?(:location_status) end |