Class: Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Details of the wave for products using the Orchestrated integration model.
Instance Attribute Summary collapse
-
#completed_resources_count ⇒ Fixnum
Output only.
-
#estimated_completion_time ⇒ String
Output only.
-
#estimated_total_resources_count ⇒ Fixnum
Output only.
-
#failed_locations ⇒ Array<String>
Output only.
-
#failed_resources_count ⇒ Fixnum
Output only.
-
#location_status ⇒ Hash<String,Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails
constructor
A new instance of RolloutWaveDetailsOrchestratedWaveDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails
Returns a new instance of RolloutWaveDetailsOrchestratedWaveDetails.
50737 50738 50739 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_resources_count ⇒ Fixnum
Output only. Resource completed so far.
Corresponds to the JSON property completedResourcesCount
50704 50705 50706 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50704 def completed_resources_count @completed_resources_count end |
#estimated_completion_time ⇒ String
Output only. Estimated timestamp at which the wave will complete. Extrapolated
from
current progress.
Corresponds to the JSON property estimatedCompletionTime
50711 50712 50713 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50711 def estimated_completion_time @estimated_completion_time end |
#estimated_total_resources_count ⇒ Fixnum
Output only. Estimated total count of resources.
Corresponds to the JSON property estimatedTotalResourcesCount
50716 50717 50718 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50716 def estimated_total_resources_count @estimated_total_resources_count end |
#failed_locations ⇒ Array<String>
Output only. Locations that failed during orchestration, and
ProgressiveRollout
stopped retrying. There may be some successful resources rolled out in
the wave as the location may have failed later in the Rollout.
Corresponds to the JSON property failedLocations
50724 50725 50726 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50724 def failed_locations @failed_locations end |
#failed_resources_count ⇒ Fixnum
Output only. Resources failed.
Corresponds to the JSON property failedResourcesCount
50729 50730 50731 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50729 def failed_resources_count @failed_resources_count end |
#location_status ⇒ Hash<String,Google::Apis::ComputeV1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>
Output only. Status of each location in the wave. Map keys (locations) must be
specified like "us-east1" or "asia-west1-a".
Corresponds to the JSON property locationStatus
50735 50736 50737 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50735 def location_status @location_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50742 50743 50744 50745 50746 50747 50748 50749 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50742 def update!(**args) @completed_resources_count = args[:completed_resources_count] if args.key?(:completed_resources_count) @estimated_completion_time = args[:estimated_completion_time] if args.key?(:estimated_completion_time) @estimated_total_resources_count = args[:estimated_total_resources_count] if args.key?(:estimated_total_resources_count) @failed_locations = args[:failed_locations] if args.key?(:failed_locations) @failed_resources_count = args[:failed_resources_count] if args.key?(:failed_resources_count) @location_status = args[:location_status] if args.key?(:location_status) end |