Class: Google::Apis::ComputeV1::RolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutsListResponse
constructor
A new instance of RolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutsListResponse
Returns a new instance of RolloutsListResponse.
52066 52067 52068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
52028 52029 52030 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52028 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52033 52034 52035 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52033 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
52038 52039 52040 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52038 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52048 52049 52050 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52048 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52053 52054 52055 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52053 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
52059 52060 52061 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52059 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52064 52065 52066 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52064 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52071 52072 52073 52074 52075 52076 52077 52078 52079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52071 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |