Class: Google::Apis::ComputeV1::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



51324
51325
51326
# File 'lib/google/apis/compute_v1/classes.rb', line 51324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51286
51287
51288
# File 'lib/google/apis/compute_v1/classes.rb', line 51286

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51291
51292
51293
# File 'lib/google/apis/compute_v1/classes.rb', line 51291

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



51296
51297
51298
# File 'lib/google/apis/compute_v1/classes.rb', line 51296

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51306
51307
51308
# File 'lib/google/apis/compute_v1/classes.rb', line 51306

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51311
51312
51313
# File 'lib/google/apis/compute_v1/classes.rb', line 51311

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51317
51318
51319
# File 'lib/google/apis/compute_v1/classes.rb', line 51317

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51322
51323
51324
# File 'lib/google/apis/compute_v1/classes.rb', line 51322

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51329
51330
51331
51332
51333
51334
51335
51336
51337
# File 'lib/google/apis/compute_v1/classes.rb', line 51329

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end