Class: Google::Apis::ComputeV1::RolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutsListResponse
constructor
A new instance of RolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutsListResponse
Returns a new instance of RolloutsListResponse.
51147 51148 51149 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
51109 51110 51111 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51109 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
51114 51115 51116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51114 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
51119 51120 51121 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51119 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51129 51130 51131 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51129 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51134 51135 51136 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51134 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
51140 51141 51142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51140 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51145 51146 51147 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51145 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51152 51153 51154 51155 51156 51157 51158 51159 51160 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51152 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |