Class: Google::Apis::ComputeV1::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



51148
51149
51150
# File 'lib/google/apis/compute_v1/classes.rb', line 51148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51110
51111
51112
# File 'lib/google/apis/compute_v1/classes.rb', line 51110

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51115
51116
51117
# File 'lib/google/apis/compute_v1/classes.rb', line 51115

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



51120
51121
51122
# File 'lib/google/apis/compute_v1/classes.rb', line 51120

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51130
51131
51132
# File 'lib/google/apis/compute_v1/classes.rb', line 51130

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51135
51136
51137
# File 'lib/google/apis/compute_v1/classes.rb', line 51135

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51141
51142
51143
# File 'lib/google/apis/compute_v1/classes.rb', line 51141

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51146
51147
51148
# File 'lib/google/apis/compute_v1/classes.rb', line 51146

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51153
51154
51155
51156
51157
51158
51159
51160
51161
# File 'lib/google/apis/compute_v1/classes.rb', line 51153

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end