Class: Google::Apis::ComputeV1::RolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutsListResponse
constructor
A new instance of RolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutsListResponse
Returns a new instance of RolloutsListResponse.
50830 50831 50832 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
50792 50793 50794 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50792 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50797 50798 50799 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50797 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
50802 50803 50804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50802 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50812 50813 50814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50812 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50817 50818 50819 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50817 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
50823 50824 50825 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50823 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
50828 50829 50830 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50828 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50835 50836 50837 50838 50839 50840 50841 50842 50843 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50835 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |