Class: Google::Apis::ComputeV1::Route
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Route
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Route resource. A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read theRoutes overview.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#as_paths ⇒ Array<Google::Apis::ComputeV1::RouteAsPath>
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#dest_range ⇒ String
The destination range of outgoing packets that this route applies to.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
Fully-qualified URL of the network that this route applies to.
-
#next_hop_gateway ⇒ String
The URL to a gateway that should handle matching packets.
-
#next_hop_hub ⇒ String
Output only.
-
#next_hop_ilb ⇒ String
The URL to a forwarding rule of typeloadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule.
-
#next_hop_instance ⇒ String
The URL to an instance that should handle matching packets.
-
#next_hop_inter_region_cost ⇒ Fixnum
Output only.
-
#next_hop_interconnect_attachment ⇒ String
Output only.
-
#next_hop_ip ⇒ String
The network IP address of an instance that should handle matching packets.
-
#next_hop_med ⇒ Fixnum
Output only.
-
#next_hop_network ⇒ String
The URL of the local network if it should handle matching packets.
-
#next_hop_origin ⇒ String
Output only.
-
#next_hop_peering ⇒ String
Output only.
-
#next_hop_vpn_tunnel ⇒ String
The URL to a VpnTunnel that should handle matching packets.
-
#params ⇒ Google::Apis::ComputeV1::RouteParams
Additional route parameters.
-
#priority ⇒ Fixnum
The priority of this route.
-
#route_status ⇒ String
[Output only] The status of the route.
-
#route_type ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined fully-qualified URL for this resource.
-
#tags ⇒ Array<String>
A list of instance tags to which this route applies.
-
#warnings ⇒ Array<Google::Apis::ComputeV1::Route::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Route
constructor
A new instance of Route.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Route
Returns a new instance of Route.
52369 52370 52371 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#as_paths ⇒ Array<Google::Apis::ComputeV1::RouteAsPath>
Output only. [Output Only] AS path.
Corresponds to the JSON property asPaths
52162 52163 52164 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52162 def as_paths @as_paths end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
52168 52169 52170 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52168 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this field when you
create the resource.
Corresponds to the JSON property description
52174 52175 52176 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52174 def description @description end |
#dest_range ⇒ String
The destination range of outgoing packets that this route applies to. Both
IPv4 and IPv6 are supported.
Must specify an IPv4 range (e.g. 192.0.2.0/24) or an IPv6 range in RFC 4291
format (e.g. 2001:db8::/32). IPv6 range will be displayed using RFC 5952
compressed format.
Corresponds to the JSON property destRange
52183 52184 52185 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52183 def dest_range @dest_range end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
52190 52191 52192 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52190 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of this resource. Always compute#routes for
Route resources.
Corresponds to the JSON property kind
52196 52197 52198 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52196 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a
lowercase letter, and all following characters (except for the last
character) must be a dash, lowercase letter, or digit. The last character
must be a lowercase letter or digit.
Corresponds to the JSON property name
52207 52208 52209 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52207 def name @name end |
#network ⇒ String
Fully-qualified URL of the network that this route applies to.
Corresponds to the JSON property network
52212 52213 52214 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52212 def network @network end |
#next_hop_gateway ⇒ String
The URL to a gateway that should handle matching packets.
You can only specify the internet gateway using a full or
partial valid URL: projects/project/global/gateways/default-internet-gateway
Corresponds to the JSON property nextHopGateway
52219 52220 52221 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52219 def next_hop_gateway @next_hop_gateway end |
#next_hop_hub ⇒ String
Output only. [Output Only] The full resource name of the Network Connectivity
Center hub
that will handle matching packets.
Corresponds to the JSON property nextHopHub
52226 52227 52228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52226 def next_hop_hub @next_hop_hub end |
#next_hop_ilb ⇒ String
The URL to a forwarding rule of typeloadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ forwardingRules/forwardingRule
regions/region/forwardingRules/forwardingRule If an IP address is provided, must specify an IPv4 address in dot-decimal notation or an IPv6 address in RFC 4291 format. For example, the following are all valid IP addresses:
10.128.0.56
2001:db8::2d9:51:0:0
2001:db8:0:0:2d9:51:0:0 IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address. Corresponds to the JSON property
nextHopIlb
52249 52250 52251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52249 def next_hop_ilb @next_hop_ilb end |
#next_hop_instance ⇒ String
The URL to an instance that should handle matching packets. You can specify
this as a full or partial URL.
For example:
https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/
Corresponds to the JSON property nextHopInstance
52257 52258 52259 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52257 def next_hop_instance @next_hop_instance end |
#next_hop_inter_region_cost ⇒ Fixnum
Output only. [Output only] Internal fixed region-to-region cost that Google
Cloud
calculates based on factors such as network performance, distance, and
available bandwidth between regions.
Corresponds to the JSON property nextHopInterRegionCost
52265 52266 52267 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52265 def next_hop_inter_region_cost @next_hop_inter_region_cost end |
#next_hop_interconnect_attachment ⇒ String
Output only. [Output Only] The URL to an InterconnectAttachment which is the
next hop
for the route.
This field will only be populated for dynamic routes generated by
Cloud Router with a linked interconnectAttachment or the static route
generated by each L2 Interconnect Attachment.
Corresponds to the JSON property nextHopInterconnectAttachment
52275 52276 52277 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52275 def @next_hop_interconnect_attachment end |
#next_hop_ip ⇒ String
The network IP address of an instance that should handle matching packets.
Both IPv6 address and IPv4 addresses are supported.
Must specify an IPv4 address in dot-decimal notation (e.g. 192.0.2.99) or
an IPv6 address in RFC 4291 format (e.g. 2001:db8::2d9:51:0:0 or
2001:db8:0:0:2d9:51:0:0). IPv6 addresses will be displayed using RFC 5952
compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an
IPv4-mapped IPv6 address.
Corresponds to the JSON property nextHopIp
52286 52287 52288 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52286 def next_hop_ip @next_hop_ip end |
#next_hop_med ⇒ Fixnum
Output only. [Output Only] Multi-Exit Discriminator, a BGP route metric that
indicates
the desirability of a particular route in a network.
Corresponds to the JSON property nextHopMed
52293 52294 52295 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52293 def next_hop_med @next_hop_med end |
#next_hop_network ⇒ String
The URL of the local network if it should handle matching packets.
Corresponds to the JSON property nextHopNetwork
52298 52299 52300 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52298 def next_hop_network @next_hop_network end |
#next_hop_origin ⇒ String
Output only. [Output Only] Indicates the origin of the route. Can be IGP
(Interior Gateway Protocol), EGP (Exterior Gateway Protocol),
or INCOMPLETE.
Corresponds to the JSON property nextHopOrigin
52305 52306 52307 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52305 def next_hop_origin @next_hop_origin end |
#next_hop_peering ⇒ String
Output only. [Output Only] The network peering name that should handle
matching packets,
which should conform to RFC1035.
Corresponds to the JSON property nextHopPeering
52312 52313 52314 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52312 def next_hop_peering @next_hop_peering end |
#next_hop_vpn_tunnel ⇒ String
The URL to a VpnTunnel that should handle matching packets.
Corresponds to the JSON property nextHopVpnTunnel
52317 52318 52319 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52317 def next_hop_vpn_tunnel @next_hop_vpn_tunnel end |
#params ⇒ Google::Apis::ComputeV1::RouteParams
Additional route parameters.
Corresponds to the JSON property params
52322 52323 52324 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52322 def params @params end |
#priority ⇒ Fixnum
The priority of this route. Priority is used to break ties in cases
where there is more than one matching route of equal prefix length. In
cases where multiple routes have equal prefix length, the one with the
lowest-numbered priority value wins. The default value is 1000. The
priority value must be from 0 to 65535, inclusive.
Corresponds to the JSON property priority
52331 52332 52333 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52331 def priority @priority end |
#route_status ⇒ String
[Output only] The status of the route. This status applies to
dynamic routes learned by Cloud Routers. It is also applicable to routes
undergoing migration.
Corresponds to the JSON property routeStatus
52338 52339 52340 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52338 def route_status @route_status end |
#route_type ⇒ String
Output only. [Output Only] The type of this route, which can be one of the following values:
- 'TRANSIT' for a transit route that this router learned from another Cloud Router and will readvertise to one of its BGP peers
- 'SUBNET' for a route from a subnet of the VPC
- 'BGP' for a route learned from a BGP peer of this router
- 'STATIC' for a static route
Corresponds to the JSON property
routeType
52350 52351 52352 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52350 def route_type @route_type end |
#self_link ⇒ String
[Output Only] Server-defined fully-qualified URL for this resource.
Corresponds to the JSON property selfLink
52355 52356 52357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52355 def self_link @self_link end |
#tags ⇒ Array<String>
A list of instance tags to which this route applies.
Corresponds to the JSON property tags
52360 52361 52362 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52360 def @tags end |
#warnings ⇒ Array<Google::Apis::ComputeV1::Route::Warning>
Output only. [Output Only] If potential misconfigurations are detected for
this
route, this field will be populated with warning messages.
Corresponds to the JSON property warnings
52367 52368 52369 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52367 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52374 52375 52376 52377 52378 52379 52380 52381 52382 52383 52384 52385 52386 52387 52388 52389 52390 52391 52392 52393 52394 52395 52396 52397 52398 52399 52400 52401 52402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52374 def update!(**args) @as_paths = args[:as_paths] if args.key?(:as_paths) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @dest_range = args[:dest_range] if args.key?(:dest_range) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @next_hop_gateway = args[:next_hop_gateway] if args.key?(:next_hop_gateway) @next_hop_hub = args[:next_hop_hub] if args.key?(:next_hop_hub) @next_hop_ilb = args[:next_hop_ilb] if args.key?(:next_hop_ilb) @next_hop_instance = args[:next_hop_instance] if args.key?(:next_hop_instance) @next_hop_inter_region_cost = args[:next_hop_inter_region_cost] if args.key?(:next_hop_inter_region_cost) @next_hop_interconnect_attachment = args[:next_hop_interconnect_attachment] if args.key?(:next_hop_interconnect_attachment) @next_hop_ip = args[:next_hop_ip] if args.key?(:next_hop_ip) @next_hop_med = args[:next_hop_med] if args.key?(:next_hop_med) @next_hop_network = args[:next_hop_network] if args.key?(:next_hop_network) @next_hop_origin = args[:next_hop_origin] if args.key?(:next_hop_origin) @next_hop_peering = args[:next_hop_peering] if args.key?(:next_hop_peering) @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel) @params = args[:params] if args.key?(:params) @priority = args[:priority] if args.key?(:priority) @route_status = args[:route_status] if args.key?(:route_status) @route_type = args[:route_type] if args.key?(:route_type) @self_link = args[:self_link] if args.key?(:self_link) @tags = args[:tags] if args.key?(:tags) @warnings = args[:warnings] if args.key?(:warnings) end |