Class: Google::Apis::ComputeV1::Route

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Route resource. A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read theRoutes overview.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



51119
51120
51121
# File 'lib/google/apis/compute_v1/classes.rb', line 51119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#as_pathsArray<Google::Apis::ComputeV1::RouteAsPath>

Output only. [Output Only] AS path. Corresponds to the JSON property asPaths



50912
50913
50914
# File 'lib/google/apis/compute_v1/classes.rb', line 50912

def as_paths
  @as_paths
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


50918
50919
50920
# File 'lib/google/apis/compute_v1/classes.rb', line 50918

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


50924
50925
50926
# File 'lib/google/apis/compute_v1/classes.rb', line 50924

def description
  @description
end

#dest_rangeString

The destination range of outgoing packets that this route applies to. Both IPv4 and IPv6 are supported. Must specify an IPv4 range (e.g. 192.0.2.0/24) or an IPv6 range in RFC 4291 format (e.g. 2001:db8::/32). IPv6 range will be displayed using RFC 5952 compressed format. Corresponds to the JSON property destRange

Returns:

  • (String)


50933
50934
50935
# File 'lib/google/apis/compute_v1/classes.rb', line 50933

def dest_range
  @dest_range
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


50940
50941
50942
# File 'lib/google/apis/compute_v1/classes.rb', line 50940

def id
  @id
end

#kindString

Output only. [Output Only] Type of this resource. Always compute#routes for Route resources. Corresponds to the JSON property kind

Returns:

  • (String)


50946
50947
50948
# File 'lib/google/apis/compute_v1/classes.rb', line 50946

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit. Corresponds to the JSON property name

Returns:

  • (String)


50957
50958
50959
# File 'lib/google/apis/compute_v1/classes.rb', line 50957

def name
  @name
end

#networkString

Fully-qualified URL of the network that this route applies to. Corresponds to the JSON property network

Returns:

  • (String)


50962
50963
50964
# File 'lib/google/apis/compute_v1/classes.rb', line 50962

def network
  @network
end

#next_hop_gatewayString

The URL to a gateway that should handle matching packets. You can only specify the internet gateway using a full or partial valid URL: projects/project/global/gateways/default-internet-gateway Corresponds to the JSON property nextHopGateway

Returns:

  • (String)


50969
50970
50971
# File 'lib/google/apis/compute_v1/classes.rb', line 50969

def next_hop_gateway
  @next_hop_gateway
end

#next_hop_hubString

Output only. [Output Only] The full resource name of the Network Connectivity Center hub that will handle matching packets. Corresponds to the JSON property nextHopHub

Returns:

  • (String)


50976
50977
50978
# File 'lib/google/apis/compute_v1/classes.rb', line 50976

def next_hop_hub
  @next_hop_hub
end

#next_hop_ilbString

The URL to a forwarding rule of typeloadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs:

  • https://www.googleapis.com/compute/v1/projects/project/regions/region/ forwardingRules/forwardingRule
  • regions/region/forwardingRules/forwardingRule If an IP address is provided, must specify an IPv4 address in dot-decimal notation or an IPv6 address in RFC 4291 format. For example, the following are all valid IP addresses:

  • 10.128.0.56

  • 2001:db8::2d9:51:0:0

  • 2001:db8:0:0:2d9:51:0:0 IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address. Corresponds to the JSON property nextHopIlb

Returns:

  • (String)


50999
51000
51001
# File 'lib/google/apis/compute_v1/classes.rb', line 50999

def next_hop_ilb
  @next_hop_ilb
end

#next_hop_instanceString

The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/ Corresponds to the JSON property nextHopInstance

Returns:

  • (String)


51007
51008
51009
# File 'lib/google/apis/compute_v1/classes.rb', line 51007

def next_hop_instance
  @next_hop_instance
end

#next_hop_inter_region_costFixnum

Output only. [Output only] Internal fixed region-to-region cost that Google Cloud calculates based on factors such as network performance, distance, and available bandwidth between regions. Corresponds to the JSON property nextHopInterRegionCost

Returns:

  • (Fixnum)


51015
51016
51017
# File 'lib/google/apis/compute_v1/classes.rb', line 51015

def next_hop_inter_region_cost
  @next_hop_inter_region_cost
end

#next_hop_interconnect_attachmentString

Output only. [Output Only] The URL to an InterconnectAttachment which is the next hop for the route. This field will only be populated for dynamic routes generated by Cloud Router with a linked interconnectAttachment or the static route generated by each L2 Interconnect Attachment. Corresponds to the JSON property nextHopInterconnectAttachment

Returns:

  • (String)


51025
51026
51027
# File 'lib/google/apis/compute_v1/classes.rb', line 51025

def next_hop_interconnect_attachment
  @next_hop_interconnect_attachment
end

#next_hop_ipString

The network IP address of an instance that should handle matching packets. Both IPv6 address and IPv4 addresses are supported. Must specify an IPv4 address in dot-decimal notation (e.g. 192.0.2.99) or an IPv6 address in RFC 4291 format (e.g. 2001:db8::2d9:51:0:0 or 2001:db8:0:0:2d9:51:0:0). IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address. Corresponds to the JSON property nextHopIp

Returns:

  • (String)


51036
51037
51038
# File 'lib/google/apis/compute_v1/classes.rb', line 51036

def next_hop_ip
  @next_hop_ip
end

#next_hop_medFixnum

Output only. [Output Only] Multi-Exit Discriminator, a BGP route metric that indicates the desirability of a particular route in a network. Corresponds to the JSON property nextHopMed

Returns:

  • (Fixnum)


51043
51044
51045
# File 'lib/google/apis/compute_v1/classes.rb', line 51043

def next_hop_med
  @next_hop_med
end

#next_hop_networkString

The URL of the local network if it should handle matching packets. Corresponds to the JSON property nextHopNetwork

Returns:

  • (String)


51048
51049
51050
# File 'lib/google/apis/compute_v1/classes.rb', line 51048

def next_hop_network
  @next_hop_network
end

#next_hop_originString

Output only. [Output Only] Indicates the origin of the route. Can be IGP (Interior Gateway Protocol), EGP (Exterior Gateway Protocol), or INCOMPLETE. Corresponds to the JSON property nextHopOrigin

Returns:

  • (String)


51055
51056
51057
# File 'lib/google/apis/compute_v1/classes.rb', line 51055

def next_hop_origin
  @next_hop_origin
end

#next_hop_peeringString

Output only. [Output Only] The network peering name that should handle matching packets, which should conform to RFC1035. Corresponds to the JSON property nextHopPeering

Returns:

  • (String)


51062
51063
51064
# File 'lib/google/apis/compute_v1/classes.rb', line 51062

def next_hop_peering
  @next_hop_peering
end

#next_hop_vpn_tunnelString

The URL to a VpnTunnel that should handle matching packets. Corresponds to the JSON property nextHopVpnTunnel

Returns:

  • (String)


51067
51068
51069
# File 'lib/google/apis/compute_v1/classes.rb', line 51067

def next_hop_vpn_tunnel
  @next_hop_vpn_tunnel
end

#paramsGoogle::Apis::ComputeV1::RouteParams

Additional route parameters. Corresponds to the JSON property params



51072
51073
51074
# File 'lib/google/apis/compute_v1/classes.rb', line 51072

def params
  @params
end

#priorityFixnum

The priority of this route. Priority is used to break ties in cases where there is more than one matching route of equal prefix length. In cases where multiple routes have equal prefix length, the one with the lowest-numbered priority value wins. The default value is 1000. The priority value must be from 0 to 65535, inclusive. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


51081
51082
51083
# File 'lib/google/apis/compute_v1/classes.rb', line 51081

def priority
  @priority
end

#route_statusString

[Output only] The status of the route. This status applies to dynamic routes learned by Cloud Routers. It is also applicable to routes undergoing migration. Corresponds to the JSON property routeStatus

Returns:

  • (String)


51088
51089
51090
# File 'lib/google/apis/compute_v1/classes.rb', line 51088

def route_status
  @route_status
end

#route_typeString

Output only. [Output Only] The type of this route, which can be one of the following values:

  • 'TRANSIT' for a transit route that this router learned from another Cloud Router and will readvertise to one of its BGP peers
  • 'SUBNET' for a route from a subnet of the VPC
  • 'BGP' for a route learned from a BGP peer of this router
  • 'STATIC' for a static route Corresponds to the JSON property routeType

Returns:

  • (String)


51100
51101
51102
# File 'lib/google/apis/compute_v1/classes.rb', line 51100

def route_type
  @route_type
end

[Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51105
51106
51107
# File 'lib/google/apis/compute_v1/classes.rb', line 51105

def self_link
  @self_link
end

#tagsArray<String>

A list of instance tags to which this route applies. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


51110
51111
51112
# File 'lib/google/apis/compute_v1/classes.rb', line 51110

def tags
  @tags
end

#warningsArray<Google::Apis::ComputeV1::Route::Warning>

Output only. [Output Only] If potential misconfigurations are detected for this route, this field will be populated with warning messages. Corresponds to the JSON property warnings



51117
51118
51119
# File 'lib/google/apis/compute_v1/classes.rb', line 51117

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51124
51125
51126
51127
51128
51129
51130
51131
51132
51133
51134
51135
51136
51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
51147
51148
51149
51150
51151
51152
# File 'lib/google/apis/compute_v1/classes.rb', line 51124

def update!(**args)
  @as_paths = args[:as_paths] if args.key?(:as_paths)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @next_hop_gateway = args[:next_hop_gateway] if args.key?(:next_hop_gateway)
  @next_hop_hub = args[:next_hop_hub] if args.key?(:next_hop_hub)
  @next_hop_ilb = args[:next_hop_ilb] if args.key?(:next_hop_ilb)
  @next_hop_instance = args[:next_hop_instance] if args.key?(:next_hop_instance)
  @next_hop_inter_region_cost = args[:next_hop_inter_region_cost] if args.key?(:next_hop_inter_region_cost)
  @next_hop_interconnect_attachment = args[:next_hop_interconnect_attachment] if args.key?(:next_hop_interconnect_attachment)
  @next_hop_ip = args[:next_hop_ip] if args.key?(:next_hop_ip)
  @next_hop_med = args[:next_hop_med] if args.key?(:next_hop_med)
  @next_hop_network = args[:next_hop_network] if args.key?(:next_hop_network)
  @next_hop_origin = args[:next_hop_origin] if args.key?(:next_hop_origin)
  @next_hop_peering = args[:next_hop_peering] if args.key?(:next_hop_peering)
  @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel)
  @params = args[:params] if args.key?(:params)
  @priority = args[:priority] if args.key?(:priority)
  @route_status = args[:route_status] if args.key?(:route_status)
  @route_type = args[:route_type] if args.key?(:route_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @tags = args[:tags] if args.key?(:tags)
  @warnings = args[:warnings] if args.key?(:warnings)
end