Class: Google::Apis::ComputeV1::Route

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Route resource. A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read theRoutes overview.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



46167
46168
46169
# File 'lib/google/apis/compute_v1/classes.rb', line 46167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#as_pathsArray<Google::Apis::ComputeV1::RouteAsPath>

Output only. [Output Only] AS path. Corresponds to the JSON property asPaths



45960
45961
45962
# File 'lib/google/apis/compute_v1/classes.rb', line 45960

def as_paths
  @as_paths
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


45966
45967
45968
# File 'lib/google/apis/compute_v1/classes.rb', line 45966

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


45972
45973
45974
# File 'lib/google/apis/compute_v1/classes.rb', line 45972

def description
  @description
end

#dest_rangeString

The destination range of outgoing packets that this route applies to. Both IPv4 and IPv6 are supported. Must specify an IPv4 range (e.g. 192.0.2.0/24) or an IPv6 range in RFC 4291 format (e.g. 2001:db8::/32). IPv6 range will be displayed using RFC 5952 compressed format. Corresponds to the JSON property destRange

Returns:

  • (String)


45981
45982
45983
# File 'lib/google/apis/compute_v1/classes.rb', line 45981

def dest_range
  @dest_range
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


45988
45989
45990
# File 'lib/google/apis/compute_v1/classes.rb', line 45988

def id
  @id
end

#kindString

Output only. [Output Only] Type of this resource. Always compute#routes for Route resources. Corresponds to the JSON property kind

Returns:

  • (String)


45994
45995
45996
# File 'lib/google/apis/compute_v1/classes.rb', line 45994

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit. Corresponds to the JSON property name

Returns:

  • (String)


46005
46006
46007
# File 'lib/google/apis/compute_v1/classes.rb', line 46005

def name
  @name
end

#networkString

Fully-qualified URL of the network that this route applies to. Corresponds to the JSON property network

Returns:

  • (String)


46010
46011
46012
# File 'lib/google/apis/compute_v1/classes.rb', line 46010

def network
  @network
end

#next_hop_gatewayString

The URL to a gateway that should handle matching packets. You can only specify the internet gateway using a full or partial valid URL: projects/project/global/gateways/default-internet-gateway Corresponds to the JSON property nextHopGateway

Returns:

  • (String)


46017
46018
46019
# File 'lib/google/apis/compute_v1/classes.rb', line 46017

def next_hop_gateway
  @next_hop_gateway
end

#next_hop_hubString

Output only. [Output Only] The full resource name of the Network Connectivity Center hub that will handle matching packets. Corresponds to the JSON property nextHopHub

Returns:

  • (String)


46024
46025
46026
# File 'lib/google/apis/compute_v1/classes.rb', line 46024

def next_hop_hub
  @next_hop_hub
end

#next_hop_ilbString

The URL to a forwarding rule of typeloadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs:

  • https://www.googleapis.com/compute/v1/projects/project/regions/region/ forwardingRules/forwardingRule
  • regions/region/forwardingRules/forwardingRule If an IP address is provided, must specify an IPv4 address in dot-decimal notation or an IPv6 address in RFC 4291 format. For example, the following are all valid IP addresses:

  • 10.128.0.56

  • 2001:db8::2d9:51:0:0

  • 2001:db8:0:0:2d9:51:0:0 IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address. Corresponds to the JSON property nextHopIlb

Returns:

  • (String)


46047
46048
46049
# File 'lib/google/apis/compute_v1/classes.rb', line 46047

def next_hop_ilb
  @next_hop_ilb
end

#next_hop_instanceString

The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/ Corresponds to the JSON property nextHopInstance

Returns:

  • (String)


46055
46056
46057
# File 'lib/google/apis/compute_v1/classes.rb', line 46055

def next_hop_instance
  @next_hop_instance
end

#next_hop_inter_region_costFixnum

Output only. [Output only] Internal fixed region-to-region cost that Google Cloud calculates based on factors such as network performance, distance, and available bandwidth between regions. Corresponds to the JSON property nextHopInterRegionCost

Returns:

  • (Fixnum)


46063
46064
46065
# File 'lib/google/apis/compute_v1/classes.rb', line 46063

def next_hop_inter_region_cost
  @next_hop_inter_region_cost
end

#next_hop_interconnect_attachmentString

Output only. [Output Only] The URL to an InterconnectAttachment which is the next hop for the route. This field will only be populated for dynamic routes generated by Cloud Router with a linked interconnectAttachment or the static route generated by each L2 Interconnect Attachment. Corresponds to the JSON property nextHopInterconnectAttachment

Returns:

  • (String)


46073
46074
46075
# File 'lib/google/apis/compute_v1/classes.rb', line 46073

def next_hop_interconnect_attachment
  @next_hop_interconnect_attachment
end

#next_hop_ipString

The network IP address of an instance that should handle matching packets. Both IPv6 address and IPv4 addresses are supported. Must specify an IPv4 address in dot-decimal notation (e.g. 192.0.2.99) or an IPv6 address in RFC 4291 format (e.g. 2001:db8::2d9:51:0:0 or 2001:db8:0:0:2d9:51:0:0). IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address. Corresponds to the JSON property nextHopIp

Returns:

  • (String)


46084
46085
46086
# File 'lib/google/apis/compute_v1/classes.rb', line 46084

def next_hop_ip
  @next_hop_ip
end

#next_hop_medFixnum

Output only. [Output Only] Multi-Exit Discriminator, a BGP route metric that indicates the desirability of a particular route in a network. Corresponds to the JSON property nextHopMed

Returns:

  • (Fixnum)


46091
46092
46093
# File 'lib/google/apis/compute_v1/classes.rb', line 46091

def next_hop_med
  @next_hop_med
end

#next_hop_networkString

The URL of the local network if it should handle matching packets. Corresponds to the JSON property nextHopNetwork

Returns:

  • (String)


46096
46097
46098
# File 'lib/google/apis/compute_v1/classes.rb', line 46096

def next_hop_network
  @next_hop_network
end

#next_hop_originString

Output only. [Output Only] Indicates the origin of the route. Can be IGP (Interior Gateway Protocol), EGP (Exterior Gateway Protocol), or INCOMPLETE. Corresponds to the JSON property nextHopOrigin

Returns:

  • (String)


46103
46104
46105
# File 'lib/google/apis/compute_v1/classes.rb', line 46103

def next_hop_origin
  @next_hop_origin
end

#next_hop_peeringString

Output only. [Output Only] The network peering name that should handle matching packets, which should conform to RFC1035. Corresponds to the JSON property nextHopPeering

Returns:

  • (String)


46110
46111
46112
# File 'lib/google/apis/compute_v1/classes.rb', line 46110

def next_hop_peering
  @next_hop_peering
end

#next_hop_vpn_tunnelString

The URL to a VpnTunnel that should handle matching packets. Corresponds to the JSON property nextHopVpnTunnel

Returns:

  • (String)


46115
46116
46117
# File 'lib/google/apis/compute_v1/classes.rb', line 46115

def next_hop_vpn_tunnel
  @next_hop_vpn_tunnel
end

#paramsGoogle::Apis::ComputeV1::RouteParams

Additional route parameters. Corresponds to the JSON property params



46120
46121
46122
# File 'lib/google/apis/compute_v1/classes.rb', line 46120

def params
  @params
end

#priorityFixnum

The priority of this route. Priority is used to break ties in cases where there is more than one matching route of equal prefix length. In cases where multiple routes have equal prefix length, the one with the lowest-numbered priority value wins. The default value is 1000. The priority value must be from 0 to 65535, inclusive. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


46129
46130
46131
# File 'lib/google/apis/compute_v1/classes.rb', line 46129

def priority
  @priority
end

#route_statusString

[Output only] The status of the route. This status applies to dynamic routes learned by Cloud Routers. It is also applicable to routes undergoing migration. Corresponds to the JSON property routeStatus

Returns:

  • (String)


46136
46137
46138
# File 'lib/google/apis/compute_v1/classes.rb', line 46136

def route_status
  @route_status
end

#route_typeString

Output only. [Output Only] The type of this route, which can be one of the following values:

  • 'TRANSIT' for a transit route that this router learned from another Cloud Router and will readvertise to one of its BGP peers
  • 'SUBNET' for a route from a subnet of the VPC
  • 'BGP' for a route learned from a BGP peer of this router
  • 'STATIC' for a static route Corresponds to the JSON property routeType

Returns:

  • (String)


46148
46149
46150
# File 'lib/google/apis/compute_v1/classes.rb', line 46148

def route_type
  @route_type
end

[Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46153
46154
46155
# File 'lib/google/apis/compute_v1/classes.rb', line 46153

def self_link
  @self_link
end

#tagsArray<String>

A list of instance tags to which this route applies. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


46158
46159
46160
# File 'lib/google/apis/compute_v1/classes.rb', line 46158

def tags
  @tags
end

#warningsArray<Google::Apis::ComputeV1::Route::Warning>

Output only. [Output Only] If potential misconfigurations are detected for this route, this field will be populated with warning messages. Corresponds to the JSON property warnings



46165
46166
46167
# File 'lib/google/apis/compute_v1/classes.rb', line 46165

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46172
46173
46174
46175
46176
46177
46178
46179
46180
46181
46182
46183
46184
46185
46186
46187
46188
46189
46190
46191
46192
46193
46194
46195
46196
46197
46198
46199
46200
# File 'lib/google/apis/compute_v1/classes.rb', line 46172

def update!(**args)
  @as_paths = args[:as_paths] if args.key?(:as_paths)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @next_hop_gateway = args[:next_hop_gateway] if args.key?(:next_hop_gateway)
  @next_hop_hub = args[:next_hop_hub] if args.key?(:next_hop_hub)
  @next_hop_ilb = args[:next_hop_ilb] if args.key?(:next_hop_ilb)
  @next_hop_instance = args[:next_hop_instance] if args.key?(:next_hop_instance)
  @next_hop_inter_region_cost = args[:next_hop_inter_region_cost] if args.key?(:next_hop_inter_region_cost)
  @next_hop_interconnect_attachment = args[:next_hop_interconnect_attachment] if args.key?(:next_hop_interconnect_attachment)
  @next_hop_ip = args[:next_hop_ip] if args.key?(:next_hop_ip)
  @next_hop_med = args[:next_hop_med] if args.key?(:next_hop_med)
  @next_hop_network = args[:next_hop_network] if args.key?(:next_hop_network)
  @next_hop_origin = args[:next_hop_origin] if args.key?(:next_hop_origin)
  @next_hop_peering = args[:next_hop_peering] if args.key?(:next_hop_peering)
  @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel)
  @params = args[:params] if args.key?(:params)
  @priority = args[:priority] if args.key?(:priority)
  @route_status = args[:route_status] if args.key?(:route_status)
  @route_type = args[:route_type] if args.key?(:route_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @tags = args[:tags] if args.key?(:tags)
  @warnings = args[:warnings] if args.key?(:warnings)
end