Class: Google::Apis::ComputeV1::Route

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Route resource. A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read the Routes overview.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



28538
28539
28540
# File 'lib/google/apis/compute_v1/classes.rb', line 28538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#as_pathsArray<Google::Apis::ComputeV1::RouteAsPath>

[Output Only] AS path. Corresponds to the JSON property asPaths



28414
28415
28416
# File 'lib/google/apis/compute_v1/classes.rb', line 28414

def as_paths
  @as_paths
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


28419
28420
28421
# File 'lib/google/apis/compute_v1/classes.rb', line 28419

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


28425
28426
28427
# File 'lib/google/apis/compute_v1/classes.rb', line 28425

def description
  @description
end

#dest_rangeString

The destination range of outgoing packets that this route applies to. Both IPv4 and IPv6 are supported. Corresponds to the JSON property destRange

Returns:

  • (String)


28431
28432
28433
# File 'lib/google/apis/compute_v1/classes.rb', line 28431

def dest_range
  @dest_range
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28437
28438
28439
# File 'lib/google/apis/compute_v1/classes.rb', line 28437

def id
  @id
end

#kindString

[Output Only] Type of this resource. Always compute#routes for Route resources. Corresponds to the JSON property kind

Returns:

  • (String)


28442
28443
28444
# File 'lib/google/apis/compute_v1/classes.rb', line 28442

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit. Corresponds to the JSON property name

Returns:

  • (String)


28452
28453
28454
# File 'lib/google/apis/compute_v1/classes.rb', line 28452

def name
  @name
end

#networkString

Fully-qualified URL of the network that this route applies to. Corresponds to the JSON property network

Returns:

  • (String)


28457
28458
28459
# File 'lib/google/apis/compute_v1/classes.rb', line 28457

def network
  @network
end

#next_hop_gatewayString

The URL to a gateway that should handle matching packets. You can only specify the internet gateway using a full or partial valid URL: projects/ project/ global/gateways/default-internet-gateway Corresponds to the JSON property nextHopGateway

Returns:

  • (String)


28464
28465
28466
# File 'lib/google/apis/compute_v1/classes.rb', line 28464

def next_hop_gateway
  @next_hop_gateway
end

#next_hop_ilbString

The URL to a forwarding rule of type loadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs: - 10.128.0.56 - https://www.googleapis.com/ compute/v1/projects/project/regions/region /forwardingRules/forwardingRule - regions/region/forwardingRules/forwardingRule Corresponds to the JSON property nextHopIlb

Returns:

  • (String)


28473
28474
28475
# File 'lib/google/apis/compute_v1/classes.rb', line 28473

def next_hop_ilb
  @next_hop_ilb
end

#next_hop_instanceString

The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/ v1/projects/project/zones/zone/instances/ Corresponds to the JSON property nextHopInstance

Returns:

  • (String)


28480
28481
28482
# File 'lib/google/apis/compute_v1/classes.rb', line 28480

def next_hop_instance
  @next_hop_instance
end

#next_hop_ipString

The network IP address of an instance that should handle matching packets. Only IPv4 is supported. Corresponds to the JSON property nextHopIp

Returns:

  • (String)


28486
28487
28488
# File 'lib/google/apis/compute_v1/classes.rb', line 28486

def next_hop_ip
  @next_hop_ip
end

#next_hop_networkString

The URL of the local network if it should handle matching packets. Corresponds to the JSON property nextHopNetwork

Returns:

  • (String)


28491
28492
28493
# File 'lib/google/apis/compute_v1/classes.rb', line 28491

def next_hop_network
  @next_hop_network
end

#next_hop_peeringString

[Output Only] The network peering name that should handle matching packets, which should conform to RFC1035. Corresponds to the JSON property nextHopPeering

Returns:

  • (String)


28497
28498
28499
# File 'lib/google/apis/compute_v1/classes.rb', line 28497

def next_hop_peering
  @next_hop_peering
end

#next_hop_vpn_tunnelString

The URL to a VpnTunnel that should handle matching packets. Corresponds to the JSON property nextHopVpnTunnel

Returns:

  • (String)


28502
28503
28504
# File 'lib/google/apis/compute_v1/classes.rb', line 28502

def next_hop_vpn_tunnel
  @next_hop_vpn_tunnel
end

#priorityFixnum

The priority of this route. Priority is used to break ties in cases where there is more than one matching route of equal prefix length. In cases where multiple routes have equal prefix length, the one with the lowest-numbered priority value wins. The default value is 1000. The priority value must be from 0 to 65535, inclusive. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


28511
28512
28513
# File 'lib/google/apis/compute_v1/classes.rb', line 28511

def priority
  @priority
end

#route_typeString

[Output Only] The type of this route, which can be one of the following values:

  • 'TRANSIT' for a transit route that this router learned from another Cloud Router and will readvertise to one of its BGP peers - 'SUBNET' for a route from a subnet of the VPC - 'BGP' for a route learned from a BGP peer of this router - 'STATIC' for a static route Corresponds to the JSON property routeType

Returns:

  • (String)


28520
28521
28522
# File 'lib/google/apis/compute_v1/classes.rb', line 28520

def route_type
  @route_type
end

[Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28525
28526
28527
# File 'lib/google/apis/compute_v1/classes.rb', line 28525

def self_link
  @self_link
end

#tagsArray<String>

A list of instance tags to which this route applies. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


28530
28531
28532
# File 'lib/google/apis/compute_v1/classes.rb', line 28530

def tags
  @tags
end

#warningsArray<Google::Apis::ComputeV1::Route::Warning>

[Output Only] If potential misconfigurations are detected for this route, this field will be populated with warning messages. Corresponds to the JSON property warnings



28536
28537
28538
# File 'lib/google/apis/compute_v1/classes.rb', line 28536

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28543
28544
28545
28546
28547
28548
28549
28550
28551
28552
28553
28554
28555
28556
28557
28558
28559
28560
28561
28562
28563
28564
# File 'lib/google/apis/compute_v1/classes.rb', line 28543

def update!(**args)
  @as_paths = args[:as_paths] if args.key?(:as_paths)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @next_hop_gateway = args[:next_hop_gateway] if args.key?(:next_hop_gateway)
  @next_hop_ilb = args[:next_hop_ilb] if args.key?(:next_hop_ilb)
  @next_hop_instance = args[:next_hop_instance] if args.key?(:next_hop_instance)
  @next_hop_ip = args[:next_hop_ip] if args.key?(:next_hop_ip)
  @next_hop_network = args[:next_hop_network] if args.key?(:next_hop_network)
  @next_hop_peering = args[:next_hop_peering] if args.key?(:next_hop_peering)
  @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel)
  @priority = args[:priority] if args.key?(:priority)
  @route_type = args[:route_type] if args.key?(:route_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @tags = args[:tags] if args.key?(:tags)
  @warnings = args[:warnings] if args.key?(:warnings)
end