Class: Google::Apis::ComputeV1::RouteList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Route resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteList

Returns a new instance of RouteList.



52550
52551
52552
# File 'lib/google/apis/compute_v1/classes.rb', line 52550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52518
52519
52520
# File 'lib/google/apis/compute_v1/classes.rb', line 52518

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Route>

A list of Route resources. Corresponds to the JSON property items

Returns:



52523
52524
52525
# File 'lib/google/apis/compute_v1/classes.rb', line 52523

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


52528
52529
52530
# File 'lib/google/apis/compute_v1/classes.rb', line 52528

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52538
52539
52540
# File 'lib/google/apis/compute_v1/classes.rb', line 52538

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52543
52544
52545
# File 'lib/google/apis/compute_v1/classes.rb', line 52543

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RouteList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52548
52549
52550
# File 'lib/google/apis/compute_v1/classes.rb', line 52548

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52555
52556
52557
52558
52559
52560
52561
52562
# File 'lib/google/apis/compute_v1/classes.rb', line 52555

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end