Class: Google::Apis::ComputeV1::RouteList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Route resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteList

Returns a new instance of RouteList.



49805
49806
49807
# File 'lib/google/apis/compute_v1/classes.rb', line 49805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49773
49774
49775
# File 'lib/google/apis/compute_v1/classes.rb', line 49773

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Route>

A list of Route resources. Corresponds to the JSON property items

Returns:



49778
49779
49780
# File 'lib/google/apis/compute_v1/classes.rb', line 49778

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


49783
49784
49785
# File 'lib/google/apis/compute_v1/classes.rb', line 49783

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49793
49794
49795
# File 'lib/google/apis/compute_v1/classes.rb', line 49793

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49798
49799
49800
# File 'lib/google/apis/compute_v1/classes.rb', line 49798

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RouteList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49803
49804
49805
# File 'lib/google/apis/compute_v1/classes.rb', line 49803

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49810
49811
49812
49813
49814
49815
49816
49817
# File 'lib/google/apis/compute_v1/classes.rb', line 49810

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end