Class: Google::Apis::ComputeV1::RouteList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Route resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteList

Returns a new instance of RouteList.



46348
46349
46350
# File 'lib/google/apis/compute_v1/classes.rb', line 46348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46316
46317
46318
# File 'lib/google/apis/compute_v1/classes.rb', line 46316

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Route>

A list of Route resources. Corresponds to the JSON property items

Returns:



46321
46322
46323
# File 'lib/google/apis/compute_v1/classes.rb', line 46321

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


46326
46327
46328
# File 'lib/google/apis/compute_v1/classes.rb', line 46326

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46336
46337
46338
# File 'lib/google/apis/compute_v1/classes.rb', line 46336

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46341
46342
46343
# File 'lib/google/apis/compute_v1/classes.rb', line 46341

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RouteList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46346
46347
46348
# File 'lib/google/apis/compute_v1/classes.rb', line 46346

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46353
46354
46355
46356
46357
46358
46359
46360
# File 'lib/google/apis/compute_v1/classes.rb', line 46353

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end