Class: Google::Apis::ComputeV1::RoutePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutePolicy

Returns a new instance of RoutePolicy.



51469
51470
51471
# File 'lib/google/apis/compute_v1/classes.rb', line 51469

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of route policy. Corresponds to the JSON property description

Returns:

  • (String)


51436
51437
51438
# File 'lib/google/apis/compute_v1/classes.rb', line 51436

def description
  @description
end

#fingerprintString

A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getRoutePolicy() request to retrieve a Route Policy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


51449
51450
51451
# File 'lib/google/apis/compute_v1/classes.rb', line 51449

def fingerprint
  @fingerprint
end

#nameString

Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


51455
51456
51457
# File 'lib/google/apis/compute_v1/classes.rb', line 51455

def name
  @name
end

#termsArray<Google::Apis::ComputeV1::RoutePolicyPolicyTerm>

List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later. Corresponds to the JSON property terms



51462
51463
51464
# File 'lib/google/apis/compute_v1/classes.rb', line 51462

def terms
  @terms
end

#typeString

Corresponds to the JSON property type

Returns:

  • (String)


51467
51468
51469
# File 'lib/google/apis/compute_v1/classes.rb', line 51467

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51474
51475
51476
51477
51478
51479
51480
# File 'lib/google/apis/compute_v1/classes.rb', line 51474

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @terms = args[:terms] if args.key?(:terms)
  @type = args[:type] if args.key?(:type)
end