Class: Google::Apis::ComputeV1::RoutePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of route policy.
-
#fingerprint ⇒ String
A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking.
-
#name ⇒ String
Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies.
-
#terms ⇒ Array<Google::Apis::ComputeV1::RoutePolicyPolicyTerm>
List of terms (the order in the list is not important, they are evaluated in order of priority).
-
#type ⇒ String
Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutePolicy
constructor
A new instance of RoutePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutePolicy
Returns a new instance of RoutePolicy.
51455 51456 51457 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of route policy.
Corresponds to the JSON property description
51422 51423 51424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51422 def description @description end |
#fingerprint ⇒ String
A fingerprint for the Route Policy being applied to this Router, which is
essentially a hash of the Route Policy used for optimistic locking.
The fingerprint is initially generated by Compute Engine and changes
after every request to modify or update Route Policy. You must always
provide an up-to-date fingerprint hash in order to update or change
labels.
To see the latest fingerprint, make a getRoutePolicy() request
to retrieve a Route Policy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
51435 51436 51437 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51435 def fingerprint @fingerprint end |
#name ⇒ String
Route Policy name, which must be a resource ID segment and unique
within all the router's Route Policies. Name should conform to RFC1035.
Corresponds to the JSON property name
51441 51442 51443 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51441 def name @name end |
#terms ⇒ Array<Google::Apis::ComputeV1::RoutePolicyPolicyTerm>
List of terms (the order in the list is not important, they are evaluated
in order of priority). Order of policies is not retained and might change
when getting policy later.
Corresponds to the JSON property terms
51448 51449 51450 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51448 def terms @terms end |
#type ⇒ String
Corresponds to the JSON property type
51453 51454 51455 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51453 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51460 51461 51462 51463 51464 51465 51466 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51460 def update!(**args) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @terms = args[:terms] if args.key?(:terms) @type = args[:type] if args.key?(:type) end |