Class: Google::Apis::ComputeV1::RoutePolicyPolicyTerm
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutePolicyPolicyTerm
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::ComputeV1::Expr>
CEL expressions to evaluate to modify a route when this term matches.
-
#match ⇒ Google::Apis::ComputeV1::Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.
-
#priority ⇒ Fixnum
The evaluation priority for this term, which must be between 0 (inclusive) and 2^31 (exclusive), and unique within the list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutePolicyPolicyTerm
constructor
A new instance of RoutePolicyPolicyTerm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutePolicyPolicyTerm
Returns a new instance of RoutePolicyPolicyTerm.
45371 45372 45373 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45371 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::ComputeV1::Expr>
CEL expressions to evaluate to modify a route when this term matches.
Corresponds to the JSON property actions
45337 45338 45339 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45337 def actions @actions end |
#match ⇒ Google::Apis::ComputeV1::Expr
Represents a textual expression in the Common Expression Language (CEL)
syntax. CEL is a C-like expression language. The syntax and semantics of CEL
are documented at https://github.com/google/cel-spec.
Example (Comparison):
title: "Summary size limit"
description: "Determines if a summary is less than 100 chars"
expression: "document.summary.size() < 100"
Example (Equality):
title: "Requestor is owner"
description: "Determines if requestor is the document owner"
expression: "document.owner == request.auth.claims.email"
Example (Logic):
title: "Public documents"
description: "Determine whether the document should be publicly visible"
expression: "document.type != 'private' && document.type != 'internal'"
Example (Data Manipulation):
title: "Notification string"
description: "Create a notification string with a timestamp."
expression: "'New message received at ' + string(document.create_time)"
The exact variables and functions that may be referenced within an expression
are determined by the service that evaluates it. See the service
documentation for additional information.
Corresponds to the JSON property match
45363 45364 45365 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45363 def match @match end |
#priority ⇒ Fixnum
The evaluation priority for this term, which must be between 0
(inclusive) and 2^31 (exclusive), and unique within the list.
Corresponds to the JSON property priority
45369 45370 45371 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45369 def priority @priority end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45376 45377 45378 45379 45380 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45376 def update!(**args) @actions = args[:actions] if args.key?(:actions) @match = args[:match] if args.key?(:match) @priority = args[:priority] if args.key?(:priority) end |