Class: Google::Apis::ComputeV1::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



52883
52884
52885
# File 'lib/google/apis/compute_v1/classes.rb', line 52883

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeV1::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



52781
52782
52783
# File 'lib/google/apis/compute_v1/classes.rb', line 52781

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeV1::RouterBgpPeer>

BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273. Corresponds to the JSON property bgpPeers



52789
52790
52791
# File 'lib/google/apis/compute_v1/classes.rb', line 52789

def bgp_peers
  @bgp_peers
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


52795
52796
52797
# File 'lib/google/apis/compute_v1/classes.rb', line 52795

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


52801
52802
52803
# File 'lib/google/apis/compute_v1/classes.rb', line 52801

def description
  @description
end

#encrypted_interconnect_routerBoolean Also known as: encrypted_interconnect_router?

Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments). Corresponds to the JSON property encryptedInterconnectRouter

Returns:

  • (Boolean)


52807
52808
52809
# File 'lib/google/apis/compute_v1/classes.rb', line 52807

def encrypted_interconnect_router
  @encrypted_interconnect_router
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


52814
52815
52816
# File 'lib/google/apis/compute_v1/classes.rb', line 52814

def id
  @id
end

#interfacesArray<Google::Apis::ComputeV1::RouterInterface>

Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:

  • linkedVpnTunnel
  • linkedInterconnectAttachment
  • subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface. Corresponds to the JSON property interfaces


52827
52828
52829
# File 'lib/google/apis/compute_v1/classes.rb', line 52827

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


52833
52834
52835
# File 'lib/google/apis/compute_v1/classes.rb', line 52833

def kind
  @kind
end

#md5_authentication_keysArray<Google::Apis::ComputeV1::RouterMd5AuthenticationKey>

Keys used for MD5 authentication. Corresponds to the JSON property md5AuthenticationKeys



52838
52839
52840
# File 'lib/google/apis/compute_v1/classes.rb', line 52838

def md5_authentication_keys
  @md5_authentication_keys
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


52849
52850
52851
# File 'lib/google/apis/compute_v1/classes.rb', line 52849

def name
  @name
end

#natsArray<Google::Apis::ComputeV1::RouterNat>

A list of NAT services created in this router. Corresponds to the JSON property nats



52854
52855
52856
# File 'lib/google/apis/compute_v1/classes.rb', line 52854

def nats
  @nats
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


52859
52860
52861
# File 'lib/google/apis/compute_v1/classes.rb', line 52859

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


52864
52865
52866
# File 'lib/google/apis/compute_v1/classes.rb', line 52864

def network
  @network
end

#paramsGoogle::Apis::ComputeV1::RouterParams

Additional router parameters. Corresponds to the JSON property params



52869
52870
52871
# File 'lib/google/apis/compute_v1/classes.rb', line 52869

def params
  @params
end

#regionString

[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


52876
52877
52878
# File 'lib/google/apis/compute_v1/classes.rb', line 52876

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52881
52882
52883
# File 'lib/google/apis/compute_v1/classes.rb', line 52881

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52888
52889
52890
52891
52892
52893
52894
52895
52896
52897
52898
52899
52900
52901
52902
52903
52904
52905
# File 'lib/google/apis/compute_v1/classes.rb', line 52888

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys)
  @name = args[:name] if args.key?(:name)
  @nats = args[:nats] if args.key?(:nats)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end