Class: Google::Apis::ComputeV1::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



52141
52142
52143
# File 'lib/google/apis/compute_v1/classes.rb', line 52141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeV1::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



52039
52040
52041
# File 'lib/google/apis/compute_v1/classes.rb', line 52039

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeV1::RouterBgpPeer>

BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273. Corresponds to the JSON property bgpPeers



52047
52048
52049
# File 'lib/google/apis/compute_v1/classes.rb', line 52047

def bgp_peers
  @bgp_peers
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


52053
52054
52055
# File 'lib/google/apis/compute_v1/classes.rb', line 52053

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


52059
52060
52061
# File 'lib/google/apis/compute_v1/classes.rb', line 52059

def description
  @description
end

#encrypted_interconnect_routerBoolean Also known as: encrypted_interconnect_router?

Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments). Corresponds to the JSON property encryptedInterconnectRouter

Returns:

  • (Boolean)


52065
52066
52067
# File 'lib/google/apis/compute_v1/classes.rb', line 52065

def encrypted_interconnect_router
  @encrypted_interconnect_router
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


52072
52073
52074
# File 'lib/google/apis/compute_v1/classes.rb', line 52072

def id
  @id
end

#interfacesArray<Google::Apis::ComputeV1::RouterInterface>

Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:

  • linkedVpnTunnel
  • linkedInterconnectAttachment
  • subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface. Corresponds to the JSON property interfaces


52085
52086
52087
# File 'lib/google/apis/compute_v1/classes.rb', line 52085

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


52091
52092
52093
# File 'lib/google/apis/compute_v1/classes.rb', line 52091

def kind
  @kind
end

#md5_authentication_keysArray<Google::Apis::ComputeV1::RouterMd5AuthenticationKey>

Keys used for MD5 authentication. Corresponds to the JSON property md5AuthenticationKeys



52096
52097
52098
# File 'lib/google/apis/compute_v1/classes.rb', line 52096

def md5_authentication_keys
  @md5_authentication_keys
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


52107
52108
52109
# File 'lib/google/apis/compute_v1/classes.rb', line 52107

def name
  @name
end

#natsArray<Google::Apis::ComputeV1::RouterNat>

A list of NAT services created in this router. Corresponds to the JSON property nats



52112
52113
52114
# File 'lib/google/apis/compute_v1/classes.rb', line 52112

def nats
  @nats
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


52117
52118
52119
# File 'lib/google/apis/compute_v1/classes.rb', line 52117

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


52122
52123
52124
# File 'lib/google/apis/compute_v1/classes.rb', line 52122

def network
  @network
end

#paramsGoogle::Apis::ComputeV1::RouterParams

Additional router parameters. Corresponds to the JSON property params



52127
52128
52129
# File 'lib/google/apis/compute_v1/classes.rb', line 52127

def params
  @params
end

#regionString

[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


52134
52135
52136
# File 'lib/google/apis/compute_v1/classes.rb', line 52134

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52139
52140
52141
# File 'lib/google/apis/compute_v1/classes.rb', line 52139

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52146
52147
52148
52149
52150
52151
52152
52153
52154
52155
52156
52157
52158
52159
52160
52161
52162
52163
# File 'lib/google/apis/compute_v1/classes.rb', line 52146

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys)
  @name = args[:name] if args.key?(:name)
  @nats = args[:nats] if args.key?(:nats)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end