Class: Google::Apis::ComputeV1::Router
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Router
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ Google::Apis::ComputeV1::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ Array<Google::Apis::ComputeV1::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ Boolean
(also: #encrypted_interconnect_router?)
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ Array<Google::Apis::ComputeV1::RouterInterface>
Router interfaces.
-
#kind ⇒ String
Output only.
-
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeV1::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
-
#name ⇒ String
Name of the resource.
-
#nats ⇒ Array<Google::Apis::ComputeV1::RouterNat>
A list of NAT services created in this router.
-
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
-
#network ⇒ String
URI of the network to which this router belongs.
-
#params ⇒ Google::Apis::ComputeV1::RouterParams
Additional router parameters.
-
#region ⇒ String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Router
constructor
A new instance of Router.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Router
Returns a new instance of Router.
51964 51965 51966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp ⇒ Google::Apis::ComputeV1::RouterBgp
BGP information specific to this router.
Corresponds to the JSON property bgp
51862 51863 51864 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51862 def bgp @bgp end |
#bgp_peers ⇒ Array<Google::Apis::ComputeV1::RouterBgpPeer>
BGP information that must be configured into the routing stack to
establish BGP peering. This information must specify the peer ASN and
either the interface name, IP address, or peer IP address. Please refer
toRFC4273.
Corresponds to the JSON property bgpPeers
51870 51871 51872 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51870 def bgp_peers @bgp_peers end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
51876 51877 51878 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51876 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
51882 51883 51884 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51882 def description @description end |
#encrypted_interconnect_router ⇒ Boolean Also known as: encrypted_interconnect_router?
Indicates if a router is dedicated for use with encrypted VLAN
attachments (interconnectAttachments).
Corresponds to the JSON property encryptedInterconnectRouter
51888 51889 51890 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51888 def encrypted_interconnect_router @encrypted_interconnect_router end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
51895 51896 51897 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51895 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeV1::RouterInterface>
Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
- linkedVpnTunnel
- linkedInterconnectAttachment
- subnetwork
You can create a router interface without any of these fields specified.
However, you cannot create a BGP peer that uses that interface.
Corresponds to the JSON property
interfaces
51908 51909 51910 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51908 def interfaces @interfaces end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
51914 51915 51916 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51914 def kind @kind end |
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeV1::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
Corresponds to the JSON property md5AuthenticationKeys
51919 51920 51921 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51919 def md5_authentication_keys @md5_authentication_keys end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
51930 51931 51932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51930 def name @name end |
#nats ⇒ Array<Google::Apis::ComputeV1::RouterNat>
A list of NAT services created in this router.
Corresponds to the JSON property nats
51935 51936 51937 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51935 def nats @nats end |
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
Corresponds to the JSON property nccGateway
51940 51941 51942 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51940 def ncc_gateway @ncc_gateway end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
51945 51946 51947 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51945 def network @network end |
#params ⇒ Google::Apis::ComputeV1::RouterParams
Additional router parameters.
Corresponds to the JSON property params
51950 51951 51952 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51950 def params @params end |
#region ⇒ String
[Output Only] URI of the region where the router resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
51957 51958 51959 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51957 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
51962 51963 51964 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51962 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51969 51970 51971 51972 51973 51974 51975 51976 51977 51978 51979 51980 51981 51982 51983 51984 51985 51986 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51969 def update!(**args) @bgp = args[:bgp] if args.key?(:bgp) @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys) @name = args[:name] if args.key?(:name) @nats = args[:nats] if args.key?(:nats) @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |