Class: Google::Apis::ComputeV1::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



51965
51966
51967
# File 'lib/google/apis/compute_v1/classes.rb', line 51965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeV1::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



51863
51864
51865
# File 'lib/google/apis/compute_v1/classes.rb', line 51863

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeV1::RouterBgpPeer>

BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273. Corresponds to the JSON property bgpPeers



51871
51872
51873
# File 'lib/google/apis/compute_v1/classes.rb', line 51871

def bgp_peers
  @bgp_peers
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


51877
51878
51879
# File 'lib/google/apis/compute_v1/classes.rb', line 51877

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


51883
51884
51885
# File 'lib/google/apis/compute_v1/classes.rb', line 51883

def description
  @description
end

#encrypted_interconnect_routerBoolean Also known as: encrypted_interconnect_router?

Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments). Corresponds to the JSON property encryptedInterconnectRouter

Returns:

  • (Boolean)


51889
51890
51891
# File 'lib/google/apis/compute_v1/classes.rb', line 51889

def encrypted_interconnect_router
  @encrypted_interconnect_router
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


51896
51897
51898
# File 'lib/google/apis/compute_v1/classes.rb', line 51896

def id
  @id
end

#interfacesArray<Google::Apis::ComputeV1::RouterInterface>

Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:

  • linkedVpnTunnel
  • linkedInterconnectAttachment
  • subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface. Corresponds to the JSON property interfaces


51909
51910
51911
# File 'lib/google/apis/compute_v1/classes.rb', line 51909

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


51915
51916
51917
# File 'lib/google/apis/compute_v1/classes.rb', line 51915

def kind
  @kind
end

#md5_authentication_keysArray<Google::Apis::ComputeV1::RouterMd5AuthenticationKey>

Keys used for MD5 authentication. Corresponds to the JSON property md5AuthenticationKeys



51920
51921
51922
# File 'lib/google/apis/compute_v1/classes.rb', line 51920

def md5_authentication_keys
  @md5_authentication_keys
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


51931
51932
51933
# File 'lib/google/apis/compute_v1/classes.rb', line 51931

def name
  @name
end

#natsArray<Google::Apis::ComputeV1::RouterNat>

A list of NAT services created in this router. Corresponds to the JSON property nats



51936
51937
51938
# File 'lib/google/apis/compute_v1/classes.rb', line 51936

def nats
  @nats
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


51941
51942
51943
# File 'lib/google/apis/compute_v1/classes.rb', line 51941

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


51946
51947
51948
# File 'lib/google/apis/compute_v1/classes.rb', line 51946

def network
  @network
end

#paramsGoogle::Apis::ComputeV1::RouterParams

Additional router parameters. Corresponds to the JSON property params



51951
51952
51953
# File 'lib/google/apis/compute_v1/classes.rb', line 51951

def params
  @params
end

#regionString

[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


51958
51959
51960
# File 'lib/google/apis/compute_v1/classes.rb', line 51958

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51963
51964
51965
# File 'lib/google/apis/compute_v1/classes.rb', line 51963

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51970
51971
51972
51973
51974
51975
51976
51977
51978
51979
51980
51981
51982
51983
51984
51985
51986
51987
# File 'lib/google/apis/compute_v1/classes.rb', line 51970

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys)
  @name = args[:name] if args.key?(:name)
  @nats = args[:nats] if args.key?(:nats)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end