Class: Google::Apis::ComputeV1::Router
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Router
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ Google::Apis::ComputeV1::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ Array<Google::Apis::ComputeV1::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ Boolean
(also: #encrypted_interconnect_router?)
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ Array<Google::Apis::ComputeV1::RouterInterface>
Router interfaces.
-
#kind ⇒ String
Output only.
-
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeV1::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
-
#name ⇒ String
Name of the resource.
-
#nats ⇒ Array<Google::Apis::ComputeV1::RouterNat>
A list of NAT services created in this router.
-
#network ⇒ String
URI of the network to which this router belongs.
-
#params ⇒ Google::Apis::ComputeV1::RouterParams
Additional router parameters.
-
#region ⇒ String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Router
constructor
A new instance of Router.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Router
Returns a new instance of Router.
46676 46677 46678 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46676 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp ⇒ Google::Apis::ComputeV1::RouterBgp
BGP information specific to this router.
Corresponds to the JSON property bgp
46579 46580 46581 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46579 def bgp @bgp end |
#bgp_peers ⇒ Array<Google::Apis::ComputeV1::RouterBgpPeer>
BGP information that must be configured into the routing stack to
establish BGP peering. This information must specify the peer ASN and
either the interface name, IP address, or peer IP address. Please refer
toRFC4273.
Corresponds to the JSON property bgpPeers
46587 46588 46589 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46587 def bgp_peers @bgp_peers end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
46593 46594 46595 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46593 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
46599 46600 46601 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46599 def description @description end |
#encrypted_interconnect_router ⇒ Boolean Also known as: encrypted_interconnect_router?
Indicates if a router is dedicated for use with encrypted VLAN
attachments (interconnectAttachments).
Corresponds to the JSON property encryptedInterconnectRouter
46605 46606 46607 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46605 def encrypted_interconnect_router @encrypted_interconnect_router end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
46612 46613 46614 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46612 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeV1::RouterInterface>
Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
- linkedVpnTunnel
- linkedInterconnectAttachment
- subnetwork
You can create a router interface without any of these fields specified.
However, you cannot create a BGP peer that uses that interface.
Corresponds to the JSON property
interfaces
46625 46626 46627 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46625 def interfaces @interfaces end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
46631 46632 46633 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46631 def kind @kind end |
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeV1::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
Corresponds to the JSON property md5AuthenticationKeys
46636 46637 46638 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46636 def md5_authentication_keys @md5_authentication_keys end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
46647 46648 46649 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46647 def name @name end |
#nats ⇒ Array<Google::Apis::ComputeV1::RouterNat>
A list of NAT services created in this router.
Corresponds to the JSON property nats
46652 46653 46654 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46652 def nats @nats end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
46657 46658 46659 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46657 def network @network end |
#params ⇒ Google::Apis::ComputeV1::RouterParams
Additional router parameters.
Corresponds to the JSON property params
46662 46663 46664 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46662 def params @params end |
#region ⇒ String
[Output Only] URI of the region where the router resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
46669 46670 46671 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46669 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
46674 46675 46676 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46674 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46681 46682 46683 46684 46685 46686 46687 46688 46689 46690 46691 46692 46693 46694 46695 46696 46697 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46681 def update!(**args) @bgp = args[:bgp] if args.key?(:bgp) @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys) @name = args[:name] if args.key?(:name) @nats = args[:nats] if args.key?(:nats) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |