Class: Google::Apis::ComputeV1::Router
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Router
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ Google::Apis::ComputeV1::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ Array<Google::Apis::ComputeV1::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ Boolean
(also: #encrypted_interconnect_router?)
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ Array<Google::Apis::ComputeV1::RouterInterface>
Router interfaces.
-
#kind ⇒ String
Output only.
-
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeV1::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
-
#name ⇒ String
Name of the resource.
-
#nats ⇒ Array<Google::Apis::ComputeV1::RouterNat>
A list of NAT services created in this router.
-
#network ⇒ String
URI of the network to which this router belongs.
-
#params ⇒ Google::Apis::ComputeV1::RouterParams
Additional router parameters.
-
#region ⇒ String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Router
constructor
A new instance of Router.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Router
Returns a new instance of Router.
45489 45490 45491 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp ⇒ Google::Apis::ComputeV1::RouterBgp
BGP information specific to this router.
Corresponds to the JSON property bgp
45392 45393 45394 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45392 def bgp @bgp end |
#bgp_peers ⇒ Array<Google::Apis::ComputeV1::RouterBgpPeer>
BGP information that must be configured into the routing stack to
establish BGP peering. This information must specify the peer ASN and
either the interface name, IP address, or peer IP address. Please refer
toRFC4273.
Corresponds to the JSON property bgpPeers
45400 45401 45402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45400 def bgp_peers @bgp_peers end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
45406 45407 45408 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45406 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
45412 45413 45414 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45412 def description @description end |
#encrypted_interconnect_router ⇒ Boolean Also known as: encrypted_interconnect_router?
Indicates if a router is dedicated for use with encrypted VLAN
attachments (interconnectAttachments).
Corresponds to the JSON property encryptedInterconnectRouter
45418 45419 45420 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45418 def encrypted_interconnect_router @encrypted_interconnect_router end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
45425 45426 45427 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45425 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeV1::RouterInterface>
Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
- linkedVpnTunnel
- linkedInterconnectAttachment
- subnetwork
You can create a router interface without any of these fields specified.
However, you cannot create a BGP peer that uses that interface.
Corresponds to the JSON property
interfaces
45438 45439 45440 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45438 def interfaces @interfaces end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
45444 45445 45446 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45444 def kind @kind end |
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeV1::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
Corresponds to the JSON property md5AuthenticationKeys
45449 45450 45451 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45449 def md5_authentication_keys @md5_authentication_keys end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
45460 45461 45462 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45460 def name @name end |
#nats ⇒ Array<Google::Apis::ComputeV1::RouterNat>
A list of NAT services created in this router.
Corresponds to the JSON property nats
45465 45466 45467 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45465 def nats @nats end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
45470 45471 45472 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45470 def network @network end |
#params ⇒ Google::Apis::ComputeV1::RouterParams
Additional router parameters.
Corresponds to the JSON property params
45475 45476 45477 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45475 def params @params end |
#region ⇒ String
[Output Only] URI of the region where the router resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
45482 45483 45484 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45482 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
45487 45488 45489 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45487 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45494 45495 45496 45497 45498 45499 45500 45501 45502 45503 45504 45505 45506 45507 45508 45509 45510 |
# File 'lib/google/apis/compute_v1/classes.rb', line 45494 def update!(**args) @bgp = args[:bgp] if args.key?(:bgp) @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys) @name = args[:name] if args.key?(:name) @nats = args[:nats] if args.key?(:nats) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |