Class: Google::Apis::ComputeV1::Router
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Router
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Cloud Router resource. For more information about Cloud Router, read the Cloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ Google::Apis::ComputeV1::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ Array<Google::Apis::ComputeV1::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ Boolean
(also: #encrypted_interconnect_router?)
Indicates if a router is dedicated for use with encrypted VLAN attachments ( interconnectAttachments).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ Array<Google::Apis::ComputeV1::RouterInterface>
Router interfaces.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#name ⇒ String
Name of the resource.
-
#nats ⇒ Array<Google::Apis::ComputeV1::RouterNat>
A list of NAT services created in this router.
-
#network ⇒ String
URI of the network to which this router belongs.
-
#region ⇒ String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Router
constructor
A new instance of Router.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Router
Returns a new instance of Router.
28864 28865 28866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp ⇒ Google::Apis::ComputeV1::RouterBgp
BGP information specific to this router.
Corresponds to the JSON property bgp
28787 28788 28789 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28787 def bgp @bgp end |
#bgp_peers ⇒ Array<Google::Apis::ComputeV1::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish
BGP peering. This information must specify the peer ASN and either the
interface name, IP address, or peer IP address. Please refer to RFC4273.
Corresponds to the JSON property bgpPeers
28794 28795 28796 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28794 def bgp_peers @bgp_peers end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
28799 28800 28801 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28799 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
28805 28806 28807 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28805 def description @description end |
#encrypted_interconnect_router ⇒ Boolean Also known as: encrypted_interconnect_router?
Indicates if a router is dedicated for use with encrypted VLAN attachments (
interconnectAttachments). Not currently available publicly.
Corresponds to the JSON property encryptedInterconnectRouter
28811 28812 28813 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28811 def encrypted_interconnect_router @encrypted_interconnect_router end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
28818 28819 28820 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28818 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeV1::RouterInterface>
Router interfaces. Each interface requires either one linked resource, (for
example, linkedVpnTunnel), or IP address and IP address range (for example,
ipRange), or both.
Corresponds to the JSON property interfaces
28825 28826 28827 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28825 def interfaces @interfaces end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#router for routers.
Corresponds to the JSON property kind
28830 28831 28832 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28830 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
28840 28841 28842 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28840 def name @name end |
#nats ⇒ Array<Google::Apis::ComputeV1::RouterNat>
A list of NAT services created in this router.
Corresponds to the JSON property nats
28845 28846 28847 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28845 def nats @nats end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
28850 28851 28852 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28850 def network @network end |
#region ⇒ String
[Output Only] URI of the region where the router resides. You must specify
this field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
28857 28858 28859 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28857 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
28862 28863 28864 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28862 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28869 28870 28871 28872 28873 28874 28875 28876 28877 28878 28879 28880 28881 28882 28883 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28869 def update!(**args) @bgp = args[:bgp] if args.key?(:bgp) @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @nats = args[:nats] if args.key?(:nats) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |