Class: Google::Apis::ComputeV1::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



52235
52236
52237
# File 'lib/google/apis/compute_v1/classes.rb', line 52235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52198
52199
52200
# File 'lib/google/apis/compute_v1/classes.rb', line 52198

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



52203
52204
52205
# File 'lib/google/apis/compute_v1/classes.rb', line 52203

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


52208
52209
52210
# File 'lib/google/apis/compute_v1/classes.rb', line 52208

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52218
52219
52220
# File 'lib/google/apis/compute_v1/classes.rb', line 52218

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52223
52224
52225
# File 'lib/google/apis/compute_v1/classes.rb', line 52223

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52228
52229
52230
# File 'lib/google/apis/compute_v1/classes.rb', line 52228

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52233
52234
52235
# File 'lib/google/apis/compute_v1/classes.rb', line 52233

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52240
52241
52242
52243
52244
52245
52246
52247
52248
# File 'lib/google/apis/compute_v1/classes.rb', line 52240

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end