Class: Google::Apis::ComputeV1::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
52223 52224 52225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52186 52187 52188 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52186 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
52191 52192 52193 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52191 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
52196 52197 52198 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52196 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52206 52207 52208 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52206 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52211 52212 52213 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52211 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
52216 52217 52218 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52216 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52221 52222 52223 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52221 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52228 52229 52230 52231 52232 52233 52234 52235 52236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52228 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |