Class: Google::Apis::ComputeV1::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



52058
52059
52060
# File 'lib/google/apis/compute_v1/classes.rb', line 52058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52021
52022
52023
# File 'lib/google/apis/compute_v1/classes.rb', line 52021

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



52026
52027
52028
# File 'lib/google/apis/compute_v1/classes.rb', line 52026

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


52031
52032
52033
# File 'lib/google/apis/compute_v1/classes.rb', line 52031

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52041
52042
52043
# File 'lib/google/apis/compute_v1/classes.rb', line 52041

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52046
52047
52048
# File 'lib/google/apis/compute_v1/classes.rb', line 52046

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52051
52052
52053
# File 'lib/google/apis/compute_v1/classes.rb', line 52051

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52056
52057
52058
# File 'lib/google/apis/compute_v1/classes.rb', line 52056

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52063
52064
52065
52066
52067
52068
52069
52070
52071
# File 'lib/google/apis/compute_v1/classes.rb', line 52063

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end