Class: Google::Apis::ComputeV1::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



51721
51722
51723
# File 'lib/google/apis/compute_v1/classes.rb', line 51721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51684
51685
51686
# File 'lib/google/apis/compute_v1/classes.rb', line 51684

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



51689
51690
51691
# File 'lib/google/apis/compute_v1/classes.rb', line 51689

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


51694
51695
51696
# File 'lib/google/apis/compute_v1/classes.rb', line 51694

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51704
51705
51706
# File 'lib/google/apis/compute_v1/classes.rb', line 51704

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51709
51710
51711
# File 'lib/google/apis/compute_v1/classes.rb', line 51709

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51714
51715
51716
# File 'lib/google/apis/compute_v1/classes.rb', line 51714

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51719
51720
51721
# File 'lib/google/apis/compute_v1/classes.rb', line 51719

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51726
51727
51728
51729
51730
51731
51732
51733
51734
# File 'lib/google/apis/compute_v1/classes.rb', line 51726

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end