Class: Google::Apis::ComputeV1::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
50226 50227 50228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50189 50190 50191 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50189 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
50194 50195 50196 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50194 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
50199 50200 50201 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50199 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50209 50210 50211 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50209 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50214 50215 50216 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50214 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
50219 50220 50221 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50219 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
50224 50225 50226 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50224 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50231 50232 50233 50234 50235 50236 50237 50238 50239 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50231 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |