Class: Google::Apis::ComputeV1::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



46769
46770
46771
# File 'lib/google/apis/compute_v1/classes.rb', line 46769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46732
46733
46734
# File 'lib/google/apis/compute_v1/classes.rb', line 46732

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



46737
46738
46739
# File 'lib/google/apis/compute_v1/classes.rb', line 46737

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


46742
46743
46744
# File 'lib/google/apis/compute_v1/classes.rb', line 46742

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46752
46753
46754
# File 'lib/google/apis/compute_v1/classes.rb', line 46752

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46757
46758
46759
# File 'lib/google/apis/compute_v1/classes.rb', line 46757

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46762
46763
46764
# File 'lib/google/apis/compute_v1/classes.rb', line 46762

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46767
46768
46769
# File 'lib/google/apis/compute_v1/classes.rb', line 46767

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46774
46775
46776
46777
46778
46779
46780
46781
46782
# File 'lib/google/apis/compute_v1/classes.rb', line 46774

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end