Class: Google::Apis::ComputeV1::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
28954 28955 28956 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
28918 28919 28920 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28918 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
28923 28924 28925 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28923 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
28928 28929 28930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28928 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
28937 28938 28939 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28937 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
28942 28943 28944 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28942 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
28947 28948 28949 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28947 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
28952 28953 28954 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28952 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28959 28960 28961 28962 28963 28964 28965 28966 28967 |
# File 'lib/google/apis/compute_v1/classes.rb', line 28959 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |