Class: Google::Apis::ComputeV1::RouterBgp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterBgp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#advertise_mode ⇒ String
User-specified flag to indicate which mode to use for advertisement.
-
#advertised_groups ⇒ Array<String>
User-specified list of prefix groups to advertise in custom mode.
-
#advertised_ip_ranges ⇒ Array<Google::Apis::ComputeV1::RouterAdvertisedIpRange>
User-specified list of individual IP ranges to advertise in custom mode.
-
#asn ⇒ Fixnum
Local BGP Autonomous System Number (ASN).
-
#identifier_range ⇒ String
Explicitly specifies a range of valid BGP Identifiers for this Router.
-
#keepalive_interval ⇒ Fixnum
The interval in seconds between BGP keepalive messages that are sent to the peer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterBgp
constructor
A new instance of RouterBgp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterBgp
Returns a new instance of RouterBgp.
52380 52381 52382 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertise_mode ⇒ String
User-specified flag to indicate which mode to use for advertisement.
The options are DEFAULT or CUSTOM.
Corresponds to the JSON property advertiseMode
52329 52330 52331 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52329 def advertise_mode @advertise_mode end |
#advertised_groups ⇒ Array<String>
User-specified list of prefix groups to advertise in custom mode.
This field can only be populated if advertise_mode is CUSTOM and
is advertised to all peers of the router.
These groups will be advertised in addition to any specified prefixes.
Leave this field blank to advertise no custom groups.
Corresponds to the JSON property advertisedGroups
52338 52339 52340 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52338 def advertised_groups @advertised_groups end |
#advertised_ip_ranges ⇒ Array<Google::Apis::ComputeV1::RouterAdvertisedIpRange>
User-specified list of individual IP ranges to advertise in custom mode.
This field can only be populated if advertise_mode is CUSTOM and
is advertised to all peers of the router.
These IP ranges will be advertised in addition to any specified groups.
Leave this field blank to advertise no custom IP ranges.
Corresponds to the JSON property advertisedIpRanges
52347 52348 52349 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52347 def advertised_ip_ranges @advertised_ip_ranges end |
#asn ⇒ Fixnum
Local BGP Autonomous System Number (ASN).
Must be anRFC6996 private ASN, either 16-bit or 32-bit. The
value will be fixed for this router resource. All VPN tunnels that link
to this router will have the same local ASN.
Corresponds to the JSON property asn
52355 52356 52357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52355 def asn @asn end |
#identifier_range ⇒ String
Explicitly specifies a range of valid BGP Identifiers for this Router. It
is provided as a link-local IPv4 range (from 169.254.0.0/16), of size at
least /30, even if the BGP sessions are over IPv6. It must not overlap
with any IPv4 BGP session ranges.
Other vendors commonly call this "router ID".
Corresponds to the JSON property identifierRange
52364 52365 52366 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52364 def identifier_range @identifier_range end |
#keepalive_interval ⇒ Fixnum
The interval in seconds between BGP keepalive messages that are
sent to the peer.
Hold time is three times the interval at which keepalive messages are
sent, and the hold time is the maximum number of seconds allowed to
elapse between successive keepalive messages that BGP receives from a
peer.
BGP will use the smaller of either the local hold time value or the
peer's hold time value as the hold time for the BGP connection between
the two peers.
If set, this value must be between 20 and 60. The default is 20.
Corresponds to the JSON property keepaliveInterval
52378 52379 52380 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52378 def keepalive_interval @keepalive_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52385 52386 52387 52388 52389 52390 52391 52392 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52385 def update!(**args) @advertise_mode = args[:advertise_mode] if args.key?(:advertise_mode) @advertised_groups = args[:advertised_groups] if args.key?(:advertised_groups) @advertised_ip_ranges = args[:advertised_ip_ranges] if args.key?(:advertised_ip_ranges) @asn = args[:asn] if args.key?(:asn) @identifier_range = args[:identifier_range] if args.key?(:identifier_range) @keepalive_interval = args[:keepalive_interval] if args.key?(:keepalive_interval) end |