Class: Google::Apis::ComputeV1::RouterBgpPeer

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterBgpPeer

Returns a new instance of RouterBgpPeer.



45919
45920
45921
# File 'lib/google/apis/compute_v1/classes.rb', line 45919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

User-specified flag to indicate which mode to use for advertisement. Corresponds to the JSON property advertiseMode

Returns:

  • (String)


45749
45750
45751
# File 'lib/google/apis/compute_v1/classes.rb', line 45749

def advertise_mode
  @advertise_mode
end

#advertised_groupsArray<String>

User-specified list of prefix groups to advertise in custom mode, which currently supports the following option:

  • ALL_SUBNETS: Advertises all of the router's own VPC subnets. This excludes any routes learned for subnets that use VPC Network Peering. Note that this field can only be populated if advertise_mode is CUSTOM and overrides the list defined for the router (in the "bgp" message). These groups are advertised in addition to any specified prefixes. Leave this field blank to advertise no custom groups. Corresponds to the JSON property advertisedGroups

Returns:

  • (Array<String>)


45763
45764
45765
# File 'lib/google/apis/compute_v1/classes.rb', line 45763

def advertised_groups
  @advertised_groups
end

#advertised_ip_rangesArray<Google::Apis::ComputeV1::RouterAdvertisedIpRange>

User-specified list of individual IP ranges to advertise in custom mode. This field can only be populated if advertise_mode is CUSTOM and overrides the list defined for the router (in the "bgp" message). These IP ranges are advertised in addition to any specified groups. Leave this field blank to advertise no custom IP ranges. Corresponds to the JSON property advertisedIpRanges



45772
45773
45774
# File 'lib/google/apis/compute_v1/classes.rb', line 45772

def advertised_ip_ranges
  @advertised_ip_ranges
end

#advertised_route_priorityFixnum

The priority of routes advertised to this BGP peer. Where there is more than one matching route of maximum length, the routes with the lowest priority value win. Corresponds to the JSON property advertisedRoutePriority

Returns:

  • (Fixnum)


45779
45780
45781
# File 'lib/google/apis/compute_v1/classes.rb', line 45779

def advertised_route_priority
  @advertised_route_priority
end

#bfdGoogle::Apis::ComputeV1::RouterBgpPeerBfd

BFD configuration for the BGP peering. Corresponds to the JSON property bfd



45784
45785
45786
# File 'lib/google/apis/compute_v1/classes.rb', line 45784

def bfd
  @bfd
end

#custom_learned_ip_rangesArray<Google::Apis::ComputeV1::RouterBgpPeerCustomLearnedIpRange>

A list of user-defined custom learned route IP address ranges for a BGP session. Corresponds to the JSON property customLearnedIpRanges



45790
45791
45792
# File 'lib/google/apis/compute_v1/classes.rb', line 45790

def custom_learned_ip_ranges
  @custom_learned_ip_ranges
end

#custom_learned_route_priorityFixnum

The user-defined custom learned route priority for a BGP session. This value is applied to all custom learned route ranges for the session. You can choose a value from 0 to 65335. If you don't provide a value, Google Cloud assigns a priority of 100 to the ranges. Corresponds to the JSON property customLearnedRoutePriority

Returns:

  • (Fixnum)


45798
45799
45800
# File 'lib/google/apis/compute_v1/classes.rb', line 45798

def custom_learned_route_priority
  @custom_learned_route_priority
end

#enableString

The status of the BGP peer connection. If set to FALSE, any active session with the peer is terminated and all associated routing information is removed. If set to TRUE, the peer connection can be established with routing information. The default is TRUE. Corresponds to the JSON property enable

Returns:

  • (String)


45807
45808
45809
# File 'lib/google/apis/compute_v1/classes.rb', line 45807

def enable
  @enable
end

#enable_ipv4Boolean Also known as: enable_ipv4?

Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4. Corresponds to the JSON property enableIpv4

Returns:

  • (Boolean)


45813
45814
45815
# File 'lib/google/apis/compute_v1/classes.rb', line 45813

def enable_ipv4
  @enable_ipv4
end

#enable_ipv6Boolean Also known as: enable_ipv6?

Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6. Corresponds to the JSON property enableIpv6

Returns:

  • (Boolean)


45820
45821
45822
# File 'lib/google/apis/compute_v1/classes.rb', line 45820

def enable_ipv6
  @enable_ipv6
end

#export_policiesArray<String>

List of export policies applied to this peer, in the order they must be evaluated. The name must correspond to an existing policy that has ROUTE_POLICY_TYPE_EXPORT type. Corresponds to the JSON property exportPolicies

Returns:

  • (Array<String>)


45828
45829
45830
# File 'lib/google/apis/compute_v1/classes.rb', line 45828

def export_policies
  @export_policies
end

#import_policiesArray<String>

List of import policies applied to this peer, in the order they must be evaluated. The name must correspond to an existing policy that has ROUTE_POLICY_TYPE_IMPORT type. Corresponds to the JSON property importPolicies

Returns:

  • (Array<String>)


45835
45836
45837
# File 'lib/google/apis/compute_v1/classes.rb', line 45835

def import_policies
  @import_policies
end

#interface_nameString

Name of the interface the BGP peer is associated with. Corresponds to the JSON property interfaceName

Returns:

  • (String)


45840
45841
45842
# File 'lib/google/apis/compute_v1/classes.rb', line 45840

def interface_name
  @interface_name
end

#ip_addressString

IP address of the interface inside Google Cloud Platform. Corresponds to the JSON property ipAddress

Returns:

  • (String)


45845
45846
45847
# File 'lib/google/apis/compute_v1/classes.rb', line 45845

def ip_address
  @ip_address
end

#ipv4_nexthop_addressString

IPv4 address of the interface inside Google Cloud Platform. Corresponds to the JSON property ipv4NexthopAddress

Returns:

  • (String)


45850
45851
45852
# File 'lib/google/apis/compute_v1/classes.rb', line 45850

def ipv4_nexthop_address
  @ipv4_nexthop_address
end

#ipv6_nexthop_addressString

IPv6 address of the interface inside Google Cloud Platform. Corresponds to the JSON property ipv6NexthopAddress

Returns:

  • (String)


45855
45856
45857
# File 'lib/google/apis/compute_v1/classes.rb', line 45855

def ipv6_nexthop_address
  @ipv6_nexthop_address
end

#management_typeString

Output only. [Output Only] The resource that configures and manages this BGP peer.

  • MANAGED_BY_USER is the default value and can be managed by you or other users
  • MANAGED_BY_ATTACHMENT is a BGP peer that is configured and managed by Cloud Interconnect, specifically by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of BGP peer when the PARTNER InterconnectAttachment is created, updated, or deleted. Corresponds to the JSON property managementType

Returns:

  • (String)


45869
45870
45871
# File 'lib/google/apis/compute_v1/classes.rb', line 45869

def management_type
  @management_type
end

#md5_authentication_key_nameString

Present if MD5 authentication is enabled for the peering. Must be the name of one of the entries in the Router.md5_authentication_keys. The field must comply with RFC1035. Corresponds to the JSON property md5AuthenticationKeyName

Returns:

  • (String)


45876
45877
45878
# File 'lib/google/apis/compute_v1/classes.rb', line 45876

def md5_authentication_key_name
  @md5_authentication_key_name
end

#nameString

Name of this BGP peer. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


45887
45888
45889
# File 'lib/google/apis/compute_v1/classes.rb', line 45887

def name
  @name
end

#peer_asnFixnum

Peer BGP Autonomous System Number (ASN). Each BGP interface may use a different value. Corresponds to the JSON property peerAsn

Returns:

  • (Fixnum)


45893
45894
45895
# File 'lib/google/apis/compute_v1/classes.rb', line 45893

def peer_asn
  @peer_asn
end

#peer_ip_addressString

IP address of the BGP interface outside Google Cloud Platform. Corresponds to the JSON property peerIpAddress

Returns:

  • (String)


45898
45899
45900
# File 'lib/google/apis/compute_v1/classes.rb', line 45898

def peer_ip_address
  @peer_ip_address
end

#peer_ipv4_nexthop_addressString

IPv4 address of the BGP interface outside Google Cloud Platform. Corresponds to the JSON property peerIpv4NexthopAddress

Returns:

  • (String)


45903
45904
45905
# File 'lib/google/apis/compute_v1/classes.rb', line 45903

def peer_ipv4_nexthop_address
  @peer_ipv4_nexthop_address
end

#peer_ipv6_nexthop_addressString

IPv6 address of the BGP interface outside Google Cloud Platform. Corresponds to the JSON property peerIpv6NexthopAddress

Returns:

  • (String)


45908
45909
45910
# File 'lib/google/apis/compute_v1/classes.rb', line 45908

def peer_ipv6_nexthop_address
  @peer_ipv6_nexthop_address
end

#router_appliance_instanceString

URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance must be located in zones contained in the same region as this Cloud Router. The VM instance is the peer side of the BGP session. Corresponds to the JSON property routerApplianceInstance

Returns:

  • (String)


45917
45918
45919
# File 'lib/google/apis/compute_v1/classes.rb', line 45917

def router_appliance_instance
  @router_appliance_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45924
45925
45926
45927
45928
45929
45930
45931
45932
45933
45934
45935
45936
45937
45938
45939
45940
45941
45942
45943
45944
45945
45946
45947
45948
45949
# File 'lib/google/apis/compute_v1/classes.rb', line 45924

def update!(**args)
  @advertise_mode = args[:advertise_mode] if args.key?(:advertise_mode)
  @advertised_groups = args[:advertised_groups] if args.key?(:advertised_groups)
  @advertised_ip_ranges = args[:advertised_ip_ranges] if args.key?(:advertised_ip_ranges)
  @advertised_route_priority = args[:advertised_route_priority] if args.key?(:advertised_route_priority)
  @bfd = args[:bfd] if args.key?(:bfd)
  @custom_learned_ip_ranges = args[:custom_learned_ip_ranges] if args.key?(:custom_learned_ip_ranges)
  @custom_learned_route_priority = args[:custom_learned_route_priority] if args.key?(:custom_learned_route_priority)
  @enable = args[:enable] if args.key?(:enable)
  @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4)
  @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6)
  @export_policies = args[:export_policies] if args.key?(:export_policies)
  @import_policies = args[:import_policies] if args.key?(:import_policies)
  @interface_name = args[:interface_name] if args.key?(:interface_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address)
  @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address)
  @management_type = args[:management_type] if args.key?(:management_type)
  @md5_authentication_key_name = args[:md5_authentication_key_name] if args.key?(:md5_authentication_key_name)
  @name = args[:name] if args.key?(:name)
  @peer_asn = args[:peer_asn] if args.key?(:peer_asn)
  @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address)
  @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address)
  @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address)
  @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance)
end