Class: Google::Apis::ComputeV1::RouterInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#ip_range ⇒ String
IP address and range of the interface.
-
#linked_interconnect_attachment ⇒ String
URI of the linked Interconnect attachment.
-
#linked_vpn_tunnel ⇒ String
URI of the linked VPN tunnel, which must be in the same region as the router.
-
#management_type ⇒ String
[Output Only] The resource that configures and manages this interface.
-
#name ⇒ String
Name of this interface entry.
-
#private_ip_address ⇒ String
The regional private internal IP address that is used to establish BGP sessions to a VM instance acting as a third-party Router Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN VM.
-
#redundant_interface ⇒ String
Name of the interface that will be redundant with the current interface you are creating.
-
#subnetwork ⇒ String
The URI of the subnetwork resource that this interface belongs to, which must be in the same region as the Cloud Router.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterInterface
constructor
A new instance of RouterInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterInterface
Returns a new instance of RouterInterface.
29359 29360 29361 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_range ⇒ String
IP address and range of the interface. The IP range must be in the RFC3927
link-local IP address space. The value must be a CIDR-formatted string, for
example: 169.254.0.1/30. NOTE: Do not truncate the address as it represents
the IP address of the interface.
Corresponds to the JSON property ipRange
29294 29295 29296 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29294 def ip_range @ip_range end |
#linked_interconnect_attachment ⇒ String
URI of the linked Interconnect attachment. It must be in the same region as
the router. Each interface can have one linked resource, which can be a VPN
tunnel, an Interconnect attachment, or a virtual machine instance.
Corresponds to the JSON property linkedInterconnectAttachment
29301 29302 29303 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29301 def @linked_interconnect_attachment end |
#linked_vpn_tunnel ⇒ String
URI of the linked VPN tunnel, which must be in the same region as the router.
Each interface can have one linked resource, which can be a VPN tunnel, an
Interconnect attachment, or a virtual machine instance.
Corresponds to the JSON property linkedVpnTunnel
29308 29309 29310 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29308 def linked_vpn_tunnel @linked_vpn_tunnel end |
#management_type ⇒ String
[Output Only] The resource that configures and manages this interface. -
MANAGED_BY_USER is the default value and can be managed directly by users. -
MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud
Interconnect, specifically, by an InterconnectAttachment of type PARTNER.
Google automatically creates, updates, and deletes this type of interface when
the PARTNER InterconnectAttachment is created, updated, or deleted.
Corresponds to the JSON property managementType
29318 29319 29320 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29318 def management_type @management_type end |
#name ⇒ String
Name of this interface entry. The name must be 1-63 characters long, and
comply with RFC1035. Specifically, the name must be 1-63 characters long and
match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the
first character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
29328 29329 29330 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29328 def name @name end |
#private_ip_address ⇒ String
The regional private internal IP address that is used to establish BGP
sessions to a VM instance acting as a third-party Router Appliance, such as a
Next Gen Firewall, a Virtual Router, or an SD-WAN VM.
Corresponds to the JSON property privateIpAddress
29335 29336 29337 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29335 def private_ip_address @private_ip_address end |
#redundant_interface ⇒ String
Name of the interface that will be redundant with the current interface you
are creating. The redundantInterface must belong to the same Cloud Router as
the interface here. To establish the BGP session to a Router Appliance VM, you
must create two BGP peers. The two BGP peers must be attached to two separate
interfaces that are redundant with each other. The redundant_interface must be
1-63 characters long, and comply with RFC1035. Specifically, the
redundant_interface must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must
be a lowercase letter, and all following characters must be a dash, lowercase
letter, or digit, except the last character, which cannot be a dash.
Corresponds to the JSON property redundantInterface
29349 29350 29351 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29349 def redundant_interface @redundant_interface end |
#subnetwork ⇒ String
The URI of the subnetwork resource that this interface belongs to, which must
be in the same region as the Cloud Router. When you establish a BGP session to
a VM instance using this interface, the VM instance must belong to the same
subnetwork as the subnetwork specified here.
Corresponds to the JSON property subnetwork
29357 29358 29359 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29357 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29364 29365 29366 29367 29368 29369 29370 29371 29372 29373 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29364 def update!(**args) @ip_range = args[:ip_range] if args.key?(:ip_range) @linked_interconnect_attachment = args[:linked_interconnect_attachment] if args.key?(:linked_interconnect_attachment) @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel) @management_type = args[:management_type] if args.key?(:management_type) @name = args[:name] if args.key?(:name) @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address) @redundant_interface = args[:redundant_interface] if args.key?(:redundant_interface) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |