Class: Google::Apis::ComputeV1::RouterList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Router resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterList

Returns a new instance of RouterList.



53578
53579
53580
# File 'lib/google/apis/compute_v1/classes.rb', line 53578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53545
53546
53547
# File 'lib/google/apis/compute_v1/classes.rb', line 53545

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Router>

A list of Router resources. Corresponds to the JSON property items



53550
53551
53552
# File 'lib/google/apis/compute_v1/classes.rb', line 53550

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


53556
53557
53558
# File 'lib/google/apis/compute_v1/classes.rb', line 53556

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53566
53567
53568
# File 'lib/google/apis/compute_v1/classes.rb', line 53566

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53571
53572
53573
# File 'lib/google/apis/compute_v1/classes.rb', line 53571

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RouterList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53576
53577
53578
# File 'lib/google/apis/compute_v1/classes.rb', line 53576

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53583
53584
53585
53586
53587
53588
53589
53590
# File 'lib/google/apis/compute_v1/classes.rb', line 53583

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end