Class: Google::Apis::ComputeV1::RouterList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Router resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Router>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RouterList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterList
constructor
A new instance of RouterList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterList
Returns a new instance of RouterList.
52836 52837 52838 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52836 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52803 52804 52805 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52803 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Router>
A list of Router resources.
Corresponds to the JSON property items
52808 52809 52810 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52808 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
52814 52815 52816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52814 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52824 52825 52826 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52824 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52829 52830 52831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52829 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RouterList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52834 52835 52836 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52834 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52841 52842 52843 52844 52845 52846 52847 52848 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52841 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |