Class: Google::Apis::ComputeV1::RouterList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Router resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterList

Returns a new instance of RouterList.



52322
52323
52324
# File 'lib/google/apis/compute_v1/classes.rb', line 52322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52289
52290
52291
# File 'lib/google/apis/compute_v1/classes.rb', line 52289

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Router>

A list of Router resources. Corresponds to the JSON property items



52294
52295
52296
# File 'lib/google/apis/compute_v1/classes.rb', line 52294

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


52300
52301
52302
# File 'lib/google/apis/compute_v1/classes.rb', line 52300

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52310
52311
52312
# File 'lib/google/apis/compute_v1/classes.rb', line 52310

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52315
52316
52317
# File 'lib/google/apis/compute_v1/classes.rb', line 52315

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RouterList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52320
52321
52322
# File 'lib/google/apis/compute_v1/classes.rb', line 52320

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52327
52328
52329
52330
52331
52332
52333
52334
# File 'lib/google/apis/compute_v1/classes.rb', line 52327

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end