Class: Google::Apis::ComputeV1::RouterList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Router resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterList

Returns a new instance of RouterList.



47370
47371
47372
# File 'lib/google/apis/compute_v1/classes.rb', line 47370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47337
47338
47339
# File 'lib/google/apis/compute_v1/classes.rb', line 47337

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Router>

A list of Router resources. Corresponds to the JSON property items



47342
47343
47344
# File 'lib/google/apis/compute_v1/classes.rb', line 47342

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


47348
47349
47350
# File 'lib/google/apis/compute_v1/classes.rb', line 47348

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47358
47359
47360
# File 'lib/google/apis/compute_v1/classes.rb', line 47358

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47363
47364
47365
# File 'lib/google/apis/compute_v1/classes.rb', line 47363

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::RouterList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47368
47369
47370
# File 'lib/google/apis/compute_v1/classes.rb', line 47368

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47375
47376
47377
47378
47379
47380
47381
47382
# File 'lib/google/apis/compute_v1/classes.rb', line 47375

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end