Class: Google::Apis::ComputeV1::RouterList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Router resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Router>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RouterList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterList
constructor
A new instance of RouterList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterList
Returns a new instance of RouterList.
46183 46184 46185 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46150 46151 46152 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46150 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Router>
A list of Router resources.
Corresponds to the JSON property items
46155 46156 46157 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46155 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
46161 46162 46163 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46161 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46171 46172 46173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46171 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46176 46177 46178 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46176 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::RouterList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46181 46182 46183 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46181 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46188 46189 46190 46191 46192 46193 46194 46195 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46188 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |