Class: Google::Apis::ComputeV1::RouterMd5AuthenticationKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterMd5AuthenticationKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
[Input only] Value of the key.
-
#name ⇒ String
Name used to identify the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterMd5AuthenticationKey
constructor
A new instance of RouterMd5AuthenticationKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterMd5AuthenticationKey
Returns a new instance of RouterMd5AuthenticationKey.
52929 52930 52931 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
[Input only] Value of the key.
For patch and update calls, it can be skipped to
copy the value from the previous configuration. This is allowed if the
key with the same name existed before the operation. Maximum length is 80
characters. Can only contain printable ASCII characters.
Corresponds to the JSON property key
52920 52921 52922 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52920 def key @key end |
#name ⇒ String
Name used to identify the key.
Must be unique within a router. Must be referenced by exactly
one bgpPeer. Must comply withRFC1035.
Corresponds to the JSON property name
52927 52928 52929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52927 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52934 52935 52936 52937 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52934 def update!(**args) @key = args[:key] if args.key?(:key) @name = args[:name] if args.key?(:name) end |