Class: Google::Apis::ComputeV1::RouterNat
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterNat
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Nat resource. It enables the VMs within the specified subnetworks to access Internet without external IP addresses. It specifies a list of subnetworks (and the ranges within) that want to use NAT. Customers can also provide the external IPs that would be used for NAT. GCP would auto-allocate ephemeral IPs if no external IPs are provided.
Instance Attribute Summary collapse
-
#auto_network_tier ⇒ String
The network tier to use when automatically reserving NAT IP addresses.
-
#drain_nat_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained.
-
#enable_dynamic_port_allocation ⇒ Boolean
(also: #enable_dynamic_port_allocation?)
Enable Dynamic Port Allocation.
-
#enable_endpoint_independent_mapping ⇒ Boolean
(also: #enable_endpoint_independent_mapping?)
Corresponds to the JSON property
enableEndpointIndependentMapping. -
#endpoint_types ⇒ Array<String>
List of NAT-ted endpoint types supported by the Nat Gateway.
-
#icmp_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for ICMP connections.
-
#log_config ⇒ Google::Apis::ComputeV1::RouterNatLogConfig
Configuration of logging on a NAT.
-
#max_ports_per_vm ⇒ Fixnum
Maximum number of ports allocated to a VM from this NAT config when Dynamic Port Allocation is enabled.
-
#min_ports_per_vm ⇒ Fixnum
Minimum number of ports allocated to a VM from this NAT config.
-
#name ⇒ String
Unique name of this Nat service.
-
#nat64_subnetworks ⇒ Array<Google::Apis::ComputeV1::RouterNatSubnetworkToNat64>
List of Subnetwork resources whose traffic should be translated by NAT64 Gateway.
-
#nat_ip_allocate_option ⇒ String
Specify the NatIpAllocateOption, which can take one of the following values:.
-
#nat_ips ⇒ Array<String>
A list of URLs of the IP resources used for this Nat service.
-
#rules ⇒ Array<Google::Apis::ComputeV1::RouterNatRule>
A list of rules associated with this NAT.
-
#source_subnetwork_ip_ranges_to_nat ⇒ String
Specify the Nat option, which can take one of the following values:.
-
#source_subnetwork_ip_ranges_to_nat64 ⇒ String
Specify the Nat option for NAT64, which can take one of the following values:.
-
#subnetworks ⇒ Array<Google::Apis::ComputeV1::RouterNatSubnetworkToNat>
A list of Subnetwork resources whose traffic should be translated by NAT Gateway.
-
#tcp_established_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP established connections.
-
#tcp_time_wait_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP connections that are in TIME_WAIT state.
-
#tcp_transitory_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP transitory connections.
-
#type ⇒ String
Indicates whether this NAT is used for public or private IP translation.
-
#udp_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for UDP connections.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNat
constructor
A new instance of RouterNat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNat
Returns a new instance of RouterNat.
47674 47675 47676 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_network_tier ⇒ String
The network tier to use when automatically reserving NAT IP addresses.
Must be one of: PREMIUM, STANDARD.
If not specified, then the current
project-level default tier is used.
Corresponds to the JSON property autoNetworkTier
47500 47501 47502 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47500 def auto_network_tier @auto_network_tier end |
#drain_nat_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained. These IPs
must be valid static external IPs that have been assigned to the NAT.
These IPs should be used for updating/patching a NAT only.
Corresponds to the JSON property drainNatIps
47507 47508 47509 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47507 def drain_nat_ips @drain_nat_ips end |
#enable_dynamic_port_allocation ⇒ Boolean Also known as: enable_dynamic_port_allocation?
Enable Dynamic Port Allocation. If not specified, it is disabled by default. If set to true,
- Dynamic Port Allocation will be enabled on this NAT config.
- enableEndpointIndependentMapping cannot be set to true.
- If minPorts is set, minPortsPerVm must be set to a
power of two greater than or equal to 32. If minPortsPerVm is not set, a
minimum of 32 ports will be allocated to a VM from this NAT
config.
Corresponds to the JSON property
enableDynamicPortAllocation
47522 47523 47524 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47522 def enable_dynamic_port_allocation @enable_dynamic_port_allocation end |
#enable_endpoint_independent_mapping ⇒ Boolean Also known as: enable_endpoint_independent_mapping?
Corresponds to the JSON property enableEndpointIndependentMapping
47528 47529 47530 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47528 def enable_endpoint_independent_mapping @enable_endpoint_independent_mapping end |
#endpoint_types ⇒ Array<String>
List of NAT-ted endpoint types supported by the Nat Gateway. If the list
is empty, then it will be equivalent to include ENDPOINT_TYPE_VM
Corresponds to the JSON property endpointTypes
47535 47536 47537 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47535 def endpoint_types @endpoint_types end |
#icmp_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for ICMP connections. Defaults to 30s if not set.
Corresponds to the JSON property icmpIdleTimeoutSec
47540 47541 47542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47540 def icmp_idle_timeout_sec @icmp_idle_timeout_sec end |
#log_config ⇒ Google::Apis::ComputeV1::RouterNatLogConfig
Configuration of logging on a NAT.
Corresponds to the JSON property logConfig
47545 47546 47547 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47545 def log_config @log_config end |
#max_ports_per_vm ⇒ Fixnum
Maximum number of ports allocated to a VM from this NAT config when
Dynamic Port Allocation is enabled.
If Dynamic Port Allocation is not enabled, this field has no effect.
If Dynamic Port Allocation is enabled, and this field is set, it must be
set to a power of two greater than minPortsPerVm, or 64 if minPortsPerVm
is not set.
If Dynamic Port Allocation is enabled and this field is not set,
a maximum of 65536 ports will be allocated to a VM from this NAT
config.
Corresponds to the JSON property maxPortsPerVm
47558 47559 47560 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47558 def max_ports_per_vm @max_ports_per_vm end |
#min_ports_per_vm ⇒ Fixnum
Minimum number of ports allocated to a VM from this NAT config. If not
set, a default number of ports is allocated to a VM. This is rounded
up to the nearest power of 2. For example, if the value of this field is
50, at least 64 ports are allocated to a VM.
Corresponds to the JSON property minPortsPerVm
47566 47567 47568 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47566 def min_ports_per_vm @min_ports_per_vm end |
#name ⇒ String
Unique name of this Nat service.
The name must be 1-63 characters long and comply withRFC1035.
Corresponds to the JSON property name
47572 47573 47574 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47572 def name @name end |
#nat64_subnetworks ⇒ Array<Google::Apis::ComputeV1::RouterNatSubnetworkToNat64>
List of Subnetwork resources whose traffic should be translated by NAT64
Gateway. It is used only when LIST_OF_IPV6_SUBNETWORKS is
selected for the SubnetworkIpRangeToNat64Option above.
Corresponds to the JSON property nat64Subnetworks
47579 47580 47581 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47579 def nat64_subnetworks @nat64_subnetworks end |
#nat_ip_allocate_option ⇒ String
Specify the NatIpAllocateOption, which can take one of the following values:
- MANUAL_ONLY: Uses only Nat IP addresses provided by customers. When there are not enough specified Nat IPs, the Nat service fails for new VMs.
- AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform; customers
can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip should
be empty.
Corresponds to the JSON property
natIpAllocateOption
47592 47593 47594 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47592 def nat_ip_allocate_option @nat_ip_allocate_option end |
#nat_ips ⇒ Array<String>
A list of URLs of the IP resources used for this Nat service. These IP
addresses must be valid static external IP addresses assigned to the
project.
Corresponds to the JSON property natIps
47599 47600 47601 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47599 def nat_ips @nat_ips end |
#rules ⇒ Array<Google::Apis::ComputeV1::RouterNatRule>
A list of rules associated with this NAT.
Corresponds to the JSON property rules
47604 47605 47606 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47604 def rules @rules end |
#source_subnetwork_ip_ranges_to_nat ⇒ String
Specify the Nat option, which can take one of the following values:
- ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are allowed to Nat.
- ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP ranges in every Subnetwork are allowed to Nat.
- LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat
(specified in the field subnetwork below)
The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED.
Note that if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES then there
should not be any other Router.Nat section in any Router for this network
in this region.
Corresponds to the JSON property
sourceSubnetworkIpRangesToNat
47620 47621 47622 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47620 def source_subnetwork_ip_ranges_to_nat @source_subnetwork_ip_ranges_to_nat end |
#source_subnetwork_ip_ranges_to_nat64 ⇒ String
Specify the Nat option for NAT64, which can take one of the following values:
- ALL_IPV6_SUBNETWORKS: All of the IP ranges in every Subnetwork are allowed to Nat.
- LIST_OF_IPV6_SUBNETWORKS: A list of Subnetworks are allowed to Nat
(specified in the field nat64_subnetwork below)
The default is NAT64_OPTION_UNSPECIFIED.
Note that if this field contains NAT64_ALL_V6_SUBNETWORKS no other
Router.Nat section in this region can also enable NAT64 for any
Subnetworks in this network. Other Router.Nat sections can still be
present to enable NAT44 only.
Corresponds to the JSON property
sourceSubnetworkIpRangesToNat64
47636 47637 47638 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47636 def source_subnetwork_ip_ranges_to_nat64 @source_subnetwork_ip_ranges_to_nat64 end |
#subnetworks ⇒ Array<Google::Apis::ComputeV1::RouterNatSubnetworkToNat>
A list of Subnetwork resources whose traffic should be translated by NAT
Gateway. It is used only when LIST_OF_SUBNETWORKS is selected for the
SubnetworkIpRangeToNatOption above.
Corresponds to the JSON property subnetworks
47643 47644 47645 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47643 def subnetworks @subnetworks end |
#tcp_established_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP established connections. Defaults to 1200s
if not set.
Corresponds to the JSON property tcpEstablishedIdleTimeoutSec
47649 47650 47651 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47649 def tcp_established_idle_timeout_sec @tcp_established_idle_timeout_sec end |
#tcp_time_wait_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP connections that are in TIME_WAIT state.
Defaults to 120s if not set.
Corresponds to the JSON property tcpTimeWaitTimeoutSec
47655 47656 47657 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47655 def tcp_time_wait_timeout_sec @tcp_time_wait_timeout_sec end |
#tcp_transitory_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP transitory connections. Defaults to 30s if
not set.
Corresponds to the JSON property tcpTransitoryIdleTimeoutSec
47661 47662 47663 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47661 def tcp_transitory_idle_timeout_sec @tcp_transitory_idle_timeout_sec end |
#type ⇒ String
Indicates whether this NAT is used for public or private IP
translation. If unspecified, it defaults to PUBLIC.
Corresponds to the JSON property type
47667 47668 47669 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47667 def type @type end |
#udp_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for UDP connections. Defaults to 30s if not set.
Corresponds to the JSON property udpIdleTimeoutSec
47672 47673 47674 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47672 def udp_idle_timeout_sec @udp_idle_timeout_sec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47679 47680 47681 47682 47683 47684 47685 47686 47687 47688 47689 47690 47691 47692 47693 47694 47695 47696 47697 47698 47699 47700 47701 47702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 47679 def update!(**args) @auto_network_tier = args[:auto_network_tier] if args.key?(:auto_network_tier) @drain_nat_ips = args[:drain_nat_ips] if args.key?(:drain_nat_ips) @enable_dynamic_port_allocation = args[:enable_dynamic_port_allocation] if args.key?(:enable_dynamic_port_allocation) @enable_endpoint_independent_mapping = args[:enable_endpoint_independent_mapping] if args.key?(:enable_endpoint_independent_mapping) @endpoint_types = args[:endpoint_types] if args.key?(:endpoint_types) @icmp_idle_timeout_sec = args[:icmp_idle_timeout_sec] if args.key?(:icmp_idle_timeout_sec) @log_config = args[:log_config] if args.key?(:log_config) @max_ports_per_vm = args[:max_ports_per_vm] if args.key?(:max_ports_per_vm) @min_ports_per_vm = args[:min_ports_per_vm] if args.key?(:min_ports_per_vm) @name = args[:name] if args.key?(:name) @nat64_subnetworks = args[:nat64_subnetworks] if args.key?(:nat64_subnetworks) @nat_ip_allocate_option = args[:nat_ip_allocate_option] if args.key?(:nat_ip_allocate_option) @nat_ips = args[:nat_ips] if args.key?(:nat_ips) @rules = args[:rules] if args.key?(:rules) @source_subnetwork_ip_ranges_to_nat = args[:source_subnetwork_ip_ranges_to_nat] if args.key?(:source_subnetwork_ip_ranges_to_nat) @source_subnetwork_ip_ranges_to_nat64 = args[:source_subnetwork_ip_ranges_to_nat64] if args.key?(:source_subnetwork_ip_ranges_to_nat64) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) @tcp_established_idle_timeout_sec = args[:tcp_established_idle_timeout_sec] if args.key?(:tcp_established_idle_timeout_sec) @tcp_time_wait_timeout_sec = args[:tcp_time_wait_timeout_sec] if args.key?(:tcp_time_wait_timeout_sec) @tcp_transitory_idle_timeout_sec = args[:tcp_transitory_idle_timeout_sec] if args.key?(:tcp_transitory_idle_timeout_sec) @type = args[:type] if args.key?(:type) @udp_idle_timeout_sec = args[:udp_idle_timeout_sec] if args.key?(:udp_idle_timeout_sec) end |