Class: Google::Apis::ComputeV1::RouterNat

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Nat resource. It enables the VMs within the specified subnetworks to access Internet without external IP addresses. It specifies a list of subnetworks (and the ranges within) that want to use NAT. Customers can also provide the external IPs that would be used for NAT. GCP would auto-allocate ephemeral IPs if no external IPs are provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNat

Returns a new instance of RouterNat.



46487
46488
46489
# File 'lib/google/apis/compute_v1/classes.rb', line 46487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_network_tierString

The network tier to use when automatically reserving NAT IP addresses. Must be one of: PREMIUM, STANDARD. If not specified, then the current project-level default tier is used. Corresponds to the JSON property autoNetworkTier

Returns:

  • (String)


46313
46314
46315
# File 'lib/google/apis/compute_v1/classes.rb', line 46313

def auto_network_tier
  @auto_network_tier
end

#drain_nat_ipsArray<String>

A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT only. Corresponds to the JSON property drainNatIps

Returns:

  • (Array<String>)


46320
46321
46322
# File 'lib/google/apis/compute_v1/classes.rb', line 46320

def drain_nat_ips
  @drain_nat_ips
end

#enable_dynamic_port_allocationBoolean Also known as: enable_dynamic_port_allocation?

Enable Dynamic Port Allocation. If not specified, it is disabled by default. If set to true,

  • Dynamic Port Allocation will be enabled on this NAT config.
  • enableEndpointIndependentMapping cannot be set to true.
  • If minPorts is set, minPortsPerVm must be set to a power of two greater than or equal to 32. If minPortsPerVm is not set, a minimum of 32 ports will be allocated to a VM from this NAT config. Corresponds to the JSON property enableDynamicPortAllocation

Returns:

  • (Boolean)


46335
46336
46337
# File 'lib/google/apis/compute_v1/classes.rb', line 46335

def enable_dynamic_port_allocation
  @enable_dynamic_port_allocation
end

#enable_endpoint_independent_mappingBoolean Also known as: enable_endpoint_independent_mapping?

Corresponds to the JSON property enableEndpointIndependentMapping

Returns:

  • (Boolean)


46341
46342
46343
# File 'lib/google/apis/compute_v1/classes.rb', line 46341

def enable_endpoint_independent_mapping
  @enable_endpoint_independent_mapping
end

#endpoint_typesArray<String>

List of NAT-ted endpoint types supported by the Nat Gateway. If the list is empty, then it will be equivalent to include ENDPOINT_TYPE_VM Corresponds to the JSON property endpointTypes

Returns:

  • (Array<String>)


46348
46349
46350
# File 'lib/google/apis/compute_v1/classes.rb', line 46348

def endpoint_types
  @endpoint_types
end

#icmp_idle_timeout_secFixnum

Timeout (in seconds) for ICMP connections. Defaults to 30s if not set. Corresponds to the JSON property icmpIdleTimeoutSec

Returns:

  • (Fixnum)


46353
46354
46355
# File 'lib/google/apis/compute_v1/classes.rb', line 46353

def icmp_idle_timeout_sec
  @icmp_idle_timeout_sec
end

#log_configGoogle::Apis::ComputeV1::RouterNatLogConfig

Configuration of logging on a NAT. Corresponds to the JSON property logConfig



46358
46359
46360
# File 'lib/google/apis/compute_v1/classes.rb', line 46358

def log_config
  @log_config
end

#max_ports_per_vmFixnum

Maximum number of ports allocated to a VM from this NAT config when Dynamic Port Allocation is enabled. If Dynamic Port Allocation is not enabled, this field has no effect. If Dynamic Port Allocation is enabled, and this field is set, it must be set to a power of two greater than minPortsPerVm, or 64 if minPortsPerVm is not set. If Dynamic Port Allocation is enabled and this field is not set, a maximum of 65536 ports will be allocated to a VM from this NAT config. Corresponds to the JSON property maxPortsPerVm

Returns:

  • (Fixnum)


46371
46372
46373
# File 'lib/google/apis/compute_v1/classes.rb', line 46371

def max_ports_per_vm
  @max_ports_per_vm
end

#min_ports_per_vmFixnum

Minimum number of ports allocated to a VM from this NAT config. If not set, a default number of ports is allocated to a VM. This is rounded up to the nearest power of 2. For example, if the value of this field is 50, at least 64 ports are allocated to a VM. Corresponds to the JSON property minPortsPerVm

Returns:

  • (Fixnum)


46379
46380
46381
# File 'lib/google/apis/compute_v1/classes.rb', line 46379

def min_ports_per_vm
  @min_ports_per_vm
end

#nameString

Unique name of this Nat service. The name must be 1-63 characters long and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


46385
46386
46387
# File 'lib/google/apis/compute_v1/classes.rb', line 46385

def name
  @name
end

#nat64_subnetworksArray<Google::Apis::ComputeV1::RouterNatSubnetworkToNat64>

List of Subnetwork resources whose traffic should be translated by NAT64 Gateway. It is used only when LIST_OF_IPV6_SUBNETWORKS is selected for the SubnetworkIpRangeToNat64Option above. Corresponds to the JSON property nat64Subnetworks



46392
46393
46394
# File 'lib/google/apis/compute_v1/classes.rb', line 46392

def nat64_subnetworks
  @nat64_subnetworks
end

#nat_ip_allocate_optionString

Specify the NatIpAllocateOption, which can take one of the following values:

  • MANUAL_ONLY: Uses only Nat IP addresses provided by customers. When there are not enough specified Nat IPs, the Nat service fails for new VMs.
  • AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform; customers can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip should be empty. Corresponds to the JSON property natIpAllocateOption

Returns:

  • (String)


46405
46406
46407
# File 'lib/google/apis/compute_v1/classes.rb', line 46405

def nat_ip_allocate_option
  @nat_ip_allocate_option
end

#nat_ipsArray<String>

A list of URLs of the IP resources used for this Nat service. These IP addresses must be valid static external IP addresses assigned to the project. Corresponds to the JSON property natIps

Returns:

  • (Array<String>)


46412
46413
46414
# File 'lib/google/apis/compute_v1/classes.rb', line 46412

def nat_ips
  @nat_ips
end

#rulesArray<Google::Apis::ComputeV1::RouterNatRule>

A list of rules associated with this NAT. Corresponds to the JSON property rules



46417
46418
46419
# File 'lib/google/apis/compute_v1/classes.rb', line 46417

def rules
  @rules
end

#source_subnetwork_ip_ranges_to_natString

Specify the Nat option, which can take one of the following values:

  • ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are allowed to Nat.
  • ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP ranges in every Subnetwork are allowed to Nat.
  • LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field subnetwork below) The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES then there should not be any other Router.Nat section in any Router for this network in this region. Corresponds to the JSON property sourceSubnetworkIpRangesToNat

Returns:

  • (String)


46433
46434
46435
# File 'lib/google/apis/compute_v1/classes.rb', line 46433

def source_subnetwork_ip_ranges_to_nat
  @source_subnetwork_ip_ranges_to_nat
end

#source_subnetwork_ip_ranges_to_nat64String

Specify the Nat option for NAT64, which can take one of the following values:

  • ALL_IPV6_SUBNETWORKS: All of the IP ranges in every Subnetwork are allowed to Nat.
  • LIST_OF_IPV6_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field nat64_subnetwork below) The default is NAT64_OPTION_UNSPECIFIED. Note that if this field contains NAT64_ALL_V6_SUBNETWORKS no other Router.Nat section in this region can also enable NAT64 for any Subnetworks in this network. Other Router.Nat sections can still be present to enable NAT44 only. Corresponds to the JSON property sourceSubnetworkIpRangesToNat64

Returns:

  • (String)


46449
46450
46451
# File 'lib/google/apis/compute_v1/classes.rb', line 46449

def source_subnetwork_ip_ranges_to_nat64
  @source_subnetwork_ip_ranges_to_nat64
end

#subnetworksArray<Google::Apis::ComputeV1::RouterNatSubnetworkToNat>

A list of Subnetwork resources whose traffic should be translated by NAT Gateway. It is used only when LIST_OF_SUBNETWORKS is selected for the SubnetworkIpRangeToNatOption above. Corresponds to the JSON property subnetworks



46456
46457
46458
# File 'lib/google/apis/compute_v1/classes.rb', line 46456

def subnetworks
  @subnetworks
end

#tcp_established_idle_timeout_secFixnum

Timeout (in seconds) for TCP established connections. Defaults to 1200s if not set. Corresponds to the JSON property tcpEstablishedIdleTimeoutSec

Returns:

  • (Fixnum)


46462
46463
46464
# File 'lib/google/apis/compute_v1/classes.rb', line 46462

def tcp_established_idle_timeout_sec
  @tcp_established_idle_timeout_sec
end

#tcp_time_wait_timeout_secFixnum

Timeout (in seconds) for TCP connections that are in TIME_WAIT state. Defaults to 120s if not set. Corresponds to the JSON property tcpTimeWaitTimeoutSec

Returns:

  • (Fixnum)


46468
46469
46470
# File 'lib/google/apis/compute_v1/classes.rb', line 46468

def tcp_time_wait_timeout_sec
  @tcp_time_wait_timeout_sec
end

#tcp_transitory_idle_timeout_secFixnum

Timeout (in seconds) for TCP transitory connections. Defaults to 30s if not set. Corresponds to the JSON property tcpTransitoryIdleTimeoutSec

Returns:

  • (Fixnum)


46474
46475
46476
# File 'lib/google/apis/compute_v1/classes.rb', line 46474

def tcp_transitory_idle_timeout_sec
  @tcp_transitory_idle_timeout_sec
end

#typeString

Indicates whether this NAT is used for public or private IP translation. If unspecified, it defaults to PUBLIC. Corresponds to the JSON property type

Returns:

  • (String)


46480
46481
46482
# File 'lib/google/apis/compute_v1/classes.rb', line 46480

def type
  @type
end

#udp_idle_timeout_secFixnum

Timeout (in seconds) for UDP connections. Defaults to 30s if not set. Corresponds to the JSON property udpIdleTimeoutSec

Returns:

  • (Fixnum)


46485
46486
46487
# File 'lib/google/apis/compute_v1/classes.rb', line 46485

def udp_idle_timeout_sec
  @udp_idle_timeout_sec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46492
46493
46494
46495
46496
46497
46498
46499
46500
46501
46502
46503
46504
46505
46506
46507
46508
46509
46510
46511
46512
46513
46514
46515
# File 'lib/google/apis/compute_v1/classes.rb', line 46492

def update!(**args)
  @auto_network_tier = args[:auto_network_tier] if args.key?(:auto_network_tier)
  @drain_nat_ips = args[:drain_nat_ips] if args.key?(:drain_nat_ips)
  @enable_dynamic_port_allocation = args[:enable_dynamic_port_allocation] if args.key?(:enable_dynamic_port_allocation)
  @enable_endpoint_independent_mapping = args[:enable_endpoint_independent_mapping] if args.key?(:enable_endpoint_independent_mapping)
  @endpoint_types = args[:endpoint_types] if args.key?(:endpoint_types)
  @icmp_idle_timeout_sec = args[:icmp_idle_timeout_sec] if args.key?(:icmp_idle_timeout_sec)
  @log_config = args[:log_config] if args.key?(:log_config)
  @max_ports_per_vm = args[:max_ports_per_vm] if args.key?(:max_ports_per_vm)
  @min_ports_per_vm = args[:min_ports_per_vm] if args.key?(:min_ports_per_vm)
  @name = args[:name] if args.key?(:name)
  @nat64_subnetworks = args[:nat64_subnetworks] if args.key?(:nat64_subnetworks)
  @nat_ip_allocate_option = args[:nat_ip_allocate_option] if args.key?(:nat_ip_allocate_option)
  @nat_ips = args[:nat_ips] if args.key?(:nat_ips)
  @rules = args[:rules] if args.key?(:rules)
  @source_subnetwork_ip_ranges_to_nat = args[:source_subnetwork_ip_ranges_to_nat] if args.key?(:source_subnetwork_ip_ranges_to_nat)
  @source_subnetwork_ip_ranges_to_nat64 = args[:source_subnetwork_ip_ranges_to_nat64] if args.key?(:source_subnetwork_ip_ranges_to_nat64)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
  @tcp_established_idle_timeout_sec = args[:tcp_established_idle_timeout_sec] if args.key?(:tcp_established_idle_timeout_sec)
  @tcp_time_wait_timeout_sec = args[:tcp_time_wait_timeout_sec] if args.key?(:tcp_time_wait_timeout_sec)
  @tcp_transitory_idle_timeout_sec = args[:tcp_transitory_idle_timeout_sec] if args.key?(:tcp_transitory_idle_timeout_sec)
  @type = args[:type] if args.key?(:type)
  @udp_idle_timeout_sec = args[:udp_idle_timeout_sec] if args.key?(:udp_idle_timeout_sec)
end