Class: Google::Apis::ComputeV1::RouterNat
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterNat
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Nat resource. It enables the VMs within the specified subnetworks to access Internet without external IP addresses. It specifies a list of subnetworks (and the ranges within) that want to use NAT. Customers can also provide the external IPs that would be used for NAT. GCP would auto-allocate ephemeral IPs if no external IPs are provided.
Instance Attribute Summary collapse
-
#drain_nat_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained.
-
#enable_dynamic_port_allocation ⇒ Boolean
(also: #enable_dynamic_port_allocation?)
Enable Dynamic Port Allocation.
-
#enable_endpoint_independent_mapping ⇒ Boolean
(also: #enable_endpoint_independent_mapping?)
Corresponds to the JSON property
enableEndpointIndependentMapping. -
#icmp_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for ICMP connections.
-
#log_config ⇒ Google::Apis::ComputeV1::RouterNatLogConfig
Configuration of logging on a NAT.
-
#max_ports_per_vm ⇒ Fixnum
Maximum number of ports allocated to a VM from this NAT config when Dynamic Port Allocation is enabled.
-
#min_ports_per_vm ⇒ Fixnum
Minimum number of ports allocated to a VM from this NAT config.
-
#name ⇒ String
Unique name of this Nat service.
-
#nat_ip_allocate_option ⇒ String
Specify the NatIpAllocateOption, which can take one of the following values: - MANUAL_ONLY: Uses only Nat IP addresses provided by customers.
-
#nat_ips ⇒ Array<String>
A list of URLs of the IP resources used for this Nat service.
-
#rules ⇒ Array<Google::Apis::ComputeV1::RouterNatRule>
A list of rules associated with this NAT.
-
#source_subnetwork_ip_ranges_to_nat ⇒ String
Specify the Nat option, which can take one of the following values: - ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are allowed to Nat.
-
#subnetworks ⇒ Array<Google::Apis::ComputeV1::RouterNatSubnetworkToNat>
A list of Subnetwork resources whose traffic should be translated by NAT Gateway.
-
#tcp_established_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP established connections.
-
#tcp_time_wait_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP connections that are in TIME_WAIT state.
-
#tcp_transitory_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP transitory connections.
-
#udp_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for UDP connections.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNat
constructor
A new instance of RouterNat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNat
Returns a new instance of RouterNat.
29623 29624 29625 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drain_nat_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained. These IPs must be valid
static external IPs that have been assigned to the NAT. These IPs should be
used for updating/patching a NAT only.
Corresponds to the JSON property drainNatIps
29506 29507 29508 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29506 def drain_nat_ips @drain_nat_ips end |
#enable_dynamic_port_allocation ⇒ Boolean Also known as: enable_dynamic_port_allocation?
Enable Dynamic Port Allocation. If not specified, it is disabled by default.
If set to true, - Dynamic Port Allocation will be enabled on this NAT config. -
enableEndpointIndependentMapping cannot be set to true. - If minPorts is set,
minPortsPerVm must be set to a power of two greater than or equal to 32. If
minPortsPerVm is not set, a minimum of 32 ports will be allocated to a VM from
this NAT config.
Corresponds to the JSON property enableDynamicPortAllocation
29516 29517 29518 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29516 def enable_dynamic_port_allocation @enable_dynamic_port_allocation end |
#enable_endpoint_independent_mapping ⇒ Boolean Also known as: enable_endpoint_independent_mapping?
Corresponds to the JSON property enableEndpointIndependentMapping
29522 29523 29524 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29522 def enable_endpoint_independent_mapping @enable_endpoint_independent_mapping end |
#icmp_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for ICMP connections. Defaults to 30s if not set.
Corresponds to the JSON property icmpIdleTimeoutSec
29528 29529 29530 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29528 def icmp_idle_timeout_sec @icmp_idle_timeout_sec end |
#log_config ⇒ Google::Apis::ComputeV1::RouterNatLogConfig
Configuration of logging on a NAT.
Corresponds to the JSON property logConfig
29533 29534 29535 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29533 def log_config @log_config end |
#max_ports_per_vm ⇒ Fixnum
Maximum number of ports allocated to a VM from this NAT config when Dynamic
Port Allocation is enabled. If Dynamic Port Allocation is not enabled, this
field has no effect. If Dynamic Port Allocation is enabled, and this field is
set, it must be set to a power of two greater than minPortsPerVm, or 64 if
minPortsPerVm is not set. If Dynamic Port Allocation is enabled and this field
is not set, a maximum of 65536 ports will be allocated to a VM from this NAT
config.
Corresponds to the JSON property maxPortsPerVm
29544 29545 29546 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29544 def max_ports_per_vm @max_ports_per_vm end |
#min_ports_per_vm ⇒ Fixnum
Minimum number of ports allocated to a VM from this NAT config. If not set, a
default number of ports is allocated to a VM. This is rounded up to the
nearest power of 2. For example, if the value of this field is 50, at least 64
ports are allocated to a VM.
Corresponds to the JSON property minPortsPerVm
29552 29553 29554 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29552 def min_ports_per_vm @min_ports_per_vm end |
#name ⇒ String
Unique name of this Nat service. The name must be 1-63 characters long and
comply with RFC1035.
Corresponds to the JSON property name
29558 29559 29560 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29558 def name @name end |
#nat_ip_allocate_option ⇒ String
Specify the NatIpAllocateOption, which can take one of the following values: -
MANUAL_ONLY: Uses only Nat IP addresses provided by customers. When there are
not enough specified Nat IPs, the Nat service fails for new VMs. - AUTO_ONLY:
Nat IPs are allocated by Google Cloud Platform; customers can't specify any
Nat IPs. When choosing AUTO_ONLY, then nat_ip should be empty.
Corresponds to the JSON property natIpAllocateOption
29567 29568 29569 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29567 def nat_ip_allocate_option @nat_ip_allocate_option end |
#nat_ips ⇒ Array<String>
A list of URLs of the IP resources used for this Nat service. These IP
addresses must be valid static external IP addresses assigned to the project.
Corresponds to the JSON property natIps
29573 29574 29575 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29573 def nat_ips @nat_ips end |
#rules ⇒ Array<Google::Apis::ComputeV1::RouterNatRule>
A list of rules associated with this NAT.
Corresponds to the JSON property rules
29578 29579 29580 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29578 def rules @rules end |
#source_subnetwork_ip_ranges_to_nat ⇒ String
Specify the Nat option, which can take one of the following values: -
ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are
allowed to Nat. - ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP
ranges in every Subnetwork are allowed to Nat. - LIST_OF_SUBNETWORKS: A list
of Subnetworks are allowed to Nat (specified in the field subnetwork below)
The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if
this field contains ALL_SUBNETWORKS_ALL_IP_RANGES or
ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES, then there should not be any other
Router.Nat section in any Router for this network in this region.
Corresponds to the JSON property sourceSubnetworkIpRangesToNat
29591 29592 29593 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29591 def source_subnetwork_ip_ranges_to_nat @source_subnetwork_ip_ranges_to_nat end |
#subnetworks ⇒ Array<Google::Apis::ComputeV1::RouterNatSubnetworkToNat>
A list of Subnetwork resources whose traffic should be translated by NAT
Gateway. It is used only when LIST_OF_SUBNETWORKS is selected for the
SubnetworkIpRangeToNatOption above.
Corresponds to the JSON property subnetworks
29598 29599 29600 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29598 def subnetworks @subnetworks end |
#tcp_established_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP established connections. Defaults to 1200s if not
set.
Corresponds to the JSON property tcpEstablishedIdleTimeoutSec
29604 29605 29606 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29604 def tcp_established_idle_timeout_sec @tcp_established_idle_timeout_sec end |
#tcp_time_wait_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP connections that are in TIME_WAIT state. Defaults
to 120s if not set.
Corresponds to the JSON property tcpTimeWaitTimeoutSec
29610 29611 29612 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29610 def tcp_time_wait_timeout_sec @tcp_time_wait_timeout_sec end |
#tcp_transitory_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for TCP transitory connections. Defaults to 30s if not
set.
Corresponds to the JSON property tcpTransitoryIdleTimeoutSec
29616 29617 29618 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29616 def tcp_transitory_idle_timeout_sec @tcp_transitory_idle_timeout_sec end |
#udp_idle_timeout_sec ⇒ Fixnum
Timeout (in seconds) for UDP connections. Defaults to 30s if not set.
Corresponds to the JSON property udpIdleTimeoutSec
29621 29622 29623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29621 def udp_idle_timeout_sec @udp_idle_timeout_sec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29628 29629 29630 29631 29632 29633 29634 29635 29636 29637 29638 29639 29640 29641 29642 29643 29644 29645 29646 |
# File 'lib/google/apis/compute_v1/classes.rb', line 29628 def update!(**args) @drain_nat_ips = args[:drain_nat_ips] if args.key?(:drain_nat_ips) @enable_dynamic_port_allocation = args[:enable_dynamic_port_allocation] if args.key?(:enable_dynamic_port_allocation) @enable_endpoint_independent_mapping = args[:enable_endpoint_independent_mapping] if args.key?(:enable_endpoint_independent_mapping) @icmp_idle_timeout_sec = args[:icmp_idle_timeout_sec] if args.key?(:icmp_idle_timeout_sec) @log_config = args[:log_config] if args.key?(:log_config) @max_ports_per_vm = args[:max_ports_per_vm] if args.key?(:max_ports_per_vm) @min_ports_per_vm = args[:min_ports_per_vm] if args.key?(:min_ports_per_vm) @name = args[:name] if args.key?(:name) @nat_ip_allocate_option = args[:nat_ip_allocate_option] if args.key?(:nat_ip_allocate_option) @nat_ips = args[:nat_ips] if args.key?(:nat_ips) @rules = args[:rules] if args.key?(:rules) @source_subnetwork_ip_ranges_to_nat = args[:source_subnetwork_ip_ranges_to_nat] if args.key?(:source_subnetwork_ip_ranges_to_nat) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) @tcp_established_idle_timeout_sec = args[:tcp_established_idle_timeout_sec] if args.key?(:tcp_established_idle_timeout_sec) @tcp_time_wait_timeout_sec = args[:tcp_time_wait_timeout_sec] if args.key?(:tcp_time_wait_timeout_sec) @tcp_transitory_idle_timeout_sec = args[:tcp_transitory_idle_timeout_sec] if args.key?(:tcp_transitory_idle_timeout_sec) @udp_idle_timeout_sec = args[:udp_idle_timeout_sec] if args.key?(:udp_idle_timeout_sec) end |