Class: Google::Apis::ComputeV1::RouterNatLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration of logging on a NAT.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNatLogConfig

Returns a new instance of RouterNatLogConfig.



53946
53947
53948
# File 'lib/google/apis/compute_v1/classes.rb', line 53946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Indicates whether or not to export logs. This is false by default. Corresponds to the JSON property enable

Returns:

  • (Boolean)


53930
53931
53932
# File 'lib/google/apis/compute_v1/classes.rb', line 53930

def enable
  @enable
end

#filterString

Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:

  • ERRORS_ONLY: Export logs only for connection failures.
  • TRANSLATIONS_ONLY: Export logs only for successful connections.
  • ALL: Export logs for all connections, successful and unsuccessful. Corresponds to the JSON property filter

Returns:

  • (String)


53944
53945
53946
# File 'lib/google/apis/compute_v1/classes.rb', line 53944

def filter
  @filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53951
53952
53953
53954
# File 'lib/google/apis/compute_v1/classes.rb', line 53951

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @filter = args[:filter] if args.key?(:filter)
end