Class: Google::Apis::ComputeV1::RouterNatLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterNatLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Configuration of logging on a NAT.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
Indicates whether or not to export logs.
-
#filter ⇒ String
Specify the desired filtering of logs on this NAT.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNatLogConfig
constructor
A new instance of RouterNatLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNatLogConfig
Returns a new instance of RouterNatLogConfig.
53018 53019 53020 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
Indicates whether or not to export logs. This is false by default.
Corresponds to the JSON property enable
53002 53003 53004 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53002 def enable @enable end |
#filter ⇒ String
Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:
- ERRORS_ONLY: Export logs only for connection failures.
- TRANSLATIONS_ONLY: Export logs only for successful connections.
- ALL: Export logs for all connections, successful and
unsuccessful.
Corresponds to the JSON property
filter
53016 53017 53018 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53016 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53023 53024 53025 53026 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53023 def update!(**args) @enable = args[:enable] if args.key?(:enable) @filter = args[:filter] if args.key?(:filter) end |