Class: Google::Apis::ComputeV1::RouterNatLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration of logging on a NAT.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNatLogConfig

Returns a new instance of RouterNatLogConfig.



47728
47729
47730
# File 'lib/google/apis/compute_v1/classes.rb', line 47728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Indicates whether or not to export logs. This is false by default. Corresponds to the JSON property enable

Returns:

  • (Boolean)


47712
47713
47714
# File 'lib/google/apis/compute_v1/classes.rb', line 47712

def enable
  @enable
end

#filterString

Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:

  • ERRORS_ONLY: Export logs only for connection failures.
  • TRANSLATIONS_ONLY: Export logs only for successful connections.
  • ALL: Export logs for all connections, successful and unsuccessful. Corresponds to the JSON property filter

Returns:

  • (String)


47726
47727
47728
# File 'lib/google/apis/compute_v1/classes.rb', line 47726

def filter
  @filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47733
47734
47735
47736
# File 'lib/google/apis/compute_v1/classes.rb', line 47733

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @filter = args[:filter] if args.key?(:filter)
end