Class: Google::Apis::ComputeV1::RouterNatRuleAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterNatRuleAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#source_nat_active_ips ⇒ Array<String>
A list of URLs of the IP resources used for this NAT rule.
-
#source_nat_active_ranges ⇒ Array<String>
A list of URLs of the subnetworks used as source ranges for this NAT Rule.
-
#source_nat_drain_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained.
-
#source_nat_drain_ranges ⇒ Array<String>
A list of URLs of subnetworks representing source ranges to be drained.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNatRuleAction
constructor
A new instance of RouterNatRuleAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNatRuleAction
Returns a new instance of RouterNatRuleAction.
53123 53124 53125 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_nat_active_ips ⇒ Array<String>
A list of URLs of the IP resources used for this NAT rule. These IP
addresses must be valid static external IP addresses assigned to the
project.
This field is used for public NAT.
Corresponds to the JSON property sourceNatActiveIps
53097 53098 53099 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53097 def source_nat_active_ips @source_nat_active_ips end |
#source_nat_active_ranges ⇒ Array<String>
A list of URLs of the subnetworks used as source ranges for this
NAT Rule. These subnetworks must have purpose set to PRIVATE_NAT.
This field is used for private NAT.
Corresponds to the JSON property sourceNatActiveRanges
53104 53105 53106 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53104 def source_nat_active_ranges @source_nat_active_ranges end |
#source_nat_drain_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained. These IPs
must be valid static external IPs that have been assigned to the NAT.
These IPs should be used for updating/patching a NAT rule only.
This field is used for public NAT.
Corresponds to the JSON property sourceNatDrainIps
53112 53113 53114 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53112 def source_nat_drain_ips @source_nat_drain_ips end |
#source_nat_drain_ranges ⇒ Array<String>
A list of URLs of subnetworks representing source ranges to be
drained. This is only supported on patch/update, and these
subnetworks must have previously been used as active ranges in this
NAT Rule.
This field is used for private NAT.
Corresponds to the JSON property sourceNatDrainRanges
53121 53122 53123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53121 def source_nat_drain_ranges @source_nat_drain_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53128 53129 53130 53131 53132 53133 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53128 def update!(**args) @source_nat_active_ips = args[:source_nat_active_ips] if args.key?(:source_nat_active_ips) @source_nat_active_ranges = args[:source_nat_active_ranges] if args.key?(:source_nat_active_ranges) @source_nat_drain_ips = args[:source_nat_drain_ips] if args.key?(:source_nat_drain_ips) @source_nat_drain_ranges = args[:source_nat_drain_ranges] if args.key?(:source_nat_drain_ranges) end |