Class: Google::Apis::ComputeV1::RouterNatRuleAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNatRuleAction

Returns a new instance of RouterNatRuleAction.



52790
52791
52792
# File 'lib/google/apis/compute_v1/classes.rb', line 52790

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_nat_active_ipsArray<String>

A list of URLs of the IP resources used for this NAT rule. These IP addresses must be valid static external IP addresses assigned to the project. This field is used for public NAT. Corresponds to the JSON property sourceNatActiveIps

Returns:

  • (Array<String>)


52764
52765
52766
# File 'lib/google/apis/compute_v1/classes.rb', line 52764

def source_nat_active_ips
  @source_nat_active_ips
end

#source_nat_active_rangesArray<String>

A list of URLs of the subnetworks used as source ranges for this NAT Rule. These subnetworks must have purpose set to PRIVATE_NAT. This field is used for private NAT. Corresponds to the JSON property sourceNatActiveRanges

Returns:

  • (Array<String>)


52771
52772
52773
# File 'lib/google/apis/compute_v1/classes.rb', line 52771

def source_nat_active_ranges
  @source_nat_active_ranges
end

#source_nat_drain_ipsArray<String>

A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT rule only. This field is used for public NAT. Corresponds to the JSON property sourceNatDrainIps

Returns:

  • (Array<String>)


52779
52780
52781
# File 'lib/google/apis/compute_v1/classes.rb', line 52779

def source_nat_drain_ips
  @source_nat_drain_ips
end

#source_nat_drain_rangesArray<String>

A list of URLs of subnetworks representing source ranges to be drained. This is only supported on patch/update, and these subnetworks must have previously been used as active ranges in this NAT Rule. This field is used for private NAT. Corresponds to the JSON property sourceNatDrainRanges

Returns:

  • (Array<String>)


52788
52789
52790
# File 'lib/google/apis/compute_v1/classes.rb', line 52788

def source_nat_drain_ranges
  @source_nat_drain_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52795
52796
52797
52798
52799
52800
# File 'lib/google/apis/compute_v1/classes.rb', line 52795

def update!(**args)
  @source_nat_active_ips = args[:source_nat_active_ips] if args.key?(:source_nat_active_ips)
  @source_nat_active_ranges = args[:source_nat_active_ranges] if args.key?(:source_nat_active_ranges)
  @source_nat_drain_ips = args[:source_nat_drain_ips] if args.key?(:source_nat_drain_ips)
  @source_nat_drain_ranges = args[:source_nat_drain_ranges] if args.key?(:source_nat_drain_ranges)
end