Class: Google::Apis::ComputeV1::RouterStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatus

Returns a new instance of RouterStatus.



54186
54187
54188
# File 'lib/google/apis/compute_v1/classes.rb', line 54186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#best_routesArray<Google::Apis::ComputeV1::Route>

A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router. Lists all of the best routes per prefix that are programmed into this region's VPC data plane. When global dynamic routing mode is turned on in the VPC network, this list can include cross-region dynamic routes from Cloud Routers in other regions. Corresponds to the JSON property bestRoutes

Returns:



54156
54157
54158
# File 'lib/google/apis/compute_v1/classes.rb', line 54156

def best_routes
  @best_routes
end

#best_routes_for_routerArray<Google::Apis::ComputeV1::Route>

A list of the best BGP routes learned by this Cloud Router. It is possible that routes listed might not be programmed into the data plane, if the Google Cloud control plane finds a more optimal route for a prefix than a route learned by this Cloud Router. Corresponds to the JSON property bestRoutesForRouter

Returns:



54164
54165
54166
# File 'lib/google/apis/compute_v1/classes.rb', line 54164

def best_routes_for_router
  @best_routes_for_router
end

#bgp_peer_statusArray<Google::Apis::ComputeV1::RouterStatusBgpPeerStatus>

Corresponds to the JSON property bgpPeerStatus



54169
54170
54171
# File 'lib/google/apis/compute_v1/classes.rb', line 54169

def bgp_peer_status
  @bgp_peer_status
end

#nat_statusArray<Google::Apis::ComputeV1::RouterStatusNatStatus>

Corresponds to the JSON property natStatus



54174
54175
54176
# File 'lib/google/apis/compute_v1/classes.rb', line 54174

def nat_status
  @nat_status
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


54179
54180
54181
# File 'lib/google/apis/compute_v1/classes.rb', line 54179

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


54184
54185
54186
# File 'lib/google/apis/compute_v1/classes.rb', line 54184

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54191
54192
54193
54194
54195
54196
54197
54198
# File 'lib/google/apis/compute_v1/classes.rb', line 54191

def update!(**args)
  @best_routes = args[:best_routes] if args.key?(:best_routes)
  @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router)
  @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status)
  @nat_status = args[:nat_status] if args.key?(:nat_status)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
end