Class: Google::Apis::ComputeV1::RouterStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#best_routes ⇒ Array<Google::Apis::ComputeV1::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
-
#best_routes_for_router ⇒ Array<Google::Apis::ComputeV1::Route>
A list of the best BGP routes learned by this Cloud Router.
-
#bgp_peer_status ⇒ Array<Google::Apis::ComputeV1::RouterStatusBgpPeerStatus>
Corresponds to the JSON property
bgpPeerStatus. -
#nat_status ⇒ Array<Google::Apis::ComputeV1::RouterStatusNatStatus>
Corresponds to the JSON property
natStatus. -
#network ⇒ String
URI of the network to which this router belongs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterStatus
constructor
A new instance of RouterStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterStatus
Returns a new instance of RouterStatus.
52929 52930 52931 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#best_routes ⇒ Array<Google::Apis::ComputeV1::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private
Cloud (VPC) network in the same region as this Cloud Router.
Lists all of the best routes per prefix that are programmed into this
region's VPC data plane.
When global dynamic routing mode is turned on in the VPC network, this list
can include cross-region dynamic routes from Cloud Routers in other
regions.
Corresponds to the JSON property bestRoutes
52904 52905 52906 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52904 def best_routes @best_routes end |
#best_routes_for_router ⇒ Array<Google::Apis::ComputeV1::Route>
A list of the best BGP routes learned by this Cloud Router.
It is possible that routes listed might not be programmed into the data
plane, if the Google Cloud control plane finds a more optimal route for a
prefix than a route learned by this Cloud Router.
Corresponds to the JSON property bestRoutesForRouter
52912 52913 52914 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52912 def best_routes_for_router @best_routes_for_router end |
#bgp_peer_status ⇒ Array<Google::Apis::ComputeV1::RouterStatusBgpPeerStatus>
Corresponds to the JSON property bgpPeerStatus
52917 52918 52919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52917 def bgp_peer_status @bgp_peer_status end |
#nat_status ⇒ Array<Google::Apis::ComputeV1::RouterStatusNatStatus>
Corresponds to the JSON property natStatus
52922 52923 52924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52922 def nat_status @nat_status end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
52927 52928 52929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52927 def network @network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52934 52935 52936 52937 52938 52939 52940 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52934 def update!(**args) @best_routes = args[:best_routes] if args.key?(:best_routes) @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router) @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status) @nat_status = args[:nat_status] if args.key?(:nat_status) @network = args[:network] if args.key?(:network) end |