Class: Google::Apis::ComputeV1::RouterStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#best_routes ⇒ Array<Google::Apis::ComputeV1::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
-
#best_routes_for_router ⇒ Array<Google::Apis::ComputeV1::Route>
A list of the best BGP routes learned by this Cloud Router.
-
#bgp_peer_status ⇒ Array<Google::Apis::ComputeV1::RouterStatusBgpPeerStatus>
Corresponds to the JSON property
bgpPeerStatus. -
#nat_status ⇒ Array<Google::Apis::ComputeV1::RouterStatusNatStatus>
Corresponds to the JSON property
natStatus. -
#network ⇒ String
URI of the network to which this router belongs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterStatus
constructor
A new instance of RouterStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterStatus
Returns a new instance of RouterStatus.
46776 46777 46778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46776 def initialize(**args) update!(**args) end |
Instance Attribute Details
#best_routes ⇒ Array<Google::Apis::ComputeV1::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private
Cloud (VPC) network in the same region as this Cloud Router.
Lists all of the best routes per prefix that are programmed into this
region's VPC data plane.
When global dynamic routing mode is turned on in the VPC network, this list
can include cross-region dynamic routes from Cloud Routers in other
regions.
Corresponds to the JSON property bestRoutes
46751 46752 46753 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46751 def best_routes @best_routes end |
#best_routes_for_router ⇒ Array<Google::Apis::ComputeV1::Route>
A list of the best BGP routes learned by this Cloud Router.
It is possible that routes listed might not be programmed into the data
plane, if the Google Cloud control plane finds a more optimal route for a
prefix than a route learned by this Cloud Router.
Corresponds to the JSON property bestRoutesForRouter
46759 46760 46761 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46759 def best_routes_for_router @best_routes_for_router end |
#bgp_peer_status ⇒ Array<Google::Apis::ComputeV1::RouterStatusBgpPeerStatus>
Corresponds to the JSON property bgpPeerStatus
46764 46765 46766 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46764 def bgp_peer_status @bgp_peer_status end |
#nat_status ⇒ Array<Google::Apis::ComputeV1::RouterStatusNatStatus>
Corresponds to the JSON property natStatus
46769 46770 46771 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46769 def nat_status @nat_status end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
46774 46775 46776 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46774 def network @network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46781 46782 46783 46784 46785 46786 46787 |
# File 'lib/google/apis/compute_v1/classes.rb', line 46781 def update!(**args) @best_routes = args[:best_routes] if args.key?(:best_routes) @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router) @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status) @nat_status = args[:nat_status] if args.key?(:nat_status) @network = args[:network] if args.key?(:network) end |