Class: Google::Apis::ComputeV1::RouterStatusBgpPeerStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterStatusBgpPeerStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#advertised_routes ⇒ Array<Google::Apis::ComputeV1::Route>
Routes that were advertised to the remote BGP peer Corresponds to the JSON property
advertisedRoutes. -
#bfd_status ⇒ Google::Apis::ComputeV1::BfdStatus
Next free: 15 Corresponds to the JSON property
bfdStatus. -
#enable_ipv4 ⇒ Boolean
(also: #enable_ipv4?)
Output only.
-
#enable_ipv6 ⇒ Boolean
(also: #enable_ipv6?)
Output only.
-
#ip_address ⇒ String
Output only.
-
#ipv4_nexthop_address ⇒ String
Output only.
-
#ipv6_nexthop_address ⇒ String
Output only.
-
#linked_vpn_tunnel ⇒ String
Output only.
-
#md5_auth_enabled ⇒ Boolean
(also: #md5_auth_enabled?)
Informs whether MD5 authentication is enabled on this BGP peer.
-
#name ⇒ String
Output only.
-
#num_learned_routes ⇒ Fixnum
Output only.
-
#peer_ip_address ⇒ String
Output only.
-
#peer_ipv4_nexthop_address ⇒ String
Output only.
-
#peer_ipv6_nexthop_address ⇒ String
Output only.
-
#router_appliance_instance ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_reason ⇒ String
Indicates why particular status was returned.
-
#uptime ⇒ String
Output only.
-
#uptime_seconds ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterStatusBgpPeerStatus
constructor
A new instance of RouterStatusBgpPeerStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterStatusBgpPeerStatus
Returns a new instance of RouterStatusBgpPeerStatus.
54320 54321 54322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_routes ⇒ Array<Google::Apis::ComputeV1::Route>
Routes that were advertised to the remote BGP peer
Corresponds to the JSON property advertisedRoutes
54208 54209 54210 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54208 def advertised_routes @advertised_routes end |
#bfd_status ⇒ Google::Apis::ComputeV1::BfdStatus
Next free: 15
Corresponds to the JSON property bfdStatus
54213 54214 54215 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54213 def bfd_status @bfd_status end |
#enable_ipv4 ⇒ Boolean Also known as: enable_ipv4?
Output only. Enable IPv4 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 4.
Corresponds to the JSON property enableIpv4
54219 54220 54221 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54219 def enable_ipv4 @enable_ipv4 end |
#enable_ipv6 ⇒ Boolean Also known as: enable_ipv6?
Output only. Enable IPv6 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 6.
Corresponds to the JSON property enableIpv6
54226 54227 54228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54226 def enable_ipv6 @enable_ipv6 end |
#ip_address ⇒ String
Output only. IP address of the local BGP interface.
Corresponds to the JSON property ipAddress
54232 54233 54234 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54232 def ip_address @ip_address end |
#ipv4_nexthop_address ⇒ String
Output only. IPv4 address of the local BGP interface.
Corresponds to the JSON property ipv4NexthopAddress
54237 54238 54239 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54237 def ipv4_nexthop_address @ipv4_nexthop_address end |
#ipv6_nexthop_address ⇒ String
Output only. IPv6 address of the local BGP interface.
Corresponds to the JSON property ipv6NexthopAddress
54242 54243 54244 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54242 def ipv6_nexthop_address @ipv6_nexthop_address end |
#linked_vpn_tunnel ⇒ String
Output only. URL of the VPN tunnel that this BGP peer controls.
Corresponds to the JSON property linkedVpnTunnel
54247 54248 54249 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54247 def linked_vpn_tunnel @linked_vpn_tunnel end |
#md5_auth_enabled ⇒ Boolean Also known as: md5_auth_enabled?
Informs whether MD5 authentication is enabled on this BGP peer.
Corresponds to the JSON property md5AuthEnabled
54252 54253 54254 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54252 def md5_auth_enabled @md5_auth_enabled end |
#name ⇒ String
Output only. Name of this BGP peer. Unique within the Routers resource.
Corresponds to the JSON property name
54258 54259 54260 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54258 def name @name end |
#num_learned_routes ⇒ Fixnum
Output only. Number of routes learned from the remote BGP Peer.
Corresponds to the JSON property numLearnedRoutes
54263 54264 54265 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54263 def num_learned_routes @num_learned_routes end |
#peer_ip_address ⇒ String
Output only. IP address of the remote BGP interface.
Corresponds to the JSON property peerIpAddress
54268 54269 54270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54268 def peer_ip_address @peer_ip_address end |
#peer_ipv4_nexthop_address ⇒ String
Output only. IPv4 address of the remote BGP interface.
Corresponds to the JSON property peerIpv4NexthopAddress
54273 54274 54275 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54273 def peer_ipv4_nexthop_address @peer_ipv4_nexthop_address end |
#peer_ipv6_nexthop_address ⇒ String
Output only. IPv6 address of the remote BGP interface.
Corresponds to the JSON property peerIpv6NexthopAddress
54278 54279 54280 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54278 def peer_ipv6_nexthop_address @peer_ipv6_nexthop_address end |
#router_appliance_instance ⇒ String
Output only. [Output only] URI of the VM instance that is used as third-party
router
appliances such as Next Gen Firewalls, Virtual Routers, or Router
Appliances.
The VM instance is the peer side of the BGP session.
Corresponds to the JSON property routerApplianceInstance
54287 54288 54289 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54287 def router_appliance_instance @router_appliance_instance end |
#state ⇒ String
Output only. The state of the BGP session. For a list of possible values for
this
field, seeBGP session states.
Corresponds to the JSON property state
54294 54295 54296 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54294 def state @state end |
#status ⇒ String
Output only. Status of the BGP peer: UP, DOWN
Corresponds to the JSON property status
54299 54300 54301 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54299 def status @status end |
#status_reason ⇒ String
Indicates why particular status was returned.
Corresponds to the JSON property statusReason
54304 54305 54306 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54304 def status_reason @status_reason end |
#uptime ⇒ String
Output only. Time this session has been up.
Format:
14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds
Corresponds to the JSON property uptime
54311 54312 54313 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54311 def uptime @uptime end |
#uptime_seconds ⇒ String
Output only. Time this session has been up, in seconds.
Format:
145
Corresponds to the JSON property uptimeSeconds
54318 54319 54320 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54318 def uptime_seconds @uptime_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54325 54326 54327 54328 54329 54330 54331 54332 54333 54334 54335 54336 54337 54338 54339 54340 54341 54342 54343 54344 54345 54346 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54325 def update!(**args) @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes) @bfd_status = args[:bfd_status] if args.key?(:bfd_status) @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4) @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address) @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address) @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel) @md5_auth_enabled = args[:md5_auth_enabled] if args.key?(:md5_auth_enabled) @name = args[:name] if args.key?(:name) @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes) @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address) @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address) @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address) @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @status_reason = args[:status_reason] if args.key?(:status_reason) @uptime = args[:uptime] if args.key?(:uptime) @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds) end |