Class: Google::Apis::ComputeV1::RouterStatusBgpPeerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatusBgpPeerStatus

Returns a new instance of RouterStatusBgpPeerStatus.



53578
53579
53580
# File 'lib/google/apis/compute_v1/classes.rb', line 53578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertised_routesArray<Google::Apis::ComputeV1::Route>

Routes that were advertised to the remote BGP peer Corresponds to the JSON property advertisedRoutes

Returns:



53466
53467
53468
# File 'lib/google/apis/compute_v1/classes.rb', line 53466

def advertised_routes
  @advertised_routes
end

#bfd_statusGoogle::Apis::ComputeV1::BfdStatus

Next free: 15 Corresponds to the JSON property bfdStatus



53471
53472
53473
# File 'lib/google/apis/compute_v1/classes.rb', line 53471

def bfd_status
  @bfd_status
end

#enable_ipv4Boolean Also known as: enable_ipv4?

Output only. Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4. Corresponds to the JSON property enableIpv4

Returns:

  • (Boolean)


53477
53478
53479
# File 'lib/google/apis/compute_v1/classes.rb', line 53477

def enable_ipv4
  @enable_ipv4
end

#enable_ipv6Boolean Also known as: enable_ipv6?

Output only. Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6. Corresponds to the JSON property enableIpv6

Returns:

  • (Boolean)


53484
53485
53486
# File 'lib/google/apis/compute_v1/classes.rb', line 53484

def enable_ipv6
  @enable_ipv6
end

#ip_addressString

Output only. IP address of the local BGP interface. Corresponds to the JSON property ipAddress

Returns:

  • (String)


53490
53491
53492
# File 'lib/google/apis/compute_v1/classes.rb', line 53490

def ip_address
  @ip_address
end

#ipv4_nexthop_addressString

Output only. IPv4 address of the local BGP interface. Corresponds to the JSON property ipv4NexthopAddress

Returns:

  • (String)


53495
53496
53497
# File 'lib/google/apis/compute_v1/classes.rb', line 53495

def ipv4_nexthop_address
  @ipv4_nexthop_address
end

#ipv6_nexthop_addressString

Output only. IPv6 address of the local BGP interface. Corresponds to the JSON property ipv6NexthopAddress

Returns:

  • (String)


53500
53501
53502
# File 'lib/google/apis/compute_v1/classes.rb', line 53500

def ipv6_nexthop_address
  @ipv6_nexthop_address
end

#linked_vpn_tunnelString

Output only. URL of the VPN tunnel that this BGP peer controls. Corresponds to the JSON property linkedVpnTunnel

Returns:

  • (String)


53505
53506
53507
# File 'lib/google/apis/compute_v1/classes.rb', line 53505

def linked_vpn_tunnel
  @linked_vpn_tunnel
end

#md5_auth_enabledBoolean Also known as: md5_auth_enabled?

Informs whether MD5 authentication is enabled on this BGP peer. Corresponds to the JSON property md5AuthEnabled

Returns:

  • (Boolean)


53510
53511
53512
# File 'lib/google/apis/compute_v1/classes.rb', line 53510

def md5_auth_enabled
  @md5_auth_enabled
end

#nameString

Output only. Name of this BGP peer. Unique within the Routers resource. Corresponds to the JSON property name

Returns:

  • (String)


53516
53517
53518
# File 'lib/google/apis/compute_v1/classes.rb', line 53516

def name
  @name
end

#num_learned_routesFixnum

Output only. Number of routes learned from the remote BGP Peer. Corresponds to the JSON property numLearnedRoutes

Returns:

  • (Fixnum)


53521
53522
53523
# File 'lib/google/apis/compute_v1/classes.rb', line 53521

def num_learned_routes
  @num_learned_routes
end

#peer_ip_addressString

Output only. IP address of the remote BGP interface. Corresponds to the JSON property peerIpAddress

Returns:

  • (String)


53526
53527
53528
# File 'lib/google/apis/compute_v1/classes.rb', line 53526

def peer_ip_address
  @peer_ip_address
end

#peer_ipv4_nexthop_addressString

Output only. IPv4 address of the remote BGP interface. Corresponds to the JSON property peerIpv4NexthopAddress

Returns:

  • (String)


53531
53532
53533
# File 'lib/google/apis/compute_v1/classes.rb', line 53531

def peer_ipv4_nexthop_address
  @peer_ipv4_nexthop_address
end

#peer_ipv6_nexthop_addressString

Output only. IPv6 address of the remote BGP interface. Corresponds to the JSON property peerIpv6NexthopAddress

Returns:

  • (String)


53536
53537
53538
# File 'lib/google/apis/compute_v1/classes.rb', line 53536

def peer_ipv6_nexthop_address
  @peer_ipv6_nexthop_address
end

#router_appliance_instanceString

Output only. [Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session. Corresponds to the JSON property routerApplianceInstance

Returns:

  • (String)


53545
53546
53547
# File 'lib/google/apis/compute_v1/classes.rb', line 53545

def router_appliance_instance
  @router_appliance_instance
end

#stateString

Output only. The state of the BGP session. For a list of possible values for this field, seeBGP session states. Corresponds to the JSON property state

Returns:

  • (String)


53552
53553
53554
# File 'lib/google/apis/compute_v1/classes.rb', line 53552

def state
  @state
end

#statusString

Output only. Status of the BGP peer: UP, DOWN Corresponds to the JSON property status

Returns:

  • (String)


53557
53558
53559
# File 'lib/google/apis/compute_v1/classes.rb', line 53557

def status
  @status
end

#status_reasonString

Indicates why particular status was returned. Corresponds to the JSON property statusReason

Returns:

  • (String)


53562
53563
53564
# File 'lib/google/apis/compute_v1/classes.rb', line 53562

def status_reason
  @status_reason
end

#uptimeString

Output only. Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds Corresponds to the JSON property uptime

Returns:

  • (String)


53569
53570
53571
# File 'lib/google/apis/compute_v1/classes.rb', line 53569

def uptime
  @uptime
end

#uptime_secondsString

Output only. Time this session has been up, in seconds. Format: 145 Corresponds to the JSON property uptimeSeconds

Returns:

  • (String)


53576
53577
53578
# File 'lib/google/apis/compute_v1/classes.rb', line 53576

def uptime_seconds
  @uptime_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53583
53584
53585
53586
53587
53588
53589
53590
53591
53592
53593
53594
53595
53596
53597
53598
53599
53600
53601
53602
53603
53604
# File 'lib/google/apis/compute_v1/classes.rb', line 53583

def update!(**args)
  @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes)
  @bfd_status = args[:bfd_status] if args.key?(:bfd_status)
  @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4)
  @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address)
  @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address)
  @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel)
  @md5_auth_enabled = args[:md5_auth_enabled] if args.key?(:md5_auth_enabled)
  @name = args[:name] if args.key?(:name)
  @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes)
  @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address)
  @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address)
  @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address)
  @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @status_reason = args[:status_reason] if args.key?(:status_reason)
  @uptime = args[:uptime] if args.key?(:uptime)
  @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds)
end