Class: Google::Apis::ComputeV1::RouterStatusBgpPeerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatusBgpPeerStatus

Returns a new instance of RouterStatusBgpPeerStatus.



53401
53402
53403
# File 'lib/google/apis/compute_v1/classes.rb', line 53401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertised_routesArray<Google::Apis::ComputeV1::Route>

Routes that were advertised to the remote BGP peer Corresponds to the JSON property advertisedRoutes

Returns:



53289
53290
53291
# File 'lib/google/apis/compute_v1/classes.rb', line 53289

def advertised_routes
  @advertised_routes
end

#bfd_statusGoogle::Apis::ComputeV1::BfdStatus

Next free: 15 Corresponds to the JSON property bfdStatus



53294
53295
53296
# File 'lib/google/apis/compute_v1/classes.rb', line 53294

def bfd_status
  @bfd_status
end

#enable_ipv4Boolean Also known as: enable_ipv4?

Output only. Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4. Corresponds to the JSON property enableIpv4

Returns:

  • (Boolean)


53300
53301
53302
# File 'lib/google/apis/compute_v1/classes.rb', line 53300

def enable_ipv4
  @enable_ipv4
end

#enable_ipv6Boolean Also known as: enable_ipv6?

Output only. Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6. Corresponds to the JSON property enableIpv6

Returns:

  • (Boolean)


53307
53308
53309
# File 'lib/google/apis/compute_v1/classes.rb', line 53307

def enable_ipv6
  @enable_ipv6
end

#ip_addressString

Output only. IP address of the local BGP interface. Corresponds to the JSON property ipAddress

Returns:

  • (String)


53313
53314
53315
# File 'lib/google/apis/compute_v1/classes.rb', line 53313

def ip_address
  @ip_address
end

#ipv4_nexthop_addressString

Output only. IPv4 address of the local BGP interface. Corresponds to the JSON property ipv4NexthopAddress

Returns:

  • (String)


53318
53319
53320
# File 'lib/google/apis/compute_v1/classes.rb', line 53318

def ipv4_nexthop_address
  @ipv4_nexthop_address
end

#ipv6_nexthop_addressString

Output only. IPv6 address of the local BGP interface. Corresponds to the JSON property ipv6NexthopAddress

Returns:

  • (String)


53323
53324
53325
# File 'lib/google/apis/compute_v1/classes.rb', line 53323

def ipv6_nexthop_address
  @ipv6_nexthop_address
end

#linked_vpn_tunnelString

Output only. URL of the VPN tunnel that this BGP peer controls. Corresponds to the JSON property linkedVpnTunnel

Returns:

  • (String)


53328
53329
53330
# File 'lib/google/apis/compute_v1/classes.rb', line 53328

def linked_vpn_tunnel
  @linked_vpn_tunnel
end

#md5_auth_enabledBoolean Also known as: md5_auth_enabled?

Informs whether MD5 authentication is enabled on this BGP peer. Corresponds to the JSON property md5AuthEnabled

Returns:

  • (Boolean)


53333
53334
53335
# File 'lib/google/apis/compute_v1/classes.rb', line 53333

def md5_auth_enabled
  @md5_auth_enabled
end

#nameString

Output only. Name of this BGP peer. Unique within the Routers resource. Corresponds to the JSON property name

Returns:

  • (String)


53339
53340
53341
# File 'lib/google/apis/compute_v1/classes.rb', line 53339

def name
  @name
end

#num_learned_routesFixnum

Output only. Number of routes learned from the remote BGP Peer. Corresponds to the JSON property numLearnedRoutes

Returns:

  • (Fixnum)


53344
53345
53346
# File 'lib/google/apis/compute_v1/classes.rb', line 53344

def num_learned_routes
  @num_learned_routes
end

#peer_ip_addressString

Output only. IP address of the remote BGP interface. Corresponds to the JSON property peerIpAddress

Returns:

  • (String)


53349
53350
53351
# File 'lib/google/apis/compute_v1/classes.rb', line 53349

def peer_ip_address
  @peer_ip_address
end

#peer_ipv4_nexthop_addressString

Output only. IPv4 address of the remote BGP interface. Corresponds to the JSON property peerIpv4NexthopAddress

Returns:

  • (String)


53354
53355
53356
# File 'lib/google/apis/compute_v1/classes.rb', line 53354

def peer_ipv4_nexthop_address
  @peer_ipv4_nexthop_address
end

#peer_ipv6_nexthop_addressString

Output only. IPv6 address of the remote BGP interface. Corresponds to the JSON property peerIpv6NexthopAddress

Returns:

  • (String)


53359
53360
53361
# File 'lib/google/apis/compute_v1/classes.rb', line 53359

def peer_ipv6_nexthop_address
  @peer_ipv6_nexthop_address
end

#router_appliance_instanceString

Output only. [Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session. Corresponds to the JSON property routerApplianceInstance

Returns:

  • (String)


53368
53369
53370
# File 'lib/google/apis/compute_v1/classes.rb', line 53368

def router_appliance_instance
  @router_appliance_instance
end

#stateString

Output only. The state of the BGP session. For a list of possible values for this field, seeBGP session states. Corresponds to the JSON property state

Returns:

  • (String)


53375
53376
53377
# File 'lib/google/apis/compute_v1/classes.rb', line 53375

def state
  @state
end

#statusString

Output only. Status of the BGP peer: UP, DOWN Corresponds to the JSON property status

Returns:

  • (String)


53380
53381
53382
# File 'lib/google/apis/compute_v1/classes.rb', line 53380

def status
  @status
end

#status_reasonString

Indicates why particular status was returned. Corresponds to the JSON property statusReason

Returns:

  • (String)


53385
53386
53387
# File 'lib/google/apis/compute_v1/classes.rb', line 53385

def status_reason
  @status_reason
end

#uptimeString

Output only. Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds Corresponds to the JSON property uptime

Returns:

  • (String)


53392
53393
53394
# File 'lib/google/apis/compute_v1/classes.rb', line 53392

def uptime
  @uptime
end

#uptime_secondsString

Output only. Time this session has been up, in seconds. Format: 145 Corresponds to the JSON property uptimeSeconds

Returns:

  • (String)


53399
53400
53401
# File 'lib/google/apis/compute_v1/classes.rb', line 53399

def uptime_seconds
  @uptime_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53406
53407
53408
53409
53410
53411
53412
53413
53414
53415
53416
53417
53418
53419
53420
53421
53422
53423
53424
53425
53426
53427
# File 'lib/google/apis/compute_v1/classes.rb', line 53406

def update!(**args)
  @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes)
  @bfd_status = args[:bfd_status] if args.key?(:bfd_status)
  @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4)
  @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address)
  @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address)
  @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel)
  @md5_auth_enabled = args[:md5_auth_enabled] if args.key?(:md5_auth_enabled)
  @name = args[:name] if args.key?(:name)
  @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes)
  @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address)
  @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address)
  @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address)
  @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @status_reason = args[:status_reason] if args.key?(:status_reason)
  @uptime = args[:uptime] if args.key?(:uptime)
  @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds)
end