Class: Google::Apis::ComputeV1::RouterStatusBgpPeerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatusBgpPeerStatus

Returns a new instance of RouterStatusBgpPeerStatus.



29901
29902
29903
# File 'lib/google/apis/compute_v1/classes.rb', line 29901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertised_routesArray<Google::Apis::ComputeV1::Route>

Routes that were advertised to the remote BGP peer Corresponds to the JSON property advertisedRoutes

Returns:



29840
29841
29842
# File 'lib/google/apis/compute_v1/classes.rb', line 29840

def advertised_routes
  @advertised_routes
end

#bfd_statusGoogle::Apis::ComputeV1::BfdStatus

Next free: 15 Corresponds to the JSON property bfdStatus



29845
29846
29847
# File 'lib/google/apis/compute_v1/classes.rb', line 29845

def bfd_status
  @bfd_status
end

#ip_addressString

IP address of the local BGP interface. Corresponds to the JSON property ipAddress

Returns:

  • (String)


29850
29851
29852
# File 'lib/google/apis/compute_v1/classes.rb', line 29850

def ip_address
  @ip_address
end

#linked_vpn_tunnelString

URL of the VPN tunnel that this BGP peer controls. Corresponds to the JSON property linkedVpnTunnel

Returns:

  • (String)


29855
29856
29857
# File 'lib/google/apis/compute_v1/classes.rb', line 29855

def linked_vpn_tunnel
  @linked_vpn_tunnel
end

#nameString

Name of this BGP peer. Unique within the Routers resource. Corresponds to the JSON property name

Returns:

  • (String)


29860
29861
29862
# File 'lib/google/apis/compute_v1/classes.rb', line 29860

def name
  @name
end

#num_learned_routesFixnum

Number of routes learned from the remote BGP Peer. Corresponds to the JSON property numLearnedRoutes

Returns:

  • (Fixnum)


29865
29866
29867
# File 'lib/google/apis/compute_v1/classes.rb', line 29865

def num_learned_routes
  @num_learned_routes
end

#peer_ip_addressString

IP address of the remote BGP interface. Corresponds to the JSON property peerIpAddress

Returns:

  • (String)


29870
29871
29872
# File 'lib/google/apis/compute_v1/classes.rb', line 29870

def peer_ip_address
  @peer_ip_address
end

#router_appliance_instanceString

[Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session. Corresponds to the JSON property routerApplianceInstance

Returns:

  • (String)


29877
29878
29879
# File 'lib/google/apis/compute_v1/classes.rb', line 29877

def router_appliance_instance
  @router_appliance_instance
end

#stateString

The state of the BGP session. For a list of possible values for this field, see BGP session states. Corresponds to the JSON property state

Returns:

  • (String)


29883
29884
29885
# File 'lib/google/apis/compute_v1/classes.rb', line 29883

def state
  @state
end

#statusString

Status of the BGP peer: UP, DOWN Corresponds to the JSON property status

Returns:

  • (String)


29888
29889
29890
# File 'lib/google/apis/compute_v1/classes.rb', line 29888

def status
  @status
end

#uptimeString

Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds Corresponds to the JSON property uptime

Returns:

  • (String)


29894
29895
29896
# File 'lib/google/apis/compute_v1/classes.rb', line 29894

def uptime
  @uptime
end

#uptime_secondsString

Time this session has been up, in seconds. Format: 145 Corresponds to the JSON property uptimeSeconds

Returns:

  • (String)


29899
29900
29901
# File 'lib/google/apis/compute_v1/classes.rb', line 29899

def uptime_seconds
  @uptime_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29906
29907
29908
29909
29910
29911
29912
29913
29914
29915
29916
29917
29918
29919
# File 'lib/google/apis/compute_v1/classes.rb', line 29906

def update!(**args)
  @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes)
  @bfd_status = args[:bfd_status] if args.key?(:bfd_status)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel)
  @name = args[:name] if args.key?(:name)
  @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes)
  @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address)
  @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @uptime = args[:uptime] if args.key?(:uptime)
  @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds)
end