Class: Google::Apis::ComputeV1::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
54640 54641 54642 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54640 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
54596 54597 54598 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54596 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
54602 54603 54604 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54602 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
54608 54609 54610 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54608 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54618 54619 54620 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54618 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
54623 54624 54625 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54623 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54628 54629 54630 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54628 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
54633 54634 54635 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54633 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54638 54639 54640 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54638 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54645 54646 54647 54648 54649 54650 54651 54652 54653 54654 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54645 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |