Class: Google::Apis::ComputeV1::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



54594
54595
54596
# File 'lib/google/apis/compute_v1/classes.rb', line 54594

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54550
54551
54552
# File 'lib/google/apis/compute_v1/classes.rb', line 54550

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54556
54557
54558
# File 'lib/google/apis/compute_v1/classes.rb', line 54556

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


54562
54563
54564
# File 'lib/google/apis/compute_v1/classes.rb', line 54562

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54572
54573
54574
# File 'lib/google/apis/compute_v1/classes.rb', line 54572

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



54577
54578
54579
# File 'lib/google/apis/compute_v1/classes.rb', line 54577

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54582
54583
54584
# File 'lib/google/apis/compute_v1/classes.rb', line 54582

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54587
54588
54589
# File 'lib/google/apis/compute_v1/classes.rb', line 54587

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54592
54593
54594
# File 'lib/google/apis/compute_v1/classes.rb', line 54592

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54599
54600
54601
54602
54603
54604
54605
54606
54607
54608
# File 'lib/google/apis/compute_v1/classes.rb', line 54599

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end