Class: Google::Apis::ComputeV1::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



53852
53853
53854
# File 'lib/google/apis/compute_v1/classes.rb', line 53852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53808
53809
53810
# File 'lib/google/apis/compute_v1/classes.rb', line 53808

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53814
53815
53816
# File 'lib/google/apis/compute_v1/classes.rb', line 53814

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


53820
53821
53822
# File 'lib/google/apis/compute_v1/classes.rb', line 53820

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53830
53831
53832
# File 'lib/google/apis/compute_v1/classes.rb', line 53830

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



53835
53836
53837
# File 'lib/google/apis/compute_v1/classes.rb', line 53835

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53840
53841
53842
# File 'lib/google/apis/compute_v1/classes.rb', line 53840

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53845
53846
53847
# File 'lib/google/apis/compute_v1/classes.rb', line 53845

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53850
53851
53852
# File 'lib/google/apis/compute_v1/classes.rb', line 53850

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53857
53858
53859
53860
53861
53862
53863
53864
53865
53866
# File 'lib/google/apis/compute_v1/classes.rb', line 53857

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end