Class: Google::Apis::ComputeV1::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
53650 53651 53652 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
53606 53607 53608 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53606 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
53612 53613 53614 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53612 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
53618 53619 53620 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53618 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53628 53629 53630 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53628 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
53633 53634 53635 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53633 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53638 53639 53640 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53638 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
53643 53644 53645 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53643 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
53648 53649 53650 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53648 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53655 53656 53657 53658 53659 53660 53661 53662 53663 53664 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53655 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |