Class: Google::Apis::ComputeV1::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



53641
53642
53643
# File 'lib/google/apis/compute_v1/classes.rb', line 53641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53597
53598
53599
# File 'lib/google/apis/compute_v1/classes.rb', line 53597

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53603
53604
53605
# File 'lib/google/apis/compute_v1/classes.rb', line 53603

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


53609
53610
53611
# File 'lib/google/apis/compute_v1/classes.rb', line 53609

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53619
53620
53621
# File 'lib/google/apis/compute_v1/classes.rb', line 53619

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



53624
53625
53626
# File 'lib/google/apis/compute_v1/classes.rb', line 53624

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53629
53630
53631
# File 'lib/google/apis/compute_v1/classes.rb', line 53629

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53634
53635
53636
# File 'lib/google/apis/compute_v1/classes.rb', line 53634

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53639
53640
53641
# File 'lib/google/apis/compute_v1/classes.rb', line 53639

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53646
53647
53648
53649
53650
53651
53652
53653
53654
53655
# File 'lib/google/apis/compute_v1/classes.rb', line 53646

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end