Class: Google::Apis::ComputeV1::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
51802 51803 51804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51802 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
51758 51759 51760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51758 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
51764 51765 51766 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51764 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
51770 51771 51772 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51770 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51780 51781 51782 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51780 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
51785 51786 51787 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51785 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51790 51791 51792 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51790 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
51795 51796 51797 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51795 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51800 51801 51802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51800 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51807 51808 51809 51810 51811 51812 51813 51814 51815 51816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51807 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |