Class: Google::Apis::ComputeV1::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
48345 48346 48347 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48345 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
48301 48302 48303 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48301 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
48307 48308 48309 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48307 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
48313 48314 48315 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48313 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48323 48324 48325 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48323 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
48328 48329 48330 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48328 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48333 48334 48335 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48333 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
48338 48339 48340 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48338 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
48343 48344 48345 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48343 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48350 48351 48352 48353 48354 48355 48356 48357 48358 48359 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48350 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |