Class: Google::Apis::ComputeV1::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
54778 54779 54780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
54734 54735 54736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54734 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
54740 54741 54742 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54740 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
54746 54747 54748 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54746 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54756 54757 54758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54756 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
54761 54762 54763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54761 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54766 54767 54768 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54766 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
54771 54772 54773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54771 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54776 54777 54778 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54776 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54783 54784 54785 54786 54787 54788 54789 54790 54791 54792 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54783 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |