Class: Google::Apis::ComputeV1::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
54732 54733 54734 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
54688 54689 54690 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54688 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
54694 54695 54696 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54694 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
54700 54701 54702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54700 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54710 54711 54712 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54710 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
54715 54716 54717 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54715 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54720 54721 54722 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54720 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
54725 54726 54727 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54725 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54730 54731 54732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54730 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54737 54738 54739 54740 54741 54742 54743 54744 54745 54746 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54737 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |