Class: Google::Apis::ComputeV1::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
53978 53979 53980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
53934 53935 53936 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53934 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
53940 53941 53942 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53940 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
53946 53947 53948 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53946 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53956 53957 53958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53956 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
53961 53962 53963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53961 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53966 53967 53968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53966 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
53971 53972 53973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53971 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
53976 53977 53978 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53976 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53983 53984 53985 53986 53987 53988 53989 53990 53991 53992 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53983 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |