Class: Google::Apis::ComputeV1::RoutersListRoutePolicies
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutersListRoutePolicies
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::RoutePolicy>
[Output Only] A list of route policies.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListRoutePolicies
constructor
A new instance of RoutersListRoutePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListRoutePolicies
Returns a new instance of RoutersListRoutePolicies.
54916 54917 54918 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
54872 54873 54874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54872 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
54878 54879 54880 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54878 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListRoutePolicies for lists of route policies.
Corresponds to the JSON property kind
54884 54885 54886 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54884 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54894 54895 54896 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54894 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::RoutePolicy>
[Output Only] A list of route policies.
Corresponds to the JSON property result
54899 54900 54901 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54899 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54904 54905 54906 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54904 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
54909 54910 54911 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54909 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54914 54915 54916 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54914 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54921 54922 54923 54924 54925 54926 54927 54928 54929 54930 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54921 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |