Class: Google::Apis::ComputeV1::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



54128
54129
54130
# File 'lib/google/apis/compute_v1/classes.rb', line 54128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54084
54085
54086
# File 'lib/google/apis/compute_v1/classes.rb', line 54084

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54090
54091
54092
# File 'lib/google/apis/compute_v1/classes.rb', line 54090

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


54096
54097
54098
# File 'lib/google/apis/compute_v1/classes.rb', line 54096

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54106
54107
54108
# File 'lib/google/apis/compute_v1/classes.rb', line 54106

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



54111
54112
54113
# File 'lib/google/apis/compute_v1/classes.rb', line 54111

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54116
54117
54118
# File 'lib/google/apis/compute_v1/classes.rb', line 54116

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54121
54122
54123
# File 'lib/google/apis/compute_v1/classes.rb', line 54121

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54126
54127
54128
# File 'lib/google/apis/compute_v1/classes.rb', line 54126

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54133
54134
54135
54136
54137
54138
54139
54140
54141
54142
# File 'lib/google/apis/compute_v1/classes.rb', line 54133

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end