Class: Google::Apis::ComputeV1::RoutersListRoutePolicies
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RoutersListRoutePolicies
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::RoutePolicy>
[Output Only] A list of route policies.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListRoutePolicies
constructor
A new instance of RoutersListRoutePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListRoutePolicies
Returns a new instance of RoutersListRoutePolicies.
54116 54117 54118 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
54072 54073 54074 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54072 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
54078 54079 54080 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54078 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListRoutePolicies for lists of route policies.
Corresponds to the JSON property kind
54084 54085 54086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54084 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54094 54095 54096 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54094 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::RoutePolicy>
[Output Only] A list of route policies.
Corresponds to the JSON property result
54099 54100 54101 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54099 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54104 54105 54106 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54104 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
54109 54110 54111 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54109 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54114 54115 54116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54114 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54121 54122 54123 54124 54125 54126 54127 54128 54129 54130 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54121 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |