Class: Google::Apis::ComputeV1::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



53788
53789
53790
# File 'lib/google/apis/compute_v1/classes.rb', line 53788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53744
53745
53746
# File 'lib/google/apis/compute_v1/classes.rb', line 53744

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53750
53751
53752
# File 'lib/google/apis/compute_v1/classes.rb', line 53750

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


53756
53757
53758
# File 'lib/google/apis/compute_v1/classes.rb', line 53756

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53766
53767
53768
# File 'lib/google/apis/compute_v1/classes.rb', line 53766

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



53771
53772
53773
# File 'lib/google/apis/compute_v1/classes.rb', line 53771

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53776
53777
53778
# File 'lib/google/apis/compute_v1/classes.rb', line 53776

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53781
53782
53783
# File 'lib/google/apis/compute_v1/classes.rb', line 53781

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53786
53787
53788
# File 'lib/google/apis/compute_v1/classes.rb', line 53786

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53793
53794
53795
53796
53797
53798
53799
53800
53801
53802
# File 'lib/google/apis/compute_v1/classes.rb', line 53793

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end