Class: Google::Apis::ComputeV1::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



53779
53780
53781
# File 'lib/google/apis/compute_v1/classes.rb', line 53779

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53735
53736
53737
# File 'lib/google/apis/compute_v1/classes.rb', line 53735

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53741
53742
53743
# File 'lib/google/apis/compute_v1/classes.rb', line 53741

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


53747
53748
53749
# File 'lib/google/apis/compute_v1/classes.rb', line 53747

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53757
53758
53759
# File 'lib/google/apis/compute_v1/classes.rb', line 53757

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



53762
53763
53764
# File 'lib/google/apis/compute_v1/classes.rb', line 53762

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53767
53768
53769
# File 'lib/google/apis/compute_v1/classes.rb', line 53767

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53772
53773
53774
# File 'lib/google/apis/compute_v1/classes.rb', line 53772

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53777
53778
53779
# File 'lib/google/apis/compute_v1/classes.rb', line 53777

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53784
53785
53786
53787
53788
53789
53790
53791
53792
53793
# File 'lib/google/apis/compute_v1/classes.rb', line 53784

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end