Class: Google::Apis::ComputeV1::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



51940
51941
51942
# File 'lib/google/apis/compute_v1/classes.rb', line 51940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51896
51897
51898
# File 'lib/google/apis/compute_v1/classes.rb', line 51896

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51902
51903
51904
# File 'lib/google/apis/compute_v1/classes.rb', line 51902

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


51908
51909
51910
# File 'lib/google/apis/compute_v1/classes.rb', line 51908

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51918
51919
51920
# File 'lib/google/apis/compute_v1/classes.rb', line 51918

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



51923
51924
51925
# File 'lib/google/apis/compute_v1/classes.rb', line 51923

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51928
51929
51930
# File 'lib/google/apis/compute_v1/classes.rb', line 51928

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51933
51934
51935
# File 'lib/google/apis/compute_v1/classes.rb', line 51933

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51938
51939
51940
# File 'lib/google/apis/compute_v1/classes.rb', line 51938

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51945
51946
51947
51948
51949
51950
51951
51952
51953
51954
# File 'lib/google/apis/compute_v1/classes.rb', line 51945

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end