Class: Google::Apis::ComputeV1::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



48483
48484
48485
# File 'lib/google/apis/compute_v1/classes.rb', line 48483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


48439
48440
48441
# File 'lib/google/apis/compute_v1/classes.rb', line 48439

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48445
48446
48447
# File 'lib/google/apis/compute_v1/classes.rb', line 48445

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


48451
48452
48453
# File 'lib/google/apis/compute_v1/classes.rb', line 48451

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48461
48462
48463
# File 'lib/google/apis/compute_v1/classes.rb', line 48461

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



48466
48467
48468
# File 'lib/google/apis/compute_v1/classes.rb', line 48466

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48471
48472
48473
# File 'lib/google/apis/compute_v1/classes.rb', line 48471

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48476
48477
48478
# File 'lib/google/apis/compute_v1/classes.rb', line 48476

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48481
48482
48483
# File 'lib/google/apis/compute_v1/classes.rb', line 48481

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48488
48489
48490
48491
48492
48493
48494
48495
48496
48497
# File 'lib/google/apis/compute_v1/classes.rb', line 48488

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end