Class: Google::Apis::ComputeV1::SavedAttachedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedAttachedDisk

Returns a new instance of SavedAttachedDisk.



55261
55262
55263
# File 'lib/google/apis/compute_v1/classes.rb', line 55261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteBoolean Also known as: auto_delete?

Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance). Corresponds to the JSON property autoDelete

Returns:

  • (Boolean)


55165
55166
55167
# File 'lib/google/apis/compute_v1/classes.rb', line 55165

def auto_delete
  @auto_delete
end

#bootBoolean Also known as: boot?

Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem. Corresponds to the JSON property boot

Returns:

  • (Boolean)


55172
55173
55174
# File 'lib/google/apis/compute_v1/classes.rb', line 55172

def boot
  @boot
end

#device_nameString

Specifies the name of the disk attached to the source instance. Corresponds to the JSON property deviceName

Returns:

  • (String)


55178
55179
55180
# File 'lib/google/apis/compute_v1/classes.rb', line 55178

def device_name
  @device_name
end

#disk_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The encryption key for the disk. Corresponds to the JSON property diskEncryptionKey



55183
55184
55185
# File 'lib/google/apis/compute_v1/classes.rb', line 55183

def disk_encryption_key
  @disk_encryption_key
end

#disk_size_gbFixnum

The size of the disk in base-2 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


55188
55189
55190
# File 'lib/google/apis/compute_v1/classes.rb', line 55188

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Output only. [Output Only] URL of the disk type resource. For example:projects/ project/zones/zone/diskTypes/pd-standard or pd-ssd Corresponds to the JSON property diskType

Returns:

  • (String)


55195
55196
55197
# File 'lib/google/apis/compute_v1/classes.rb', line 55195

def disk_type
  @disk_type
end

#guest_os_featuresArray<Google::Apis::ComputeV1::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



55203
55204
55205
# File 'lib/google/apis/compute_v1/classes.rb', line 55203

def guest_os_features
  @guest_os_features
end

#indexFixnum

Output only. Specifies zero-based index of the disk that is attached to the source instance. Corresponds to the JSON property index

Returns:

  • (Fixnum)


55210
55211
55212
# File 'lib/google/apis/compute_v1/classes.rb', line 55210

def index
  @index
end

#interfaceString

Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Corresponds to the JSON property interface

Returns:

  • (String)


55216
55217
55218
# File 'lib/google/apis/compute_v1/classes.rb', line 55216

def interface
  @interface
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


55222
55223
55224
# File 'lib/google/apis/compute_v1/classes.rb', line 55222

def kind
  @kind
end

#licensesArray<String>

Output only. [Output Only] Any valid publicly visible licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


55227
55228
55229
# File 'lib/google/apis/compute_v1/classes.rb', line 55227

def licenses
  @licenses
end

#modeString

The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Corresponds to the JSON property mode

Returns:

  • (String)


55233
55234
55235
# File 'lib/google/apis/compute_v1/classes.rb', line 55233

def mode
  @mode
end

#sourceString

Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property source

Returns:

  • (String)


55238
55239
55240
# File 'lib/google/apis/compute_v1/classes.rb', line 55238

def source
  @source
end

#storage_bytesFixnum

Output only. [Output Only] A size of the storage used by the disk's snapshot by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


55245
55246
55247
# File 'lib/google/apis/compute_v1/classes.rb', line 55245

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


55254
55255
55256
# File 'lib/google/apis/compute_v1/classes.rb', line 55254

def storage_bytes_status
  @storage_bytes_status
end

#typeString

Specifies the type of the attached disk, either SCRATCH orPERSISTENT. Corresponds to the JSON property type

Returns:

  • (String)


55259
55260
55261
# File 'lib/google/apis/compute_v1/classes.rb', line 55259

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55266
55267
55268
55269
55270
55271
55272
55273
55274
55275
55276
55277
55278
55279
55280
55281
55282
55283
# File 'lib/google/apis/compute_v1/classes.rb', line 55266

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @boot = args[:boot] if args.key?(:boot)
  @device_name = args[:device_name] if args.key?(:device_name)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @index = args[:index] if args.key?(:index)
  @interface = args[:interface] if args.key?(:interface)
  @kind = args[:kind] if args.key?(:kind)
  @licenses = args[:licenses] if args.key?(:licenses)
  @mode = args[:mode] if args.key?(:mode)
  @source = args[:source] if args.key?(:source)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
  @type = args[:type] if args.key?(:type)
end