Class: Google::Apis::ComputeV1::SavedAttachedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedAttachedDisk

Returns a new instance of SavedAttachedDisk.



53826
53827
53828
# File 'lib/google/apis/compute_v1/classes.rb', line 53826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteBoolean Also known as: auto_delete?

Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance). Corresponds to the JSON property autoDelete

Returns:

  • (Boolean)


53730
53731
53732
# File 'lib/google/apis/compute_v1/classes.rb', line 53730

def auto_delete
  @auto_delete
end

#bootBoolean Also known as: boot?

Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem. Corresponds to the JSON property boot

Returns:

  • (Boolean)


53737
53738
53739
# File 'lib/google/apis/compute_v1/classes.rb', line 53737

def boot
  @boot
end

#device_nameString

Specifies the name of the disk attached to the source instance. Corresponds to the JSON property deviceName

Returns:

  • (String)


53743
53744
53745
# File 'lib/google/apis/compute_v1/classes.rb', line 53743

def device_name
  @device_name
end

#disk_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The encryption key for the disk. Corresponds to the JSON property diskEncryptionKey



53748
53749
53750
# File 'lib/google/apis/compute_v1/classes.rb', line 53748

def disk_encryption_key
  @disk_encryption_key
end

#disk_size_gbFixnum

The size of the disk in base-2 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


53753
53754
53755
# File 'lib/google/apis/compute_v1/classes.rb', line 53753

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Output only. [Output Only] URL of the disk type resource. For example:projects/ project/zones/zone/diskTypes/pd-standard or pd-ssd Corresponds to the JSON property diskType

Returns:

  • (String)


53760
53761
53762
# File 'lib/google/apis/compute_v1/classes.rb', line 53760

def disk_type
  @disk_type
end

#guest_os_featuresArray<Google::Apis::ComputeV1::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



53768
53769
53770
# File 'lib/google/apis/compute_v1/classes.rb', line 53768

def guest_os_features
  @guest_os_features
end

#indexFixnum

Output only. Specifies zero-based index of the disk that is attached to the source instance. Corresponds to the JSON property index

Returns:

  • (Fixnum)


53775
53776
53777
# File 'lib/google/apis/compute_v1/classes.rb', line 53775

def index
  @index
end

#interfaceString

Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Corresponds to the JSON property interface

Returns:

  • (String)


53781
53782
53783
# File 'lib/google/apis/compute_v1/classes.rb', line 53781

def interface
  @interface
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


53787
53788
53789
# File 'lib/google/apis/compute_v1/classes.rb', line 53787

def kind
  @kind
end

#licensesArray<String>

Output only. [Output Only] Any valid publicly visible licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


53792
53793
53794
# File 'lib/google/apis/compute_v1/classes.rb', line 53792

def licenses
  @licenses
end

#modeString

The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Corresponds to the JSON property mode

Returns:

  • (String)


53798
53799
53800
# File 'lib/google/apis/compute_v1/classes.rb', line 53798

def mode
  @mode
end

#sourceString

Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property source

Returns:

  • (String)


53803
53804
53805
# File 'lib/google/apis/compute_v1/classes.rb', line 53803

def source
  @source
end

#storage_bytesFixnum

Output only. [Output Only] A size of the storage used by the disk's snapshot by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


53810
53811
53812
# File 'lib/google/apis/compute_v1/classes.rb', line 53810

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


53819
53820
53821
# File 'lib/google/apis/compute_v1/classes.rb', line 53819

def storage_bytes_status
  @storage_bytes_status
end

#typeString

Specifies the type of the attached disk, either SCRATCH orPERSISTENT. Corresponds to the JSON property type

Returns:

  • (String)


53824
53825
53826
# File 'lib/google/apis/compute_v1/classes.rb', line 53824

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53831
53832
53833
53834
53835
53836
53837
53838
53839
53840
53841
53842
53843
53844
53845
53846
53847
53848
# File 'lib/google/apis/compute_v1/classes.rb', line 53831

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @boot = args[:boot] if args.key?(:boot)
  @device_name = args[:device_name] if args.key?(:device_name)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @index = args[:index] if args.key?(:index)
  @interface = args[:interface] if args.key?(:interface)
  @kind = args[:kind] if args.key?(:kind)
  @licenses = args[:licenses] if args.key?(:licenses)
  @mode = args[:mode] if args.key?(:mode)
  @source = args[:source] if args.key?(:source)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
  @type = args[:type] if args.key?(:type)
end