Class: Google::Apis::ComputeV1::SavedAttachedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedAttachedDisk

Returns a new instance of SavedAttachedDisk.



30393
30394
30395
# File 'lib/google/apis/compute_v1/classes.rb', line 30393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteBoolean Also known as: auto_delete?

Specifies whether the disk will be auto-deleted when the instance is deleted ( but not when the disk is detached from the instance). Corresponds to the JSON property autoDelete

Returns:

  • (Boolean)


30303
30304
30305
# File 'lib/google/apis/compute_v1/classes.rb', line 30303

def auto_delete
  @auto_delete
end

#bootBoolean Also known as: boot?

Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem. Corresponds to the JSON property boot

Returns:

  • (Boolean)


30310
30311
30312
# File 'lib/google/apis/compute_v1/classes.rb', line 30310

def boot
  @boot
end

#device_nameString

Specifies the name of the disk attached to the source instance. Corresponds to the JSON property deviceName

Returns:

  • (String)


30316
30317
30318
# File 'lib/google/apis/compute_v1/classes.rb', line 30316

def device_name
  @device_name
end

#disk_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

The encryption key for the disk. Corresponds to the JSON property diskEncryptionKey



30321
30322
30323
# File 'lib/google/apis/compute_v1/classes.rb', line 30321

def disk_encryption_key
  @disk_encryption_key
end

#disk_size_gbFixnum

The size of the disk in base-2 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


30326
30327
30328
# File 'lib/google/apis/compute_v1/classes.rb', line 30326

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

[Output Only] URL of the disk type resource. For example: projects/project / zones/zone/diskTypes/pd-standard or pd-ssd Corresponds to the JSON property diskType

Returns:

  • (String)


30332
30333
30334
# File 'lib/google/apis/compute_v1/classes.rb', line 30332

def disk_type
  @disk_type
end

#guest_os_featuresArray<Google::Apis::ComputeV1::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



30339
30340
30341
# File 'lib/google/apis/compute_v1/classes.rb', line 30339

def guest_os_features
  @guest_os_features
end

#indexFixnum

Specifies zero-based index of the disk that is attached to the source instance. Corresponds to the JSON property index

Returns:

  • (Fixnum)


30344
30345
30346
# File 'lib/google/apis/compute_v1/classes.rb', line 30344

def index
  @index
end

#interfaceString

Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Corresponds to the JSON property interface

Returns:

  • (String)


30350
30351
30352
# File 'lib/google/apis/compute_v1/classes.rb', line 30350

def interface
  @interface
end

#kindString

[Output Only] Type of the resource. Always compute#attachedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


30356
30357
30358
# File 'lib/google/apis/compute_v1/classes.rb', line 30356

def kind
  @kind
end

#licensesArray<String>

[Output Only] Any valid publicly visible licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


30361
30362
30363
# File 'lib/google/apis/compute_v1/classes.rb', line 30361

def licenses
  @licenses
end

#modeString

The mode in which this disk is attached to the source instance, either READ_WRITE or READ_ONLY. Corresponds to the JSON property mode

Returns:

  • (String)


30367
30368
30369
# File 'lib/google/apis/compute_v1/classes.rb', line 30367

def mode
  @mode
end

#sourceString

Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property source

Returns:

  • (String)


30372
30373
30374
# File 'lib/google/apis/compute_v1/classes.rb', line 30372

def source
  @source
end

#storage_bytesFixnum

[Output Only] A size of the storage used by the disk's snapshot by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


30378
30379
30380
# File 'lib/google/apis/compute_v1/classes.rb', line 30378

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

[Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


30386
30387
30388
# File 'lib/google/apis/compute_v1/classes.rb', line 30386

def storage_bytes_status
  @storage_bytes_status
end

#typeString

Specifies the type of the attached disk, either SCRATCH or PERSISTENT. Corresponds to the JSON property type

Returns:

  • (String)


30391
30392
30393
# File 'lib/google/apis/compute_v1/classes.rb', line 30391

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30398
30399
30400
30401
30402
30403
30404
30405
30406
30407
30408
30409
30410
30411
30412
30413
30414
30415
# File 'lib/google/apis/compute_v1/classes.rb', line 30398

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @boot = args[:boot] if args.key?(:boot)
  @device_name = args[:device_name] if args.key?(:device_name)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @index = args[:index] if args.key?(:index)
  @interface = args[:interface] if args.key?(:interface)
  @kind = args[:kind] if args.key?(:kind)
  @licenses = args[:licenses] if args.key?(:licenses)
  @mode = args[:mode] if args.key?(:mode)
  @source = args[:source] if args.key?(:source)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
  @type = args[:type] if args.key?(:type)
end