Class: Google::Apis::ComputeV1::SavedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SavedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
An instance-attached disk resource.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#source_disk ⇒ String
Output only.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedDisk
constructor
A new instance of SavedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedDisk
Returns a new instance of SavedDisk.
53901 53902 53903 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the attached disk.
Corresponds to the JSON property architecture
53872 53873 53874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53872 def architecture @architecture end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#savedDisk
for attached disks.
Corresponds to the JSON property kind
53878 53879 53880 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53878 def kind @kind end |
#source_disk ⇒ String
Output only. Specifies a URL of the disk attached to the source instance.
Corresponds to the JSON property sourceDisk
53883 53884 53885 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53883 def source_disk @source_disk end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] Size of the individual disk snapshot used by this
machine
image.
Corresponds to the JSON property storageBytes
53890 53891 53892 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53890 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
53899 53900 53901 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53899 def storage_bytes_status @storage_bytes_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53906 53907 53908 53909 53910 53911 53912 |
# File 'lib/google/apis/compute_v1/classes.rb', line 53906 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @kind = args[:kind] if args.key?(:kind) @source_disk = args[:source_disk] if args.key?(:source_disk) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) end |