Class: Google::Apis::ComputeV1::SavedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedDisk

Returns a new instance of SavedDisk.



47748
47749
47750
# File 'lib/google/apis/compute_v1/classes.rb', line 47748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. [Output Only] The architecture of the attached disk. Corresponds to the JSON property architecture

Returns:

  • (String)


47719
47720
47721
# File 'lib/google/apis/compute_v1/classes.rb', line 47719

def architecture
  @architecture
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#savedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


47725
47726
47727
# File 'lib/google/apis/compute_v1/classes.rb', line 47725

def kind
  @kind
end

#source_diskString

Output only. Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property sourceDisk

Returns:

  • (String)


47730
47731
47732
# File 'lib/google/apis/compute_v1/classes.rb', line 47730

def source_disk
  @source_disk
end

#storage_bytesFixnum

Output only. [Output Only] Size of the individual disk snapshot used by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


47737
47738
47739
# File 'lib/google/apis/compute_v1/classes.rb', line 47737

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


47746
47747
47748
# File 'lib/google/apis/compute_v1/classes.rb', line 47746

def storage_bytes_status
  @storage_bytes_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47753
47754
47755
47756
47757
47758
47759
# File 'lib/google/apis/compute_v1/classes.rb', line 47753

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @kind = args[:kind] if args.key?(:kind)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
end