Class: Google::Apis::ComputeV1::Scheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Scheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Sets the scheduling options for an Instance.
Instance Attribute Summary collapse
-
#automatic_restart ⇒ Boolean
(also: #automatic_restart?)
Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user).
-
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in.
-
#host_error_timeout_seconds ⇒ Fixnum
Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used.
-
#instance_termination_action ⇒ String
Specifies the termination action for the instance.
-
#local_ssd_recovery_timeout ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#location_hint ⇒ String
An opaque location hint used to place the instance close to other resources.
-
#max_run_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#min_node_cpus ⇒ Fixnum
The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
-
#node_affinities ⇒ Array<Google::Apis::ComputeV1::SchedulingNodeAffinity>
A set of node affinity and anti-affinity configurations.
-
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance.
-
#on_instance_stop_action ⇒ Google::Apis::ComputeV1::SchedulingOnInstanceStopAction
Defines the behaviour for instances with the instance_termination_actionSTOP.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Defines whether the instance is preemptible.
-
#provisioning_model ⇒ String
Specifies the provisioning model of the instance.
-
#skip_guest_os_shutdown ⇒ Boolean
(also: #skip_guest_os_shutdown?)
Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs.
-
#termination_time ⇒ String
Specifies the timestamp, when the instance will be terminated, inRFC3339 text format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scheduling
constructor
A new instance of Scheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Scheduling
Returns a new instance of Scheduling.
54736 54737 54738 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_restart ⇒ Boolean Also known as: automatic_restart?
Specifies whether the instance should be automatically restarted if it is
terminated by Compute Engine (not terminated by a user). You can only set
the automatic restart option for standard instances.Preemptible instances
cannot be automatically restarted.
By default, this is set to true so an instance is
automatically restarted if it is terminated by Compute Engine.
Corresponds to the JSON property automaticRestart
54633 54634 54635 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54633 def automatic_restart @automatic_restart end |
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in. The value
must be a number between 1 and the number of availability domains
specified in the spread placement policy attached to the instance.
Corresponds to the JSON property availabilityDomain
54641 54642 54643 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54641 def availability_domain @availability_domain end |
#host_error_timeout_seconds ⇒ Fixnum
Specify the time in seconds for host error detection, the value must be
within the range of [90, 330] with the increment of 30, if unset, the
default behavior of host error recovery will be used.
Corresponds to the JSON property hostErrorTimeoutSeconds
54648 54649 54650 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54648 def host_error_timeout_seconds @host_error_timeout_seconds end |
#instance_termination_action ⇒ String
Specifies the termination action for the instance.
Corresponds to the JSON property instanceTerminationAction
54653 54654 54655 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54653 def instance_termination_action @instance_termination_action end |
#local_ssd_recovery_timeout ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property localSsdRecoveryTimeout
54661 54662 54663 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54661 def local_ssd_recovery_timeout @local_ssd_recovery_timeout end |
#location_hint ⇒ String
An opaque location hint used to place the instance close to other
resources.
This field is for use by internal tools that use the public API.
Corresponds to the JSON property locationHint
54668 54669 54670 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54668 def location_hint @location_hint end |
#max_run_duration ⇒ Google::Apis::ComputeV1::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxRunDuration
54676 54677 54678 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54676 def max_run_duration @max_run_duration end |
#min_node_cpus ⇒ Fixnum
The minimum number of virtual CPUs this instance will consume when running
on a sole-tenant node.
Corresponds to the JSON property minNodeCpus
54682 54683 54684 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54682 def min_node_cpus @min_node_cpus end |
#node_affinities ⇒ Array<Google::Apis::ComputeV1::SchedulingNodeAffinity>
A set of node affinity and anti-affinity configurations. Refer toConfiguring
node
affinity for more information.
Overrides reservationAffinity.
Corresponds to the JSON property nodeAffinities
54690 54691 54692 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54690 def node_affinities @node_affinities end |
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance. For standard instances,
the default behavior is MIGRATE. Forpreemptible instances,
the default and only possible behavior is TERMINATE. For more
information, see
Set
VM host maintenance policy.
Corresponds to the JSON property onHostMaintenance
54700 54701 54702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54700 def on_host_maintenance @on_host_maintenance end |
#on_instance_stop_action ⇒ Google::Apis::ComputeV1::SchedulingOnInstanceStopAction
Defines the behaviour for instances with the instance_termination_actionSTOP.
Corresponds to the JSON property onInstanceStopAction
54705 54706 54707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54705 def on_instance_stop_action @on_instance_stop_action end |
#preemptible ⇒ Boolean Also known as: preemptible?
Defines whether the instance is preemptible. This can only be set during
instance creation or while the instance isstopped and
therefore, in a TERMINATED state. SeeInstance Life
Cycle for more information on the possible instance states.
Corresponds to the JSON property preemptible
54713 54714 54715 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54713 def preemptible @preemptible end |
#provisioning_model ⇒ String
Specifies the provisioning model of the instance.
Corresponds to the JSON property provisioningModel
54719 54720 54721 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54719 def provisioning_model @provisioning_model end |
#skip_guest_os_shutdown ⇒ Boolean Also known as: skip_guest_os_shutdown?
Default is false and there will be 120 seconds between GCE ACPI G2 Soft
Off and ACPI G3 Mechanical
Off for Standard VMs and 30 seconds for Spot VMs.
Corresponds to the JSON property skipGuestOsShutdown
54726 54727 54728 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54726 def skip_guest_os_shutdown @skip_guest_os_shutdown end |
#termination_time ⇒ String
Specifies the timestamp, when the instance will be terminated, inRFC3339 text
format. If specified, the instance
termination action will be performed at the termination time.
Corresponds to the JSON property terminationTime
54734 54735 54736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54734 def termination_time @termination_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54741 54742 54743 54744 54745 54746 54747 54748 54749 54750 54751 54752 54753 54754 54755 54756 54757 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54741 def update!(**args) @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart) @availability_domain = args[:availability_domain] if args.key?(:availability_domain) @host_error_timeout_seconds = args[:host_error_timeout_seconds] if args.key?(:host_error_timeout_seconds) @instance_termination_action = args[:instance_termination_action] if args.key?(:instance_termination_action) @local_ssd_recovery_timeout = args[:local_ssd_recovery_timeout] if args.key?(:local_ssd_recovery_timeout) @location_hint = args[:location_hint] if args.key?(:location_hint) @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration) @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus) @node_affinities = args[:node_affinities] if args.key?(:node_affinities) @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance) @on_instance_stop_action = args[:on_instance_stop_action] if args.key?(:on_instance_stop_action) @preemptible = args[:preemptible] if args.key?(:preemptible) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) @skip_guest_os_shutdown = args[:skip_guest_os_shutdown] if args.key?(:skip_guest_os_shutdown) @termination_time = args[:termination_time] if args.key?(:termination_time) end |