Class: Google::Apis::ComputeV1::Scheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Scheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Sets the scheduling options for an Instance. NextID: 21
Instance Attribute Summary collapse
-
#automatic_restart ⇒ Boolean
(also: #automatic_restart?)
Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user).
-
#instance_termination_action ⇒ String
Specifies the termination action for the instance.
-
#location_hint ⇒ String
An opaque location hint used to place the instance close to other resources.
-
#min_node_cpus ⇒ Fixnum
The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
-
#node_affinities ⇒ Array<Google::Apis::ComputeV1::SchedulingNodeAffinity>
A set of node affinity and anti-affinity configurations.
-
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Defines whether the instance is preemptible.
-
#provisioning_model ⇒ String
Specifies the provisioning model of the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scheduling
constructor
A new instance of Scheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Scheduling
Returns a new instance of Scheduling.
30553 30554 30555 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_restart ⇒ Boolean Also known as: automatic_restart?
Specifies whether the instance should be automatically restarted if it is
terminated by Compute Engine (not terminated by a user). You can only set the
automatic restart option for standard instances. Preemptible instances cannot
be automatically restarted. By default, this is set to true so an instance is
automatically restarted if it is terminated by Compute Engine.
Corresponds to the JSON property automaticRestart
30505 30506 30507 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30505 def automatic_restart @automatic_restart end |
#instance_termination_action ⇒ String
Specifies the termination action for the instance.
Corresponds to the JSON property instanceTerminationAction
30511 30512 30513 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30511 def instance_termination_action @instance_termination_action end |
#location_hint ⇒ String
An opaque location hint used to place the instance close to other resources.
This field is for use by internal tools that use the public API.
Corresponds to the JSON property locationHint
30517 30518 30519 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30517 def location_hint @location_hint end |
#min_node_cpus ⇒ Fixnum
The minimum number of virtual CPUs this instance will consume when running on
a sole-tenant node.
Corresponds to the JSON property minNodeCpus
30523 30524 30525 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30523 def min_node_cpus @min_node_cpus end |
#node_affinities ⇒ Array<Google::Apis::ComputeV1::SchedulingNodeAffinity>
A set of node affinity and anti-affinity configurations. Refer to Configuring
node affinity for more information. Overrides reservationAffinity.
Corresponds to the JSON property nodeAffinities
30529 30530 30531 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30529 def node_affinities @node_affinities end |
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance. For standard instances,
the default behavior is MIGRATE. For preemptible instances, the default and
only possible behavior is TERMINATE. For more information, see Set VM
availability policies.
Corresponds to the JSON property onHostMaintenance
30537 30538 30539 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30537 def on_host_maintenance @on_host_maintenance end |
#preemptible ⇒ Boolean Also known as: preemptible?
Defines whether the instance is preemptible. This can only be set during
instance creation or while the instance is stopped and therefore, in a
TERMINATED state. See Instance Life Cycle for more information on the
possible instance states.
Corresponds to the JSON property preemptible
30545 30546 30547 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30545 def preemptible @preemptible end |
#provisioning_model ⇒ String
Specifies the provisioning model of the instance.
Corresponds to the JSON property provisioningModel
30551 30552 30553 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30551 def provisioning_model @provisioning_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30558 30559 30560 30561 30562 30563 30564 30565 30566 30567 |
# File 'lib/google/apis/compute_v1/classes.rb', line 30558 def update!(**args) @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart) @instance_termination_action = args[:instance_termination_action] if args.key?(:instance_termination_action) @location_hint = args[:location_hint] if args.key?(:location_hint) @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus) @node_affinities = args[:node_affinities] if args.key?(:node_affinities) @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance) @preemptible = args[:preemptible] if args.key?(:preemptible) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) end |