Class: Google::Apis::ComputeV1::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



55690
55691
55692
# File 'lib/google/apis/compute_v1/classes.rb', line 55690

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


55646
55647
55648
# File 'lib/google/apis/compute_v1/classes.rb', line 55646

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55651
55652
55653
# File 'lib/google/apis/compute_v1/classes.rb', line 55651

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



55656
55657
55658
# File 'lib/google/apis/compute_v1/classes.rb', line 55656

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


55663
55664
55665
# File 'lib/google/apis/compute_v1/classes.rb', line 55663

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55673
55674
55675
# File 'lib/google/apis/compute_v1/classes.rb', line 55673

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55678
55679
55680
# File 'lib/google/apis/compute_v1/classes.rb', line 55678

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


55683
55684
55685
# File 'lib/google/apis/compute_v1/classes.rb', line 55683

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55688
55689
55690
# File 'lib/google/apis/compute_v1/classes.rb', line 55688

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55695
55696
55697
55698
55699
55700
55701
55702
55703
55704
# File 'lib/google/apis/compute_v1/classes.rb', line 55695

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end