Class: Google::Apis::ComputeV1::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



54892
54893
54894
# File 'lib/google/apis/compute_v1/classes.rb', line 54892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54848
54849
54850
# File 'lib/google/apis/compute_v1/classes.rb', line 54848

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54853
54854
54855
# File 'lib/google/apis/compute_v1/classes.rb', line 54853

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



54858
54859
54860
# File 'lib/google/apis/compute_v1/classes.rb', line 54858

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


54865
54866
54867
# File 'lib/google/apis/compute_v1/classes.rb', line 54865

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54875
54876
54877
# File 'lib/google/apis/compute_v1/classes.rb', line 54875

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54880
54881
54882
# File 'lib/google/apis/compute_v1/classes.rb', line 54880

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54885
54886
54887
# File 'lib/google/apis/compute_v1/classes.rb', line 54885

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54890
54891
54892
# File 'lib/google/apis/compute_v1/classes.rb', line 54890

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54897
54898
54899
54900
54901
54902
54903
54904
54905
54906
# File 'lib/google/apis/compute_v1/classes.rb', line 54897

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end