Class: Google::Apis::ComputeV1::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



54225
54226
54227
# File 'lib/google/apis/compute_v1/classes.rb', line 54225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54181
54182
54183
# File 'lib/google/apis/compute_v1/classes.rb', line 54181

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54186
54187
54188
# File 'lib/google/apis/compute_v1/classes.rb', line 54186

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



54191
54192
54193
# File 'lib/google/apis/compute_v1/classes.rb', line 54191

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


54198
54199
54200
# File 'lib/google/apis/compute_v1/classes.rb', line 54198

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54208
54209
54210
# File 'lib/google/apis/compute_v1/classes.rb', line 54208

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54213
54214
54215
# File 'lib/google/apis/compute_v1/classes.rb', line 54213

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54218
54219
54220
# File 'lib/google/apis/compute_v1/classes.rb', line 54218

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54223
54224
54225
# File 'lib/google/apis/compute_v1/classes.rb', line 54223

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54230
54231
54232
54233
54234
54235
54236
54237
54238
54239
# File 'lib/google/apis/compute_v1/classes.rb', line 54230

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end