Class: Google::Apis::ComputeV1::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



54211
54212
54213
# File 'lib/google/apis/compute_v1/classes.rb', line 54211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54167
54168
54169
# File 'lib/google/apis/compute_v1/classes.rb', line 54167

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54172
54173
54174
# File 'lib/google/apis/compute_v1/classes.rb', line 54172

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



54177
54178
54179
# File 'lib/google/apis/compute_v1/classes.rb', line 54177

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


54184
54185
54186
# File 'lib/google/apis/compute_v1/classes.rb', line 54184

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54194
54195
54196
# File 'lib/google/apis/compute_v1/classes.rb', line 54194

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54199
54200
54201
# File 'lib/google/apis/compute_v1/classes.rb', line 54199

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54204
54205
54206
# File 'lib/google/apis/compute_v1/classes.rb', line 54204

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54209
54210
54211
# File 'lib/google/apis/compute_v1/classes.rb', line 54209

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54216
54217
54218
54219
54220
54221
54222
54223
54224
54225
# File 'lib/google/apis/compute_v1/classes.rb', line 54216

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end