Class: Google::Apis::ComputeV1::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



48072
48073
48074
# File 'lib/google/apis/compute_v1/classes.rb', line 48072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


48028
48029
48030
# File 'lib/google/apis/compute_v1/classes.rb', line 48028

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48033
48034
48035
# File 'lib/google/apis/compute_v1/classes.rb', line 48033

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



48038
48039
48040
# File 'lib/google/apis/compute_v1/classes.rb', line 48038

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


48045
48046
48047
# File 'lib/google/apis/compute_v1/classes.rb', line 48045

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48055
48056
48057
# File 'lib/google/apis/compute_v1/classes.rb', line 48055

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48060
48061
48062
# File 'lib/google/apis/compute_v1/classes.rb', line 48060

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48065
48066
48067
# File 'lib/google/apis/compute_v1/classes.rb', line 48065

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48070
48071
48072
# File 'lib/google/apis/compute_v1/classes.rb', line 48070

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48077
48078
48079
48080
48081
48082
48083
48084
48085
48086
# File 'lib/google/apis/compute_v1/classes.rb', line 48077

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end