Class: Google::Apis::ComputeV1::SecurityPoliciesScopedList::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Informational warning which replaces the list of security policies when the list is empty.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



48231
48232
48233
# File 'lib/google/apis/compute_v1/classes.rb', line 48231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


48213
48214
48215
# File 'lib/google/apis/compute_v1/classes.rb', line 48213

def code
  @code
end

#dataArray<Google::Apis::ComputeV1::SecurityPoliciesScopedList::Warning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" Corresponds to the JSON property data



48224
48225
48226
# File 'lib/google/apis/compute_v1/classes.rb', line 48224

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


48229
48230
48231
# File 'lib/google/apis/compute_v1/classes.rb', line 48229

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48236
48237
48238
48239
48240
# File 'lib/google/apis/compute_v1/classes.rb', line 48236

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end