Class: Google::Apis::ComputeV1::SecurityPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Google Cloud Armor security policy resource. Only external backend services that use load balancers can reference a security policy. For more information, see Google Cloud Armor security policy overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicy

Returns a new instance of SecurityPolicy.



53118
53119
53120
# File 'lib/google/apis/compute_v1/classes.rb', line 53118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptive_protection_configGoogle::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfig

Configuration options for Cloud Armor Adaptive Protection (CAAP). Corresponds to the JSON property adaptiveProtectionConfig



52948
52949
52950
# File 'lib/google/apis/compute_v1/classes.rb', line 52948

def adaptive_protection_config
  @adaptive_protection_config
end

#advanced_options_configGoogle::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfig

Corresponds to the JSON property advancedOptionsConfig



52953
52954
52955
# File 'lib/google/apis/compute_v1/classes.rb', line 52953

def advanced_options_config
  @advanced_options_config
end

#associationsArray<Google::Apis::ComputeV1::SecurityPolicyAssociation>

A list of associations that belong to this policy. Corresponds to the JSON property associations



52958
52959
52960
# File 'lib/google/apis/compute_v1/classes.rb', line 52958

def associations
  @associations
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


52964
52965
52966
# File 'lib/google/apis/compute_v1/classes.rb', line 52964

def creation_timestamp
  @creation_timestamp
end

#ddos_protection_configGoogle::Apis::ComputeV1::SecurityPolicyDdosProtectionConfig

Corresponds to the JSON property ddosProtectionConfig



52969
52970
52971
# File 'lib/google/apis/compute_v1/classes.rb', line 52969

def ddos_protection_config
  @ddos_protection_config
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


52975
52976
52977
# File 'lib/google/apis/compute_v1/classes.rb', line 52975

def description
  @description
end

#fingerprintString

Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make get() request to the security policy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


52988
52989
52990
# File 'lib/google/apis/compute_v1/classes.rb', line 52988

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


52995
52996
52997
# File 'lib/google/apis/compute_v1/classes.rb', line 52995

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute# securityPolicyfor security policies Corresponds to the JSON property kind

Returns:

  • (String)


53001
53002
53003
# File 'lib/google/apis/compute_v1/classes.rb', line 53001

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this security policy, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the security policy. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


53013
53014
53015
# File 'lib/google/apis/compute_v1/classes.rb', line 53013

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


53020
53021
53022
# File 'lib/google/apis/compute_v1/classes.rb', line 53020

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


53031
53032
53033
# File 'lib/google/apis/compute_v1/classes.rb', line 53031

def name
  @name
end

#parentString

Output only. [Output Only] The parent of the security policy. Corresponds to the JSON property parent

Returns:

  • (String)


53036
53037
53038
# File 'lib/google/apis/compute_v1/classes.rb', line 53036

def parent
  @parent
end

#recaptcha_options_configGoogle::Apis::ComputeV1::SecurityPolicyRecaptchaOptionsConfig

Corresponds to the JSON property recaptchaOptionsConfig



53041
53042
53043
# File 'lib/google/apis/compute_v1/classes.rb', line 53041

def recaptcha_options_config
  @recaptcha_options_config
end

#regionString

Output only. [Output Only] URL of the region where the regional security policy resides. This field is not applicable to global security policies. Corresponds to the JSON property region

Returns:

  • (String)


53048
53049
53050
# File 'lib/google/apis/compute_v1/classes.rb', line 53048

def region
  @region
end

#rulesArray<Google::Apis::ComputeV1::SecurityPolicyRule>

A list of rules that belong to this policy. There must always be a default rule which is a rule with priority 2147483647 and match all condition (for the match condition this means match "" for srcIpRanges and for the networkMatch condition every field must be either match "" or not set). If no rules are provided when creating a security policy, a default rule with action "allow" will be added. Corresponds to the JSON property rules



53059
53060
53061
# File 'lib/google/apis/compute_v1/classes.rb', line 53059

def rules
  @rules
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53064
53065
53066
# File 'lib/google/apis/compute_v1/classes.rb', line 53064

def self_link
  @self_link
end

#short_nameString

User-provided name of the organization security policy. The name should be unique in the organization in which the security policy is created. This should only be used when SecurityPolicyType is CLOUD_ARMOR. The name must be 1-63 characters long, and comply with https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property shortName

Returns:

  • (String)


53077
53078
53079
# File 'lib/google/apis/compute_v1/classes.rb', line 53077

def short_name
  @short_name
end

#typeString

The type indicates the intended use of the security policy.

  • CLOUD_ARMOR: Cloud Armor backend security policies can be configured to filter incoming HTTP requests targeting backend services. They filter requests before they hit the origin servers.
  • CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can be configured to filter incoming HTTP requests targeting backend services (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). They filter requests before the request is served from Google's cache.
  • CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor internal service policies can be configured to filter HTTP requests targeting services managed by Traffic Director in a service mesh. They filter requests before the request is served from the application.
  • CLOUD_ARMOR_NETWORK: Cloud Armor network policies can be configured to filter packets targeting network load balancing resources such as backend services, target pools, target instances, and instances with external IPs. They filter requests before the request is served from the application. This field can be set only at resource creation time. Corresponds to the JSON property type

Returns:

  • (String)


53100
53101
53102
# File 'lib/google/apis/compute_v1/classes.rb', line 53100

def type
  @type
end

#user_defined_fieldsArray<Google::Apis::ComputeV1::SecurityPolicyUserDefinedField>

Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies. A user-defined field consists of up to 4 bytes extracted from a fixed offset in the packet, relative to the IPv4, IPv6, TCP, or UDP header, with an optional mask to select certain bits. Rules may then specify matching values for these fields. Example: userDefinedFields:

  • name: "ipv4_fragment_offset" base: IPV4 offset: 6 size: 2 mask: "0x1fff" Corresponds to the JSON property userDefinedFields


53116
53117
53118
# File 'lib/google/apis/compute_v1/classes.rb', line 53116

def user_defined_fields
  @user_defined_fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53123
53124
53125
53126
53127
53128
53129
53130
53131
53132
53133
53134
53135
53136
53137
53138
53139
53140
53141
53142
53143
53144
# File 'lib/google/apis/compute_v1/classes.rb', line 53123

def update!(**args)
  @adaptive_protection_config = args[:adaptive_protection_config] if args.key?(:adaptive_protection_config)
  @advanced_options_config = args[:advanced_options_config] if args.key?(:advanced_options_config)
  @associations = args[:associations] if args.key?(:associations)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @ddos_protection_config = args[:ddos_protection_config] if args.key?(:ddos_protection_config)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @recaptcha_options_config = args[:recaptcha_options_config] if args.key?(:recaptcha_options_config)
  @region = args[:region] if args.key?(:region)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @short_name = args[:short_name] if args.key?(:short_name)
  @type = args[:type] if args.key?(:type)
  @user_defined_fields = args[:user_defined_fields] if args.key?(:user_defined_fields)
end