Class: Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#auto_deploy_confidence_threshold ⇒ Float
Corresponds to the JSON property
autoDeployConfidenceThreshold. -
#auto_deploy_expiration_sec ⇒ Fixnum
Corresponds to the JSON property
autoDeployExpirationSec. -
#auto_deploy_impacted_baseline_threshold ⇒ Float
Corresponds to the JSON property
autoDeployImpactedBaselineThreshold. -
#auto_deploy_load_threshold ⇒ Float
Corresponds to the JSON property
autoDeployLoadThreshold. -
#detection_absolute_qps ⇒ Float
Corresponds to the JSON property
detectionAbsoluteQps. -
#detection_load_threshold ⇒ Float
Corresponds to the JSON property
detectionLoadThreshold. -
#detection_relative_to_baseline_qps ⇒ Float
Corresponds to the JSON property
detectionRelativeToBaselineQps. -
#name ⇒ String
The name must be 1-63 characters long, and comply withRFC1035.
-
#traffic_granularity_configs ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>
Configuration options for enabling Adaptive Protection to operate on specified granular traffic units.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
constructor
A new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.
55108 55109 55110 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_deploy_confidence_threshold ⇒ Float
Corresponds to the JSON property autoDeployConfidenceThreshold
55064 55065 55066 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55064 def auto_deploy_confidence_threshold @auto_deploy_confidence_threshold end |
#auto_deploy_expiration_sec ⇒ Fixnum
Corresponds to the JSON property autoDeployExpirationSec
55069 55070 55071 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55069 def auto_deploy_expiration_sec @auto_deploy_expiration_sec end |
#auto_deploy_impacted_baseline_threshold ⇒ Float
Corresponds to the JSON property autoDeployImpactedBaselineThreshold
55074 55075 55076 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55074 def auto_deploy_impacted_baseline_threshold @auto_deploy_impacted_baseline_threshold end |
#auto_deploy_load_threshold ⇒ Float
Corresponds to the JSON property autoDeployLoadThreshold
55079 55080 55081 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55079 def auto_deploy_load_threshold @auto_deploy_load_threshold end |
#detection_absolute_qps ⇒ Float
Corresponds to the JSON property detectionAbsoluteQps
55084 55085 55086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55084 def detection_absolute_qps @detection_absolute_qps end |
#detection_load_threshold ⇒ Float
Corresponds to the JSON property detectionLoadThreshold
55089 55090 55091 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55089 def detection_load_threshold @detection_load_threshold end |
#detection_relative_to_baseline_qps ⇒ Float
Corresponds to the JSON property detectionRelativeToBaselineQps
55094 55095 55096 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55094 def detection_relative_to_baseline_qps @detection_relative_to_baseline_qps end |
#name ⇒ String
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the security policy.
Corresponds to the JSON property name
55100 55101 55102 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55100 def name @name end |
#traffic_granularity_configs ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>
Configuration options for enabling Adaptive Protection to operate
on specified granular traffic units.
Corresponds to the JSON property trafficGranularityConfigs
55106 55107 55108 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55106 def traffic_granularity_configs @traffic_granularity_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55113 55114 55115 55116 55117 55118 55119 55120 55121 55122 55123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55113 def update!(**args) @auto_deploy_confidence_threshold = args[:auto_deploy_confidence_threshold] if args.key?(:auto_deploy_confidence_threshold) @auto_deploy_expiration_sec = args[:auto_deploy_expiration_sec] if args.key?(:auto_deploy_expiration_sec) @auto_deploy_impacted_baseline_threshold = args[:auto_deploy_impacted_baseline_threshold] if args.key?(:auto_deploy_impacted_baseline_threshold) @auto_deploy_load_threshold = args[:auto_deploy_load_threshold] if args.key?(:auto_deploy_load_threshold) @detection_absolute_qps = args[:detection_absolute_qps] if args.key?(:detection_absolute_qps) @detection_load_threshold = args[:detection_load_threshold] if args.key?(:detection_load_threshold) @detection_relative_to_baseline_qps = args[:detection_relative_to_baseline_qps] if args.key?(:detection_relative_to_baseline_qps) @name = args[:name] if args.key?(:name) @traffic_granularity_configs = args[:traffic_granularity_configs] if args.key?(:traffic_granularity_configs) end |