Class: Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.



54769
54770
54771
# File 'lib/google/apis/compute_v1/classes.rb', line 54769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deploy_confidence_thresholdFloat

Corresponds to the JSON property autoDeployConfidenceThreshold

Returns:

  • (Float)


54725
54726
54727
# File 'lib/google/apis/compute_v1/classes.rb', line 54725

def auto_deploy_confidence_threshold
  @auto_deploy_confidence_threshold
end

#auto_deploy_expiration_secFixnum

Corresponds to the JSON property autoDeployExpirationSec

Returns:

  • (Fixnum)


54730
54731
54732
# File 'lib/google/apis/compute_v1/classes.rb', line 54730

def auto_deploy_expiration_sec
  @auto_deploy_expiration_sec
end

#auto_deploy_impacted_baseline_thresholdFloat

Corresponds to the JSON property autoDeployImpactedBaselineThreshold

Returns:

  • (Float)


54735
54736
54737
# File 'lib/google/apis/compute_v1/classes.rb', line 54735

def auto_deploy_impacted_baseline_threshold
  @auto_deploy_impacted_baseline_threshold
end

#auto_deploy_load_thresholdFloat

Corresponds to the JSON property autoDeployLoadThreshold

Returns:

  • (Float)


54740
54741
54742
# File 'lib/google/apis/compute_v1/classes.rb', line 54740

def auto_deploy_load_threshold
  @auto_deploy_load_threshold
end

#detection_absolute_qpsFloat

Corresponds to the JSON property detectionAbsoluteQps

Returns:

  • (Float)


54745
54746
54747
# File 'lib/google/apis/compute_v1/classes.rb', line 54745

def detection_absolute_qps
  @detection_absolute_qps
end

#detection_load_thresholdFloat

Corresponds to the JSON property detectionLoadThreshold

Returns:

  • (Float)


54750
54751
54752
# File 'lib/google/apis/compute_v1/classes.rb', line 54750

def detection_load_threshold
  @detection_load_threshold
end

#detection_relative_to_baseline_qpsFloat

Corresponds to the JSON property detectionRelativeToBaselineQps

Returns:

  • (Float)


54755
54756
54757
# File 'lib/google/apis/compute_v1/classes.rb', line 54755

def detection_relative_to_baseline_qps
  @detection_relative_to_baseline_qps
end

#nameString

The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the security policy. Corresponds to the JSON property name

Returns:

  • (String)


54761
54762
54763
# File 'lib/google/apis/compute_v1/classes.rb', line 54761

def name
  @name
end

#traffic_granularity_configsArray<Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>

Configuration options for enabling Adaptive Protection to operate on specified granular traffic units. Corresponds to the JSON property trafficGranularityConfigs



54767
54768
54769
# File 'lib/google/apis/compute_v1/classes.rb', line 54767

def traffic_granularity_configs
  @traffic_granularity_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54774
54775
54776
54777
54778
54779
54780
54781
54782
54783
54784
# File 'lib/google/apis/compute_v1/classes.rb', line 54774

def update!(**args)
  @auto_deploy_confidence_threshold = args[:auto_deploy_confidence_threshold] if args.key?(:auto_deploy_confidence_threshold)
  @auto_deploy_expiration_sec = args[:auto_deploy_expiration_sec] if args.key?(:auto_deploy_expiration_sec)
  @auto_deploy_impacted_baseline_threshold = args[:auto_deploy_impacted_baseline_threshold] if args.key?(:auto_deploy_impacted_baseline_threshold)
  @auto_deploy_load_threshold = args[:auto_deploy_load_threshold] if args.key?(:auto_deploy_load_threshold)
  @detection_absolute_qps = args[:detection_absolute_qps] if args.key?(:detection_absolute_qps)
  @detection_load_threshold = args[:detection_load_threshold] if args.key?(:detection_load_threshold)
  @detection_relative_to_baseline_qps = args[:detection_relative_to_baseline_qps] if args.key?(:detection_relative_to_baseline_qps)
  @name = args[:name] if args.key?(:name)
  @traffic_granularity_configs = args[:traffic_granularity_configs] if args.key?(:traffic_granularity_configs)
end