Class: Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#auto_deploy_confidence_threshold ⇒ Float
Corresponds to the JSON property
autoDeployConfidenceThreshold. -
#auto_deploy_expiration_sec ⇒ Fixnum
Corresponds to the JSON property
autoDeployExpirationSec. -
#auto_deploy_impacted_baseline_threshold ⇒ Float
Corresponds to the JSON property
autoDeployImpactedBaselineThreshold. -
#auto_deploy_load_threshold ⇒ Float
Corresponds to the JSON property
autoDeployLoadThreshold. -
#detection_absolute_qps ⇒ Float
Corresponds to the JSON property
detectionAbsoluteQps. -
#detection_load_threshold ⇒ Float
Corresponds to the JSON property
detectionLoadThreshold. -
#detection_relative_to_baseline_qps ⇒ Float
Corresponds to the JSON property
detectionRelativeToBaselineQps. -
#name ⇒ String
The name must be 1-63 characters long, and comply withRFC1035.
-
#traffic_granularity_configs ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>
Configuration options for enabling Adaptive Protection to operate on specified granular traffic units.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
constructor
A new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.
49803 49804 49805 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_deploy_confidence_threshold ⇒ Float
Corresponds to the JSON property autoDeployConfidenceThreshold
49759 49760 49761 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49759 def auto_deploy_confidence_threshold @auto_deploy_confidence_threshold end |
#auto_deploy_expiration_sec ⇒ Fixnum
Corresponds to the JSON property autoDeployExpirationSec
49764 49765 49766 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49764 def auto_deploy_expiration_sec @auto_deploy_expiration_sec end |
#auto_deploy_impacted_baseline_threshold ⇒ Float
Corresponds to the JSON property autoDeployImpactedBaselineThreshold
49769 49770 49771 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49769 def auto_deploy_impacted_baseline_threshold @auto_deploy_impacted_baseline_threshold end |
#auto_deploy_load_threshold ⇒ Float
Corresponds to the JSON property autoDeployLoadThreshold
49774 49775 49776 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49774 def auto_deploy_load_threshold @auto_deploy_load_threshold end |
#detection_absolute_qps ⇒ Float
Corresponds to the JSON property detectionAbsoluteQps
49779 49780 49781 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49779 def detection_absolute_qps @detection_absolute_qps end |
#detection_load_threshold ⇒ Float
Corresponds to the JSON property detectionLoadThreshold
49784 49785 49786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49784 def detection_load_threshold @detection_load_threshold end |
#detection_relative_to_baseline_qps ⇒ Float
Corresponds to the JSON property detectionRelativeToBaselineQps
49789 49790 49791 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49789 def detection_relative_to_baseline_qps @detection_relative_to_baseline_qps end |
#name ⇒ String
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the security policy.
Corresponds to the JSON property name
49795 49796 49797 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49795 def name @name end |
#traffic_granularity_configs ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>
Configuration options for enabling Adaptive Protection to operate
on specified granular traffic units.
Corresponds to the JSON property trafficGranularityConfigs
49801 49802 49803 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49801 def traffic_granularity_configs @traffic_granularity_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49808 49809 49810 49811 49812 49813 49814 49815 49816 49817 49818 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49808 def update!(**args) @auto_deploy_confidence_threshold = args[:auto_deploy_confidence_threshold] if args.key?(:auto_deploy_confidence_threshold) @auto_deploy_expiration_sec = args[:auto_deploy_expiration_sec] if args.key?(:auto_deploy_expiration_sec) @auto_deploy_impacted_baseline_threshold = args[:auto_deploy_impacted_baseline_threshold] if args.key?(:auto_deploy_impacted_baseline_threshold) @auto_deploy_load_threshold = args[:auto_deploy_load_threshold] if args.key?(:auto_deploy_load_threshold) @detection_absolute_qps = args[:detection_absolute_qps] if args.key?(:detection_absolute_qps) @detection_load_threshold = args[:detection_load_threshold] if args.key?(:detection_load_threshold) @detection_relative_to_baseline_qps = args[:detection_relative_to_baseline_qps] if args.key?(:detection_relative_to_baseline_qps) @name = args[:name] if args.key?(:name) @traffic_granularity_configs = args[:traffic_granularity_configs] if args.key?(:traffic_granularity_configs) end |