Class: Google::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdvancedOptionsConfig

Returns a new instance of SecurityPolicyAdvancedOptionsConfig.



56320
56321
56322
# File 'lib/google/apis/compute_v1/classes.rb', line 56320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#json_custom_configGoogle::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig

Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD. Corresponds to the JSON property jsonCustomConfig



56295
56296
56297
# File 'lib/google/apis/compute_v1/classes.rb', line 56295

def json_custom_config
  @json_custom_config
end

#json_parsingString

Corresponds to the JSON property jsonParsing

Returns:

  • (String)


56300
56301
56302
# File 'lib/google/apis/compute_v1/classes.rb', line 56300

def json_parsing
  @json_parsing
end

#log_levelString

Corresponds to the JSON property logLevel

Returns:

  • (String)


56305
56306
56307
# File 'lib/google/apis/compute_v1/classes.rb', line 56305

def log_level
  @log_level
end

#request_body_inspection_sizeString

The maximum request size chosen by the customer with Waf enabled. Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB". Values are case insensitive. Corresponds to the JSON property requestBodyInspectionSize

Returns:

  • (String)


56312
56313
56314
# File 'lib/google/apis/compute_v1/classes.rb', line 56312

def request_body_inspection_size
  @request_body_inspection_size
end

#user_ip_request_headersArray<String>

An optional list of case-insensitive request header names to use for resolving the callers client IP address. Corresponds to the JSON property userIpRequestHeaders

Returns:

  • (Array<String>)


56318
56319
56320
# File 'lib/google/apis/compute_v1/classes.rb', line 56318

def user_ip_request_headers
  @user_ip_request_headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56325
56326
56327
56328
56329
56330
56331
# File 'lib/google/apis/compute_v1/classes.rb', line 56325

def update!(**args)
  @json_custom_config = args[:json_custom_config] if args.key?(:json_custom_config)
  @json_parsing = args[:json_parsing] if args.key?(:json_parsing)
  @log_level = args[:log_level] if args.key?(:log_level)
  @request_body_inspection_size = args[:request_body_inspection_size] if args.key?(:request_body_inspection_size)
  @user_ip_request_headers = args[:user_ip_request_headers] if args.key?(:user_ip_request_headers)
end