Class: Google::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdvancedOptionsConfig

Returns a new instance of SecurityPolicyAdvancedOptionsConfig.



55522
55523
55524
# File 'lib/google/apis/compute_v1/classes.rb', line 55522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#json_custom_configGoogle::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig

Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD. Corresponds to the JSON property jsonCustomConfig



55497
55498
55499
# File 'lib/google/apis/compute_v1/classes.rb', line 55497

def json_custom_config
  @json_custom_config
end

#json_parsingString

Corresponds to the JSON property jsonParsing

Returns:

  • (String)


55502
55503
55504
# File 'lib/google/apis/compute_v1/classes.rb', line 55502

def json_parsing
  @json_parsing
end

#log_levelString

Corresponds to the JSON property logLevel

Returns:

  • (String)


55507
55508
55509
# File 'lib/google/apis/compute_v1/classes.rb', line 55507

def log_level
  @log_level
end

#request_body_inspection_sizeString

The maximum request size chosen by the customer with Waf enabled. Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB". Values are case insensitive. Corresponds to the JSON property requestBodyInspectionSize

Returns:

  • (String)


55514
55515
55516
# File 'lib/google/apis/compute_v1/classes.rb', line 55514

def request_body_inspection_size
  @request_body_inspection_size
end

#user_ip_request_headersArray<String>

An optional list of case-insensitive request header names to use for resolving the callers client IP address. Corresponds to the JSON property userIpRequestHeaders

Returns:

  • (Array<String>)


55520
55521
55522
# File 'lib/google/apis/compute_v1/classes.rb', line 55520

def user_ip_request_headers
  @user_ip_request_headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55527
55528
55529
55530
55531
55532
55533
# File 'lib/google/apis/compute_v1/classes.rb', line 55527

def update!(**args)
  @json_custom_config = args[:json_custom_config] if args.key?(:json_custom_config)
  @json_parsing = args[:json_parsing] if args.key?(:json_parsing)
  @log_level = args[:log_level] if args.key?(:log_level)
  @request_body_inspection_size = args[:request_body_inspection_size] if args.key?(:request_body_inspection_size)
  @user_ip_request_headers = args[:user_ip_request_headers] if args.key?(:user_ip_request_headers)
end