Class: Google::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#json_custom_config ⇒ Google::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Custom configuration to apply the JSON parsing.
-
#json_parsing ⇒ String
Corresponds to the JSON property
jsonParsing. -
#log_level ⇒ String
Corresponds to the JSON property
logLevel. -
#request_body_inspection_size ⇒ String
The maximum request size chosen by the customer with Waf enabled.
-
#user_ip_request_headers ⇒ Array<String>
An optional list of case-insensitive request header names to use for resolving the callers client IP address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdvancedOptionsConfig
constructor
A new instance of SecurityPolicyAdvancedOptionsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdvancedOptionsConfig
Returns a new instance of SecurityPolicyAdvancedOptionsConfig.
49889 49890 49891 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#json_custom_config ⇒ Google::Apis::ComputeV1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Custom configuration to apply the JSON parsing. Only applicable when
json_parsing is set to STANDARD.
Corresponds to the JSON property jsonCustomConfig
49864 49865 49866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49864 def json_custom_config @json_custom_config end |
#json_parsing ⇒ String
Corresponds to the JSON property jsonParsing
49869 49870 49871 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49869 def json_parsing @json_parsing end |
#log_level ⇒ String
Corresponds to the JSON property logLevel
49874 49875 49876 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49874 def log_level @log_level end |
#request_body_inspection_size ⇒ String
The maximum request size chosen by the customer with Waf enabled.
Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB".
Values are case insensitive.
Corresponds to the JSON property requestBodyInspectionSize
49881 49882 49883 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49881 def request_body_inspection_size @request_body_inspection_size end |
#user_ip_request_headers ⇒ Array<String>
An optional list of case-insensitive request header names to use for
resolving the callers client IP address.
Corresponds to the JSON property userIpRequestHeaders
49887 49888 49889 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49887 def user_ip_request_headers @user_ip_request_headers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49894 49895 49896 49897 49898 49899 49900 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49894 def update!(**args) @json_custom_config = args[:json_custom_config] if args.key?(:json_custom_config) @json_parsing = args[:json_parsing] if args.key?(:json_parsing) @log_level = args[:log_level] if args.key?(:log_level) @request_body_inspection_size = args[:request_body_inspection_size] if args.key?(:request_body_inspection_size) @user_ip_request_headers = args[:user_ip_request_headers] if args.key?(:user_ip_request_headers) end |