Class: Google::Apis::ComputeV1::SecurityPolicyAssociation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAssociation

Returns a new instance of SecurityPolicyAssociation.



55601
55602
55603
# File 'lib/google/apis/compute_v1/classes.rb', line 55601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_idString

The resource that the security policy is attached to. Corresponds to the JSON property attachmentId

Returns:

  • (String)


55567
55568
55569
# File 'lib/google/apis/compute_v1/classes.rb', line 55567

def attachment_id
  @attachment_id
end

#display_nameString

Output only. [Output Only] The display name of the security policy of the association. Corresponds to the JSON property displayName

Returns:

  • (String)


55573
55574
55575
# File 'lib/google/apis/compute_v1/classes.rb', line 55573

def display_name
  @display_name
end

#excluded_foldersArray<String>

A list of folders to exclude from the security policy. Corresponds to the JSON property excludedFolders

Returns:

  • (Array<String>)


55578
55579
55580
# File 'lib/google/apis/compute_v1/classes.rb', line 55578

def excluded_folders
  @excluded_folders
end

#excluded_projectsArray<String>

A list of projects to exclude from the security policy. Corresponds to the JSON property excludedProjects

Returns:

  • (Array<String>)


55583
55584
55585
# File 'lib/google/apis/compute_v1/classes.rb', line 55583

def excluded_projects
  @excluded_projects
end

#nameString

The name for an association. Corresponds to the JSON property name

Returns:

  • (String)


55588
55589
55590
# File 'lib/google/apis/compute_v1/classes.rb', line 55588

def name
  @name
end

#security_policy_idString

Output only. [Output Only] The security policy ID of the association. Corresponds to the JSON property securityPolicyId

Returns:

  • (String)


55593
55594
55595
# File 'lib/google/apis/compute_v1/classes.rb', line 55593

def security_policy_id
  @security_policy_id
end

#short_nameString

Output only. [Output Only] The short name of the security policy of the association. Corresponds to the JSON property shortName

Returns:

  • (String)


55599
55600
55601
# File 'lib/google/apis/compute_v1/classes.rb', line 55599

def short_name
  @short_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55606
55607
55608
55609
55610
55611
55612
55613
55614
# File 'lib/google/apis/compute_v1/classes.rb', line 55606

def update!(**args)
  @attachment_id = args[:attachment_id] if args.key?(:attachment_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @excluded_folders = args[:excluded_folders] if args.key?(:excluded_folders)
  @excluded_projects = args[:excluded_projects] if args.key?(:excluded_projects)
  @name = args[:name] if args.key?(:name)
  @security_policy_id = args[:security_policy_id] if args.key?(:security_policy_id)
  @short_name = args[:short_name] if args.key?(:short_name)
end