Class: Google::Apis::ComputeV1::SecurityPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyAssociation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#attachment_id ⇒ String
The resource that the security policy is attached to.
-
#display_name ⇒ String
Output only.
-
#excluded_folders ⇒ Array<String>
A list of folders to exclude from the security policy.
-
#excluded_projects ⇒ Array<String>
A list of projects to exclude from the security policy.
-
#name ⇒ String
The name for an association.
-
#security_policy_id ⇒ String
Output only.
-
#short_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAssociation
constructor
A new instance of SecurityPolicyAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAssociation
Returns a new instance of SecurityPolicyAssociation.
54934 54935 54936 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_id ⇒ String
The resource that the security policy is attached to.
Corresponds to the JSON property attachmentId
54900 54901 54902 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54900 def @attachment_id end |
#display_name ⇒ String
Output only. [Output Only] The display name of the security policy of the
association.
Corresponds to the JSON property displayName
54906 54907 54908 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54906 def display_name @display_name end |
#excluded_folders ⇒ Array<String>
A list of folders to exclude from the security policy.
Corresponds to the JSON property excludedFolders
54911 54912 54913 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54911 def excluded_folders @excluded_folders end |
#excluded_projects ⇒ Array<String>
A list of projects to exclude from the security policy.
Corresponds to the JSON property excludedProjects
54916 54917 54918 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54916 def excluded_projects @excluded_projects end |
#name ⇒ String
The name for an association.
Corresponds to the JSON property name
54921 54922 54923 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54921 def name @name end |
#security_policy_id ⇒ String
Output only. [Output Only] The security policy ID of the association.
Corresponds to the JSON property securityPolicyId
54926 54927 54928 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54926 def security_policy_id @security_policy_id end |
#short_name ⇒ String
Output only. [Output Only] The short name of the security policy of the
association.
Corresponds to the JSON property shortName
54932 54933 54934 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54932 def short_name @short_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54939 54940 54941 54942 54943 54944 54945 54946 54947 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54939 def update!(**args) @attachment_id = args[:attachment_id] if args.key?(:attachment_id) @display_name = args[:display_name] if args.key?(:display_name) @excluded_folders = args[:excluded_folders] if args.key?(:excluded_folders) @excluded_projects = args[:excluded_projects] if args.key?(:excluded_projects) @name = args[:name] if args.key?(:name) @security_policy_id = args[:security_policy_id] if args.key?(:security_policy_id) @short_name = args[:short_name] if args.key?(:short_name) end |