Class: Google::Apis::ComputeV1::SecurityPolicyAssociation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAssociation

Returns a new instance of SecurityPolicyAssociation.



49968
49969
49970
# File 'lib/google/apis/compute_v1/classes.rb', line 49968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_idString

The resource that the security policy is attached to. Corresponds to the JSON property attachmentId

Returns:

  • (String)


49934
49935
49936
# File 'lib/google/apis/compute_v1/classes.rb', line 49934

def attachment_id
  @attachment_id
end

#display_nameString

Output only. [Output Only] The display name of the security policy of the association. Corresponds to the JSON property displayName

Returns:

  • (String)


49940
49941
49942
# File 'lib/google/apis/compute_v1/classes.rb', line 49940

def display_name
  @display_name
end

#excluded_foldersArray<String>

A list of folders to exclude from the security policy. Corresponds to the JSON property excludedFolders

Returns:

  • (Array<String>)


49945
49946
49947
# File 'lib/google/apis/compute_v1/classes.rb', line 49945

def excluded_folders
  @excluded_folders
end

#excluded_projectsArray<String>

A list of projects to exclude from the security policy. Corresponds to the JSON property excludedProjects

Returns:

  • (Array<String>)


49950
49951
49952
# File 'lib/google/apis/compute_v1/classes.rb', line 49950

def excluded_projects
  @excluded_projects
end

#nameString

The name for an association. Corresponds to the JSON property name

Returns:

  • (String)


49955
49956
49957
# File 'lib/google/apis/compute_v1/classes.rb', line 49955

def name
  @name
end

#security_policy_idString

Output only. [Output Only] The security policy ID of the association. Corresponds to the JSON property securityPolicyId

Returns:

  • (String)


49960
49961
49962
# File 'lib/google/apis/compute_v1/classes.rb', line 49960

def security_policy_id
  @security_policy_id
end

#short_nameString

Output only. [Output Only] The short name of the security policy of the association. Corresponds to the JSON property shortName

Returns:

  • (String)


49966
49967
49968
# File 'lib/google/apis/compute_v1/classes.rb', line 49966

def short_name
  @short_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49973
49974
49975
49976
49977
49978
49979
49980
49981
# File 'lib/google/apis/compute_v1/classes.rb', line 49973

def update!(**args)
  @attachment_id = args[:attachment_id] if args.key?(:attachment_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @excluded_folders = args[:excluded_folders] if args.key?(:excluded_folders)
  @excluded_projects = args[:excluded_projects] if args.key?(:excluded_projects)
  @name = args[:name] if args.key?(:name)
  @security_policy_id = args[:security_policy_id] if args.key?(:security_policy_id)
  @short_name = args[:short_name] if args.key?(:short_name)
end