Class: Google::Apis::ComputeV1::SecurityPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyAssociation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#attachment_id ⇒ String
The resource that the security policy is attached to.
-
#display_name ⇒ String
Output only.
-
#excluded_folders ⇒ Array<String>
A list of folders to exclude from the security policy.
-
#excluded_projects ⇒ Array<String>
A list of projects to exclude from the security policy.
-
#name ⇒ String
The name for an association.
-
#security_policy_id ⇒ String
Output only.
-
#short_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAssociation
constructor
A new instance of SecurityPolicyAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAssociation
Returns a new instance of SecurityPolicyAssociation.
48781 48782 48783 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_id ⇒ String
The resource that the security policy is attached to.
Corresponds to the JSON property attachmentId
48747 48748 48749 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48747 def @attachment_id end |
#display_name ⇒ String
Output only. [Output Only] The display name of the security policy of the
association.
Corresponds to the JSON property displayName
48753 48754 48755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48753 def display_name @display_name end |
#excluded_folders ⇒ Array<String>
A list of folders to exclude from the security policy.
Corresponds to the JSON property excludedFolders
48758 48759 48760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48758 def excluded_folders @excluded_folders end |
#excluded_projects ⇒ Array<String>
A list of projects to exclude from the security policy.
Corresponds to the JSON property excludedProjects
48763 48764 48765 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48763 def excluded_projects @excluded_projects end |
#name ⇒ String
The name for an association.
Corresponds to the JSON property name
48768 48769 48770 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48768 def name @name end |
#security_policy_id ⇒ String
Output only. [Output Only] The security policy ID of the association.
Corresponds to the JSON property securityPolicyId
48773 48774 48775 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48773 def security_policy_id @security_policy_id end |
#short_name ⇒ String
Output only. [Output Only] The short name of the security policy of the
association.
Corresponds to the JSON property shortName
48779 48780 48781 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48779 def short_name @short_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48786 48787 48788 48789 48790 48791 48792 48793 48794 |
# File 'lib/google/apis/compute_v1/classes.rb', line 48786 def update!(**args) @attachment_id = args[:attachment_id] if args.key?(:attachment_id) @display_name = args[:display_name] if args.key?(:display_name) @excluded_folders = args[:excluded_folders] if args.key?(:excluded_folders) @excluded_projects = args[:excluded_projects] if args.key?(:excluded_projects) @name = args[:name] if args.key?(:name) @security_policy_id = args[:security_policy_id] if args.key?(:security_policy_id) @short_name = args[:short_name] if args.key?(:short_name) end |