Class: Google::Apis::ComputeV1::SecurityPolicyDdosProtectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyDdosProtectionConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#ddos_adaptive_protection ⇒ String
Corresponds to the JSON property
ddosAdaptiveProtection. -
#ddos_impacted_baseline_threshold ⇒ Float
DDoS Protection for Network Load Balancers (and VMs with public IPs) builds DDoS mitigations that minimize collateral damage.
-
#ddos_protection ⇒ String
Corresponds to the JSON property
ddosProtection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyDdosProtectionConfig
constructor
A new instance of SecurityPolicyDdosProtectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyDdosProtectionConfig
Returns a new instance of SecurityPolicyDdosProtectionConfig.
55661 55662 55663 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55661 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ddos_adaptive_protection ⇒ String
Corresponds to the JSON property ddosAdaptiveProtection
55636 55637 55638 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55636 def ddos_adaptive_protection @ddos_adaptive_protection end |
#ddos_impacted_baseline_threshold ⇒ Float
DDoS Protection for Network Load Balancers (and VMs with public IPs)
builds DDoS mitigations that minimize collateral damage. It quantifies
this as the fraction of a non-abuse baseline that's inadvertently
blocked.
Rules whose collateral damage exceeds ddosImpactedBaselineThreshold will
not be deployed. Using a lower value will prioritize keeping collateral
damage low, possibly at the cost of its effectiveness in rate limiting
some or all of the attack. It should typically be unset, so Advanced DDoS
(and Adaptive Protection) uses the best mitigation it can find. Setting
the threshold is advised if there are logs for false positive detections
with high collateral damage, and will cause Advanced DDoS to attempt to
find a less aggressive rule that satisfies the constraint. If a suitable
rule cannot be found, the system falls back to either no mitigation for
smaller attacks or broader network throttles for larger ones.
Corresponds to the JSON property ddosImpactedBaselineThreshold
55654 55655 55656 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55654 def ddos_impacted_baseline_threshold @ddos_impacted_baseline_threshold end |
#ddos_protection ⇒ String
Corresponds to the JSON property ddosProtection
55659 55660 55661 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55659 def ddos_protection @ddos_protection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55666 55667 55668 55669 55670 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55666 def update!(**args) @ddos_adaptive_protection = args[:ddos_adaptive_protection] if args.key?(:ddos_adaptive_protection) @ddos_impacted_baseline_threshold = args[:ddos_impacted_baseline_threshold] if args.key?(:ddos_impacted_baseline_threshold) @ddos_protection = args[:ddos_protection] if args.key?(:ddos_protection) end |