Class: Google::Apis::ComputeV1::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
56540 56541 56542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56512 56513 56514 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56512 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
56517 56518 56519 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56517 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
56523 56524 56525 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56523 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56533 56534 56535 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56533 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56538 56539 56540 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56538 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56545 56546 56547 56548 56549 56550 56551 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56545 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |