Class: Google::Apis::ComputeV1::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
56494 56495 56496 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56466 56467 56468 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56466 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
56471 56472 56473 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56471 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
56477 56478 56479 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56477 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56487 56488 56489 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56487 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56492 56493 56494 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56492 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56499 56500 56501 56502 56503 56504 56505 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56499 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |