Class: Google::Apis::ComputeV1::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeV1::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
55696 55697 55698 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55696 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55668 55669 55670 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55668 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
55673 55674 55675 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55673 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
55679 55680 55681 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55679 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55689 55690 55691 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55689 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeV1::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55694 55695 55696 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55694 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55701 55702 55703 55704 55705 55706 55707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55701 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |