Class: Google::Apis::ComputeV1::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



55334
55335
55336
# File 'lib/google/apis/compute_v1/classes.rb', line 55334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55306
55307
55308
# File 'lib/google/apis/compute_v1/classes.rb', line 55306

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



55311
55312
55313
# File 'lib/google/apis/compute_v1/classes.rb', line 55311

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


55317
55318
55319
# File 'lib/google/apis/compute_v1/classes.rb', line 55317

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55327
55328
55329
# File 'lib/google/apis/compute_v1/classes.rb', line 55327

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55332
55333
55334
# File 'lib/google/apis/compute_v1/classes.rb', line 55332

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55339
55340
55341
55342
55343
55344
55345
# File 'lib/google/apis/compute_v1/classes.rb', line 55339

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end