Class: Google::Apis::ComputeV1::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



48851
48852
48853
# File 'lib/google/apis/compute_v1/classes.rb', line 48851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48823
48824
48825
# File 'lib/google/apis/compute_v1/classes.rb', line 48823

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



48828
48829
48830
# File 'lib/google/apis/compute_v1/classes.rb', line 48828

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


48834
48835
48836
# File 'lib/google/apis/compute_v1/classes.rb', line 48834

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48844
48845
48846
# File 'lib/google/apis/compute_v1/classes.rb', line 48844

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48849
48850
48851
# File 'lib/google/apis/compute_v1/classes.rb', line 48849

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48856
48857
48858
48859
48860
48861
48862
# File 'lib/google/apis/compute_v1/classes.rb', line 48856

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end