Class: Google::Apis::ComputeV1::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



30887
30888
30889
# File 'lib/google/apis/compute_v1/classes.rb', line 30887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30860
30861
30862
# File 'lib/google/apis/compute_v1/classes.rb', line 30860

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



30865
30866
30867
# File 'lib/google/apis/compute_v1/classes.rb', line 30865

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


30871
30872
30873
# File 'lib/google/apis/compute_v1/classes.rb', line 30871

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30880
30881
30882
# File 'lib/google/apis/compute_v1/classes.rb', line 30880

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeV1::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30885
30886
30887
# File 'lib/google/apis/compute_v1/classes.rb', line 30885

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30892
30893
30894
30895
30896
30897
30898
# File 'lib/google/apis/compute_v1/classes.rb', line 30892

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end