Class: Google::Apis::ComputeV1::SecurityPolicyRecaptchaOptionsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyRecaptchaOptionsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#redirect_site_key ⇒ String
An optional field to supply a reCAPTCHA site key to be used for all the rules using the redirect action with the type of GOOGLE_RECAPTCHA under the security policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRecaptchaOptionsConfig
constructor
A new instance of SecurityPolicyRecaptchaOptionsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRecaptchaOptionsConfig
Returns a new instance of SecurityPolicyRecaptchaOptionsConfig.
50137 50138 50139 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#redirect_site_key ⇒ String
An optional field to supply a reCAPTCHA site key to be used for all the
rules using the redirect action with the type of GOOGLE_RECAPTCHA under
the security policy. The specified site key needs to be created from the
reCAPTCHA API. The user is responsible for the validity of the specified
site key. If not specified, a Google-managed site key is used.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
Corresponds to the JSON property redirectSiteKey
50135 50136 50137 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50135 def redirect_site_key @redirect_site_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50142 50143 50144 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50142 def update!(**args) @redirect_site_key = args[:redirect_site_key] if args.key?(:redirect_site_key) end |