Class: Google::Apis::ComputeV1::SecurityPolicyRuleMatcherExprOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyRuleMatcherExprOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#recaptcha_options ⇒ Google::Apis::ComputeV1::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
reCAPTCHA configuration options to be applied for the rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptions
constructor
A new instance of SecurityPolicyRuleMatcherExprOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptions
Returns a new instance of SecurityPolicyRuleMatcherExprOptions.
50426 50427 50428 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recaptcha_options ⇒ Google::Apis::ComputeV1::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
reCAPTCHA configuration options to be applied for the rule. If the
rule does not evaluate reCAPTCHA tokens, this field has no effect.
Corresponds to the JSON property recaptchaOptions
50424 50425 50426 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50424 def @recaptcha_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50431 50432 50433 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50431 def update!(**args) @recaptcha_options = args[:recaptcha_options] if args.key?(:recaptcha_options) end |