Class: Google::Apis::ComputeV1::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions

Returns a new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.



55752
55753
55754
# File 'lib/google/apis/compute_v1/classes.rb', line 55752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_token_site_keysArray<String>

A list of site keys to be used during the validation of reCAPTCHA action-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created. Corresponds to the JSON property actionTokenSiteKeys

Returns:

  • (Array<String>)


55742
55743
55744
# File 'lib/google/apis/compute_v1/classes.rb', line 55742

def action_token_site_keys
  @action_token_site_keys
end

#session_token_site_keysArray<String>

A list of site keys to be used during the validation of reCAPTCHA session-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created. Corresponds to the JSON property sessionTokenSiteKeys

Returns:

  • (Array<String>)


55750
55751
55752
# File 'lib/google/apis/compute_v1/classes.rb', line 55750

def session_token_site_keys
  @session_token_site_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55757
55758
55759
55760
# File 'lib/google/apis/compute_v1/classes.rb', line 55757

def update!(**args)
  @action_token_site_keys = args[:action_token_site_keys] if args.key?(:action_token_site_keys)
  @session_token_site_keys = args[:session_token_site_keys] if args.key?(:session_token_site_keys)
end