Class: Google::Apis::ComputeV1::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#action_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA action-tokens.
-
#session_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA session-tokens.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
constructor
A new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
Returns a new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.
49269 49270 49271 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49269 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA
action-tokens. The provided site keys need to be created from
reCAPTCHA API under the same project where the security policy is
created.
Corresponds to the JSON property actionTokenSiteKeys
49259 49260 49261 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49259 def action_token_site_keys @action_token_site_keys end |
#session_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA
session-tokens. The provided site keys need to be created from
reCAPTCHA API under the same project where the security policy is
created.
Corresponds to the JSON property sessionTokenSiteKeys
49267 49268 49269 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49267 def session_token_site_keys @session_token_site_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49274 49275 49276 49277 |
# File 'lib/google/apis/compute_v1/classes.rb', line 49274 def update!(**args) @action_token_site_keys = args[:action_token_site_keys] if args.key?(:action_token_site_keys) @session_token_site_keys = args[:session_token_site_keys] if args.key?(:session_token_site_keys) end |