Class: Google::Apis::ComputeV1::SecurityPolicyRuleNetworkMatcher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a match condition that incoming network traffic is evaluated against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleNetworkMatcher

Returns a new instance of SecurityPolicyRuleNetworkMatcher.



55472
55473
55474
# File 'lib/google/apis/compute_v1/classes.rb', line 55472

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_ip_rangesArray<String>

Destination IPv4/IPv6 addresses or CIDR prefixes, in standard text format. Corresponds to the JSON property destIpRanges

Returns:

  • (Array<String>)


55428
55429
55430
# File 'lib/google/apis/compute_v1/classes.rb', line 55428

def dest_ip_ranges
  @dest_ip_ranges
end

#dest_portsArray<String>

Destination port numbers for TCP/UDP/SCTP. Each element can be a 16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023"). Corresponds to the JSON property destPorts

Returns:

  • (Array<String>)


55434
55435
55436
# File 'lib/google/apis/compute_v1/classes.rb', line 55434

def dest_ports
  @dest_ports
end

#ip_protocolsArray<String>

IPv4 protocol / IPv6 next header (after extension headers). Each element can be an 8-bit unsigned decimal number (e.g. "6"), range (e.g. "253-254"), or one of the following protocol names: "tcp", "udp", "icmp", "esp", "ah", "ipip", or "sctp". Corresponds to the JSON property ipProtocols

Returns:

  • (Array<String>)


55442
55443
55444
# File 'lib/google/apis/compute_v1/classes.rb', line 55442

def ip_protocols
  @ip_protocols
end

#src_asnsArray<Fixnum>

BGP Autonomous System Number associated with the source IP address. Corresponds to the JSON property srcAsns

Returns:

  • (Array<Fixnum>)


55447
55448
55449
# File 'lib/google/apis/compute_v1/classes.rb', line 55447

def src_asns
  @src_asns
end

#src_ip_rangesArray<String>

Source IPv4/IPv6 addresses or CIDR prefixes, in standard text format. Corresponds to the JSON property srcIpRanges

Returns:

  • (Array<String>)


55452
55453
55454
# File 'lib/google/apis/compute_v1/classes.rb', line 55452

def src_ip_ranges
  @src_ip_ranges
end

#src_portsArray<String>

Source port numbers for TCP/UDP/SCTP. Each element can be a 16-bit unsigned decimal number (e.g. "80") or range (e.g. "0-1023"). Corresponds to the JSON property srcPorts

Returns:

  • (Array<String>)


55458
55459
55460
# File 'lib/google/apis/compute_v1/classes.rb', line 55458

def src_ports
  @src_ports
end

#src_region_codesArray<String>

Two-letter ISO 3166-1 alpha-2 country code associated with the source IP address. Corresponds to the JSON property srcRegionCodes

Returns:

  • (Array<String>)


55464
55465
55466
# File 'lib/google/apis/compute_v1/classes.rb', line 55464

def src_region_codes
  @src_region_codes
end

#user_defined_fieldsArray<Google::Apis::ComputeV1::SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>

User-defined fields. Each element names a defined field and lists the matching values for that field. Corresponds to the JSON property userDefinedFields



55470
55471
55472
# File 'lib/google/apis/compute_v1/classes.rb', line 55470

def user_defined_fields
  @user_defined_fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55477
55478
55479
55480
55481
55482
55483
55484
55485
55486
# File 'lib/google/apis/compute_v1/classes.rb', line 55477

def update!(**args)
  @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges)
  @dest_ports = args[:dest_ports] if args.key?(:dest_ports)
  @ip_protocols = args[:ip_protocols] if args.key?(:ip_protocols)
  @src_asns = args[:src_asns] if args.key?(:src_asns)
  @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges)
  @src_ports = args[:src_ports] if args.key?(:src_ports)
  @src_region_codes = args[:src_region_codes] if args.key?(:src_region_codes)
  @user_defined_fields = args[:user_defined_fields] if args.key?(:user_defined_fields)
end