Class: Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion

Returns a new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.



56283
56284
56285
# File 'lib/google/apis/compute_v1/classes.rb', line 56283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_cookies_to_excludeArray<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>

A list of request cookie names whose value will be excluded from inspection during preconfigured WAF evaluation. Corresponds to the JSON property requestCookiesToExclude



56249
56250
56251
# File 'lib/google/apis/compute_v1/classes.rb', line 56249

def request_cookies_to_exclude
  @request_cookies_to_exclude
end

#request_headers_to_excludeArray<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>

A list of request header names whose value will be excluded from inspection during preconfigured WAF evaluation. Corresponds to the JSON property requestHeadersToExclude



56255
56256
56257
# File 'lib/google/apis/compute_v1/classes.rb', line 56255

def request_headers_to_exclude
  @request_headers_to_exclude
end

#request_query_params_to_excludeArray<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>

A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation. Note that the parameter can be in the query string or in the POST body. Corresponds to the JSON property requestQueryParamsToExclude



56262
56263
56264
# File 'lib/google/apis/compute_v1/classes.rb', line 56262

def request_query_params_to_exclude
  @request_query_params_to_exclude
end

#request_uris_to_excludeArray<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>

A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation. When specifying this field, the query or fragment part should be excluded. Corresponds to the JSON property requestUrisToExclude



56269
56270
56271
# File 'lib/google/apis/compute_v1/classes.rb', line 56269

def request_uris_to_exclude
  @request_uris_to_exclude
end

#target_rule_idsArray<String>

A list of target rule IDs under the WAF rule set to apply the preconfigured WAF exclusion. If omitted, it refers to all the rule IDs under the WAF rule set. Corresponds to the JSON property targetRuleIds

Returns:

  • (Array<String>)


56276
56277
56278
# File 'lib/google/apis/compute_v1/classes.rb', line 56276

def target_rule_ids
  @target_rule_ids
end

#target_rule_setString

Target WAF rule set to apply the preconfigured WAF exclusion. Corresponds to the JSON property targetRuleSet

Returns:

  • (String)


56281
56282
56283
# File 'lib/google/apis/compute_v1/classes.rb', line 56281

def target_rule_set
  @target_rule_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56288
56289
56290
56291
56292
56293
56294
56295
# File 'lib/google/apis/compute_v1/classes.rb', line 56288

def update!(**args)
  @request_cookies_to_exclude = args[:request_cookies_to_exclude] if args.key?(:request_cookies_to_exclude)
  @request_headers_to_exclude = args[:request_headers_to_exclude] if args.key?(:request_headers_to_exclude)
  @request_query_params_to_exclude = args[:request_query_params_to_exclude] if args.key?(:request_query_params_to_exclude)
  @request_uris_to_exclude = args[:request_uris_to_exclude] if args.key?(:request_uris_to_exclude)
  @target_rule_ids = args[:target_rule_ids] if args.key?(:target_rule_ids)
  @target_rule_set = args[:target_rule_set] if args.key?(:target_rule_set)
end