Class: Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#request_cookies_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request cookie names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_headers_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request header names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_query_params_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_uris_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation.
-
#target_rule_ids ⇒ Array<String>
A list of target rule IDs under the WAF rule set to apply the preconfigured WAF exclusion.
-
#target_rule_set ⇒ String
Target WAF rule set to apply the preconfigured WAF exclusion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion
constructor
A new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion
Returns a new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.
55591 55592 55593 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_cookies_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request cookie names whose value will be excluded from
inspection during preconfigured WAF evaluation.
Corresponds to the JSON property requestCookiesToExclude
55557 55558 55559 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55557 def @request_cookies_to_exclude end |
#request_headers_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request header names whose value will be excluded from
inspection during preconfigured WAF evaluation.
Corresponds to the JSON property requestHeadersToExclude
55563 55564 55565 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55563 def request_headers_to_exclude @request_headers_to_exclude end |
#request_query_params_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request query parameter names whose value will be excluded
from inspection during preconfigured WAF evaluation. Note that the
parameter can be in the query string or in the POST body.
Corresponds to the JSON property requestQueryParamsToExclude
55570 55571 55572 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55570 def request_query_params_to_exclude @request_query_params_to_exclude end |
#request_uris_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request URIs from the request line to be excluded from
inspection during preconfigured WAF evaluation. When specifying this
field, the query or fragment part should be excluded.
Corresponds to the JSON property requestUrisToExclude
55577 55578 55579 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55577 def request_uris_to_exclude @request_uris_to_exclude end |
#target_rule_ids ⇒ Array<String>
A list of target rule IDs under the WAF rule set to apply the
preconfigured WAF exclusion. If omitted, it refers to all the rule
IDs under the WAF rule set.
Corresponds to the JSON property targetRuleIds
55584 55585 55586 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55584 def target_rule_ids @target_rule_ids end |
#target_rule_set ⇒ String
Target WAF rule set to apply the preconfigured WAF exclusion.
Corresponds to the JSON property targetRuleSet
55589 55590 55591 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55589 def target_rule_set @target_rule_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55596 55597 55598 55599 55600 55601 55602 55603 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55596 def update!(**args) @request_cookies_to_exclude = args[:request_cookies_to_exclude] if args.key?(:request_cookies_to_exclude) @request_headers_to_exclude = args[:request_headers_to_exclude] if args.key?(:request_headers_to_exclude) @request_query_params_to_exclude = args[:request_query_params_to_exclude] if args.key?(:request_query_params_to_exclude) @request_uris_to_exclude = args[:request_uris_to_exclude] if args.key?(:request_uris_to_exclude) @target_rule_ids = args[:target_rule_ids] if args.key?(:target_rule_ids) @target_rule_set = args[:target_rule_set] if args.key?(:target_rule_set) end |