Class: Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#request_cookies_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request cookie names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_headers_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request header names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_query_params_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_uris_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation.
-
#target_rule_ids ⇒ Array<String>
A list of target rule IDs under the WAF rule set to apply the preconfigured WAF exclusion.
-
#target_rule_set ⇒ String
Target WAF rule set to apply the preconfigured WAF exclusion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion
constructor
A new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion
Returns a new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.
50625 50626 50627 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_cookies_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request cookie names whose value will be excluded from
inspection during preconfigured WAF evaluation.
Corresponds to the JSON property requestCookiesToExclude
50591 50592 50593 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50591 def @request_cookies_to_exclude end |
#request_headers_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request header names whose value will be excluded from
inspection during preconfigured WAF evaluation.
Corresponds to the JSON property requestHeadersToExclude
50597 50598 50599 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50597 def request_headers_to_exclude @request_headers_to_exclude end |
#request_query_params_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request query parameter names whose value will be excluded
from inspection during preconfigured WAF evaluation. Note that the
parameter can be in the query string or in the POST body.
Corresponds to the JSON property requestQueryParamsToExclude
50604 50605 50606 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50604 def request_query_params_to_exclude @request_query_params_to_exclude end |
#request_uris_to_exclude ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request URIs from the request line to be excluded from
inspection during preconfigured WAF evaluation. When specifying this
field, the query or fragment part should be excluded.
Corresponds to the JSON property requestUrisToExclude
50611 50612 50613 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50611 def request_uris_to_exclude @request_uris_to_exclude end |
#target_rule_ids ⇒ Array<String>
A list of target rule IDs under the WAF rule set to apply the
preconfigured WAF exclusion. If omitted, it refers to all the rule
IDs under the WAF rule set.
Corresponds to the JSON property targetRuleIds
50618 50619 50620 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50618 def target_rule_ids @target_rule_ids end |
#target_rule_set ⇒ String
Target WAF rule set to apply the preconfigured WAF exclusion.
Corresponds to the JSON property targetRuleSet
50623 50624 50625 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50623 def target_rule_set @target_rule_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50630 50631 50632 50633 50634 50635 50636 50637 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50630 def update!(**args) @request_cookies_to_exclude = args[:request_cookies_to_exclude] if args.key?(:request_cookies_to_exclude) @request_headers_to_exclude = args[:request_headers_to_exclude] if args.key?(:request_headers_to_exclude) @request_query_params_to_exclude = args[:request_query_params_to_exclude] if args.key?(:request_query_params_to_exclude) @request_uris_to_exclude = args[:request_uris_to_exclude] if args.key?(:request_uris_to_exclude) @target_rule_ids = args[:target_rule_ids] if args.key?(:target_rule_ids) @target_rule_set = args[:target_rule_set] if args.key?(:target_rule_set) end |