Class: Google::Apis::ComputeV1::SecurityPolicyRuleRateLimitOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SecurityPolicyRuleRateLimitOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#ban_duration_sec ⇒ Fixnum
Can only be specified if the action for the rule is "rate_based_ban".
-
#ban_threshold ⇒ Google::Apis::ComputeV1::SecurityPolicyRuleRateLimitOptionsThreshold
Can only be specified if the action for the rule is "rate_based_ban".
-
#conform_action ⇒ String
Action to take for requests that are under the configured rate limit threshold.
-
#enforce_on_key ⇒ String
Determines the key to enforce the rate_limit_threshold on.
-
#enforce_on_key_configs ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig>
If specified, any combination of values of enforce_on_key_type/enforce_on_key_name is treated as the key on which ratelimit threshold/action is enforced.
-
#enforce_on_key_name ⇒ String
Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value.
-
#exceed_action ⇒ String
Action to take for requests that are above the configured rate limit threshold, to either deny with a specified HTTP response code, or redirect to a different endpoint.
-
#exceed_redirect_options ⇒ Google::Apis::ComputeV1::SecurityPolicyRuleRedirectOptions
Parameters defining the redirect action that is used as the exceed action.
-
#rate_limit_threshold ⇒ Google::Apis::ComputeV1::SecurityPolicyRuleRateLimitOptionsThreshold
Threshold at which to begin ratelimiting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleRateLimitOptions
constructor
A new instance of SecurityPolicyRuleRateLimitOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleRateLimitOptions
Returns a new instance of SecurityPolicyRuleRateLimitOptions.
54237 54238 54239 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ban_duration_sec ⇒ Fixnum
Can only be specified if the action for the rule is
"rate_based_ban". If specified, determines the time (in seconds)
the traffic will continue to be banned by the rate limit after the
rate falls below the threshold.
Corresponds to the JSON property banDurationSec
54132 54133 54134 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54132 def ban_duration_sec @ban_duration_sec end |
#ban_threshold ⇒ Google::Apis::ComputeV1::SecurityPolicyRuleRateLimitOptionsThreshold
Can only be specified if the action for the rule is
"rate_based_ban". If specified, the key will be banned for the
configured 'ban_duration_sec' when the number of requests that exceed
the 'rate_limit_threshold' also exceed this 'ban_threshold'.
Corresponds to the JSON property banThreshold
54140 54141 54142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54140 def ban_threshold @ban_threshold end |
#conform_action ⇒ String
Action to take for requests that are under the configured rate limit
threshold. Valid option is "allow" only.
Corresponds to the JSON property conformAction
54146 54147 54148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54146 def conform_action @conform_action end |
#enforce_on_key ⇒ String
Determines the key to enforce the rate_limit_threshold on. Possible values are:
- ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKey" is not configured.
- IP: The source IP address of the request is the key. Each IP has this limit enforced separately.
- HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults toALL.
- XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP.
- HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults toALL.
- HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes.
- SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session.
- REGION_CODE: The country/region from which the request originates.
- TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.
- USER_IP: The IP address of the originating client, which is resolved based on "userIpRequestHeaders" configured with the security policy. If there is no "userIpRequestHeaders" configuration or an IP address cannot be resolved from it, the key type defaults toIP.
- TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the
client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
key type defaults to ALL.
For "fairshare" action, this value is limited to ALL i.e. a single rate
limit threshold is enforced for all the requests matching the rule.
Corresponds to the JSON property
enforceOnKey
54191 54192 54193 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54191 def enforce_on_key @enforce_on_key end |
#enforce_on_key_configs ⇒ Array<Google::Apis::ComputeV1::SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig>
If specified, any combination of values of
enforce_on_key_type/enforce_on_key_name is treated as the key on which
ratelimit threshold/action is enforced. You can specify up to 3
enforce_on_key_configs. If enforce_on_key_configs is specified,
enforce_on_key must not be specified.
Corresponds to the JSON property enforceOnKeyConfigs
54200 54201 54202 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54200 def enforce_on_key_configs @enforce_on_key_configs end |
#enforce_on_key_name ⇒ String
Rate limit key name applicable only for the following key types:
HTTP_HEADER -- Name of the HTTP header whose value is taken as the key
value.
HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key
value.
Corresponds to the JSON property enforceOnKeyName
54209 54210 54211 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54209 def enforce_on_key_name @enforce_on_key_name end |
#exceed_action ⇒ String
Action to take for requests that are above the configured rate limit
threshold, to either deny with a specified HTTP response code, or
redirect to a different endpoint.
Valid options are deny(STATUS), where valid values for
STATUS are 403, 404, 429, and 502, and
redirect, where the redirect parameters come from
exceedRedirectOptions below.
The redirect action is only supported in Global Security Policies of
type CLOUD_ARMOR.
Corresponds to the JSON property exceedAction
54222 54223 54224 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54222 def exceed_action @exceed_action end |
#exceed_redirect_options ⇒ Google::Apis::ComputeV1::SecurityPolicyRuleRedirectOptions
Parameters defining the redirect action that is used as the exceed
action. Cannot be specified if the exceed action is not redirect.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
Corresponds to the JSON property exceedRedirectOptions
54230 54231 54232 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54230 def @exceed_redirect_options end |
#rate_limit_threshold ⇒ Google::Apis::ComputeV1::SecurityPolicyRuleRateLimitOptionsThreshold
Threshold at which to begin ratelimiting.
Corresponds to the JSON property rateLimitThreshold
54235 54236 54237 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54235 def rate_limit_threshold @rate_limit_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54242 54243 54244 54245 54246 54247 54248 54249 54250 54251 54252 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54242 def update!(**args) @ban_duration_sec = args[:ban_duration_sec] if args.key?(:ban_duration_sec) @ban_threshold = args[:ban_threshold] if args.key?(:ban_threshold) @conform_action = args[:conform_action] if args.key?(:conform_action) @enforce_on_key = args[:enforce_on_key] if args.key?(:enforce_on_key) @enforce_on_key_configs = args[:enforce_on_key_configs] if args.key?(:enforce_on_key_configs) @enforce_on_key_name = args[:enforce_on_key_name] if args.key?(:enforce_on_key_name) @exceed_action = args[:exceed_action] if args.key?(:exceed_action) @exceed_redirect_options = args[:exceed_redirect_options] if args.key?(:exceed_redirect_options) @rate_limit_threshold = args[:rate_limit_threshold] if args.key?(:rate_limit_threshold) end |