Class: Google::Apis::ComputeV1::SecurityPolicyUserDefinedField

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyUserDefinedField

Returns a new instance of SecurityPolicyUserDefinedField.



56259
56260
56261
# File 'lib/google/apis/compute_v1/classes.rb', line 56259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#baseString

The base relative to which 'offset' is measured. Possible values are:

  • IPV4: Points to the beginning of the IPv4 header.
  • IPV6: Points to the beginning of the IPv6 header.
  • TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
  • UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments. required Corresponds to the JSON property base

Returns:

  • (String)


56233
56234
56235
# File 'lib/google/apis/compute_v1/classes.rb', line 56233

def base
  @base
end

#maskString

If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask. Corresponds to the JSON property mask

Returns:

  • (String)


56241
56242
56243
# File 'lib/google/apis/compute_v1/classes.rb', line 56241

def mask
  @mask
end

#nameString

The name of this field. Must be unique within the policy. Corresponds to the JSON property name

Returns:

  • (String)


56246
56247
56248
# File 'lib/google/apis/compute_v1/classes.rb', line 56246

def name
  @name
end

#offsetFixnum

Offset of the first byte of the field (in network byte order) relative to 'base'. Corresponds to the JSON property offset

Returns:

  • (Fixnum)


56252
56253
56254
# File 'lib/google/apis/compute_v1/classes.rb', line 56252

def offset
  @offset
end

#sizeFixnum

Size of the field in bytes. Valid values: 1-4. Corresponds to the JSON property size

Returns:

  • (Fixnum)


56257
56258
56259
# File 'lib/google/apis/compute_v1/classes.rb', line 56257

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56264
56265
56266
56267
56268
56269
56270
# File 'lib/google/apis/compute_v1/classes.rb', line 56264

def update!(**args)
  @base = args[:base] if args.key?(:base)
  @mask = args[:mask] if args.key?(:mask)
  @name = args[:name] if args.key?(:name)
  @offset = args[:offset] if args.key?(:offset)
  @size = args[:size] if args.key?(:size)
end