Class: Google::Apis::ComputeV1::SecurityPolicyUserDefinedField

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyUserDefinedField

Returns a new instance of SecurityPolicyUserDefinedField.



55929
55930
55931
# File 'lib/google/apis/compute_v1/classes.rb', line 55929

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#baseString

The base relative to which 'offset' is measured. Possible values are:

  • IPV4: Points to the beginning of the IPv4 header.
  • IPV6: Points to the beginning of the IPv6 header.
  • TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
  • UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments. required Corresponds to the JSON property base

Returns:

  • (String)


55903
55904
55905
# File 'lib/google/apis/compute_v1/classes.rb', line 55903

def base
  @base
end

#maskString

If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask. Corresponds to the JSON property mask

Returns:

  • (String)


55911
55912
55913
# File 'lib/google/apis/compute_v1/classes.rb', line 55911

def mask
  @mask
end

#nameString

The name of this field. Must be unique within the policy. Corresponds to the JSON property name

Returns:

  • (String)


55916
55917
55918
# File 'lib/google/apis/compute_v1/classes.rb', line 55916

def name
  @name
end

#offsetFixnum

Offset of the first byte of the field (in network byte order) relative to 'base'. Corresponds to the JSON property offset

Returns:

  • (Fixnum)


55922
55923
55924
# File 'lib/google/apis/compute_v1/classes.rb', line 55922

def offset
  @offset
end

#sizeFixnum

Size of the field in bytes. Valid values: 1-4. Corresponds to the JSON property size

Returns:

  • (Fixnum)


55927
55928
55929
# File 'lib/google/apis/compute_v1/classes.rb', line 55927

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55934
55935
55936
55937
55938
55939
55940
# File 'lib/google/apis/compute_v1/classes.rb', line 55934

def update!(**args)
  @base = args[:base] if args.key?(:base)
  @mask = args[:mask] if args.key?(:mask)
  @name = args[:name] if args.key?(:name)
  @offset = args[:offset] if args.key?(:offset)
  @size = args[:size] if args.key?(:size)
end