Class: Google::Apis::ComputeV1::SecurityPolicyUserDefinedField

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyUserDefinedField

Returns a new instance of SecurityPolicyUserDefinedField.



49776
49777
49778
# File 'lib/google/apis/compute_v1/classes.rb', line 49776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#baseString

The base relative to which 'offset' is measured. Possible values are:

  • IPV4: Points to the beginning of the IPv4 header.
  • IPV6: Points to the beginning of the IPv6 header.
  • TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
  • UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments. required Corresponds to the JSON property base

Returns:

  • (String)


49750
49751
49752
# File 'lib/google/apis/compute_v1/classes.rb', line 49750

def base
  @base
end

#maskString

If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask. Corresponds to the JSON property mask

Returns:

  • (String)


49758
49759
49760
# File 'lib/google/apis/compute_v1/classes.rb', line 49758

def mask
  @mask
end

#nameString

The name of this field. Must be unique within the policy. Corresponds to the JSON property name

Returns:

  • (String)


49763
49764
49765
# File 'lib/google/apis/compute_v1/classes.rb', line 49763

def name
  @name
end

#offsetFixnum

Offset of the first byte of the field (in network byte order) relative to 'base'. Corresponds to the JSON property offset

Returns:

  • (Fixnum)


49769
49770
49771
# File 'lib/google/apis/compute_v1/classes.rb', line 49769

def offset
  @offset
end

#sizeFixnum

Size of the field in bytes. Valid values: 1-4. Corresponds to the JSON property size

Returns:

  • (Fixnum)


49774
49775
49776
# File 'lib/google/apis/compute_v1/classes.rb', line 49774

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49781
49782
49783
49784
49785
49786
49787
# File 'lib/google/apis/compute_v1/classes.rb', line 49781

def update!(**args)
  @base = args[:base] if args.key?(:base)
  @mask = args[:mask] if args.key?(:mask)
  @name = args[:name] if args.key?(:name)
  @offset = args[:offset] if args.key?(:offset)
  @size = args[:size] if args.key?(:size)
end