Class: Google::Apis::ComputeV1::SecuritySettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The authentication and authorization settings for a BackendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecuritySettings

Returns a new instance of SecuritySettings.



54477
54478
54479
# File 'lib/google/apis/compute_v1/classes.rb', line 54477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aws_v4_authenticationGoogle::Apis::ComputeV1::Awsv4Signature

Contains the configurations necessary to generate a signature for access to private storage buckets that support Signature Version 4 for authentication. The service name for generating the authentication header will always default to 's3'. Corresponds to the JSON property awsV4Authentication



54444
54445
54446
# File 'lib/google/apis/compute_v1/classes.rb', line 54444

def aws_v4_authentication
  @aws_v4_authentication
end

#client_tls_policyString

Optional. A URL referring to a networksecurity.ClientTlsPolicy resource that describes how clients should authenticate with this service's backends. clientTlsPolicy only applies to a globalBackendService with the loadBalancingScheme set to INTERNAL_SELF_MANAGED. If left blank, communications are not encrypted. Corresponds to the JSON property clientTlsPolicy

Returns:

  • (String)


54455
54456
54457
# File 'lib/google/apis/compute_v1/classes.rb', line 54455

def client_tls_policy
  @client_tls_policy
end

#subject_alt_namesArray<String>

Optional. A list of Subject Alternative Names (SANs) that the client verifies during a mutual TLS handshake with an server/endpoint for thisBackendService. When the server presents its X.509 certificate to the client, the client inspects the certificate'ssubjectAltName field. If the field contains one of the specified values, the communication continues. Otherwise, it fails. This additional check enables the client to verify that the server is authorized to run the requested service. Note that the contents of the server certificate's subjectAltName field are configured by the Public Key Infrastructure which provisions server identities. Only applies to a global BackendService withloadBalancingScheme set to INTERNAL_SELF_MANAGED. Only applies when BackendService has an attachedclientTlsPolicy with clientCertificate (mTLS mode). Corresponds to the JSON property subjectAltNames

Returns:

  • (Array<String>)


54475
54476
54477
# File 'lib/google/apis/compute_v1/classes.rb', line 54475

def subject_alt_names
  @subject_alt_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54482
54483
54484
54485
54486
# File 'lib/google/apis/compute_v1/classes.rb', line 54482

def update!(**args)
  @aws_v4_authentication = args[:aws_v4_authentication] if args.key?(:aws_v4_authentication)
  @client_tls_policy = args[:client_tls_policy] if args.key?(:client_tls_policy)
  @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names)
end