Class: Google::Apis::ComputeV1::SerialPortOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

An instance serial console output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SerialPortOutput

Returns a new instance of SerialPortOutput.



51070
51071
51072
# File 'lib/google/apis/compute_v1/classes.rb', line 51070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

[Output Only] The contents of the console output. Corresponds to the JSON property contents

Returns:

  • (String)


51039
51040
51041
# File 'lib/google/apis/compute_v1/classes.rb', line 51039

def contents
  @contents
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serialPortOutput for serial port output. Corresponds to the JSON property kind

Returns:

  • (String)


51045
51046
51047
# File 'lib/google/apis/compute_v1/classes.rb', line 51045

def kind
  @kind
end

#nextFixnum

[Output Only] The position of the next byte of content, regardless of whether the content exists, following the output returned in the contents property. Use this value in the next request as the start parameter. Corresponds to the JSON property next

Returns:

  • (Fixnum)


51053
51054
51055
# File 'lib/google/apis/compute_v1/classes.rb', line 51053

def next
  @next
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51058
51059
51060
# File 'lib/google/apis/compute_v1/classes.rb', line 51058

def self_link
  @self_link
end

#startFixnum

The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer (1 MB), older output is overwritten by newer content. The output start value will indicate the byte position of the output that was returned, which might be different than the start value that was specified in the request. Corresponds to the JSON property start

Returns:

  • (Fixnum)


51068
51069
51070
# File 'lib/google/apis/compute_v1/classes.rb', line 51068

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51075
51076
51077
51078
51079
51080
51081
# File 'lib/google/apis/compute_v1/classes.rb', line 51075

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @kind = args[:kind] if args.key?(:kind)
  @next = args[:next] if args.key?(:next)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start = args[:start] if args.key?(:start)
end