Class: Google::Apis::ComputeV1::SerialPortOutput
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SerialPortOutput
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
An instance serial console output.
Instance Attribute Summary collapse
-
#contents ⇒ String
[Output Only] The contents of the console output.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#next ⇒ Fixnum
[Output Only] The position of the next byte of content, regardless of whether the content exists, following the output returned in the
contentsproperty. -
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#start ⇒ Fixnum
The starting byte position of the output that was returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SerialPortOutput
constructor
A new instance of SerialPortOutput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SerialPortOutput
Returns a new instance of SerialPortOutput.
31424 31425 31426 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
[Output Only] The contents of the console output.
Corresponds to the JSON property contents
31394 31395 31396 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31394 def contents @contents end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#serialPortOutput for serial
port output.
Corresponds to the JSON property kind
31400 31401 31402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31400 def kind @kind end |
#next ⇒ Fixnum
[Output Only] The position of the next byte of content, regardless of whether
the content exists, following the output returned in the contents property.
Use this value in the next request as the start parameter.
Corresponds to the JSON property next
31407 31408 31409 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31407 def next @next end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
31412 31413 31414 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31412 def self_link @self_link end |
#start ⇒ Fixnum
The starting byte position of the output that was returned. This should match
the start parameter sent with the request. If the serial console output
exceeds the size of the buffer (1 MB), older output is overwritten by newer
content. The output start value will indicate the byte position of the output
that was returned, which might be different than the start value that was
specified in the request.
Corresponds to the JSON property start
31422 31423 31424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31422 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31429 31430 31431 31432 31433 31434 31435 |
# File 'lib/google/apis/compute_v1/classes.rb', line 31429 def update!(**args) @contents = args[:contents] if args.key?(:contents) @kind = args[:kind] if args.key?(:kind) @next = args[:next] if args.key?(:next) @self_link = args[:self_link] if args.key?(:self_link) @start = args[:start] if args.key?(:start) end |