Class: Google::Apis::ComputeV1::ServiceAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a ServiceAttachment resource. A service attachment represents a service that a producer has exposed. It encapsulates the load balancer which fronts the service runs and a list of NAT IP ranges that the producers uses to represent the consumers connecting to the service. next tag = 20

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachment

Returns a new instance of ServiceAttachment.



31607
31608
31609
# File 'lib/google/apis/compute_v1/classes.rb', line 31607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_endpointsArray<Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint>

[Output Only] An array of connections for all the consumers connected to this service attachment. Corresponds to the JSON property connectedEndpoints



31493
31494
31495
# File 'lib/google/apis/compute_v1/classes.rb', line 31493

def connected_endpoints
  @connected_endpoints
end

#connection_preferenceString

The connection preference of service attachment. The value can be set to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service attachment is one that always accepts the connection from consumer forwarding rules. Corresponds to the JSON property connectionPreference

Returns:

  • (String)


31500
31501
31502
# File 'lib/google/apis/compute_v1/classes.rb', line 31500

def connection_preference
  @connection_preference
end

#consumer_accept_listsArray<Google::Apis::ComputeV1::ServiceAttachmentConsumerProjectLimit>

Projects that are allowed to connect to this service attachment. Corresponds to the JSON property consumerAcceptLists



31505
31506
31507
# File 'lib/google/apis/compute_v1/classes.rb', line 31505

def consumer_accept_lists
  @consumer_accept_lists
end

#consumer_reject_listsArray<String>

Projects that are not allowed to connect to this service attachment. The project can be specified using its id or number. Corresponds to the JSON property consumerRejectLists

Returns:

  • (Array<String>)


31511
31512
31513
# File 'lib/google/apis/compute_v1/classes.rb', line 31511

def consumer_reject_lists
  @consumer_reject_lists
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


31516
31517
31518
# File 'lib/google/apis/compute_v1/classes.rb', line 31516

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


31522
31523
31524
# File 'lib/google/apis/compute_v1/classes.rb', line 31522

def description
  @description
end

#domain_namesArray<String>

If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS. For example, this is a valid domain name: "p.mycompany.com.". Current max number of domain names supported is 1. Corresponds to the JSON property domainNames

Returns:

  • (Array<String>)


31529
31530
31531
# File 'lib/google/apis/compute_v1/classes.rb', line 31529

def domain_names
  @domain_names
end

#enable_proxy_protocolBoolean Also known as: enable_proxy_protocol?

If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers. Corresponds to the JSON property enableProxyProtocol

Returns:

  • (Boolean)


31536
31537
31538
# File 'lib/google/apis/compute_v1/classes.rb', line 31536

def enable_proxy_protocol
  @enable_proxy_protocol
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ServiceAttachment. An up-to-date fingerprint must be provided in order to patch/update the ServiceAttachment; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the ServiceAttachment. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


31548
31549
31550
# File 'lib/google/apis/compute_v1/classes.rb', line 31548

def fingerprint
  @fingerprint
end

#idFixnum

[Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


31554
31555
31556
# File 'lib/google/apis/compute_v1/classes.rb', line 31554

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


31560
31561
31562
# File 'lib/google/apis/compute_v1/classes.rb', line 31560

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


31570
31571
31572
# File 'lib/google/apis/compute_v1/classes.rb', line 31570

def name
  @name
end

#nat_subnetsArray<String>

An array of URLs where each entry is the URL of a subnet provided by the service producer to use for NAT in this service attachment. Corresponds to the JSON property natSubnets

Returns:

  • (Array<String>)


31576
31577
31578
# File 'lib/google/apis/compute_v1/classes.rb', line 31576

def nat_subnets
  @nat_subnets
end

#producer_forwarding_ruleString

The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is serving the endpoint identified by this service attachment. Corresponds to the JSON property producerForwardingRule

Returns:

  • (String)


31582
31583
31584
# File 'lib/google/apis/compute_v1/classes.rb', line 31582

def producer_forwarding_rule
  @producer_forwarding_rule
end

#psc_service_attachment_idGoogle::Apis::ComputeV1::Uint128

[Output Only] An 128-bit global unique ID of the PSC service attachment. Corresponds to the JSON property pscServiceAttachmentId



31587
31588
31589
# File 'lib/google/apis/compute_v1/classes.rb', line 31587

def psc_service_attachment_id
  @psc_service_attachment_id
end

#regionString

[Output Only] URL of the region where the service attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


31594
31595
31596
# File 'lib/google/apis/compute_v1/classes.rb', line 31594

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31599
31600
31601
# File 'lib/google/apis/compute_v1/classes.rb', line 31599

def self_link
  @self_link
end

#target_serviceString

The URL of a service serving the endpoint identified by this service attachment. Corresponds to the JSON property targetService

Returns:

  • (String)


31605
31606
31607
# File 'lib/google/apis/compute_v1/classes.rb', line 31605

def target_service
  @target_service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31612
31613
31614
31615
31616
31617
31618
31619
31620
31621
31622
31623
31624
31625
31626
31627
31628
31629
31630
31631
# File 'lib/google/apis/compute_v1/classes.rb', line 31612

def update!(**args)
  @connected_endpoints = args[:connected_endpoints] if args.key?(:connected_endpoints)
  @connection_preference = args[:connection_preference] if args.key?(:connection_preference)
  @consumer_accept_lists = args[:consumer_accept_lists] if args.key?(:consumer_accept_lists)
  @consumer_reject_lists = args[:consumer_reject_lists] if args.key?(:consumer_reject_lists)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @domain_names = args[:domain_names] if args.key?(:domain_names)
  @enable_proxy_protocol = args[:enable_proxy_protocol] if args.key?(:enable_proxy_protocol)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @nat_subnets = args[:nat_subnets] if args.key?(:nat_subnets)
  @producer_forwarding_rule = args[:producer_forwarding_rule] if args.key?(:producer_forwarding_rule)
  @psc_service_attachment_id = args[:psc_service_attachment_id] if args.key?(:psc_service_attachment_id)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @target_service = args[:target_service] if args.key?(:target_service)
end