Class: Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] A connection connected to this service attachment.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
The url of the consumer network.
-
#endpoint ⇒ String
The url of a connected endpoint.
-
#endpoint_with_id ⇒ String
The url of a connected endpoint with resource id.
-
#nat_ips ⇒ Array<String>
NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
-
#propagated_connection_count ⇒ Fixnum
The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
-
#psc_connection_id ⇒ Fixnum
The PSC connection id of the connected endpoint.
-
#status ⇒ String
The status of a connected endpoint to this service attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint
constructor
A new instance of ServiceAttachmentConnectedEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint
Returns a new instance of ServiceAttachmentConnectedEndpoint.
57974 57975 57976 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
The url of the consumer network.
Corresponds to the JSON property consumerNetwork
57940 57941 57942 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57940 def consumer_network @consumer_network end |
#endpoint ⇒ String
The url of a connected endpoint.
Corresponds to the JSON property endpoint
57945 57946 57947 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57945 def endpoint @endpoint end |
#endpoint_with_id ⇒ String
The url of a connected endpoint with resource id.
Corresponds to the JSON property endpointWithId
57950 57951 57952 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57950 def endpoint_with_id @endpoint_with_id end |
#nat_ips ⇒ Array<String>
NAT IPs of the connected PSC endpoint and those of other endpoints
propagated from it.
Corresponds to the JSON property natIps
57956 57957 57958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57956 def nat_ips @nat_ips end |
#propagated_connection_count ⇒ Fixnum
The number of consumer Network Connectivity Center spokes that the
connected Private Service Connect endpoint has propagated to.
Corresponds to the JSON property propagatedConnectionCount
57962 57963 57964 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57962 def propagated_connection_count @propagated_connection_count end |
#psc_connection_id ⇒ Fixnum
The PSC connection id of the connected endpoint.
Corresponds to the JSON property pscConnectionId
57967 57968 57969 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57967 def psc_connection_id @psc_connection_id end |
#status ⇒ String
The status of a connected endpoint to this service attachment.
Corresponds to the JSON property status
57972 57973 57974 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57972 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57979 57980 57981 57982 57983 57984 57985 57986 57987 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57979 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @endpoint = args[:endpoint] if args.key?(:endpoint) @endpoint_with_id = args[:endpoint_with_id] if args.key?(:endpoint_with_id) @nat_ips = args[:nat_ips] if args.key?(:nat_ips) @propagated_connection_count = args[:propagated_connection_count] if args.key?(:propagated_connection_count) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @status = args[:status] if args.key?(:status) end |