Class: Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] A connection connected to this service attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint

Returns a new instance of ServiceAttachmentConnectedEndpoint.



57188
57189
57190
# File 'lib/google/apis/compute_v1/classes.rb', line 57188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

The url of the consumer network. Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


57154
57155
57156
# File 'lib/google/apis/compute_v1/classes.rb', line 57154

def consumer_network
  @consumer_network
end

#endpointString

The url of a connected endpoint. Corresponds to the JSON property endpoint

Returns:

  • (String)


57159
57160
57161
# File 'lib/google/apis/compute_v1/classes.rb', line 57159

def endpoint
  @endpoint
end

#endpoint_with_idString

The url of a connected endpoint with resource id. Corresponds to the JSON property endpointWithId

Returns:

  • (String)


57164
57165
57166
# File 'lib/google/apis/compute_v1/classes.rb', line 57164

def endpoint_with_id
  @endpoint_with_id
end

#nat_ipsArray<String>

NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it. Corresponds to the JSON property natIps

Returns:

  • (Array<String>)


57170
57171
57172
# File 'lib/google/apis/compute_v1/classes.rb', line 57170

def nat_ips
  @nat_ips
end

#propagated_connection_countFixnum

The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to. Corresponds to the JSON property propagatedConnectionCount

Returns:

  • (Fixnum)


57176
57177
57178
# File 'lib/google/apis/compute_v1/classes.rb', line 57176

def propagated_connection_count
  @propagated_connection_count
end

#psc_connection_idFixnum

The PSC connection id of the connected endpoint. Corresponds to the JSON property pscConnectionId

Returns:

  • (Fixnum)


57181
57182
57183
# File 'lib/google/apis/compute_v1/classes.rb', line 57181

def psc_connection_id
  @psc_connection_id
end

#statusString

The status of a connected endpoint to this service attachment. Corresponds to the JSON property status

Returns:

  • (String)


57186
57187
57188
# File 'lib/google/apis/compute_v1/classes.rb', line 57186

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57193
57194
57195
57196
57197
57198
57199
57200
57201
# File 'lib/google/apis/compute_v1/classes.rb', line 57193

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @endpoint_with_id = args[:endpoint_with_id] if args.key?(:endpoint_with_id)
  @nat_ips = args[:nat_ips] if args.key?(:nat_ips)
  @propagated_connection_count = args[:propagated_connection_count] if args.key?(:propagated_connection_count)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @status = args[:status] if args.key?(:status)
end