Class: Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] A connection connected to this service attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint

Returns a new instance of ServiceAttachmentConnectedEndpoint.



56477
56478
56479
# File 'lib/google/apis/compute_v1/classes.rb', line 56477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

The url of the consumer network. Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


56443
56444
56445
# File 'lib/google/apis/compute_v1/classes.rb', line 56443

def consumer_network
  @consumer_network
end

#endpointString

The url of a connected endpoint. Corresponds to the JSON property endpoint

Returns:

  • (String)


56448
56449
56450
# File 'lib/google/apis/compute_v1/classes.rb', line 56448

def endpoint
  @endpoint
end

#endpoint_with_idString

The url of a connected endpoint with resource id. Corresponds to the JSON property endpointWithId

Returns:

  • (String)


56453
56454
56455
# File 'lib/google/apis/compute_v1/classes.rb', line 56453

def endpoint_with_id
  @endpoint_with_id
end

#nat_ipsArray<String>

NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it. Corresponds to the JSON property natIps

Returns:

  • (Array<String>)


56459
56460
56461
# File 'lib/google/apis/compute_v1/classes.rb', line 56459

def nat_ips
  @nat_ips
end

#propagated_connection_countFixnum

The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to. Corresponds to the JSON property propagatedConnectionCount

Returns:

  • (Fixnum)


56465
56466
56467
# File 'lib/google/apis/compute_v1/classes.rb', line 56465

def propagated_connection_count
  @propagated_connection_count
end

#psc_connection_idFixnum

The PSC connection id of the connected endpoint. Corresponds to the JSON property pscConnectionId

Returns:

  • (Fixnum)


56470
56471
56472
# File 'lib/google/apis/compute_v1/classes.rb', line 56470

def psc_connection_id
  @psc_connection_id
end

#statusString

The status of a connected endpoint to this service attachment. Corresponds to the JSON property status

Returns:

  • (String)


56475
56476
56477
# File 'lib/google/apis/compute_v1/classes.rb', line 56475

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56482
56483
56484
56485
56486
56487
56488
56489
56490
# File 'lib/google/apis/compute_v1/classes.rb', line 56482

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @endpoint_with_id = args[:endpoint_with_id] if args.key?(:endpoint_with_id)
  @nat_ips = args[:nat_ips] if args.key?(:nat_ips)
  @propagated_connection_count = args[:propagated_connection_count] if args.key?(:propagated_connection_count)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @status = args[:status] if args.key?(:status)
end