Class: Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] A connection connected to this service attachment.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
The url of the consumer network.
-
#endpoint ⇒ String
The url of a connected endpoint.
-
#endpoint_with_id ⇒ String
The url of a connected endpoint with resource id.
-
#nat_ips ⇒ Array<String>
NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
-
#propagated_connection_count ⇒ Fixnum
The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
-
#psc_connection_id ⇒ Fixnum
The PSC connection id of the connected endpoint.
-
#status ⇒ String
The status of a connected endpoint to this service attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint
constructor
A new instance of ServiceAttachmentConnectedEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint
Returns a new instance of ServiceAttachmentConnectedEndpoint.
54968 54969 54970 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
The url of the consumer network.
Corresponds to the JSON property consumerNetwork
54934 54935 54936 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54934 def consumer_network @consumer_network end |
#endpoint ⇒ String
The url of a connected endpoint.
Corresponds to the JSON property endpoint
54939 54940 54941 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54939 def endpoint @endpoint end |
#endpoint_with_id ⇒ String
The url of a connected endpoint with resource id.
Corresponds to the JSON property endpointWithId
54944 54945 54946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54944 def endpoint_with_id @endpoint_with_id end |
#nat_ips ⇒ Array<String>
NAT IPs of the connected PSC endpoint and those of other endpoints
propagated from it.
Corresponds to the JSON property natIps
54950 54951 54952 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54950 def nat_ips @nat_ips end |
#propagated_connection_count ⇒ Fixnum
The number of consumer Network Connectivity Center spokes that the
connected Private Service Connect endpoint has propagated to.
Corresponds to the JSON property propagatedConnectionCount
54956 54957 54958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54956 def propagated_connection_count @propagated_connection_count end |
#psc_connection_id ⇒ Fixnum
The PSC connection id of the connected endpoint.
Corresponds to the JSON property pscConnectionId
54961 54962 54963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54961 def psc_connection_id @psc_connection_id end |
#status ⇒ String
The status of a connected endpoint to this service attachment.
Corresponds to the JSON property status
54966 54967 54968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54966 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54973 54974 54975 54976 54977 54978 54979 54980 54981 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54973 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @endpoint = args[:endpoint] if args.key?(:endpoint) @endpoint_with_id = args[:endpoint_with_id] if args.key?(:endpoint_with_id) @nat_ips = args[:nat_ips] if args.key?(:nat_ips) @propagated_connection_count = args[:propagated_connection_count] if args.key?(:propagated_connection_count) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @status = args[:status] if args.key?(:status) end |