Class: Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] A connection connected to this service attachment.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
The url of the consumer network.
-
#endpoint ⇒ String
The url of a connected endpoint.
-
#nat_ips ⇒ Array<String>
NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
-
#propagated_connection_count ⇒ Fixnum
The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
-
#psc_connection_id ⇒ Fixnum
The PSC connection id of the connected endpoint.
-
#status ⇒ String
The status of a connected endpoint to this service attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint
constructor
A new instance of ServiceAttachmentConnectedEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint
Returns a new instance of ServiceAttachmentConnectedEndpoint.
51506 51507 51508 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
The url of the consumer network.
Corresponds to the JSON property consumerNetwork
51477 51478 51479 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51477 def consumer_network @consumer_network end |
#endpoint ⇒ String
The url of a connected endpoint.
Corresponds to the JSON property endpoint
51482 51483 51484 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51482 def endpoint @endpoint end |
#nat_ips ⇒ Array<String>
NAT IPs of the connected PSC endpoint and those of other endpoints
propagated from it.
Corresponds to the JSON property natIps
51488 51489 51490 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51488 def nat_ips @nat_ips end |
#propagated_connection_count ⇒ Fixnum
The number of consumer Network Connectivity Center spokes that the
connected Private Service Connect endpoint has propagated to.
Corresponds to the JSON property propagatedConnectionCount
51494 51495 51496 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51494 def propagated_connection_count @propagated_connection_count end |
#psc_connection_id ⇒ Fixnum
The PSC connection id of the connected endpoint.
Corresponds to the JSON property pscConnectionId
51499 51500 51501 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51499 def psc_connection_id @psc_connection_id end |
#status ⇒ String
The status of a connected endpoint to this service attachment.
Corresponds to the JSON property status
51504 51505 51506 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51504 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51511 51512 51513 51514 51515 51516 51517 51518 |
# File 'lib/google/apis/compute_v1/classes.rb', line 51511 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @endpoint = args[:endpoint] if args.key?(:endpoint) @nat_ips = args[:nat_ips] if args.key?(:nat_ips) @propagated_connection_count = args[:propagated_connection_count] if args.key?(:propagated_connection_count) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @status = args[:status] if args.key?(:status) end |