Class: Google::Apis::ComputeV1::ServiceAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

[Output Only] A connection connected to this service attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint

Returns a new instance of ServiceAttachmentConnectedEndpoint.



50319
50320
50321
# File 'lib/google/apis/compute_v1/classes.rb', line 50319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

The url of the consumer network. Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


50290
50291
50292
# File 'lib/google/apis/compute_v1/classes.rb', line 50290

def consumer_network
  @consumer_network
end

#endpointString

The url of a connected endpoint. Corresponds to the JSON property endpoint

Returns:

  • (String)


50295
50296
50297
# File 'lib/google/apis/compute_v1/classes.rb', line 50295

def endpoint
  @endpoint
end

#nat_ipsArray<String>

NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it. Corresponds to the JSON property natIps

Returns:

  • (Array<String>)


50301
50302
50303
# File 'lib/google/apis/compute_v1/classes.rb', line 50301

def nat_ips
  @nat_ips
end

#propagated_connection_countFixnum

The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to. Corresponds to the JSON property propagatedConnectionCount

Returns:

  • (Fixnum)


50307
50308
50309
# File 'lib/google/apis/compute_v1/classes.rb', line 50307

def propagated_connection_count
  @propagated_connection_count
end

#psc_connection_idFixnum

The PSC connection id of the connected endpoint. Corresponds to the JSON property pscConnectionId

Returns:

  • (Fixnum)


50312
50313
50314
# File 'lib/google/apis/compute_v1/classes.rb', line 50312

def psc_connection_id
  @psc_connection_id
end

#statusString

The status of a connected endpoint to this service attachment. Corresponds to the JSON property status

Returns:

  • (String)


50317
50318
50319
# File 'lib/google/apis/compute_v1/classes.rb', line 50317

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50324
50325
50326
50327
50328
50329
50330
50331
# File 'lib/google/apis/compute_v1/classes.rb', line 50324

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @nat_ips = args[:nat_ips] if args.key?(:nat_ips)
  @propagated_connection_count = args[:propagated_connection_count] if args.key?(:propagated_connection_count)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @status = args[:status] if args.key?(:status)
end