Class: Google::Apis::ComputeV1::ServiceAttachmentConsumerProjectLimit

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConsumerProjectLimit

Returns a new instance of ServiceAttachmentConsumerProjectLimit.



51541
51542
51543
# File 'lib/google/apis/compute_v1/classes.rb', line 51541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_limitFixnum

The value of the limit to set. For endpoint_url, the limit should be no more than 1. Corresponds to the JSON property connectionLimit

Returns:

  • (Fixnum)


51529
51530
51531
# File 'lib/google/apis/compute_v1/classes.rb', line 51529

def connection_limit
  @connection_limit
end

#network_urlString

The network URL for the network to set the limit for. Corresponds to the JSON property networkUrl

Returns:

  • (String)


51534
51535
51536
# File 'lib/google/apis/compute_v1/classes.rb', line 51534

def network_url
  @network_url
end

#project_id_or_numString

The project id or number for the project to set the limit for. Corresponds to the JSON property projectIdOrNum

Returns:

  • (String)


51539
51540
51541
# File 'lib/google/apis/compute_v1/classes.rb', line 51539

def project_id_or_num
  @project_id_or_num
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51546
51547
51548
51549
51550
# File 'lib/google/apis/compute_v1/classes.rb', line 51546

def update!(**args)
  @connection_limit = args[:connection_limit] if args.key?(:connection_limit)
  @network_url = args[:network_url] if args.key?(:network_url)
  @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num)
end