Class: Google::Apis::ComputeV1::ServiceAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ServiceAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ServiceAttachment>
A list of ServiceAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentList
constructor
A new instance of ServiceAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentList
Returns a new instance of ServiceAttachmentList.
58118 58119 58120 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58085 58086 58087 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58085 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ServiceAttachment>
A list of ServiceAttachment resources.
Corresponds to the JSON property items
58090 58091 58092 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58090 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
serviceAttachment for service attachments.
Corresponds to the JSON property kind
58096 58097 58098 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58096 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58106 58107 58108 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58106 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58111 58112 58113 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58111 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58116 58117 58118 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58116 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58123 58124 58125 58126 58127 58128 58129 58130 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58123 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |