Class: Google::Apis::ComputeV1::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



57282
57283
57284
# File 'lib/google/apis/compute_v1/classes.rb', line 57282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57249
57250
57251
# File 'lib/google/apis/compute_v1/classes.rb', line 57249

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



57254
57255
57256
# File 'lib/google/apis/compute_v1/classes.rb', line 57254

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


57260
57261
57262
# File 'lib/google/apis/compute_v1/classes.rb', line 57260

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57270
57271
57272
# File 'lib/google/apis/compute_v1/classes.rb', line 57270

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57275
57276
57277
# File 'lib/google/apis/compute_v1/classes.rb', line 57275

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57280
57281
57282
# File 'lib/google/apis/compute_v1/classes.rb', line 57280

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57287
57288
57289
57290
57291
57292
57293
57294
# File 'lib/google/apis/compute_v1/classes.rb', line 57287

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end