Class: Google::Apis::ComputeV1::ServiceAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ServiceAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ServiceAttachment>
A list of ServiceAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentList
constructor
A new instance of ServiceAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentList
Returns a new instance of ServiceAttachmentList.
57270 57271 57272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57237 57238 57239 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57237 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ServiceAttachment>
A list of ServiceAttachment resources.
Corresponds to the JSON property items
57242 57243 57244 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57242 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
serviceAttachment for service attachments.
Corresponds to the JSON property kind
57248 57249 57250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57248 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57258 57259 57260 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57258 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57263 57264 57265 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57263 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57268 57269 57270 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57268 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57275 57276 57277 57278 57279 57280 57281 57282 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57275 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |