Class: Google::Apis::ComputeV1::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



56901
56902
56903
# File 'lib/google/apis/compute_v1/classes.rb', line 56901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56868
56869
56870
# File 'lib/google/apis/compute_v1/classes.rb', line 56868

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



56873
56874
56875
# File 'lib/google/apis/compute_v1/classes.rb', line 56873

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


56879
56880
56881
# File 'lib/google/apis/compute_v1/classes.rb', line 56879

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56889
56890
56891
# File 'lib/google/apis/compute_v1/classes.rb', line 56889

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56894
56895
56896
# File 'lib/google/apis/compute_v1/classes.rb', line 56894

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56899
56900
56901
# File 'lib/google/apis/compute_v1/classes.rb', line 56899

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56906
56907
56908
56909
56910
56911
56912
56913
# File 'lib/google/apis/compute_v1/classes.rb', line 56906

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end