Class: Google::Apis::ComputeV1::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



56557
56558
56559
# File 'lib/google/apis/compute_v1/classes.rb', line 56557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56524
56525
56526
# File 'lib/google/apis/compute_v1/classes.rb', line 56524

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



56529
56530
56531
# File 'lib/google/apis/compute_v1/classes.rb', line 56529

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


56535
56536
56537
# File 'lib/google/apis/compute_v1/classes.rb', line 56535

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56545
56546
56547
# File 'lib/google/apis/compute_v1/classes.rb', line 56545

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56550
56551
56552
# File 'lib/google/apis/compute_v1/classes.rb', line 56550

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56555
56556
56557
# File 'lib/google/apis/compute_v1/classes.rb', line 56555

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56562
56563
56564
56565
56566
56567
56568
56569
# File 'lib/google/apis/compute_v1/classes.rb', line 56562

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end