Class: Google::Apis::ComputeV1::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



55062
55063
55064
# File 'lib/google/apis/compute_v1/classes.rb', line 55062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55029
55030
55031
# File 'lib/google/apis/compute_v1/classes.rb', line 55029

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



55034
55035
55036
# File 'lib/google/apis/compute_v1/classes.rb', line 55034

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


55040
55041
55042
# File 'lib/google/apis/compute_v1/classes.rb', line 55040

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55050
55051
55052
# File 'lib/google/apis/compute_v1/classes.rb', line 55050

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55055
55056
55057
# File 'lib/google/apis/compute_v1/classes.rb', line 55055

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55060
55061
55062
# File 'lib/google/apis/compute_v1/classes.rb', line 55060

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55067
55068
55069
55070
55071
55072
55073
55074
# File 'lib/google/apis/compute_v1/classes.rb', line 55067

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end