Class: Google::Apis::ComputeV1::ServiceAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ServiceAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::ServiceAttachment>
A list of ServiceAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentList
constructor
A new instance of ServiceAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentList
Returns a new instance of ServiceAttachmentList.
50406 50407 50408 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50406 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50373 50374 50375 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50373 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ServiceAttachment>
A list of ServiceAttachment resources.
Corresponds to the JSON property items
50378 50379 50380 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50378 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
serviceAttachment for service attachments.
Corresponds to the JSON property kind
50384 50385 50386 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50384 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50394 50395 50396 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50394 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50399 50400 50401 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50399 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
50404 50405 50406 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50404 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50411 50412 50413 50414 50415 50416 50417 50418 |
# File 'lib/google/apis/compute_v1/classes.rb', line 50411 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |