Class: Google::Apis::ComputeV1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.



57510
57511
57512
# File 'lib/google/apis/compute_v1/classes.rb', line 57510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



57502
57503
57504
# File 'lib/google/apis/compute_v1/classes.rb', line 57502

def error
  @error
end

#stateString

[Output Only] Status of the action, which can be one of the following: PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE. Corresponds to the JSON property state

Returns:

  • (String)


57508
57509
57510
# File 'lib/google/apis/compute_v1/classes.rb', line 57508

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57515
57516
57517
57518
# File 'lib/google/apis/compute_v1/classes.rb', line 57515

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
end