Class: Google::Apis::ComputeV1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.



57498
57499
57500
# File 'lib/google/apis/compute_v1/classes.rb', line 57498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



57490
57491
57492
# File 'lib/google/apis/compute_v1/classes.rb', line 57490

def error
  @error
end

#stateString

[Output Only] Status of the action, which can be one of the following: PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE. Corresponds to the JSON property state

Returns:

  • (String)


57496
57497
57498
# File 'lib/google/apis/compute_v1/classes.rb', line 57496

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57503
57504
57505
57506
# File 'lib/google/apis/compute_v1/classes.rb', line 57503

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
end