Class: Google::Apis::ComputeV1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
constructor
A new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
56799 56800 56801 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeV1::Status
The Status type defines a logical error model that is suitable for
different programming environments, including REST APIs and RPC APIs. It is
used by gRPC. Each Status message contains
three pieces of data: error code, error message, and error details.
You can find out more about this error model and how to work with it in the
API Design Guide.
Corresponds to the JSON property error
56791 56792 56793 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56791 def error @error end |
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Corresponds to the JSON property state
56797 56798 56799 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56797 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56804 56805 56806 56807 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56804 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) end |