Class: Google::Apis::ComputeV1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
constructor
A new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
55290 55291 55292 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeV1::Status
The Status type defines a logical error model that is suitable for
different programming environments, including REST APIs and RPC APIs. It is
used by gRPC. Each Status message contains
three pieces of data: error code, error message, and error details.
You can find out more about this error model and how to work with it in the
API Design Guide.
Corresponds to the JSON property error
55282 55283 55284 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55282 def error @error end |
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Corresponds to the JSON property state
55288 55289 55290 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55288 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55295 55296 55297 55298 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55295 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) end |