Class: Google::Apis::ComputeV1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.



50634
50635
50636
# File 'lib/google/apis/compute_v1/classes.rb', line 50634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



50626
50627
50628
# File 'lib/google/apis/compute_v1/classes.rb', line 50626

def error
  @error
end

#stateString

[Output Only] Status of the action, which can be one of the following: PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE. Corresponds to the JSON property state

Returns:

  • (String)


50632
50633
50634
# File 'lib/google/apis/compute_v1/classes.rb', line 50632

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50639
50640
50641
50642
# File 'lib/google/apis/compute_v1/classes.rb', line 50639

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
end