Class: Google::Apis::ComputeV1::Snapshot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Snapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Persistent Disk Snapshot resource. You can use snapshots to back up data on a regular interval. For more information, read Creating persistent disk snapshots.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#auto_created ⇒ Boolean
(also: #auto_created?)
Output only.
-
#chain_name ⇒ String
Creates the new snapshot in the snapshot chain labeled with the specified name.
-
#creation_size_bytes ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ Fixnum
Output only.
-
#download_bytes ⇒ Fixnum
Output only.
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Output only.
-
#guest_flush ⇒ Boolean
(also: #guest_flush?)
[Input Only] Whether to attempt an application consistent snapshot by informing the OS to prepare for the snapshot process.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeV1::GuestOsFeature>
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot.
-
#license_codes ⇒ Array<Fixnum>
Output only.
-
#licenses ⇒ Array<String>
Output only.
-
#location_hint ⇒ String
An opaque location hint used to place the snapshot close to other resources.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#params ⇒ Google::Apis::ComputeV1::SnapshotParams
Additional snapshot params.
-
#region ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Encrypts the snapshot using acustomer-supplied encryption key.
-
#snapshot_group_id ⇒ String
Output only.
-
#snapshot_group_name ⇒ String
Output only.
-
#snapshot_type ⇒ String
Indicates the type of the snapshot.
-
#source_disk ⇒ String
The source disk used to create this snapshot.
-
#source_disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The customer-supplied encryption key of the source disk.
-
#source_disk_for_recovery_checkpoint ⇒ String
The source disk whose recovery checkpoint will be used to create this snapshot.
-
#source_disk_id ⇒ String
Output only.
-
#source_instant_snapshot ⇒ String
The source instant snapshot used to create this snapshot.
-
#source_instant_snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Customer provided encryption key when creating Snapshot from Instant Snapshot.
-
#source_instant_snapshot_id ⇒ String
Output only.
-
#source_snapshot_schedule_policy ⇒ String
Output only.
-
#source_snapshot_schedule_policy_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
-
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the snapshot (regional or multi-regional).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Snapshot
constructor
A new instance of Snapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Snapshot
Returns a new instance of Snapshot.
58026 58027 58028 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the snapshot. Valid values are
ARM64 or X86_64.
Corresponds to the JSON property architecture
57726 57727 57728 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57726 def architecture @architecture end |
#auto_created ⇒ Boolean Also known as: auto_created?
Output only. [Output Only] Set to true if snapshots are automatically created
by
applying resource policy on the target disk.
Corresponds to the JSON property autoCreated
57733 57734 57735 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57733 def auto_created @auto_created end |
#chain_name ⇒ String
Creates the new snapshot in the snapshot chain labeled with the
specified name. The chain name must be 1-63 characters long and comply
with RFC1035. This is an uncommon option only for advanced service
owners who needs to create separate snapshot chains, for example,
for chargeback tracking. When you describe your snapshot resource, this
field is visible only if it has a non-empty value.
Corresponds to the JSON property chainName
57744 57745 57746 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57744 def chain_name @chain_name end |
#creation_size_bytes ⇒ Fixnum
Output only. [Output Only] Size in bytes of the snapshot at creation time.
Corresponds to the JSON property creationSizeBytes
57749 57750 57751 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57749 def creation_size_bytes @creation_size_bytes end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
57755 57756 57757 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57755 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
57761 57762 57763 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57761 def description @description end |
#disk_size_gb ⇒ Fixnum
Output only. [Output Only] Size of the source disk, specified in GB.
Corresponds to the JSON property diskSizeGb
57766 57767 57768 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57766 def disk_size_gb @disk_size_gb end |
#download_bytes ⇒ Fixnum
Output only. [Output Only] Number of bytes downloaded to restore a snapshot to
a disk.
Corresponds to the JSON property downloadBytes
57772 57773 57774 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57772 def download_bytes @download_bytes end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Output only. Whether this snapshot is created from a confidential compute mode
disk.
[Output Only]: This field is not set by user, but from source disk.
Corresponds to the JSON property enableConfidentialCompute
57779 57780 57781 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57779 def enable_confidential_compute @enable_confidential_compute end |
#guest_flush ⇒ Boolean Also known as: guest_flush?
[Input Only] Whether to attempt an application consistent snapshot by
informing the OS to prepare for the snapshot process.
Corresponds to the JSON property guestFlush
57786 57787 57788 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57786 def guest_flush @guest_flush end |
#guest_os_features ⇒ Array<Google::Apis::ComputeV1::GuestOsFeature>
Output only. [Output Only] A list of features to enable on the guest operating
system.
Applicable only for bootable images. Read
Enabling guest operating system features to see a list of available
options.
Corresponds to the JSON property guestOsFeatures
57796 57797 57798 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57796 def guest_os_features @guest_os_features end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
57803 57804 57805 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57803 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#snapshot
for Snapshot resources.
Corresponds to the JSON property kind
57809 57810 57811 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57809 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a snapshot.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
57822 57823 57824 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57822 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot. These can be later modified by
the setLabels method.
Label values may be empty.
Corresponds to the JSON property labels
57829 57830 57831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57829 def labels @labels end |
#license_codes ⇒ Array<Fixnum>
Output only. [Output Only] Integer license codes indicating which licenses are
attached
to this snapshot.
Corresponds to the JSON property licenseCodes
57836 57837 57838 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57836 def license_codes @license_codes end |
#licenses ⇒ Array<String>
Output only. [Output Only] A list of public visible licenses that apply to
this
snapshot. This can be because the original image had licenses attached
(such as a Windows image).
Corresponds to the JSON property licenses
57844 57845 57846 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57844 def licenses @licenses end |
#location_hint ⇒ String
An opaque location hint used to place the snapshot close to other
resources.
This field is for use by internal tools that use the public API.
Corresponds to the JSON property locationHint
57851 57852 57853 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57851 def location_hint @location_hint end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
57862 57863 57864 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57862 def name @name end |
#params ⇒ Google::Apis::ComputeV1::SnapshotParams
Additional snapshot params.
Corresponds to the JSON property params
57867 57868 57869 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57867 def params @params end |
#region ⇒ String
Output only. [Output Only] URL of the region where the snapshot resides. Only
applicable
for regional snapshots.
Corresponds to the JSON property region
57874 57875 57876 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57874 def region @region end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
57879 57880 57881 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57879 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
57885 57886 57887 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57885 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
57891 57892 57893 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57891 def self_link @self_link end |
#snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Encrypts the snapshot using acustomer-supplied
encryption key.
After you encrypt a snapshot using a customer-supplied key, you must
provide the same key if you use the snapshot later. For example, you must
provide the encryption key when you create a disk from the encrypted
snapshot in a future request.
Customer-supplied encryption keys do not protect access to metadata
of the snapshot.
If you do not provide an encryption key when creating the snapshot, then
the snapshot will be encrypted using an automatically generated key and you
do not need to provide a key to use the snapshot later.
Corresponds to the JSON property snapshotEncryptionKey
57906 57907 57908 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57906 def snapshot_encryption_key @snapshot_encryption_key end |
#snapshot_group_id ⇒ String
Output only. [Output Only] The unique ID of the snapshot group that this
snapshot
belongs to. The usage of snapshot group feature is restricted.
Corresponds to the JSON property snapshotGroupId
57913 57914 57915 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57913 def snapshot_group_id @snapshot_group_id end |
#snapshot_group_name ⇒ String
Output only. [Output only] The snapshot group that this snapshot belongs to.
The usage
of snapshot group feature is restricted.
Corresponds to the JSON property snapshotGroupName
57920 57921 57922 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57920 def snapshot_group_name @snapshot_group_name end |
#snapshot_type ⇒ String
Indicates the type of the snapshot.
Corresponds to the JSON property snapshotType
57925 57926 57927 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57925 def snapshot_type @snapshot_type end |
#source_disk ⇒ String
The source disk used to create this snapshot.
Corresponds to the JSON property sourceDisk
57930 57931 57932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57930 def source_disk @source_disk end |
#source_disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The customer-supplied
encryption key of the source disk. Required if the source disk is
protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceDiskEncryptionKey
57937 57938 57939 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57937 def source_disk_encryption_key @source_disk_encryption_key end |
#source_disk_for_recovery_checkpoint ⇒ String
The source disk whose recovery checkpoint will be used to create this
snapshot.
Corresponds to the JSON property sourceDiskForRecoveryCheckpoint
57943 57944 57945 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57943 def source_disk_for_recovery_checkpoint @source_disk_for_recovery_checkpoint end |
#source_disk_id ⇒ String
Output only. [Output Only] The ID value of the disk used to create this
snapshot. This
value may be used to determine whether the snapshot was taken from the
current or a previous instance of a given disk name.
Corresponds to the JSON property sourceDiskId
57951 57952 57953 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57951 def source_disk_id @source_disk_id end |
#source_instant_snapshot ⇒ String
The source instant snapshot used to create this snapshot. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ instantSnapshots/instantSnapshot
- projects/project/zones/zone/instantSnapshots/instantSnapshot
- zones/zone/instantSnapshots/instantSnapshot
Corresponds to the JSON property
sourceInstantSnapshot
57964 57965 57966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57964 def source_instant_snapshot @source_instant_snapshot end |
#source_instant_snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Customer provided encryption key when creating Snapshot from Instant
Snapshot.
Corresponds to the JSON property sourceInstantSnapshotEncryptionKey
57970 57971 57972 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57970 def source_instant_snapshot_encryption_key @source_instant_snapshot_encryption_key end |
#source_instant_snapshot_id ⇒ String
Output only. [Output Only] The unique ID of the instant snapshot used to
create this
snapshot. This value identifies the exact instant snapshot that was used to
create this snapshot. For example, if you created the snapshot from an
instant snapshot that was later deleted and recreated under the same name,
the source instant snapshot ID would identify the exact instant snapshot
that was used.
Corresponds to the JSON property sourceInstantSnapshotId
57981 57982 57983 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57981 def source_instant_snapshot_id @source_instant_snapshot_id end |
#source_snapshot_schedule_policy ⇒ String
Output only. [Output Only] URL of the resource policy which created this
scheduled snapshot.
Corresponds to the JSON property sourceSnapshotSchedulePolicy
57987 57988 57989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57987 def source_snapshot_schedule_policy @source_snapshot_schedule_policy end |
#source_snapshot_schedule_policy_id ⇒ String
Output only. [Output Only] ID of the resource policy which created this
scheduled snapshot.
Corresponds to the JSON property sourceSnapshotSchedulePolicyId
57993 57994 57995 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57993 def source_snapshot_schedule_policy_id @source_snapshot_schedule_policy_id end |
#status ⇒ String
Output only. [Output Only] The status of the snapshot. This can beCREATING,
DELETING, FAILED,READY, or UPLOADING.
Corresponds to the JSON property status
57999 58000 58001 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57999 def status @status end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] A size of the storage used by the snapshot. As
snapshots
share storage, this number is expected to change with snapshot
creation/deletion.
Corresponds to the JSON property storageBytes
58007 58008 58009 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58007 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Deprecated] Instead, check the storageBytes field. After
snapshot creation, the storageBytesStatus field is alwaysUP_TO_DATE.
[Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be unset, meaning the snapshot is
being created, or UP_TO_DATE, meaning the size of the snapshot
is up-to-date.
Corresponds to the JSON property storageBytesStatus
58018 58019 58020 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58018 def storage_bytes_status @storage_bytes_status end |
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the snapshot (regional or
multi-regional).
Corresponds to the JSON property storageLocations
58024 58025 58026 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58024 def storage_locations @storage_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58031 58032 58033 58034 58035 58036 58037 58038 58039 58040 58041 58042 58043 58044 58045 58046 58047 58048 58049 58050 58051 58052 58053 58054 58055 58056 58057 58058 58059 58060 58061 58062 58063 58064 58065 58066 58067 58068 58069 58070 58071 58072 58073 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58031 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @auto_created = args[:auto_created] if args.key?(:auto_created) @chain_name = args[:chain_name] if args.key?(:chain_name) @creation_size_bytes = args[:creation_size_bytes] if args.key?(:creation_size_bytes) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @download_bytes = args[:download_bytes] if args.key?(:download_bytes) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) @guest_flush = args[:guest_flush] if args.key?(:guest_flush) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @license_codes = args[:license_codes] if args.key?(:license_codes) @licenses = args[:licenses] if args.key?(:licenses) @location_hint = args[:location_hint] if args.key?(:location_hint) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @snapshot_encryption_key = args[:snapshot_encryption_key] if args.key?(:snapshot_encryption_key) @snapshot_group_id = args[:snapshot_group_id] if args.key?(:snapshot_group_id) @snapshot_group_name = args[:snapshot_group_name] if args.key?(:snapshot_group_name) @snapshot_type = args[:snapshot_type] if args.key?(:snapshot_type) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key) @source_disk_for_recovery_checkpoint = args[:source_disk_for_recovery_checkpoint] if args.key?(:source_disk_for_recovery_checkpoint) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot) @source_instant_snapshot_encryption_key = args[:source_instant_snapshot_encryption_key] if args.key?(:source_instant_snapshot_encryption_key) @source_instant_snapshot_id = args[:source_instant_snapshot_id] if args.key?(:source_instant_snapshot_id) @source_snapshot_schedule_policy = args[:source_snapshot_schedule_policy] if args.key?(:source_snapshot_schedule_policy) @source_snapshot_schedule_policy_id = args[:source_snapshot_schedule_policy_id] if args.key?(:source_snapshot_schedule_policy_id) @status = args[:status] if args.key?(:status) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) @storage_locations = args[:storage_locations] if args.key?(:storage_locations) end |