Class: Google::Apis::ComputeV1::Snapshot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Snapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Persistent Disk Snapshot resource. You can use snapshots to back up data on a regular interval. For more information, read Creating persistent disk snapshots.
Instance Attribute Summary collapse
-
#auto_created ⇒ Boolean
(also: #auto_created?)
[Output Only] Set to true if snapshots are automatically created by applying resource policy on the target disk.
-
#chain_name ⇒ String
Creates the new snapshot in the snapshot chain labeled with the specified name.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ Fixnum
[Output Only] Size of the source disk, specified in GB.
-
#download_bytes ⇒ Fixnum
[Output Only] Number of bytes downloaded to restore a snapshot to a disk.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot.
-
#license_codes ⇒ Array<Fixnum>
[Output Only] Integer license codes indicating which licenses are attached to this snapshot.
-
#licenses ⇒ Array<String>
[Output Only] A list of public visible licenses that apply to this snapshot.
-
#location_hint ⇒ String
An opaque location hint used to place the snapshot close to other resources.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
[Output Only] Reserved for future use.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Encrypts the snapshot using a customer-supplied encryption key.
-
#source_disk ⇒ String
The source disk used to create this snapshot.
-
#source_disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The customer-supplied encryption key of the source disk.
-
#source_disk_id ⇒ String
[Output Only] The ID value of the disk used to create this snapshot.
-
#status ⇒ String
[Output Only] The status of the snapshot.
-
#storage_bytes ⇒ Fixnum
[Output Only] A size of the storage used by the snapshot.
-
#storage_bytes_status ⇒ String
[Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation.
-
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the snapshot (regional or multi- regional).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Snapshot
constructor
A new instance of Snapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Snapshot
Returns a new instance of Snapshot.
32383 32384 32385 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32383 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_created ⇒ Boolean Also known as: auto_created?
[Output Only] Set to true if snapshots are automatically created by applying
resource policy on the target disk.
Corresponds to the JSON property autoCreated
32223 32224 32225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32223 def auto_created @auto_created end |
#chain_name ⇒ String
Creates the new snapshot in the snapshot chain labeled with the specified name.
The chain name must be 1-63 characters long and comply with RFC1035. This is
an uncommon option only for advanced service owners who needs to create
separate snapshot chains, for example, for chargeback tracking. When you
describe your snapshot resource, this field is visible only if it has a non-
empty value.
Corresponds to the JSON property chainName
32234 32235 32236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32234 def chain_name @chain_name end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
32239 32240 32241 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32239 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
32245 32246 32247 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32245 def description @description end |
#disk_size_gb ⇒ Fixnum
[Output Only] Size of the source disk, specified in GB.
Corresponds to the JSON property diskSizeGb
32250 32251 32252 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32250 def disk_size_gb @disk_size_gb end |
#download_bytes ⇒ Fixnum
[Output Only] Number of bytes downloaded to restore a snapshot to a disk.
Corresponds to the JSON property downloadBytes
32255 32256 32257 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32255 def download_bytes @download_bytes end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
32261 32262 32263 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32261 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#snapshot for Snapshot
resources.
Corresponds to the JSON property kind
32267 32268 32269 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32267 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after every
request to modify or update labels. You must always provide an up-to-date
fingerprint hash in order to update or change labels, otherwise the request
will fail with error 412 conditionNotMet. To see the latest fingerprint, make
a get() request to retrieve a snapshot.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
32279 32280 32281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32279 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot. These can be later modified by the setLabels
method. Label values may be empty.
Corresponds to the JSON property labels
32285 32286 32287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32285 def labels @labels end |
#license_codes ⇒ Array<Fixnum>
[Output Only] Integer license codes indicating which licenses are attached to
this snapshot.
Corresponds to the JSON property licenseCodes
32291 32292 32293 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32291 def license_codes @license_codes end |
#licenses ⇒ Array<String>
[Output Only] A list of public visible licenses that apply to this snapshot.
This can be because the original image had licenses attached (such as a
Windows image).
Corresponds to the JSON property licenses
32298 32299 32300 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32298 def licenses @licenses end |
#location_hint ⇒ String
An opaque location hint used to place the snapshot close to other resources.
This field is for use by internal tools that use the public API.
Corresponds to the JSON property locationHint
32304 32305 32306 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32304 def location_hint @location_hint end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
32314 32315 32316 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32314 def name @name end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
[Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
32319 32320 32321 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32319 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
32325 32326 32327 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32325 def self_link @self_link end |
#snapshot_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Encrypts the snapshot using a customer-supplied encryption key. After you
encrypt a snapshot using a customer-supplied key, you must provide the same
key if you use the snapshot later. For example, you must provide the
encryption key when you create a disk from the encrypted snapshot in a future
request. Customer-supplied encryption keys do not protect access to metadata
of the snapshot. If you do not provide an encryption key when creating the
snapshot, then the snapshot will be encrypted using an automatically generated
key and you do not need to provide a key to use the snapshot later.
Corresponds to the JSON property snapshotEncryptionKey
32337 32338 32339 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32337 def snapshot_encryption_key @snapshot_encryption_key end |
#source_disk ⇒ String
The source disk used to create this snapshot.
Corresponds to the JSON property sourceDisk
32342 32343 32344 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32342 def source_disk @source_disk end |
#source_disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
The customer-supplied encryption key of the source disk. Required if the
source disk is protected by a customer-supplied encryption key.
Corresponds to the JSON property sourceDiskEncryptionKey
32348 32349 32350 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32348 def source_disk_encryption_key @source_disk_encryption_key end |
#source_disk_id ⇒ String
[Output Only] The ID value of the disk used to create this snapshot. This
value may be used to determine whether the snapshot was taken from the current
or a previous instance of a given disk name.
Corresponds to the JSON property sourceDiskId
32355 32356 32357 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32355 def source_disk_id @source_disk_id end |
#status ⇒ String
[Output Only] The status of the snapshot. This can be CREATING, DELETING,
FAILED, READY, or UPLOADING.
Corresponds to the JSON property status
32361 32362 32363 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32361 def status @status end |
#storage_bytes ⇒ Fixnum
[Output Only] A size of the storage used by the snapshot. As snapshots share
storage, this number is expected to change with snapshot creation/deletion.
Corresponds to the JSON property storageBytes
32367 32368 32369 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32367 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
[Output Only] An indicator whether storageBytes is in a stable state or it is
being adjusted as a result of shared storage reallocation. This status can
either be UPDATING, meaning the size of the snapshot is being updated, or
UP_TO_DATE, meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
32375 32376 32377 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32375 def storage_bytes_status @storage_bytes_status end |
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the snapshot (regional or multi-
regional).
Corresponds to the JSON property storageLocations
32381 32382 32383 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32381 def storage_locations @storage_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32388 32389 32390 32391 32392 32393 32394 32395 32396 32397 32398 32399 32400 32401 32402 32403 32404 32405 32406 32407 32408 32409 32410 32411 32412 32413 |
# File 'lib/google/apis/compute_v1/classes.rb', line 32388 def update!(**args) @auto_created = args[:auto_created] if args.key?(:auto_created) @chain_name = args[:chain_name] if args.key?(:chain_name) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @download_bytes = args[:download_bytes] if args.key?(:download_bytes) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @license_codes = args[:license_codes] if args.key?(:license_codes) @licenses = args[:licenses] if args.key?(:licenses) @location_hint = args[:location_hint] if args.key?(:location_hint) @name = args[:name] if args.key?(:name) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @snapshot_encryption_key = args[:snapshot_encryption_key] if args.key?(:snapshot_encryption_key) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @status = args[:status] if args.key?(:status) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) @storage_locations = args[:storage_locations] if args.key?(:storage_locations) end |