Class: Google::Apis::ComputeV1::SnapshotGroupParameters

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotGroupParameters

Returns a new instance of SnapshotGroupParameters.



58119
58120
58121
# File 'lib/google/apis/compute_v1/classes.rb', line 58119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#replica_zonesArray<String>

URLs of the zones where disks should be replicated to. Only applicable for regional resources. Corresponds to the JSON property replicaZones

Returns:

  • (Array<String>)


58096
58097
58098
# File 'lib/google/apis/compute_v1/classes.rb', line 58096

def replica_zones
  @replica_zones
end

#source_snapshot_groupString

The source snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


58109
58110
58111
# File 'lib/google/apis/compute_v1/classes.rb', line 58109

def source_snapshot_group
  @source_snapshot_group
end

#typeString

URL of the disk type resource describing which disk type to use to create disks. Provide this when creating the disk. For example:projects/project/zones/ zone/diskTypes/pd-ssd. See Persistent disk types. Corresponds to the JSON property type

Returns:

  • (String)


58117
58118
58119
# File 'lib/google/apis/compute_v1/classes.rb', line 58117

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58124
58125
58126
58127
58128
# File 'lib/google/apis/compute_v1/classes.rb', line 58124

def update!(**args)
  @replica_zones = args[:replica_zones] if args.key?(:replica_zones)
  @source_snapshot_group = args[:source_snapshot_group] if args.key?(:source_snapshot_group)
  @type = args[:type] if args.key?(:type)
end