Class: Google::Apis::ComputeV1::SnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Snapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotList

Returns a new instance of SnapshotList.



58170
58171
58172
# File 'lib/google/apis/compute_v1/classes.rb', line 58170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58138
58139
58140
# File 'lib/google/apis/compute_v1/classes.rb', line 58138

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Snapshot>

A list of Snapshot resources. Corresponds to the JSON property items



58143
58144
58145
# File 'lib/google/apis/compute_v1/classes.rb', line 58143

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


58148
58149
58150
# File 'lib/google/apis/compute_v1/classes.rb', line 58148

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58158
58159
58160
# File 'lib/google/apis/compute_v1/classes.rb', line 58158

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58163
58164
58165
# File 'lib/google/apis/compute_v1/classes.rb', line 58163

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58168
58169
58170
# File 'lib/google/apis/compute_v1/classes.rb', line 58168

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58175
58176
58177
58178
58179
58180
58181
58182
# File 'lib/google/apis/compute_v1/classes.rb', line 58175

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end