Class: Google::Apis::ComputeV1::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
57830 57831 57832 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57798 57799 57800 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57798 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
57803 57804 57805 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57803 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
57808 57809 57810 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57808 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57818 57819 57820 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57818 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57823 57824 57825 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57823 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57828 57829 57830 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57828 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57835 57836 57837 57838 57839 57840 57841 57842 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57835 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |