Class: Google::Apis::ComputeV1::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
57457 57458 57459 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57457 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57425 57426 57427 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57425 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
57430 57431 57432 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57430 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
57435 57436 57437 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57435 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57445 57446 57447 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57445 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57450 57451 57452 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57450 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57455 57456 57457 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57455 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57462 57463 57464 57465 57466 57467 57468 57469 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57462 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |