Class: Google::Apis::ComputeV1::SnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Snapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotList

Returns a new instance of SnapshotList.



57443
57444
57445
# File 'lib/google/apis/compute_v1/classes.rb', line 57443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57411
57412
57413
# File 'lib/google/apis/compute_v1/classes.rb', line 57411

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Snapshot>

A list of Snapshot resources. Corresponds to the JSON property items



57416
57417
57418
# File 'lib/google/apis/compute_v1/classes.rb', line 57416

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


57421
57422
57423
# File 'lib/google/apis/compute_v1/classes.rb', line 57421

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57431
57432
57433
# File 'lib/google/apis/compute_v1/classes.rb', line 57431

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57436
57437
57438
# File 'lib/google/apis/compute_v1/classes.rb', line 57436

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57441
57442
57443
# File 'lib/google/apis/compute_v1/classes.rb', line 57441

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57448
57449
57450
57451
57452
57453
57454
57455
# File 'lib/google/apis/compute_v1/classes.rb', line 57448

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end