Class: Google::Apis::ComputeV1::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
55948 55949 55950 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55916 55917 55918 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55916 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
55921 55922 55923 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55921 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
55926 55927 55928 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55926 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55936 55937 55938 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55936 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55941 55942 55943 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55941 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55946 55947 55948 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55946 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55953 55954 55955 55956 55957 55958 55959 55960 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55953 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |