Class: Google::Apis::ComputeV1::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
52412 52413 52414 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52380 52381 52382 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52380 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
52385 52386 52387 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52385 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
52390 52391 52392 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52390 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52400 52401 52402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52400 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52405 52406 52407 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52405 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52410 52411 52412 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52410 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52417 52418 52419 52420 52421 52422 52423 52424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52417 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |