Class: Google::Apis::ComputeV1::SnapshotParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SnapshotParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Additional snapshot params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotParams
constructor
A new instance of SnapshotParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotParams
Returns a new instance of SnapshotParams.
58259 58260 58261 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the snapshot. Tag keys and
values have
the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
58257 58258 58259 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58257 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58264 58265 58266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58264 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |