Class: Google::Apis::ComputeV1::SnapshotParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Additional snapshot params.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotParams

Returns a new instance of SnapshotParams.



51325
51326
51327
# File 'lib/google/apis/compute_v1/classes.rb', line 51325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_manager_tagsHash<String,String>

Resource manager tags to be bound to the snapshot. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/456` or in namespaced format such asorg_id|project_id/tag_key_short_nameand tag_value_short_name`. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON propertyresourceManagerTags`

Returns:

  • (Hash<String,String>)


51323
51324
51325
# File 'lib/google/apis/compute_v1/classes.rb', line 51323

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51330
51331
51332
# File 'lib/google/apis/compute_v1/classes.rb', line 51330

def update!(**args)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end