Class: Google::Apis::ComputeV1::SnapshotSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettings

Returns a new instance of SnapshotSettings.



58285
58286
58287
# File 'lib/google/apis/compute_v1/classes.rb', line 58285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_locationGoogle::Apis::ComputeV1::SnapshotSettingsAccessLocation

(Regional snapshots use only)Policy of which location is allowed to access snapshot. Corresponds to the JSON property accessLocation



58277
58278
58279
# File 'lib/google/apis/compute_v1/classes.rb', line 58277

def access_location
  @access_location
end

#storage_locationGoogle::Apis::ComputeV1::SnapshotSettingsStorageLocationSettings

Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out. Corresponds to the JSON property storageLocation



58283
58284
58285
# File 'lib/google/apis/compute_v1/classes.rb', line 58283

def storage_location
  @storage_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58290
58291
58292
58293
# File 'lib/google/apis/compute_v1/classes.rb', line 58290

def update!(**args)
  @access_location = args[:access_location] if args.key?(:access_location)
  @storage_location = args[:storage_location] if args.key?(:storage_location)
end