Class: Google::Apis::ComputeV1::SnapshotSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SnapshotSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#access_location ⇒ Google::Apis::ComputeV1::SnapshotSettingsAccessLocation
(Regional snapshots use only)Policy of which location is allowed to access snapshot.
-
#storage_location ⇒ Google::Apis::ComputeV1::SnapshotSettingsStorageLocationSettings
Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotSettings
constructor
A new instance of SnapshotSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotSettings
Returns a new instance of SnapshotSettings.
57957 57958 57959 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_location ⇒ Google::Apis::ComputeV1::SnapshotSettingsAccessLocation
(Regional snapshots use only)Policy of which location is allowed to access
snapshot.
Corresponds to the JSON property accessLocation
57949 57950 57951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57949 def access_location @access_location end |
#storage_location ⇒ Google::Apis::ComputeV1::SnapshotSettingsStorageLocationSettings
Policy of which storage location is going to be resolved, and additional
data that particularizes how the policy is going to be carried out.
Corresponds to the JSON property storageLocation
57955 57956 57957 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57955 def storage_location @storage_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57962 57963 57964 57965 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57962 def update!(**args) @access_location = args[:access_location] if args.key?(:access_location) @storage_location = args[:storage_location] if args.key?(:storage_location) end |