Class: Google::Apis::ComputeV1::SnapshotSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SnapshotSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#access_location ⇒ Google::Apis::ComputeV1::SnapshotSettingsAccessLocation
(Regional snapshots use only)Policy of which location is allowed to access snapshot.
-
#storage_location ⇒ Google::Apis::ComputeV1::SnapshotSettingsStorageLocationSettings
Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotSettings
constructor
A new instance of SnapshotSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotSettings
Returns a new instance of SnapshotSettings.
57584 57585 57586 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_location ⇒ Google::Apis::ComputeV1::SnapshotSettingsAccessLocation
(Regional snapshots use only)Policy of which location is allowed to access
snapshot.
Corresponds to the JSON property accessLocation
57576 57577 57578 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57576 def access_location @access_location end |
#storage_location ⇒ Google::Apis::ComputeV1::SnapshotSettingsStorageLocationSettings
Policy of which storage location is going to be resolved, and additional
data that particularizes how the policy is going to be carried out.
Corresponds to the JSON property storageLocation
57582 57583 57584 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57582 def storage_location @storage_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57589 57590 57591 57592 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57589 def update!(**args) @access_location = args[:access_location] if args.key?(:access_location) @storage_location = args[:storage_location] if args.key?(:storage_location) end |