Class: Google::Apis::ComputeV1::SnapshotSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettings

Returns a new instance of SnapshotSettings.



52533
52534
52535
# File 'lib/google/apis/compute_v1/classes.rb', line 52533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#storage_locationGoogle::Apis::ComputeV1::SnapshotSettingsStorageLocationSettings

Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out. Corresponds to the JSON property storageLocation



52531
52532
52533
# File 'lib/google/apis/compute_v1/classes.rb', line 52531

def storage_location
  @storage_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52538
52539
52540
# File 'lib/google/apis/compute_v1/classes.rb', line 52538

def update!(**args)
  @storage_location = args[:storage_location] if args.key?(:storage_location)
end