Class: Google::Apis::ComputeV1::SnapshotSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettings

Returns a new instance of SnapshotSettings.



51345
51346
51347
# File 'lib/google/apis/compute_v1/classes.rb', line 51345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#storage_locationGoogle::Apis::ComputeV1::SnapshotSettingsStorageLocationSettings

Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out. Corresponds to the JSON property storageLocation



51343
51344
51345
# File 'lib/google/apis/compute_v1/classes.rb', line 51343

def storage_location
  @storage_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51350
51351
51352
# File 'lib/google/apis/compute_v1/classes.rb', line 51350

def update!(**args)
  @storage_location = args[:storage_location] if args.key?(:storage_location)
end