Class: Google::Apis::ComputeV1::SnapshotSettingsAccessLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SnapshotSettingsAccessLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#locations ⇒ Hash<String,Google::Apis::ComputeV1::SnapshotSettingsAccessLocationAccessLocationPreference>
List of regions that can restore a regional snapshot from the current region Corresponds to the JSON property
locations. -
#policy ⇒ String
Policy of which location is allowed to access snapshot.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotSettingsAccessLocation
constructor
A new instance of SnapshotSettingsAccessLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotSettingsAccessLocation
Returns a new instance of SnapshotSettingsAccessLocation.
57942 57943 57944 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57942 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Hash<String,Google::Apis::ComputeV1::SnapshotSettingsAccessLocationAccessLocationPreference>
List of regions that can restore a regional
snapshot from the current region
Corresponds to the JSON property locations
57935 57936 57937 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57935 def locations @locations end |
#policy ⇒ String
Policy of which location is allowed to access snapshot.
Corresponds to the JSON property policy
57940 57941 57942 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57940 def policy @policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57947 57948 57949 57950 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57947 def update!(**args) @locations = args[:locations] if args.key?(:locations) @policy = args[:policy] if args.key?(:policy) end |