Class: Google::Apis::ComputeV1::SourceDiskEncryptionKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceDiskEncryptionKey

Returns a new instance of SourceDiskEncryptionKey.



52613
52614
52615
# File 'lib/google/apis/compute_v1/classes.rb', line 52613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property diskEncryptionKey



52599
52600
52601
# File 'lib/google/apis/compute_v1/classes.rb', line 52599

def disk_encryption_key
  @disk_encryption_key
end

#source_diskString

URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values:

Returns:

  • (String)


52611
52612
52613
# File 'lib/google/apis/compute_v1/classes.rb', line 52611

def source_disk
  @source_disk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52618
52619
52620
52621
# File 'lib/google/apis/compute_v1/classes.rb', line 52618

def update!(**args)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
end