Class: Google::Apis::ComputeV1::SourceDiskEncryptionKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceDiskEncryptionKey

Returns a new instance of SourceDiskEncryptionKey.



51425
51426
51427
# File 'lib/google/apis/compute_v1/classes.rb', line 51425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_encryption_keyGoogle::Apis::ComputeV1::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property diskEncryptionKey



51411
51412
51413
# File 'lib/google/apis/compute_v1/classes.rb', line 51411

def disk_encryption_key
  @disk_encryption_key
end

#source_diskString

URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values:

Returns:

  • (String)


51423
51424
51425
# File 'lib/google/apis/compute_v1/classes.rb', line 51423

def source_disk
  @source_disk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51430
51431
51432
51433
# File 'lib/google/apis/compute_v1/classes.rb', line 51430

def update!(**args)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
end