Class: Google::Apis::ComputeV1::SourceInstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceInstanceProperties

Returns a new instance of SourceInstanceProperties.



58574
58575
58576
# File 'lib/google/apis/compute_v1/classes.rb', line 58574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


58485
58486
58487
# File 'lib/google/apis/compute_v1/classes.rb', line 58485

def can_ip_forward
  @can_ip_forward
end

#deletion_protectionBoolean Also known as: deletion_protection?

Whether the instance created from this machine image should be protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


58492
58493
58494
# File 'lib/google/apis/compute_v1/classes.rb', line 58492

def deletion_protection
  @deletion_protection
end

#descriptionString

An optional text description for the instances that are created from this machine image. Corresponds to the JSON property description

Returns:

  • (String)


58499
58500
58501
# File 'lib/google/apis/compute_v1/classes.rb', line 58499

def description
  @description
end

#disksArray<Google::Apis::ComputeV1::SavedAttachedDisk>

An array of disks that are associated with the instances that are created from this machine image. Corresponds to the JSON property disks



58505
58506
58507
# File 'lib/google/apis/compute_v1/classes.rb', line 58505

def disks
  @disks
end

#guest_acceleratorsArray<Google::Apis::ComputeV1::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from this machine image. Corresponds to the JSON property guestAccelerators



58511
58512
58513
# File 'lib/google/apis/compute_v1/classes.rb', line 58511

def guest_accelerators
  @guest_accelerators
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


58517
58518
58519
# File 'lib/google/apis/compute_v1/classes.rb', line 58517

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from this machine image. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


58522
58523
58524
# File 'lib/google/apis/compute_v1/classes.rb', line 58522

def labels
  @labels
end

#machine_typeString

The machine type to use for instances that are created from this machine image. Corresponds to the JSON property machineType

Returns:

  • (String)


58528
58529
58530
# File 'lib/google/apis/compute_v1/classes.rb', line 58528

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



58533
58534
58535
# File 'lib/google/apis/compute_v1/classes.rb', line 58533

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances created from this machine image. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


58544
58545
58546
# File 'lib/google/apis/compute_v1/classes.rb', line 58544

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeV1::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



58549
58550
58551
# File 'lib/google/apis/compute_v1/classes.rb', line 58549

def network_interfaces
  @network_interfaces
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


58554
58555
58556
# File 'lib/google/apis/compute_v1/classes.rb', line 58554

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#schedulingGoogle::Apis::ComputeV1::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



58559
58560
58561
# File 'lib/google/apis/compute_v1/classes.rb', line 58559

def scheduling
  @scheduling
end

#service_accountsArray<Google::Apis::ComputeV1::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from this machine image. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



58567
58568
58569
# File 'lib/google/apis/compute_v1/classes.rb', line 58567

def service_accounts
  @service_accounts
end

#tagsGoogle::Apis::ComputeV1::Tags

A set of instance tags. Corresponds to the JSON property tags



58572
58573
58574
# File 'lib/google/apis/compute_v1/classes.rb', line 58572

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58579
58580
58581
58582
58583
58584
58585
58586
58587
58588
58589
58590
58591
58592
58593
58594
58595
# File 'lib/google/apis/compute_v1/classes.rb', line 58579

def update!(**args)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @tags = args[:tags] if args.key?(:tags)
end