Class: Google::Apis::ComputeV1::SslCertificateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SslCertificateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateAggregatedList
constructor
A new instance of SslCertificateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateAggregatedList
Returns a new instance of SslCertificateAggregatedList.
59630 59631 59632 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59591 59592 59593 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59591 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
Corresponds to the JSON property items
59596 59597 59598 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59596 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
sslCertificateAggregatedList for lists of SSL
Certificates.
Corresponds to the JSON property kind
59603 59604 59605 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59603 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59613 59614 59615 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59613 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59618 59619 59620 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59618 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
59623 59624 59625 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59623 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59628 59629 59630 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59628 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59635 59636 59637 59638 59639 59640 59641 59642 59643 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59635 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |