Class: Google::Apis::ComputeV1::SslCertificateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SslCertificateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateAggregatedList
constructor
A new instance of SslCertificateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateAggregatedList
Returns a new instance of SslCertificateAggregatedList.
58782 58783 58784 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58782 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58743 58744 58745 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58743 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
Corresponds to the JSON property items
58748 58749 58750 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58748 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
sslCertificateAggregatedList for lists of SSL
Certificates.
Corresponds to the JSON property kind
58755 58756 58757 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58755 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58765 58766 58767 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58765 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58770 58771 58772 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58770 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
58775 58776 58777 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58775 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58780 58781 58782 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58780 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58787 58788 58789 58790 58791 58792 58793 58794 58795 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58787 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |