Class: Google::Apis::ComputeV1::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



58454
58455
58456
# File 'lib/google/apis/compute_v1/classes.rb', line 58454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58415
58416
58417
# File 'lib/google/apis/compute_v1/classes.rb', line 58415

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



58420
58421
58422
# File 'lib/google/apis/compute_v1/classes.rb', line 58420

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


58427
58428
58429
# File 'lib/google/apis/compute_v1/classes.rb', line 58427

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58437
58438
58439
# File 'lib/google/apis/compute_v1/classes.rb', line 58437

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58442
58443
58444
# File 'lib/google/apis/compute_v1/classes.rb', line 58442

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58447
58448
58449
# File 'lib/google/apis/compute_v1/classes.rb', line 58447

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58452
58453
58454
# File 'lib/google/apis/compute_v1/classes.rb', line 58452

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58459
58460
58461
58462
58463
58464
58465
58466
58467
# File 'lib/google/apis/compute_v1/classes.rb', line 58459

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end