Class: Google::Apis::ComputeV1::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



58413
58414
58415
# File 'lib/google/apis/compute_v1/classes.rb', line 58413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58374
58375
58376
# File 'lib/google/apis/compute_v1/classes.rb', line 58374

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



58379
58380
58381
# File 'lib/google/apis/compute_v1/classes.rb', line 58379

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


58386
58387
58388
# File 'lib/google/apis/compute_v1/classes.rb', line 58386

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58396
58397
58398
# File 'lib/google/apis/compute_v1/classes.rb', line 58396

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58401
58402
58403
# File 'lib/google/apis/compute_v1/classes.rb', line 58401

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58406
58407
58408
# File 'lib/google/apis/compute_v1/classes.rb', line 58406

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58411
58412
58413
# File 'lib/google/apis/compute_v1/classes.rb', line 58411

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58418
58419
58420
58421
58422
58423
58424
58425
58426
# File 'lib/google/apis/compute_v1/classes.rb', line 58418

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end