Class: Google::Apis::ComputeV1::SslCertificateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SslCertificateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateAggregatedList
constructor
A new instance of SslCertificateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateAggregatedList
Returns a new instance of SslCertificateAggregatedList.
58413 58414 58415 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58374 58375 58376 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58374 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
Corresponds to the JSON property items
58379 58380 58381 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58379 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
sslCertificateAggregatedList for lists of SSL
Certificates.
Corresponds to the JSON property kind
58386 58387 58388 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58386 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58396 58397 58398 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58396 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58401 58402 58403 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58401 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
58406 58407 58408 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58406 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58411 58412 58413 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58411 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58418 58419 58420 58421 58422 58423 58424 58425 58426 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58418 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |