Class: Google::Apis::ComputeV1::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



58067
58068
58069
# File 'lib/google/apis/compute_v1/classes.rb', line 58067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58028
58029
58030
# File 'lib/google/apis/compute_v1/classes.rb', line 58028

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



58033
58034
58035
# File 'lib/google/apis/compute_v1/classes.rb', line 58033

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


58040
58041
58042
# File 'lib/google/apis/compute_v1/classes.rb', line 58040

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58050
58051
58052
# File 'lib/google/apis/compute_v1/classes.rb', line 58050

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58055
58056
58057
# File 'lib/google/apis/compute_v1/classes.rb', line 58055

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58060
58061
58062
# File 'lib/google/apis/compute_v1/classes.rb', line 58060

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58065
58066
58067
# File 'lib/google/apis/compute_v1/classes.rb', line 58065

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58072
58073
58074
58075
58076
58077
58078
58079
58080
# File 'lib/google/apis/compute_v1/classes.rb', line 58072

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end