Class: Google::Apis::ComputeV1::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



52958
52959
52960
# File 'lib/google/apis/compute_v1/classes.rb', line 52958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52919
52920
52921
# File 'lib/google/apis/compute_v1/classes.rb', line 52919

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



52924
52925
52926
# File 'lib/google/apis/compute_v1/classes.rb', line 52924

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


52931
52932
52933
# File 'lib/google/apis/compute_v1/classes.rb', line 52931

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52941
52942
52943
# File 'lib/google/apis/compute_v1/classes.rb', line 52941

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52946
52947
52948
# File 'lib/google/apis/compute_v1/classes.rb', line 52946

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52951
52952
52953
# File 'lib/google/apis/compute_v1/classes.rb', line 52951

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52956
52957
52958
# File 'lib/google/apis/compute_v1/classes.rb', line 52956

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52963
52964
52965
52966
52967
52968
52969
52970
52971
# File 'lib/google/apis/compute_v1/classes.rb', line 52963

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end