Class: Google::Apis::ComputeV1::SslCertificateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SslCertificateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of SslCertificate resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::SslCertificate>
A list of SslCertificate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SslCertificateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateList
constructor
A new instance of SslCertificateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateList
Returns a new instance of SslCertificateList.
59755 59756 59757 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59755 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59723 59724 59725 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59723 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::SslCertificate>
A list of SslCertificate resources.
Corresponds to the JSON property items
59728 59729 59730 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59728 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
59733 59734 59735 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59733 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59743 59744 59745 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59743 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59748 59749 59750 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59748 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SslCertificateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59753 59754 59755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59753 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59760 59761 59762 59763 59764 59765 59766 59767 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59760 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |