Class: Google::Apis::ComputeV1::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



59705
59706
59707
# File 'lib/google/apis/compute_v1/classes.rb', line 59705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59673
59674
59675
# File 'lib/google/apis/compute_v1/classes.rb', line 59673

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



59678
59679
59680
# File 'lib/google/apis/compute_v1/classes.rb', line 59678

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


59683
59684
59685
# File 'lib/google/apis/compute_v1/classes.rb', line 59683

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59693
59694
59695
# File 'lib/google/apis/compute_v1/classes.rb', line 59693

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59698
59699
59700
# File 'lib/google/apis/compute_v1/classes.rb', line 59698

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59703
59704
59705
# File 'lib/google/apis/compute_v1/classes.rb', line 59703

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59710
59711
59712
59713
59714
59715
59716
59717
# File 'lib/google/apis/compute_v1/classes.rb', line 59710

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end