Class: Google::Apis::ComputeV1::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



58919
58920
58921
# File 'lib/google/apis/compute_v1/classes.rb', line 58919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58887
58888
58889
# File 'lib/google/apis/compute_v1/classes.rb', line 58887

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



58892
58893
58894
# File 'lib/google/apis/compute_v1/classes.rb', line 58892

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


58897
58898
58899
# File 'lib/google/apis/compute_v1/classes.rb', line 58897

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58907
58908
58909
# File 'lib/google/apis/compute_v1/classes.rb', line 58907

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58912
58913
58914
# File 'lib/google/apis/compute_v1/classes.rb', line 58912

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58917
58918
58919
# File 'lib/google/apis/compute_v1/classes.rb', line 58917

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58924
58925
58926
58927
58928
58929
58930
58931
# File 'lib/google/apis/compute_v1/classes.rb', line 58924

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end