Class: Google::Apis::ComputeV1::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



58579
58580
58581
# File 'lib/google/apis/compute_v1/classes.rb', line 58579

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58547
58548
58549
# File 'lib/google/apis/compute_v1/classes.rb', line 58547

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



58552
58553
58554
# File 'lib/google/apis/compute_v1/classes.rb', line 58552

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


58557
58558
58559
# File 'lib/google/apis/compute_v1/classes.rb', line 58557

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58567
58568
58569
# File 'lib/google/apis/compute_v1/classes.rb', line 58567

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58572
58573
58574
# File 'lib/google/apis/compute_v1/classes.rb', line 58572

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58577
58578
58579
# File 'lib/google/apis/compute_v1/classes.rb', line 58577

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58584
58585
58586
58587
58588
58589
58590
58591
# File 'lib/google/apis/compute_v1/classes.rb', line 58584

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end