Class: Google::Apis::ComputeV1::SslCertificateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SslCertificateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of SslCertificate resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::SslCertificate>
A list of SslCertificate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SslCertificateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateList
constructor
A new instance of SslCertificateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateList
Returns a new instance of SslCertificateList.
58538 58539 58540 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58538 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58506 58507 58508 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58506 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::SslCertificate>
A list of SslCertificate resources.
Corresponds to the JSON property items
58511 58512 58513 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58511 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
58516 58517 58518 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58516 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58526 58527 58528 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58526 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58531 58532 58533 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58531 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SslCertificateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58536 58537 58538 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58536 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58543 58544 58545 58546 58547 58548 58549 58550 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58543 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |