Class: Google::Apis::ComputeV1::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



53083
53084
53085
# File 'lib/google/apis/compute_v1/classes.rb', line 53083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53051
53052
53053
# File 'lib/google/apis/compute_v1/classes.rb', line 53051

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



53056
53057
53058
# File 'lib/google/apis/compute_v1/classes.rb', line 53056

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


53061
53062
53063
# File 'lib/google/apis/compute_v1/classes.rb', line 53061

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53071
53072
53073
# File 'lib/google/apis/compute_v1/classes.rb', line 53071

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53076
53077
53078
# File 'lib/google/apis/compute_v1/classes.rb', line 53076

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53081
53082
53083
# File 'lib/google/apis/compute_v1/classes.rb', line 53081

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53088
53089
53090
53091
53092
53093
53094
53095
# File 'lib/google/apis/compute_v1/classes.rb', line 53088

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end