Class: Google::Apis::ComputeV1::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



32980
32981
32982
# File 'lib/google/apis/compute_v1/classes.rb', line 32980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32949
32950
32951
# File 'lib/google/apis/compute_v1/classes.rb', line 32949

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



32954
32955
32956
# File 'lib/google/apis/compute_v1/classes.rb', line 32954

def items
  @items
end

#kindString

Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


32959
32960
32961
# File 'lib/google/apis/compute_v1/classes.rb', line 32959

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32968
32969
32970
# File 'lib/google/apis/compute_v1/classes.rb', line 32968

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32973
32974
32975
# File 'lib/google/apis/compute_v1/classes.rb', line 32973

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32978
32979
32980
# File 'lib/google/apis/compute_v1/classes.rb', line 32978

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32985
32986
32987
32988
32989
32990
32991
32992
# File 'lib/google/apis/compute_v1/classes.rb', line 32985

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end