Class: Google::Apis::ComputeV1::SslHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslHealthCheck

Returns a new instance of SslHealthCheck.



54059
54060
54061
# File 'lib/google/apis/compute_v1/classes.rb', line 54059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


54001
54002
54003
# File 'lib/google/apis/compute_v1/classes.rb', line 54001

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


54006
54007
54008
# File 'lib/google/apis/compute_v1/classes.rb', line 54006

def port_name
  @port_name
end

#port_specificationString

Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Corresponds to the JSON property portSpecification

Returns:

  • (String)


54033
54034
54035
# File 'lib/google/apis/compute_v1/classes.rb', line 54033

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


54040
54041
54042
# File 'lib/google/apis/compute_v1/classes.rb', line 54040

def proxy_header
  @proxy_header
end

#requestString

Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection and SSL handshake. Corresponds to the JSON property request

Returns:

  • (String)


54047
54048
54049
# File 'lib/google/apis/compute_v1/classes.rb', line 54047

def request
  @request
end

#responseString

Creates a content-based SSL health check. In addition to establishing a TCP connection and the TLS handshake, you can configure the health check to pass only when the backend sends this exact response ASCII string, up to 1024 bytes in length. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria- protocol-ssl-tcp Corresponds to the JSON property response

Returns:

  • (String)


54057
54058
54059
# File 'lib/google/apis/compute_v1/classes.rb', line 54057

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54064
54065
54066
54067
54068
54069
54070
54071
# File 'lib/google/apis/compute_v1/classes.rb', line 54064

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request = args[:request] if args.key?(:request)
  @response = args[:response] if args.key?(:response)
end