Class: Google::Apis::ComputeV1::SslHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslHealthCheck

Returns a new instance of SslHealthCheck.



30279
30280
30281
# File 'lib/google/apis/compute_v1/classes.rb', line 30279

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

The TCP port number for the health check request. The default value is 443. Valid values are 1 through 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


30239
30240
30241
# File 'lib/google/apis/compute_v1/classes.rb', line 30239

def port
  @port
end

#port_nameString

Port name as defined in InstanceGroup#NamedPort#name. If both port and port_name are defined, port takes precedence. Corresponds to the JSON property portName

Returns:

  • (String)


30245
30246
30247
# File 'lib/google/apis/compute_v1/classes.rb', line 30245

def port_name
  @port_name
end

#port_specificationString

Specifies how port is selected for health checking, can be one of following values: USE_FIXED_PORT: The port number in port is used for health checking. USE_NAMED_PORT: The portName is used for health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each network endpoint is used for health checking. For other backends, the port or named port specified in the Backend Service is used for health checking. If not specified, SSL health check follows behavior specified in port and portName fields. Corresponds to the JSON property portSpecification

Returns:

  • (String)


30256
30257
30258
# File 'lib/google/apis/compute_v1/classes.rb', line 30256

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


30262
30263
30264
# File 'lib/google/apis/compute_v1/classes.rb', line 30262

def proxy_header
  @proxy_header
end

#requestString

The application data to send once the SSL connection has been established ( default value is empty). If both request and response are empty, the connection establishment alone will indicate health. The request data can only be ASCII. Corresponds to the JSON property request

Returns:

  • (String)


30270
30271
30272
# File 'lib/google/apis/compute_v1/classes.rb', line 30270

def request
  @request
end

#responseString

The bytes to match against the beginning of the response data. If left empty ( the default value), any response will indicate health. The response data can only be ASCII. Corresponds to the JSON property response

Returns:

  • (String)


30277
30278
30279
# File 'lib/google/apis/compute_v1/classes.rb', line 30277

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30284
30285
30286
30287
30288
30289
30290
30291
# File 'lib/google/apis/compute_v1/classes.rb', line 30284

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request = args[:request] if args.key?(:request)
  @response = args[:response] if args.key?(:response)
end