Class: Google::Apis::ComputeV1::SslPoliciesAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SslPoliciesAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslPoliciesScopedList>
A list of SslPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SslPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslPoliciesAggregatedList
constructor
A new instance of SslPoliciesAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslPoliciesAggregatedList
Returns a new instance of SslPoliciesAggregatedList.
60001 60002 60003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60001 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
59958 59959 59960 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59958 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59963 59964 59965 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59963 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslPoliciesScopedList>
A list of SslPoliciesScopedList resources.
Corresponds to the JSON property items
59968 59969 59970 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59968 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
sslPolicyAggregatedList for lists of SSL Policies.
Corresponds to the JSON property kind
59974 59975 59976 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59974 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59984 59985 59986 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59984 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59989 59990 59991 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59989 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
59994 59995 59996 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59994 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::SslPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59999 60000 60001 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59999 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60006 60007 60008 60009 60010 60011 60012 60013 60014 60015 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60006 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |