Class: Google::Apis::ComputeV1::SslPoliciesAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SslPoliciesAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslPoliciesScopedList>
A list of SslPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SslPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslPoliciesAggregatedList
constructor
A new instance of SslPoliciesAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslPoliciesAggregatedList
Returns a new instance of SslPoliciesAggregatedList.
59203 59204 59205 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
59160 59161 59162 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59160 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59165 59166 59167 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59165 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::SslPoliciesScopedList>
A list of SslPoliciesScopedList resources.
Corresponds to the JSON property items
59170 59171 59172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59170 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
sslPolicyAggregatedList for lists of SSL Policies.
Corresponds to the JSON property kind
59176 59177 59178 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59176 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59186 59187 59188 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59186 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59191 59192 59193 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59191 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
59196 59197 59198 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59196 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::SslPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59201 59202 59203 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59201 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59208 59209 59210 59211 59212 59213 59214 59215 59216 59217 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59208 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |