Class: Google::Apis::ComputeV1::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



58488
58489
58490
# File 'lib/google/apis/compute_v1/classes.rb', line 58488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


58445
58446
58447
# File 'lib/google/apis/compute_v1/classes.rb', line 58445

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58450
58451
58452
# File 'lib/google/apis/compute_v1/classes.rb', line 58450

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



58455
58456
58457
# File 'lib/google/apis/compute_v1/classes.rb', line 58455

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


58461
58462
58463
# File 'lib/google/apis/compute_v1/classes.rb', line 58461

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58471
58472
58473
# File 'lib/google/apis/compute_v1/classes.rb', line 58471

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58476
58477
58478
# File 'lib/google/apis/compute_v1/classes.rb', line 58476

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58481
58482
58483
# File 'lib/google/apis/compute_v1/classes.rb', line 58481

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58486
58487
58488
# File 'lib/google/apis/compute_v1/classes.rb', line 58486

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58493
58494
58495
58496
58497
58498
58499
58500
58501
58502
# File 'lib/google/apis/compute_v1/classes.rb', line 58493

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end