Class: Google::Apis::ComputeV1::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



56993
56994
56995
# File 'lib/google/apis/compute_v1/classes.rb', line 56993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


56950
56951
56952
# File 'lib/google/apis/compute_v1/classes.rb', line 56950

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56955
56956
56957
# File 'lib/google/apis/compute_v1/classes.rb', line 56955

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



56960
56961
56962
# File 'lib/google/apis/compute_v1/classes.rb', line 56960

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


56966
56967
56968
# File 'lib/google/apis/compute_v1/classes.rb', line 56966

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56976
56977
56978
# File 'lib/google/apis/compute_v1/classes.rb', line 56976

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56981
56982
56983
# File 'lib/google/apis/compute_v1/classes.rb', line 56981

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


56986
56987
56988
# File 'lib/google/apis/compute_v1/classes.rb', line 56986

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56991
56992
56993
# File 'lib/google/apis/compute_v1/classes.rb', line 56991

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56998
56999
57000
57001
57002
57003
57004
57005
57006
57007
# File 'lib/google/apis/compute_v1/classes.rb', line 56998

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end