Class: Google::Apis::ComputeV1::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



53379
53380
53381
# File 'lib/google/apis/compute_v1/classes.rb', line 53379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53336
53337
53338
# File 'lib/google/apis/compute_v1/classes.rb', line 53336

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53341
53342
53343
# File 'lib/google/apis/compute_v1/classes.rb', line 53341

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



53346
53347
53348
# File 'lib/google/apis/compute_v1/classes.rb', line 53346

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


53352
53353
53354
# File 'lib/google/apis/compute_v1/classes.rb', line 53352

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53362
53363
53364
# File 'lib/google/apis/compute_v1/classes.rb', line 53362

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53367
53368
53369
# File 'lib/google/apis/compute_v1/classes.rb', line 53367

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53372
53373
53374
# File 'lib/google/apis/compute_v1/classes.rb', line 53372

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53377
53378
53379
# File 'lib/google/apis/compute_v1/classes.rb', line 53377

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53384
53385
53386
53387
53388
53389
53390
53391
53392
53393
# File 'lib/google/apis/compute_v1/classes.rb', line 53384

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end