Class: Google::Apis::ComputeV1::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



52191
52192
52193
# File 'lib/google/apis/compute_v1/classes.rb', line 52191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


52148
52149
52150
# File 'lib/google/apis/compute_v1/classes.rb', line 52148

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52153
52154
52155
# File 'lib/google/apis/compute_v1/classes.rb', line 52153

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



52158
52159
52160
# File 'lib/google/apis/compute_v1/classes.rb', line 52158

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


52164
52165
52166
# File 'lib/google/apis/compute_v1/classes.rb', line 52164

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52174
52175
52176
# File 'lib/google/apis/compute_v1/classes.rb', line 52174

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52179
52180
52181
# File 'lib/google/apis/compute_v1/classes.rb', line 52179

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52184
52185
52186
# File 'lib/google/apis/compute_v1/classes.rb', line 52184

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52189
52190
52191
# File 'lib/google/apis/compute_v1/classes.rb', line 52189

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52196
52197
52198
52199
52200
52201
52202
52203
52204
52205
# File 'lib/google/apis/compute_v1/classes.rb', line 52196

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end