Class: Google::Apis::ComputeV1::SslPoliciesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesList

Returns a new instance of SslPoliciesList.



58631
58632
58633
# File 'lib/google/apis/compute_v1/classes.rb', line 58631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58597
58598
58599
# File 'lib/google/apis/compute_v1/classes.rb', line 58597

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::SslPolicy>

Output only. A list of SslPolicy resources. Corresponds to the JSON property items



58602
58603
58604
# File 'lib/google/apis/compute_v1/classes.rb', line 58602

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#sslPoliciesList for lists of sslPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


58608
58609
58610
# File 'lib/google/apis/compute_v1/classes.rb', line 58608

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58619
58620
58621
# File 'lib/google/apis/compute_v1/classes.rb', line 58619

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58624
58625
58626
# File 'lib/google/apis/compute_v1/classes.rb', line 58624

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SslPoliciesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58629
58630
58631
# File 'lib/google/apis/compute_v1/classes.rb', line 58629

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58636
58637
58638
58639
58640
58641
58642
58643
# File 'lib/google/apis/compute_v1/classes.rb', line 58636

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end