Class: Google::Apis::ComputeV1::SslPoliciesList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SslPoliciesList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::SslPolicy>
A list of SslPolicy resources.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::SslPoliciesList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslPoliciesList
constructor
A new instance of SslPoliciesList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslPoliciesList
Returns a new instance of SslPoliciesList.
33251 33252 33253 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33219 33220 33221 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33219 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::SslPolicy>
A list of SslPolicy resources.
Corresponds to the JSON property items
33224 33225 33226 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33224 def items @items end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#sslPoliciesList for lists
of sslPolicies.
Corresponds to the JSON property kind
33230 33231 33232 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33230 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33239 33240 33241 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33239 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33244 33245 33246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33244 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SslPoliciesList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33249 33250 33251 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33249 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33256 33257 33258 33259 33260 33261 33262 33263 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33256 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |