Class: Google::Apis::ComputeV1::SslPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an SSL Policy resource. Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers. For more information, read SSL policies overview.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPolicy

Returns a new instance of SslPolicy.



59322
59323
59324
# File 'lib/google/apis/compute_v1/classes.rb', line 59322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


59217
59218
59219
# File 'lib/google/apis/compute_v1/classes.rb', line 59217

def creation_timestamp
  @creation_timestamp
end

#custom_featuresArray<String>

A list of features enabled when the selected profile is CUSTOM. The method returns the set of features that can be specified in this list. This field must be empty if the profile is notCUSTOM. Corresponds to the JSON property customFeatures

Returns:

  • (Array<String>)


59224
59225
59226
# File 'lib/google/apis/compute_v1/classes.rb', line 59224

def custom_features
  @custom_features
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


59230
59231
59232
# File 'lib/google/apis/compute_v1/classes.rb', line 59230

def description
  @description
end

#enabled_featuresArray<String>

Output only. [Output Only] The list of features enabled in the SSL policy. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


59235
59236
59237
# File 'lib/google/apis/compute_v1/classes.rb', line 59235

def enabled_features
  @enabled_features
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a SslPolicy. An up-to-date fingerprint must be provided in order to update the SslPolicy, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an SslPolicy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


59247
59248
59249
# File 'lib/google/apis/compute_v1/classes.rb', line 59247

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


59254
59255
59256
# File 'lib/google/apis/compute_v1/classes.rb', line 59254

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute#sslPolicyfor SSL policies. Corresponds to the JSON property kind

Returns:

  • (String)


59260
59261
59262
# File 'lib/google/apis/compute_v1/classes.rb', line 59260

def kind
  @kind
end

#min_tls_versionString

The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field must be set to RESTRICTED. Corresponds to the JSON property minTlsVersion

Returns:

  • (String)


59268
59269
59270
# File 'lib/google/apis/compute_v1/classes.rb', line 59268

def min_tls_version
  @min_tls_version
end

#nameString

Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


59279
59280
59281
# File 'lib/google/apis/compute_v1/classes.rb', line 59279

def name
  @name
end

#post_quantum_key_exchangeString

One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates X25519MLKEM768 key exchange when clients advertise support for it. When set to DEFAULT, or if no SSL Policy is attached to the target proxy, the load balancer disallows X25519MLKEM768 key exchange before October 2026, and allows it afterward. When set to ENABLED, the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key exchange until October 2027, and allows it afterward. Corresponds to the JSON property postQuantumKeyExchange

Returns:

  • (String)


59292
59293
59294
# File 'lib/google/apis/compute_v1/classes.rb', line 59292

def post_quantum_key_exchange
  @post_quantum_key_exchange
end

#profileString

Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in the customFeatures field. If using FIPS_202205, the min_tls_version field must be set to TLS_1_2. Corresponds to the JSON property profile

Returns:

  • (String)


59302
59303
59304
# File 'lib/google/apis/compute_v1/classes.rb', line 59302

def profile
  @profile
end

#regionString

Output only. [Output Only] URL of the region where the regional SSL policy resides. This field is not applicable to global SSL policies. Corresponds to the JSON property region

Returns:

  • (String)


59308
59309
59310
# File 'lib/google/apis/compute_v1/classes.rb', line 59308

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59313
59314
59315
# File 'lib/google/apis/compute_v1/classes.rb', line 59313

def self_link
  @self_link
end

#warningsArray<Google::Apis::ComputeV1::SslPolicy::Warning>

Output only. [Output Only] If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages. Corresponds to the JSON property warnings



59320
59321
59322
# File 'lib/google/apis/compute_v1/classes.rb', line 59320

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59327
59328
59329
59330
59331
59332
59333
59334
59335
59336
59337
59338
59339
59340
59341
59342
# File 'lib/google/apis/compute_v1/classes.rb', line 59327

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @min_tls_version = args[:min_tls_version] if args.key?(:min_tls_version)
  @name = args[:name] if args.key?(:name)
  @post_quantum_key_exchange = args[:post_quantum_key_exchange] if args.key?(:post_quantum_key_exchange)
  @profile = args[:profile] if args.key?(:profile)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warnings = args[:warnings] if args.key?(:warnings)
end