Class: Google::Apis::ComputeV1::SslPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an SSL Policy resource. Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers. For more information, read SSL policies overview.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPolicy

Returns a new instance of SslPolicy.



57427
57428
57429
# File 'lib/google/apis/compute_v1/classes.rb', line 57427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


57335
57336
57337
# File 'lib/google/apis/compute_v1/classes.rb', line 57335

def creation_timestamp
  @creation_timestamp
end

#custom_featuresArray<String>

A list of features enabled when the selected profile is CUSTOM. The method returns the set of features that can be specified in this list. This field must be empty if the profile is notCUSTOM. Corresponds to the JSON property customFeatures

Returns:

  • (Array<String>)


57342
57343
57344
# File 'lib/google/apis/compute_v1/classes.rb', line 57342

def custom_features
  @custom_features
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


57348
57349
57350
# File 'lib/google/apis/compute_v1/classes.rb', line 57348

def description
  @description
end

#enabled_featuresArray<String>

Output only. [Output Only] The list of features enabled in the SSL policy. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


57353
57354
57355
# File 'lib/google/apis/compute_v1/classes.rb', line 57353

def enabled_features
  @enabled_features
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a SslPolicy. An up-to-date fingerprint must be provided in order to update the SslPolicy, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an SslPolicy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


57365
57366
57367
# File 'lib/google/apis/compute_v1/classes.rb', line 57365

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


57372
57373
57374
# File 'lib/google/apis/compute_v1/classes.rb', line 57372

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute#sslPolicyfor SSL policies. Corresponds to the JSON property kind

Returns:

  • (String)


57378
57379
57380
# File 'lib/google/apis/compute_v1/classes.rb', line 57378

def kind
  @kind
end

#min_tls_versionString

The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field must be set to RESTRICTED. Corresponds to the JSON property minTlsVersion

Returns:

  • (String)


57386
57387
57388
# File 'lib/google/apis/compute_v1/classes.rb', line 57386

def min_tls_version
  @min_tls_version
end

#nameString

Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


57397
57398
57399
# File 'lib/google/apis/compute_v1/classes.rb', line 57397

def name
  @name
end

#profileString

Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in the customFeatures field. If using FIPS_202205, the min_tls_version field must be set to TLS_1_2. Corresponds to the JSON property profile

Returns:

  • (String)


57407
57408
57409
# File 'lib/google/apis/compute_v1/classes.rb', line 57407

def profile
  @profile
end

#regionString

Output only. [Output Only] URL of the region where the regional SSL policy resides. This field is not applicable to global SSL policies. Corresponds to the JSON property region

Returns:

  • (String)


57413
57414
57415
# File 'lib/google/apis/compute_v1/classes.rb', line 57413

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57418
57419
57420
# File 'lib/google/apis/compute_v1/classes.rb', line 57418

def self_link
  @self_link
end

#warningsArray<Google::Apis::ComputeV1::SslPolicy::Warning>

Output only. [Output Only] If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages. Corresponds to the JSON property warnings



57425
57426
57427
# File 'lib/google/apis/compute_v1/classes.rb', line 57425

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57432
57433
57434
57435
57436
57437
57438
57439
57440
57441
57442
57443
57444
57445
57446
# File 'lib/google/apis/compute_v1/classes.rb', line 57432

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @min_tls_version = args[:min_tls_version] if args.key?(:min_tls_version)
  @name = args[:name] if args.key?(:name)
  @profile = args[:profile] if args.key?(:profile)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warnings = args[:warnings] if args.key?(:warnings)
end