Class: Google::Apis::ComputeV1::SslPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SslPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents an SSL Policy resource. Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers. For more information, read SSL policies overview.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#custom_features ⇒ Array<String>
A list of features enabled when the selected profile is CUSTOM.
-
#description ⇒ String
An optional description of this resource.
-
#enabled_features ⇒ Array<String>
Output only.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#min_tls_version ⇒ String
The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer.
-
#name ⇒ String
Name of the resource.
-
#profile ⇒ String
Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warnings ⇒ Array<Google::Apis::ComputeV1::SslPolicy::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslPolicy
constructor
A new instance of SslPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslPolicy
Returns a new instance of SslPolicy.
52623 52624 52625 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
52533 52534 52535 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52533 def @creation_timestamp end |
#custom_features ⇒ Array<String>
A list of features enabled when the selected profile is CUSTOM. The
method returns the set of features that can be
specified in this list. This field must be empty if the profile is notCUSTOM.
Corresponds to the JSON property customFeatures
52540 52541 52542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52540 def custom_features @custom_features end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
52546 52547 52548 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52546 def description @description end |
#enabled_features ⇒ Array<String>
Output only. [Output Only] The list of features enabled in the SSL policy.
Corresponds to the JSON property enabledFeatures
52551 52552 52553 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52551 def enabled_features @enabled_features end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a SslPolicy. An up-to-date fingerprint must be
provided in order to update the SslPolicy, otherwise the
request will fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an SslPolicy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
52563 52564 52565 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52563 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
52570 52571 52572 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52570 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#sslPolicyfor
SSL policies.
Corresponds to the JSON property kind
52576 52577 52578 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52576 def kind @kind end |
#min_tls_version ⇒ String
The minimum version of SSL protocol that can be used by the clients to
establish a connection with the load balancer. This can be one ofTLS_1_0,
TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
must be set to RESTRICTED.
Corresponds to the JSON property minTlsVersion
52584 52585 52586 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52584 def min_tls_version @min_tls_version end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long, and comply
with RFC1035. Specifically, the name must be 1-63 characters
long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
52595 52596 52597 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52595 def name @name end |
#profile ⇒ String
Profile specifies the set of SSL features that can be used by the load
balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE,
MODERN, RESTRICTED, orCUSTOM. If using CUSTOM, the set of SSL features
to enable must be specified in the customFeatures field.
Corresponds to the JSON property profile
52603 52604 52605 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52603 def profile @profile end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional SSL policy
resides. This field is not applicable to global SSL policies.
Corresponds to the JSON property region
52609 52610 52611 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52609 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
52614 52615 52616 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52614 def self_link @self_link end |
#warnings ⇒ Array<Google::Apis::ComputeV1::SslPolicy::Warning>
Output only. [Output Only] If potential misconfigurations are detected for
this
SSL policy, this field will be populated with warning messages.
Corresponds to the JSON property warnings
52621 52622 52623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52621 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52628 52629 52630 52631 52632 52633 52634 52635 52636 52637 52638 52639 52640 52641 52642 |
# File 'lib/google/apis/compute_v1/classes.rb', line 52628 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @custom_features = args[:custom_features] if args.key?(:custom_features) @description = args[:description] if args.key?(:description) @enabled_features = args[:enabled_features] if args.key?(:enabled_features) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @min_tls_version = args[:min_tls_version] if args.key?(:min_tls_version) @name = args[:name] if args.key?(:name) @profile = args[:profile] if args.key?(:profile) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @warnings = args[:warnings] if args.key?(:warnings) end |