Class: Google::Apis::ComputeV1::SslPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents an SSL Policy resource. Use SSL policies to control the SSL features, such as versions and cipher suites, offered by an HTTPS or SSL Proxy load balancer. For more information, read SSL Policy Concepts.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPolicy

Returns a new instance of SslPolicy.



33436
33437
33438
# File 'lib/google/apis/compute_v1/classes.rb', line 33436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


33358
33359
33360
# File 'lib/google/apis/compute_v1/classes.rb', line 33358

def creation_timestamp
  @creation_timestamp
end

#custom_featuresArray<String>

A list of features enabled when the selected profile is CUSTOM. The method returns the set of features that can be specified in this list. This field must be empty if the profile is not CUSTOM. Corresponds to the JSON property customFeatures

Returns:

  • (Array<String>)


33365
33366
33367
# File 'lib/google/apis/compute_v1/classes.rb', line 33365

def custom_features
  @custom_features
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


33371
33372
33373
# File 'lib/google/apis/compute_v1/classes.rb', line 33371

def description
  @description
end

#enabled_featuresArray<String>

[Output Only] The list of features enabled in the SSL policy. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


33376
33377
33378
# File 'lib/google/apis/compute_v1/classes.rb', line 33376

def enabled_features
  @enabled_features
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a SslPolicy. An up-to-date fingerprint must be provided in order to update the SslPolicy, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an SslPolicy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


33387
33388
33389
# File 'lib/google/apis/compute_v1/classes.rb', line 33387

def fingerprint
  @fingerprint
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


33393
33394
33395
# File 'lib/google/apis/compute_v1/classes.rb', line 33393

def id
  @id
end

#kindString

[Output only] Type of the resource. Always compute#sslPolicyfor SSL policies. Corresponds to the JSON property kind

Returns:

  • (String)


33398
33399
33400
# File 'lib/google/apis/compute_v1/classes.rb', line 33398

def kind
  @kind
end

#min_tls_versionString

The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one of TLS_1_0, TLS_1_1, TLS_1_2. Corresponds to the JSON property minTlsVersion

Returns:

  • (String)


33405
33406
33407
# File 'lib/google/apis/compute_v1/classes.rb', line 33405

def min_tls_version
  @min_tls_version
end

#nameString

Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


33415
33416
33417
# File 'lib/google/apis/compute_v1/classes.rb', line 33415

def name
  @name
end

#profileString

Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one of COMPATIBLE, MODERN, RESTRICTED, or CUSTOM. If using CUSTOM, the set of SSL features to enable must be specified in the customFeatures field. Corresponds to the JSON property profile

Returns:

  • (String)


33423
33424
33425
# File 'lib/google/apis/compute_v1/classes.rb', line 33423

def profile
  @profile
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33428
33429
33430
# File 'lib/google/apis/compute_v1/classes.rb', line 33428

def self_link
  @self_link
end

#warningsArray<Google::Apis::ComputeV1::SslPolicy::Warning>

[Output Only] If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages. Corresponds to the JSON property warnings



33434
33435
33436
# File 'lib/google/apis/compute_v1/classes.rb', line 33434

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33441
33442
33443
33444
33445
33446
33447
33448
33449
33450
33451
33452
33453
33454
# File 'lib/google/apis/compute_v1/classes.rb', line 33441

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @min_tls_version = args[:min_tls_version] if args.key?(:min_tls_version)
  @name = args[:name] if args.key?(:name)
  @profile = args[:profile] if args.key?(:profile)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warnings = args[:warnings] if args.key?(:warnings)
end