Class: Google::Apis::ComputeV1::StatefulPolicyPreservedState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration of preserved resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedState

Returns a new instance of StatefulPolicyPreservedState.



59818
59819
59820
# File 'lib/google/apis/compute_v1/classes.rb', line 59818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateDiskDevice>

Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks. Corresponds to the JSON property disks



59802
59803
59804
# File 'lib/google/apis/compute_v1/classes.rb', line 59802

def disks
  @disks
end

#external_i_psHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>

External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property externalIPs



59809
59810
59811
# File 'lib/google/apis/compute_v1/classes.rb', line 59809

def external_i_ps
  @external_i_ps
end

#internal_i_psHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>

Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property internalIPs



59816
59817
59818
# File 'lib/google/apis/compute_v1/classes.rb', line 59816

def internal_i_ps
  @internal_i_ps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59823
59824
59825
59826
59827
# File 'lib/google/apis/compute_v1/classes.rb', line 59823

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps)
  @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps)
end