Class: Google::Apis::ComputeV1::StatefulPolicyPreservedState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StatefulPolicyPreservedState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Configuration of preserved resources.
Instance Attribute Summary collapse
-
#disks ⇒ Hash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateDiskDevice>
Disks created on the instances that will be preserved on instance delete, update, etc.
-
#external_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>
External network IPs assigned to the instances that will be preserved on instance delete, update, etc.
-
#internal_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>
Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatefulPolicyPreservedState
constructor
A new instance of StatefulPolicyPreservedState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatefulPolicyPreservedState
Returns a new instance of StatefulPolicyPreservedState.
59092 59093 59094 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Hash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateDiskDevice>
Disks created on the instances that will be preserved on instance
delete, update, etc. This map is keyed with the device names of
the disks.
Corresponds to the JSON property disks
59076 59077 59078 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59076 def disks @disks end |
#external_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>
External network IPs assigned to the instances that will be preserved on
instance delete, update, etc. This map is keyed with the network
interface name.
Corresponds to the JSON property externalIPs
59083 59084 59085 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59083 def external_i_ps @external_i_ps end |
#internal_i_ps ⇒ Hash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>
Internal network IPs assigned to the instances that will be preserved on
instance delete, update, etc. This map is keyed with the network
interface name.
Corresponds to the JSON property internalIPs
59090 59091 59092 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59090 def internal_i_ps @internal_i_ps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59097 59098 59099 59100 59101 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59097 def update!(**args) @disks = args[:disks] if args.key?(:disks) @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps) @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps) end |