Class: Google::Apis::ComputeV1::StatefulPolicyPreservedState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration of preserved resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedState

Returns a new instance of StatefulPolicyPreservedState.



53967
53968
53969
# File 'lib/google/apis/compute_v1/classes.rb', line 53967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateDiskDevice>

Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks. Corresponds to the JSON property disks



53951
53952
53953
# File 'lib/google/apis/compute_v1/classes.rb', line 53951

def disks
  @disks
end

#external_i_psHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>

External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property externalIPs



53958
53959
53960
# File 'lib/google/apis/compute_v1/classes.rb', line 53958

def external_i_ps
  @external_i_ps
end

#internal_i_psHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp>

Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property internalIPs



53965
53966
53967
# File 'lib/google/apis/compute_v1/classes.rb', line 53965

def internal_i_ps
  @internal_i_ps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53972
53973
53974
53975
53976
# File 'lib/google/apis/compute_v1/classes.rb', line 53972

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps)
  @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps)
end