Class: Google::Apis::ComputeV1::StatefulPolicyPreservedState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Configuration of preserved resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedState

Returns a new instance of StatefulPolicyPreservedState.



33570
33571
33572
# File 'lib/google/apis/compute_v1/classes.rb', line 33570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksHash<String,Google::Apis::ComputeV1::StatefulPolicyPreservedStateDiskDevice>

Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks. Corresponds to the JSON property disks



33568
33569
33570
# File 'lib/google/apis/compute_v1/classes.rb', line 33568

def disks
  @disks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33575
33576
33577
# File 'lib/google/apis/compute_v1/classes.rb', line 33575

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
end