Class: Google::Apis::ComputeV1::StatefulPolicyPreservedStateNetworkIp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedStateNetworkIp

Returns a new instance of StatefulPolicyPreservedStateNetworkIp.



59855
59856
59857
# File 'lib/google/apis/compute_v1/classes.rb', line 59855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteString

These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Corresponds to the JSON property autoDelete

Returns:

  • (String)


59853
59854
59855
# File 'lib/google/apis/compute_v1/classes.rb', line 59853

def auto_delete
  @auto_delete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59860
59861
59862
# File 'lib/google/apis/compute_v1/classes.rb', line 59860

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
end