Class: Google::Apis::ComputeV1::StoragePool
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StoragePool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a zonal storage pool resource.
Instance Attribute Summary collapse
-
#capacity_provisioning_type ⇒ String
Provisioning type of the byte capacity of the pool.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeV1::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type Corresponds to the JSON property
exapoolProvisionedCapacityGb. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this storage pool.
-
#name ⇒ String
Name of the resource.
-
#params ⇒ Google::Apis::ComputeV1::StoragePoolParams
Additional storage pool params.
-
#performance_provisioning_type ⇒ String
Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS.
-
#pool_provisioned_capacity_gb ⇒ Fixnum
Size of the storage pool in GiB.
-
#pool_provisioned_iops ⇒ Fixnum
Provisioned IOPS of the storage pool.
-
#pool_provisioned_throughput ⇒ Fixnum
Provisioned throughput of the storage pool in MiB/s.
-
#resource_status ⇒ Google::Apis::ComputeV1::StoragePoolResourceStatus
[Output Only] Contains output only fields.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeV1::StoragePoolResourceStatus
[Output Only] Contains output only fields.
-
#storage_pool_type ⇒ String
Type of the storage pool.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePool
constructor
A new instance of StoragePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePool
Returns a new instance of StoragePool.
57824 57825 57826 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_provisioning_type ⇒ String
Provisioning type of the byte capacity of the pool.
Corresponds to the JSON property capacityProvisioningType
57688 57689 57690 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57688 def capacity_provisioning_type @capacity_provisioning_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
57694 57695 57696 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57694 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
57700 57701 57702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57700 def description @description end |
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeV1::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type
Corresponds to the JSON property exapoolProvisionedCapacityGb
57705 57706 57707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57705 def exapool_provisioned_capacity_gb @exapool_provisioned_capacity_gb end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
57712 57713 57714 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57712 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#storagePool
for storage pools.
Corresponds to the JSON property kind
57718 57719 57720 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57718 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this storage pool, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a storage pool.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
57731 57732 57733 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57731 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this storage pool. These can be later modified by
the setLabels method.
Corresponds to the JSON property labels
57737 57738 57739 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57737 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
57748 57749 57750 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57748 def name @name end |
#params ⇒ Google::Apis::ComputeV1::StoragePoolParams
Additional storage pool params.
Corresponds to the JSON property params
57753 57754 57755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57753 def params @params end |
#performance_provisioning_type ⇒ String
Provisioning type of the performance-related parameters of the pool,
such as throughput and IOPS.
Corresponds to the JSON property performanceProvisioningType
57759 57760 57761 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57759 def performance_provisioning_type @performance_provisioning_type end |
#pool_provisioned_capacity_gb ⇒ Fixnum
Size of the storage pool in GiB. For more information about the size
limits, see https://cloud.google.com/compute/docs/disks/storage-pools.
Corresponds to the JSON property poolProvisionedCapacityGb
57765 57766 57767 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57765 def pool_provisioned_capacity_gb @pool_provisioned_capacity_gb end |
#pool_provisioned_iops ⇒ Fixnum
Provisioned IOPS of the storage pool. Only relevant if the storage pool
type is hyperdisk-balanced.
Corresponds to the JSON property poolProvisionedIops
57771 57772 57773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57771 def pool_provisioned_iops @pool_provisioned_iops end |
#pool_provisioned_throughput ⇒ Fixnum
Provisioned throughput of the storage pool in MiB/s. Only relevant if the
storage pool type is hyperdisk-balanced or hyperdisk-throughput.
Corresponds to the JSON property poolProvisionedThroughput
57777 57778 57779 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57777 def pool_provisioned_throughput @pool_provisioned_throughput end |
#resource_status ⇒ Google::Apis::ComputeV1::StoragePoolResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property resourceStatus
57782 57783 57784 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57782 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
57788 57789 57790 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57788 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
57793 57794 57795 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57793 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. [Output Only] The status of storage pool creation.
- CREATING: Storage pool is provisioning. storagePool.
- FAILED: Storage pool creation failed.
- READY: Storage pool is ready for use.
- DELETING: Storage pool is deleting.
Corresponds to the JSON property
state
57805 57806 57807 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57805 def state @state end |
#status ⇒ Google::Apis::ComputeV1::StoragePoolResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property status
57810 57811 57812 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57810 def status @status end |
#storage_pool_type ⇒ String
Type of the storage pool.
Corresponds to the JSON property storagePoolType
57815 57816 57817 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57815 def storage_pool_type @storage_pool_type end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the storage pool resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
57822 57823 57824 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57822 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 57851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57829 def update!(**args) @capacity_provisioning_type = args[:capacity_provisioning_type] if args.key?(:capacity_provisioning_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @performance_provisioning_type = args[:performance_provisioning_type] if args.key?(:performance_provisioning_type) @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb) @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops) @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @storage_pool_type = args[:storage_pool_type] if args.key?(:storage_pool_type) @zone = args[:zone] if args.key?(:zone) end |