Class: Google::Apis::ComputeV1::StoragePoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StoragePoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolAggregatedList
constructor
A new instance of StoragePoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolAggregatedList
Returns a new instance of StoragePoolAggregatedList.
60982 60983 60984 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
60938 60939 60940 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60938 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60943 60944 60945 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60943 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
Corresponds to the JSON property items
60948 60949 60950 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60948 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
storagePoolAggregatedList for aggregated lists of
storage pools.
Corresponds to the JSON property kind
60955 60956 60957 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60955 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60965 60966 60967 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60965 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60970 60971 60972 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60970 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
60975 60976 60977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60975 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60980 60981 60982 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60980 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60987 60988 60989 60990 60991 60992 60993 60994 60995 60996 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60987 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |