Class: Google::Apis::ComputeV1::StoragePoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StoragePoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolAggregatedList
constructor
A new instance of StoragePoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolAggregatedList
Returns a new instance of StoragePoolAggregatedList.
60932 60933 60934 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
60888 60889 60890 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60888 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60893 60894 60895 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60893 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
Corresponds to the JSON property items
60898 60899 60900 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60898 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
storagePoolAggregatedList for aggregated lists of
storage pools.
Corresponds to the JSON property kind
60905 60906 60907 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60905 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60915 60916 60917 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60915 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60920 60921 60922 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60920 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
60925 60926 60927 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60925 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60930 60931 60932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60930 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60937 60938 60939 60940 60941 60942 60943 60944 60945 60946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60937 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |