Class: Google::Apis::ComputeV1::StoragePoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StoragePoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolAggregatedList
constructor
A new instance of StoragePoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolAggregatedList
Returns a new instance of StoragePoolAggregatedList.
60140 60141 60142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
60096 60097 60098 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60096 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60101 60102 60103 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60101 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
Corresponds to the JSON property items
60106 60107 60108 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60106 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
storagePoolAggregatedList for aggregated lists of
storage pools.
Corresponds to the JSON property kind
60113 60114 60115 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60113 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60123 60124 60125 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60123 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60128 60129 60130 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60128 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
60133 60134 60135 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60133 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60138 60139 60140 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60138 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60145 60146 60147 60148 60149 60150 60151 60152 60153 60154 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60145 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |