Class: Google::Apis::ComputeV1::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



59760
59761
59762
# File 'lib/google/apis/compute_v1/classes.rb', line 59760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


59716
59717
59718
# File 'lib/google/apis/compute_v1/classes.rb', line 59716

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59721
59722
59723
# File 'lib/google/apis/compute_v1/classes.rb', line 59721

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



59726
59727
59728
# File 'lib/google/apis/compute_v1/classes.rb', line 59726

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


59733
59734
59735
# File 'lib/google/apis/compute_v1/classes.rb', line 59733

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59743
59744
59745
# File 'lib/google/apis/compute_v1/classes.rb', line 59743

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59748
59749
59750
# File 'lib/google/apis/compute_v1/classes.rb', line 59748

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


59753
59754
59755
# File 'lib/google/apis/compute_v1/classes.rb', line 59753

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59758
59759
59760
# File 'lib/google/apis/compute_v1/classes.rb', line 59758

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59765
59766
59767
59768
59769
59770
59771
59772
59773
59774
# File 'lib/google/apis/compute_v1/classes.rb', line 59765

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end