Class: Google::Apis::ComputeV1::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



59414
59415
59416
# File 'lib/google/apis/compute_v1/classes.rb', line 59414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


59370
59371
59372
# File 'lib/google/apis/compute_v1/classes.rb', line 59370

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59375
59376
59377
# File 'lib/google/apis/compute_v1/classes.rb', line 59375

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



59380
59381
59382
# File 'lib/google/apis/compute_v1/classes.rb', line 59380

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


59387
59388
59389
# File 'lib/google/apis/compute_v1/classes.rb', line 59387

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59397
59398
59399
# File 'lib/google/apis/compute_v1/classes.rb', line 59397

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59402
59403
59404
# File 'lib/google/apis/compute_v1/classes.rb', line 59402

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


59407
59408
59409
# File 'lib/google/apis/compute_v1/classes.rb', line 59407

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59412
59413
59414
# File 'lib/google/apis/compute_v1/classes.rb', line 59412

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59419
59420
59421
59422
59423
59424
59425
59426
59427
59428
# File 'lib/google/apis/compute_v1/classes.rb', line 59419

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end