Class: Google::Apis::ComputeV1::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



53101
53102
53103
# File 'lib/google/apis/compute_v1/classes.rb', line 53101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53057
53058
53059
# File 'lib/google/apis/compute_v1/classes.rb', line 53057

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53062
53063
53064
# File 'lib/google/apis/compute_v1/classes.rb', line 53062

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



53067
53068
53069
# File 'lib/google/apis/compute_v1/classes.rb', line 53067

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


53074
53075
53076
# File 'lib/google/apis/compute_v1/classes.rb', line 53074

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53084
53085
53086
# File 'lib/google/apis/compute_v1/classes.rb', line 53084

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53089
53090
53091
# File 'lib/google/apis/compute_v1/classes.rb', line 53089

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53094
53095
53096
# File 'lib/google/apis/compute_v1/classes.rb', line 53094

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53099
53100
53101
# File 'lib/google/apis/compute_v1/classes.rb', line 53099

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53106
53107
53108
53109
53110
53111
53112
53113
53114
53115
# File 'lib/google/apis/compute_v1/classes.rb', line 53106

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end