Class: Google::Apis::ComputeV1::StoragePoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StoragePoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of StoragePool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::StoragePool>
A list of StoragePool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::StoragePoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolList
constructor
A new instance of StoragePoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolList
Returns a new instance of StoragePoolList.
61183 61184 61185 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
61139 61140 61141 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61139 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61144 61145 61146 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61144 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::StoragePool>
A list of StoragePool resources.
Corresponds to the JSON property items
61149 61150 61151 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61149 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#storagePoolList
for lists of storagePools.
Corresponds to the JSON property kind
61155 61156 61157 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61155 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61165 61166 61167 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61165 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
61170 61171 61172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61170 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
61176 61177 61178 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61176 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::StoragePoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61181 61182 61183 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61181 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61188 61189 61190 61191 61192 61193 61194 61195 61196 61197 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61188 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |