Class: Google::Apis::ComputeV1::StoragePoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StoragePoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of StoragePool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::StoragePool>
A list of StoragePool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::StoragePoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolList
constructor
A new instance of StoragePoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolList
Returns a new instance of StoragePoolList.
60391 60392 60393 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
60347 60348 60349 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60347 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60352 60353 60354 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60352 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::StoragePool>
A list of StoragePool resources.
Corresponds to the JSON property items
60357 60358 60359 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60357 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#storagePoolList
for lists of storagePools.
Corresponds to the JSON property kind
60363 60364 60365 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60363 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60373 60374 60375 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60373 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60378 60379 60380 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60378 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
60384 60385 60386 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60384 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::StoragePoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60389 60390 60391 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60389 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60396 60397 60398 60399 60400 60401 60402 60403 60404 60405 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60396 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |