Class: Google::Apis::ComputeV1::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



60379
60380
60381
# File 'lib/google/apis/compute_v1/classes.rb', line 60379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


60335
60336
60337
# File 'lib/google/apis/compute_v1/classes.rb', line 60335

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60340
60341
60342
# File 'lib/google/apis/compute_v1/classes.rb', line 60340

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



60345
60346
60347
# File 'lib/google/apis/compute_v1/classes.rb', line 60345

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


60351
60352
60353
# File 'lib/google/apis/compute_v1/classes.rb', line 60351

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60361
60362
60363
# File 'lib/google/apis/compute_v1/classes.rb', line 60361

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60366
60367
60368
# File 'lib/google/apis/compute_v1/classes.rb', line 60366

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


60372
60373
60374
# File 'lib/google/apis/compute_v1/classes.rb', line 60372

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



60377
60378
60379
# File 'lib/google/apis/compute_v1/classes.rb', line 60377

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60384
60385
60386
60387
60388
60389
60390
60391
60392
60393
# File 'lib/google/apis/compute_v1/classes.rb', line 60384

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end