Class: Google::Apis::ComputeV1::StoragePoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StoragePoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of StoragePool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::StoragePool>
A list of StoragePool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::StoragePoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolList
constructor
A new instance of StoragePoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolList
Returns a new instance of StoragePoolList.
59679 59680 59681 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
59635 59636 59637 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59635 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59640 59641 59642 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59640 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::StoragePool>
A list of StoragePool resources.
Corresponds to the JSON property items
59645 59646 59647 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59645 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#storagePoolList
for lists of storagePools.
Corresponds to the JSON property kind
59651 59652 59653 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59651 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59661 59662 59663 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59661 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59666 59667 59668 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59666 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
59672 59673 59674 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59672 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::StoragePoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59677 59678 59679 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59677 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59684 59685 59686 59687 59688 59689 59690 59691 59692 59693 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59684 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |