Class: Google::Apis::ComputeV1::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



59665
59666
59667
# File 'lib/google/apis/compute_v1/classes.rb', line 59665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


59621
59622
59623
# File 'lib/google/apis/compute_v1/classes.rb', line 59621

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59626
59627
59628
# File 'lib/google/apis/compute_v1/classes.rb', line 59626

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



59631
59632
59633
# File 'lib/google/apis/compute_v1/classes.rb', line 59631

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


59637
59638
59639
# File 'lib/google/apis/compute_v1/classes.rb', line 59637

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59647
59648
59649
# File 'lib/google/apis/compute_v1/classes.rb', line 59647

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59652
59653
59654
# File 'lib/google/apis/compute_v1/classes.rb', line 59652

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


59658
59659
59660
# File 'lib/google/apis/compute_v1/classes.rb', line 59658

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59663
59664
59665
# File 'lib/google/apis/compute_v1/classes.rb', line 59663

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59670
59671
59672
59673
59674
59675
59676
59677
59678
59679
# File 'lib/google/apis/compute_v1/classes.rb', line 59670

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end