Class: Google::Apis::ComputeV1::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



54540
54541
54542
# File 'lib/google/apis/compute_v1/classes.rb', line 54540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54496
54497
54498
# File 'lib/google/apis/compute_v1/classes.rb', line 54496

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54501
54502
54503
# File 'lib/google/apis/compute_v1/classes.rb', line 54501

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



54506
54507
54508
# File 'lib/google/apis/compute_v1/classes.rb', line 54506

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


54512
54513
54514
# File 'lib/google/apis/compute_v1/classes.rb', line 54512

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54522
54523
54524
# File 'lib/google/apis/compute_v1/classes.rb', line 54522

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54527
54528
54529
# File 'lib/google/apis/compute_v1/classes.rb', line 54527

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54533
54534
54535
# File 'lib/google/apis/compute_v1/classes.rb', line 54533

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54538
54539
54540
# File 'lib/google/apis/compute_v1/classes.rb', line 54538

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54545
54546
54547
54548
54549
54550
54551
54552
54553
54554
# File 'lib/google/apis/compute_v1/classes.rb', line 54545

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end