Class: Google::Apis::ComputeV1::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



60532
60533
60534
# File 'lib/google/apis/compute_v1/classes.rb', line 60532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


60485
60486
60487
# File 'lib/google/apis/compute_v1/classes.rb', line 60485

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60491
60492
60493
# File 'lib/google/apis/compute_v1/classes.rb', line 60491

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



60496
60497
60498
# File 'lib/google/apis/compute_v1/classes.rb', line 60496

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


60503
60504
60505
# File 'lib/google/apis/compute_v1/classes.rb', line 60503

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60514
60515
60516
# File 'lib/google/apis/compute_v1/classes.rb', line 60514

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60519
60520
60521
# File 'lib/google/apis/compute_v1/classes.rb', line 60519

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


60525
60526
60527
# File 'lib/google/apis/compute_v1/classes.rb', line 60525

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



60530
60531
60532
# File 'lib/google/apis/compute_v1/classes.rb', line 60530

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
# File 'lib/google/apis/compute_v1/classes.rb', line 60537

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end