Class: Google::Apis::ComputeV1::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



60152
60153
60154
# File 'lib/google/apis/compute_v1/classes.rb', line 60152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


60105
60106
60107
# File 'lib/google/apis/compute_v1/classes.rb', line 60105

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60111
60112
60113
# File 'lib/google/apis/compute_v1/classes.rb', line 60111

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



60116
60117
60118
# File 'lib/google/apis/compute_v1/classes.rb', line 60116

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


60123
60124
60125
# File 'lib/google/apis/compute_v1/classes.rb', line 60123

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60134
60135
60136
# File 'lib/google/apis/compute_v1/classes.rb', line 60134

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60139
60140
60141
# File 'lib/google/apis/compute_v1/classes.rb', line 60139

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


60145
60146
60147
# File 'lib/google/apis/compute_v1/classes.rb', line 60145

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



60150
60151
60152
# File 'lib/google/apis/compute_v1/classes.rb', line 60150

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60157
60158
60159
60160
60161
60162
60163
60164
60165
60166
# File 'lib/google/apis/compute_v1/classes.rb', line 60157

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end