Class: Google::Apis::ComputeV1::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



59820
59821
59822
# File 'lib/google/apis/compute_v1/classes.rb', line 59820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


59773
59774
59775
# File 'lib/google/apis/compute_v1/classes.rb', line 59773

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59779
59780
59781
# File 'lib/google/apis/compute_v1/classes.rb', line 59779

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



59784
59785
59786
# File 'lib/google/apis/compute_v1/classes.rb', line 59784

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


59791
59792
59793
# File 'lib/google/apis/compute_v1/classes.rb', line 59791

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59802
59803
59804
# File 'lib/google/apis/compute_v1/classes.rb', line 59802

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59807
59808
59809
# File 'lib/google/apis/compute_v1/classes.rb', line 59807

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


59813
59814
59815
# File 'lib/google/apis/compute_v1/classes.rb', line 59813

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



59818
59819
59820
# File 'lib/google/apis/compute_v1/classes.rb', line 59818

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59825
59826
59827
59828
59829
59830
59831
59832
59833
59834
# File 'lib/google/apis/compute_v1/classes.rb', line 59825

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end