Class: Google::Apis::ComputeV1::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



53496
53497
53498
# File 'lib/google/apis/compute_v1/classes.rb', line 53496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53449
53450
53451
# File 'lib/google/apis/compute_v1/classes.rb', line 53449

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53455
53456
53457
# File 'lib/google/apis/compute_v1/classes.rb', line 53455

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



53460
53461
53462
# File 'lib/google/apis/compute_v1/classes.rb', line 53460

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


53467
53468
53469
# File 'lib/google/apis/compute_v1/classes.rb', line 53467

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53478
53479
53480
# File 'lib/google/apis/compute_v1/classes.rb', line 53478

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53483
53484
53485
# File 'lib/google/apis/compute_v1/classes.rb', line 53483

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53489
53490
53491
# File 'lib/google/apis/compute_v1/classes.rb', line 53489

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



53494
53495
53496
# File 'lib/google/apis/compute_v1/classes.rb', line 53494

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53501
53502
53503
53504
53505
53506
53507
53508
53509
53510
# File 'lib/google/apis/compute_v1/classes.rb', line 53501

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end