Class: Google::Apis::ComputeV1::StoragePoolParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StoragePoolParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Additional storage pool params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolParams
constructor
A new instance of StoragePoolParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolParams
Returns a new instance of StoragePoolParams.
60623 60624 60625 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the storage pool. Tag keys
and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
60621 60622 60623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60621 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60628 60629 60630 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60628 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |