Class: Google::Apis::ComputeV1::StoragePoolResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::StoragePoolResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
-
#exapool_max_read_iops ⇒ Fixnum
Output only.
-
#exapool_max_read_throughput ⇒ Fixnum
Output only.
-
#exapool_max_write_iops ⇒ Fixnum
Output only.
-
#exapool_max_write_throughput ⇒ Fixnum
Output only.
-
#last_resize_timestamp ⇒ String
Output only.
-
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
-
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool (in bytes).
-
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity.
-
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
-
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is compacted.
-
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool.
-
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
-
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolResourceStatus
constructor
A new instance of StoragePoolResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolResourceStatus
Returns a new instance of StoragePoolResourceStatus.
60352 60353 60354 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60352 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
Corresponds to the JSON property diskCount
60272 60273 60274 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60272 def disk_count @disk_count end |
#exapool_max_read_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed read IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxReadIops
60277 60278 60279 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60277 def exapool_max_read_iops @exapool_max_read_iops end |
#exapool_max_read_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed read throughput in MiB/s for
this Exapool.
Corresponds to the JSON property exapoolMaxReadThroughput
60283 60284 60285 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60283 def exapool_max_read_throughput @exapool_max_read_throughput end |
#exapool_max_write_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed write IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxWriteIops
60288 60289 60290 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60288 def exapool_max_write_iops @exapool_max_write_iops end |
#exapool_max_write_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed write throughput in MiB/s
for this Exapool.
Corresponds to the JSON property exapoolMaxWriteThroughput
60294 60295 60296 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60294 def exapool_max_write_throughput @exapool_max_write_throughput end |
#last_resize_timestamp ⇒ String
Output only. [Output Only] Timestamp of the last successful resize inRFC3339
text format.
Corresponds to the JSON property lastResizeTimestamp
60300 60301 60302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60300 def @last_resize_timestamp end |
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb
60305 60306 60307 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60305 def max_total_provisioned_disk_capacity_gb @max_total_provisioned_disk_capacity_gb end |
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool
(in bytes). This will reflect the total number of bytes written to the
disks in the pool, in contrast to the capacity of those disks.
Corresponds to the JSON property poolUsedCapacityBytes
60312 60313 60314 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60312 def pool_used_capacity_bytes @pool_used_capacity_bytes end |
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount
that is allowed per disk that is not counted towards pool's IOPS
capacity. For more information, see
https://cloud.google.com/compute/docs/disks/storage-pools.
Corresponds to the JSON property poolUsedIops
60320 60321 60322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60320 def pool_used_iops @pool_used_iops end |
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
Corresponds to the JSON property poolUsedThroughput
60325 60326 60327 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60325 def pool_used_throughput @pool_used_throughput end |
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is
compacted.
Corresponds to the JSON property poolUserWrittenBytes
60331 60332 60333 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60331 def pool_user_written_bytes @pool_user_written_bytes end |
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in
this storage pool. A disk's provisioned capacity is the same as its total
capacity.
Corresponds to the JSON property totalProvisionedDiskCapacityGb
60338 60339 60340 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60338 def total_provisioned_disk_capacity_gb @total_provisioned_disk_capacity_gb end |
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
Corresponds to the JSON property totalProvisionedDiskIops
60343 60344 60345 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60343 def total_provisioned_disk_iops @total_provisioned_disk_iops end |
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s,
minus some amount that is allowed per disk that is not counted towards
pool's throughput capacity.
Corresponds to the JSON property totalProvisionedDiskThroughput
60350 60351 60352 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60350 def total_provisioned_disk_throughput @total_provisioned_disk_throughput end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60357 60358 60359 60360 60361 60362 60363 60364 60365 60366 60367 60368 60369 60370 60371 60372 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60357 def update!(**args) @disk_count = args[:disk_count] if args.key?(:disk_count) @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops) @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput) @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops) @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput) @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp) @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb) @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes) @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops) @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput) @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes) @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb) @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops) @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput) end |