Class: Google::Apis::ComputeV1::StoragePoolsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolsScopedList

Returns a new instance of StoragePoolsScopedList.



61239
61240
61241
# File 'lib/google/apis/compute_v1/classes.rb', line 61239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#storage_poolsArray<Google::Apis::ComputeV1::StoragePool>

[Output Only] A list of storage pool contained in this scope. Corresponds to the JSON property storagePools



61231
61232
61233
# File 'lib/google/apis/compute_v1/classes.rb', line 61231

def storage_pools
  @storage_pools
end

#warningGoogle::Apis::ComputeV1::StoragePoolsScopedList::Warning

[Output Only] Informational warning which replaces the list of storage pool when the list is empty. Corresponds to the JSON property warning



61237
61238
61239
# File 'lib/google/apis/compute_v1/classes.rb', line 61237

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61244
61245
61246
61247
# File 'lib/google/apis/compute_v1/classes.rb', line 61244

def update!(**args)
  @storage_pools = args[:storage_pools] if args.key?(:storage_pools)
  @warning = args[:warning] if args.key?(:warning)
end