Class: Google::Apis::ComputeV1::Subnetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Subnetwork resource. A subnetwork (also known as a subnet) is a logical partition of a Virtual Private Cloud network with one primary IP range and zero or more secondary IP ranges. For more information, read Virtual Private Cloud (VPC) Network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subnetwork

Returns a new instance of Subnetwork.



33792
33793
33794
# File 'lib/google/apis/compute_v1/classes.rb', line 33792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


33613
33614
33615
# File 'lib/google/apis/compute_v1/classes.rb', line 33613

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. This field can be set only at resource creation time. Corresponds to the JSON property description

Returns:

  • (String)


33619
33620
33621
# File 'lib/google/apis/compute_v1/classes.rb', line 33619

def description
  @description
end

#enable_flow_logsBoolean Also known as: enable_flow_logs?

Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. This field isn't supported with the purpose field set to INTERNAL_HTTPS_LOAD_BALANCER. Corresponds to the JSON property enableFlowLogs

Returns:

  • (Boolean)


33628
33629
33630
# File 'lib/google/apis/compute_v1/classes.rb', line 33628

def enable_flow_logs
  @enable_flow_logs
end

#external_ipv6_prefixString

[Output Only] The range of external IPv6 addresses that are owned by this subnetwork. Corresponds to the JSON property externalIpv6Prefix

Returns:

  • (String)


33635
33636
33637
# File 'lib/google/apis/compute_v1/classes.rb', line 33635

def external_ipv6_prefix
  @external_ipv6_prefix
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a Subnetwork. An up-to-date fingerprint must be provided in order to update the Subnetwork, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a Subnetwork. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


33646
33647
33648
# File 'lib/google/apis/compute_v1/classes.rb', line 33646

def fingerprint
  @fingerprint
end

#gateway_addressString

[Output Only] The gateway address for default routes to reach destination addresses outside this subnetwork. Corresponds to the JSON property gatewayAddress

Returns:

  • (String)


33652
33653
33654
# File 'lib/google/apis/compute_v1/classes.rb', line 33652

def gateway_address
  @gateway_address
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


33658
33659
33660
# File 'lib/google/apis/compute_v1/classes.rb', line 33658

def id
  @id
end

#internal_ipv6_prefixString

[Output Only] The range of internal IPv6 addresses that are owned by this subnetwork. Note this is for general VM to VM communication, not to be confused with the ipv6_cidr_range field. Corresponds to the JSON property internalIpv6Prefix

Returns:

  • (String)


33665
33666
33667
# File 'lib/google/apis/compute_v1/classes.rb', line 33665

def internal_ipv6_prefix
  @internal_ipv6_prefix
end

#ip_cidr_rangeString

The range of internal addresses that are owned by this subnetwork. Provide this property when you create the subnetwork. For example, 10.0.0.0/8 or 100. 64.0.0/10. Ranges must be unique and non-overlapping within a network. Only IPv4 is supported. This field is set at resource creation time. The range can be any range listed in the Valid ranges list. The range can be expanded after creation using expandIpCidrRange. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


33675
33676
33677
# File 'lib/google/apis/compute_v1/classes.rb', line 33675

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack. If the ipv6_type is EXTERNAL then this subnet cannot enable direct path. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


33683
33684
33685
# File 'lib/google/apis/compute_v1/classes.rb', line 33683

def ipv6_access_type
  @ipv6_access_type
end

#ipv6_cidr_rangeString

[Output Only] The range of internal IPv6 addresses that are owned by this subnetwork. Note this will be for private google access only eventually. Corresponds to the JSON property ipv6CidrRange

Returns:

  • (String)


33689
33690
33691
# File 'lib/google/apis/compute_v1/classes.rb', line 33689

def ipv6_cidr_range
  @ipv6_cidr_range
end

#kindString

[Output Only] Type of the resource. Always compute#subnetwork for Subnetwork resources. Corresponds to the JSON property kind

Returns:

  • (String)


33695
33696
33697
# File 'lib/google/apis/compute_v1/classes.rb', line 33695

def kind
  @kind
end

#log_configGoogle::Apis::ComputeV1::SubnetworkLogConfig

The available logging options for this subnetwork. Corresponds to the JSON property logConfig



33700
33701
33702
# File 'lib/google/apis/compute_v1/classes.rb', line 33700

def log_config
  @log_config
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


33710
33711
33712
# File 'lib/google/apis/compute_v1/classes.rb', line 33710

def name
  @name
end

#networkString

The URL of the network to which this subnetwork belongs, provided by the client when initially creating the subnetwork. This field can be set only at resource creation time. Corresponds to the JSON property network

Returns:

  • (String)


33717
33718
33719
# File 'lib/google/apis/compute_v1/classes.rb', line 33717

def network
  @network
end

#private_ip_google_accessBoolean Also known as: private_ip_google_access?

Whether the VMs in this subnet can access Google services without assigned external IP addresses. This field can be both set at resource creation time and updated using setPrivateIpGoogleAccess. Corresponds to the JSON property privateIpGoogleAccess

Returns:

  • (Boolean)


33724
33725
33726
# File 'lib/google/apis/compute_v1/classes.rb', line 33724

def private_ip_google_access
  @private_ip_google_access
end

#private_ipv6_google_accessString

The private IPv6 google access type for the VMs in this subnet. This is an expanded field of enablePrivateV6Access. If both fields are set, privateIpv6GoogleAccess will take priority. This field can be both set at resource creation time and updated using patch. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


33733
33734
33735
# File 'lib/google/apis/compute_v1/classes.rb', line 33733

def private_ipv6_google_access
  @private_ipv6_google_access
end

#purposeString

The purpose of the resource. This field can be either PRIVATE_RFC_1918 or INTERNAL_HTTPS_LOAD_BALANCER. A subnetwork with purpose set to INTERNAL_HTTPS_LOAD_BALANCER is a user-created subnetwork that is reserved for Internal HTTP(S) Load Balancing. If unspecified, the purpose defaults to PRIVATE_RFC_1918. The enableFlowLogs field isn't supported with the purpose field set to INTERNAL_HTTPS_LOAD_BALANCER. Corresponds to the JSON property purpose

Returns:

  • (String)


33743
33744
33745
# File 'lib/google/apis/compute_v1/classes.rb', line 33743

def purpose
  @purpose
end

#regionString

URL of the region where the Subnetwork resides. This field can be set only at resource creation time. Corresponds to the JSON property region

Returns:

  • (String)


33749
33750
33751
# File 'lib/google/apis/compute_v1/classes.rb', line 33749

def region
  @region
end

#roleString

The role of subnetwork. Currently, this field is only used when purpose = INTERNAL_HTTPS_LOAD_BALANCER. The value can be set to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Internal HTTP(S) Load Balancing. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request. Corresponds to the JSON property role

Returns:

  • (String)


33759
33760
33761
# File 'lib/google/apis/compute_v1/classes.rb', line 33759

def role
  @role
end

#secondary_ip_rangesArray<Google::Apis::ComputeV1::SubnetworkSecondaryRange>

An array of configurations for secondary IP ranges for VM instances contained in this subnetwork. The primary IP of such VM must belong to the primary ipCidrRange of the subnetwork. The alias IPs may belong to either primary or secondary ranges. This field can be updated with a patch request. Corresponds to the JSON property secondaryIpRanges



33767
33768
33769
# File 'lib/google/apis/compute_v1/classes.rb', line 33767

def secondary_ip_ranges
  @secondary_ip_ranges
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33772
33773
33774
# File 'lib/google/apis/compute_v1/classes.rb', line 33772

def self_link
  @self_link
end

#stack_typeString

The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set to IPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be both set at resource creation time and updated using patch. Corresponds to the JSON property stackType

Returns:

  • (String)


33780
33781
33782
# File 'lib/google/apis/compute_v1/classes.rb', line 33780

def stack_type
  @stack_type
end

#stateString

[Output Only] The state of the subnetwork, which can be one of the following values: READY: Subnetwork is created and ready to use DRAINING: only applicable to subnetworks that have the purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load balancer are being drained. A subnetwork that is draining cannot be used or modified until it reaches a status of READY Corresponds to the JSON property state

Returns:

  • (String)


33790
33791
33792
# File 'lib/google/apis/compute_v1/classes.rb', line 33790

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33797
33798
33799
33800
33801
33802
33803
33804
33805
33806
33807
33808
33809
33810
33811
33812
33813
33814
33815
33816
33817
33818
33819
33820
33821
33822
# File 'lib/google/apis/compute_v1/classes.rb', line 33797

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @enable_flow_logs = args[:enable_flow_logs] if args.key?(:enable_flow_logs)
  @external_ipv6_prefix = args[:external_ipv6_prefix] if args.key?(:external_ipv6_prefix)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @gateway_address = args[:gateway_address] if args.key?(:gateway_address)
  @id = args[:id] if args.key?(:id)
  @internal_ipv6_prefix = args[:internal_ipv6_prefix] if args.key?(:internal_ipv6_prefix)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @ipv6_cidr_range = args[:ipv6_cidr_range] if args.key?(:ipv6_cidr_range)
  @kind = args[:kind] if args.key?(:kind)
  @log_config = args[:log_config] if args.key?(:log_config)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @private_ip_google_access = args[:private_ip_google_access] if args.key?(:private_ip_google_access)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @purpose = args[:purpose] if args.key?(:purpose)
  @region = args[:region] if args.key?(:region)
  @role = args[:role] if args.key?(:role)
  @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges)
  @self_link = args[:self_link] if args.key?(:self_link)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @state = args[:state] if args.key?(:state)
end