Class: Google::Apis::ComputeV1::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



62521
62522
62523
# File 'lib/google/apis/compute_v1/classes.rb', line 62521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62482
62483
62484
# File 'lib/google/apis/compute_v1/classes.rb', line 62482

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



62487
62488
62489
# File 'lib/google/apis/compute_v1/classes.rb', line 62487

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


62494
62495
62496
# File 'lib/google/apis/compute_v1/classes.rb', line 62494

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62504
62505
62506
# File 'lib/google/apis/compute_v1/classes.rb', line 62504

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62509
62510
62511
# File 'lib/google/apis/compute_v1/classes.rb', line 62509

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


62514
62515
62516
# File 'lib/google/apis/compute_v1/classes.rb', line 62514

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62519
62520
62521
# File 'lib/google/apis/compute_v1/classes.rb', line 62519

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62526
62527
62528
62529
62530
62531
62532
62533
62534
# File 'lib/google/apis/compute_v1/classes.rb', line 62526

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end