Class: Google::Apis::ComputeV1::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



61690
61691
61692
# File 'lib/google/apis/compute_v1/classes.rb', line 61690

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61651
61652
61653
# File 'lib/google/apis/compute_v1/classes.rb', line 61651

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



61656
61657
61658
# File 'lib/google/apis/compute_v1/classes.rb', line 61656

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


61663
61664
61665
# File 'lib/google/apis/compute_v1/classes.rb', line 61663

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61673
61674
61675
# File 'lib/google/apis/compute_v1/classes.rb', line 61673

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61678
61679
61680
# File 'lib/google/apis/compute_v1/classes.rb', line 61678

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


61683
61684
61685
# File 'lib/google/apis/compute_v1/classes.rb', line 61683

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61688
61689
61690
# File 'lib/google/apis/compute_v1/classes.rb', line 61688

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61695
61696
61697
61698
61699
61700
61701
61702
61703
# File 'lib/google/apis/compute_v1/classes.rb', line 61695

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end