Class: Google::Apis::ComputeV1::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



61678
61679
61680
# File 'lib/google/apis/compute_v1/classes.rb', line 61678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61639
61640
61641
# File 'lib/google/apis/compute_v1/classes.rb', line 61639

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



61644
61645
61646
# File 'lib/google/apis/compute_v1/classes.rb', line 61644

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


61651
61652
61653
# File 'lib/google/apis/compute_v1/classes.rb', line 61651

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61661
61662
61663
# File 'lib/google/apis/compute_v1/classes.rb', line 61661

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61666
61667
61668
# File 'lib/google/apis/compute_v1/classes.rb', line 61666

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


61671
61672
61673
# File 'lib/google/apis/compute_v1/classes.rb', line 61671

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61676
61677
61678
# File 'lib/google/apis/compute_v1/classes.rb', line 61676

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61683
61684
61685
61686
61687
61688
61689
61690
61691
# File 'lib/google/apis/compute_v1/classes.rb', line 61683

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end