Class: Google::Apis::ComputeV1::SubnetworkAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworkAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkAggregatedList
constructor
A new instance of SubnetworkAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkAggregatedList
Returns a new instance of SubnetworkAggregatedList.
61351 61352 61353 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61312 61313 61314 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61312 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
Corresponds to the JSON property items
61317 61318 61319 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61317 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
subnetworkAggregatedList for aggregated lists of
subnetworks.
Corresponds to the JSON property kind
61324 61325 61326 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61324 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61334 61335 61336 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61334 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
61339 61340 61341 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61339 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
61344 61345 61346 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61344 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61349 61350 61351 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61349 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61356 61357 61358 61359 61360 61361 61362 61363 61364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61356 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |