Class: Google::Apis::ComputeV1::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



60978
60979
60980
# File 'lib/google/apis/compute_v1/classes.rb', line 60978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60939
60940
60941
# File 'lib/google/apis/compute_v1/classes.rb', line 60939

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



60944
60945
60946
# File 'lib/google/apis/compute_v1/classes.rb', line 60944

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


60951
60952
60953
# File 'lib/google/apis/compute_v1/classes.rb', line 60951

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60961
60962
60963
# File 'lib/google/apis/compute_v1/classes.rb', line 60961

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60966
60967
60968
# File 'lib/google/apis/compute_v1/classes.rb', line 60966

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


60971
60972
60973
# File 'lib/google/apis/compute_v1/classes.rb', line 60971

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



60976
60977
60978
# File 'lib/google/apis/compute_v1/classes.rb', line 60976

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60983
60984
60985
60986
60987
60988
60989
60990
60991
# File 'lib/google/apis/compute_v1/classes.rb', line 60983

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end