Class: Google::Apis::ComputeV1::SubnetworkAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworkAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkAggregatedList
constructor
A new instance of SubnetworkAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkAggregatedList
Returns a new instance of SubnetworkAggregatedList.
60964 60965 60966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60925 60926 60927 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60925 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
Corresponds to the JSON property items
60930 60931 60932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60930 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
subnetworkAggregatedList for aggregated lists of
subnetworks.
Corresponds to the JSON property kind
60937 60938 60939 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60937 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60947 60948 60949 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60947 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60952 60953 60954 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60952 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
60957 60958 60959 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60957 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60962 60963 60964 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60962 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60969 60970 60971 60972 60973 60974 60975 60976 60977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60969 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |