Class: Google::Apis::ComputeV1::SubnetworkAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworkAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkAggregatedList
constructor
A new instance of SubnetworkAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkAggregatedList
Returns a new instance of SubnetworkAggregatedList.
55839 55840 55841 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55800 55801 55802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55800 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
Corresponds to the JSON property items
55805 55806 55807 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55805 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
subnetworkAggregatedList for aggregated lists of
subnetworks.
Corresponds to the JSON property kind
55812 55813 55814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55812 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55822 55823 55824 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55822 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55827 55828 55829 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55827 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
55832 55833 55834 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55832 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55837 55838 55839 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55837 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55844 55845 55846 55847 55848 55849 55850 55851 55852 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55844 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |