Class: Google::Apis::ComputeV1::SubnetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Subnetwork resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Subnetwork>
A list of Subnetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SubnetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkList
constructor
A new instance of SubnetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkList
Returns a new instance of SubnetworkList.
61816 61817 61818 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61783 61784 61785 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61783 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Subnetwork>
A list of Subnetwork resources.
Corresponds to the JSON property items
61788 61789 61790 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61788 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#subnetworkList
for lists of subnetworks.
Corresponds to the JSON property kind
61794 61795 61796 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61794 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61804 61805 61806 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61804 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
61809 61810 61811 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61809 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SubnetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61814 61815 61816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61814 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61821 61822 61823 61824 61825 61826 61827 61828 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61821 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |