Class: Google::Apis::ComputeV1::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Subnetwork resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



61804
61805
61806
# File 'lib/google/apis/compute_v1/classes.rb', line 61804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61771
61772
61773
# File 'lib/google/apis/compute_v1/classes.rb', line 61771

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Subnetwork>

A list of Subnetwork resources. Corresponds to the JSON property items



61776
61777
61778
# File 'lib/google/apis/compute_v1/classes.rb', line 61776

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


61782
61783
61784
# File 'lib/google/apis/compute_v1/classes.rb', line 61782

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61792
61793
61794
# File 'lib/google/apis/compute_v1/classes.rb', line 61792

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61797
61798
61799
# File 'lib/google/apis/compute_v1/classes.rb', line 61797

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SubnetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61802
61803
61804
# File 'lib/google/apis/compute_v1/classes.rb', line 61802

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61809
61810
61811
61812
61813
61814
61815
61816
# File 'lib/google/apis/compute_v1/classes.rb', line 61809

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end