Class: Google::Apis::ComputeV1::SubnetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Subnetwork resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Subnetwork>
A list of Subnetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::SubnetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkList
constructor
A new instance of SubnetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkList
Returns a new instance of SubnetworkList.
61090 61091 61092 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61057 61058 61059 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61057 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Subnetwork>
A list of Subnetwork resources.
Corresponds to the JSON property items
61062 61063 61064 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61062 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#subnetworkList
for lists of subnetworks.
Corresponds to the JSON property kind
61068 61069 61070 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61068 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61078 61079 61080 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61078 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
61083 61084 61085 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61083 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SubnetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61088 61089 61090 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61088 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61095 61096 61097 61098 61099 61100 61101 61102 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61095 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |