Class: Google::Apis::ComputeV1::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Subnetwork resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



59581
59582
59583
# File 'lib/google/apis/compute_v1/classes.rb', line 59581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59548
59549
59550
# File 'lib/google/apis/compute_v1/classes.rb', line 59548

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Subnetwork>

A list of Subnetwork resources. Corresponds to the JSON property items



59553
59554
59555
# File 'lib/google/apis/compute_v1/classes.rb', line 59553

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


59559
59560
59561
# File 'lib/google/apis/compute_v1/classes.rb', line 59559

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59569
59570
59571
# File 'lib/google/apis/compute_v1/classes.rb', line 59569

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59574
59575
59576
# File 'lib/google/apis/compute_v1/classes.rb', line 59574

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SubnetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59579
59580
59581
# File 'lib/google/apis/compute_v1/classes.rb', line 59579

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59586
59587
59588
59589
59590
59591
59592
59593
# File 'lib/google/apis/compute_v1/classes.rb', line 59586

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end