Class: Google::Apis::ComputeV1::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of Subnetwork resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



55965
55966
55967
# File 'lib/google/apis/compute_v1/classes.rb', line 55965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55932
55933
55934
# File 'lib/google/apis/compute_v1/classes.rb', line 55932

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Subnetwork>

A list of Subnetwork resources. Corresponds to the JSON property items



55937
55938
55939
# File 'lib/google/apis/compute_v1/classes.rb', line 55937

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


55943
55944
55945
# File 'lib/google/apis/compute_v1/classes.rb', line 55943

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55953
55954
55955
# File 'lib/google/apis/compute_v1/classes.rb', line 55953

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55958
55959
55960
# File 'lib/google/apis/compute_v1/classes.rb', line 55958

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::SubnetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55963
55964
55965
# File 'lib/google/apis/compute_v1/classes.rb', line 55963

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55970
55971
55972
55973
55974
55975
55976
55977
# File 'lib/google/apis/compute_v1/classes.rb', line 55970

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end