Class: Google::Apis::ComputeV1::SubnetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of Subnetwork resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Subnetwork>
A list of Subnetwork resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::SubnetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkList
constructor
A new instance of SubnetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkList
Returns a new instance of SubnetworkList.
33988 33989 33990 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33956 33957 33958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33956 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Subnetwork>
A list of Subnetwork resources.
Corresponds to the JSON property items
33961 33962 33963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33961 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#subnetworkList for lists of
subnetworks.
Corresponds to the JSON property kind
33967 33968 33969 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33967 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33976 33977 33978 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33976 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33981 33982 33983 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33981 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::SubnetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33986 33987 33988 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33986 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33993 33994 33995 33996 33997 33998 33999 34000 |
# File 'lib/google/apis/compute_v1/classes.rb', line 33993 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |