Class: Google::Apis::ComputeV1::SubnetworkLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworkLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The available logging options for this subnetwork.
Instance Attribute Summary collapse
-
#aggregation_interval ⇒ String
Can only be specified if VPC flow logging for this subnetwork is enabled.
-
#enable ⇒ Boolean
(also: #enable?)
Whether to enable flow logging for this subnetwork.
-
#filter_expr ⇒ String
Can only be specified if VPC flow logs for this subnetwork is enabled.
-
#flow_sampling ⇒ Float
Can only be specified if VPC flow logging for this subnetwork is enabled.
-
#metadata ⇒ String
Can only be specified if VPC flow logs for this subnetwork is enabled.
-
#metadata_fields ⇒ Array<String>
Can only be specified if VPC flow logs for this subnetwork is enabled and " metadata" was set to CUSTOM_METADATA.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkLogConfig
constructor
A new instance of SubnetworkLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkLogConfig
Returns a new instance of SubnetworkLogConfig.
34117 34118 34119 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_interval ⇒ String
Can only be specified if VPC flow logging for this subnetwork is enabled.
Toggles the aggregation interval for collecting flow logs. Increasing the
interval time will reduce the amount of generated flow logs for long lasting
connections. Default is an interval of 5 seconds per connection.
Corresponds to the JSON property aggregationInterval
34077 34078 34079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34077 def aggregation_interval @aggregation_interval end |
#enable ⇒ Boolean Also known as: enable?
Whether to enable flow logging for this subnetwork. If this field is not
explicitly set, it will not appear in get listings. If not set the default
behavior is determined by the org policy, if there is no org policy specified,
then it will default to disabled.
Corresponds to the JSON property enable
34085 34086 34087 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34085 def enable @enable end |
#filter_expr ⇒ String
Can only be specified if VPC flow logs for this subnetwork is enabled. The
filter expression is used to define which VPC flow logs should be exported to
Cloud Logging.
Corresponds to the JSON property filterExpr
34093 34094 34095 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34093 def filter_expr @filter_expr end |
#flow_sampling ⇒ Float
Can only be specified if VPC flow logging for this subnetwork is enabled. The
value of the field must be in [0, 1]. Set the sampling rate of VPC flow logs
within the subnetwork where 1.0 means all collected logs are reported and 0.0
means no logs are reported. Default is 0.5 unless otherwise specified by the
org policy, which means half of all collected logs are reported.
Corresponds to the JSON property flowSampling
34102 34103 34104 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34102 def flow_sampling @flow_sampling end |
#metadata ⇒ String
Can only be specified if VPC flow logs for this subnetwork is enabled.
Configures whether all, none or a subset of metadata fields should be added to
the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA.
Corresponds to the JSON property metadata
34109 34110 34111 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34109 def @metadata end |
#metadata_fields ⇒ Array<String>
Can only be specified if VPC flow logs for this subnetwork is enabled and "
metadata" was set to CUSTOM_METADATA.
Corresponds to the JSON property metadataFields
34115 34116 34117 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34115 def @metadata_fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34122 34123 34124 34125 34126 34127 34128 34129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34122 def update!(**args) @aggregation_interval = args[:aggregation_interval] if args.key?(:aggregation_interval) @enable = args[:enable] if args.key?(:enable) @filter_expr = args[:filter_expr] if args.key?(:filter_expr) @flow_sampling = args[:flow_sampling] if args.key?(:flow_sampling) @metadata = args[:metadata] if args.key?(:metadata) @metadata_fields = args[:metadata_fields] if args.key?(:metadata_fields) end |