Class: Google::Apis::ComputeV1::SubnetworkSecondaryRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworkSecondaryRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a secondary IP range of a subnetwork.
Instance Attribute Summary collapse
-
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
-
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding an alias IP/IPv6 range to a VM instance.
-
#reserved_internal_range ⇒ String
The URL of the reserved internal range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkSecondaryRange
constructor
A new instance of SubnetworkSecondaryRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkSecondaryRange
Returns a new instance of SubnetworkSecondaryRange.
56187 56188 56189 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
Provide this property when you create the subnetwork. Ranges must be
unique and non-overlapping with all primary and secondary IP ranges
within a network. Both IPv4 and IPv6 ranges are supported. For IPv4,
the range can be any range listed in theValid
ranges list.
For IPv6:
The range must have a /64 prefix length.
The range must be omitted, for auto-allocation from Google-defined ULA
IPv6 range.
For BYOGUA internal IPv6 secondary range, the range may be specified
along with the ipCollection field.
If an ipCollection is specified, the requested ip_cidr_range must lie
within the range of the PDP referenced by the ipCollection field for
allocation.
If ipCollection field is specified, but ip_cidr_range is not,
the range is auto-allocated from the PDP referenced by the ipCollection
field.
Corresponds to the JSON property ipCidrRange
56172 56173 56174 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56172 def ip_cidr_range @ip_cidr_range end |
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding
an alias IP/IPv6 range to a VM instance.
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the subnetwork.
Corresponds to the JSON property rangeName
56180 56181 56182 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56180 def range_name @range_name end |
#reserved_internal_range ⇒ String
The URL of the reserved internal range. Only IPv4 is supported.
Corresponds to the JSON property reservedInternalRange
56185 56186 56187 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56185 def reserved_internal_range @reserved_internal_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56192 56193 56194 56195 56196 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56192 def update!(**args) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @range_name = args[:range_name] if args.key?(:range_name) @reserved_internal_range = args[:reserved_internal_range] if args.key?(:reserved_internal_range) end |