Class: Google::Apis::ComputeV1::SubnetworkSecondaryRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworkSecondaryRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a secondary IP range of a subnetwork.
Instance Attribute Summary collapse
-
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
-
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance.
-
#reserved_internal_range ⇒ String
The URL of the reserved internal range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkSecondaryRange
constructor
A new instance of SubnetworkSecondaryRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkSecondaryRange
Returns a new instance of SubnetworkSecondaryRange.
54984 54985 54986 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54984 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
Provide this property when you create the subnetwork. Ranges must be
unique and non-overlapping with all primary and secondary IP ranges
within a network. Only IPv4 is supported. The range can be any range
listed in theValid
ranges list.
Corresponds to the JSON property ipCidrRange
54969 54970 54971 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54969 def ip_cidr_range @ip_cidr_range end |
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding
an alias IP range to a VM instance.
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the subnetwork.
Corresponds to the JSON property rangeName
54977 54978 54979 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54977 def range_name @range_name end |
#reserved_internal_range ⇒ String
The URL of the reserved internal range.
Corresponds to the JSON property reservedInternalRange
54982 54983 54984 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54982 def reserved_internal_range @reserved_internal_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54989 54990 54991 54992 54993 |
# File 'lib/google/apis/compute_v1/classes.rb', line 54989 def update!(**args) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @range_name = args[:range_name] if args.key?(:range_name) @reserved_internal_range = args[:reserved_internal_range] if args.key?(:reserved_internal_range) end |