Class: Google::Apis::ComputeV1::SubnetworksExpandIpCidrRangeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksExpandIpCidrRangeRequest

Returns a new instance of SubnetworksExpandIpCidrRangeRequest.



62163
62164
62165
# File 'lib/google/apis/compute_v1/classes.rb', line 62163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_cidr_rangeString

The IP (in CIDR format or netmask) of internal addresses that are legal on this Subnetwork. This range should be disjoint from other subnetworks within this network. This range can only be larger than (i.e. a superset of) the range previously defined before the update. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


62161
62162
62163
# File 'lib/google/apis/compute_v1/classes.rb', line 62161

def ip_cidr_range
  @ip_cidr_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62168
62169
62170
# File 'lib/google/apis/compute_v1/classes.rb', line 62168

def update!(**args)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
end