Class: Google::Apis::ComputeV1::SubnetworksExpandIpCidrRangeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworksExpandIpCidrRangeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#ip_cidr_range ⇒ String
The IP (in CIDR format or netmask) of internal addresses that are legal on this Subnetwork.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworksExpandIpCidrRangeRequest
constructor
A new instance of SubnetworksExpandIpCidrRangeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworksExpandIpCidrRangeRequest
Returns a new instance of SubnetworksExpandIpCidrRangeRequest.
34175 34176 34177 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_cidr_range ⇒ String
The IP (in CIDR format or netmask) of internal addresses that are legal on
this Subnetwork. This range should be disjoint from other subnetworks within
this network. This range can only be larger than (i.e. a superset of) the
range previously defined before the update.
Corresponds to the JSON property ipCidrRange
34173 34174 34175 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34173 def ip_cidr_range @ip_cidr_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34180 34181 34182 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34180 def update!(**args) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) end |