Class: Google::Apis::ComputeV1::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksScopedWarning

Returns a new instance of SubnetworksScopedWarning.



62296
62297
62298
# File 'lib/google/apis/compute_v1/classes.rb', line 62296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scope_nameString

Name of the scope containing this set of Subnetworks. Corresponds to the JSON property scopeName

Returns:

  • (String)


62289
62290
62291
# File 'lib/google/apis/compute_v1/classes.rb', line 62289

def scope_name
  @scope_name
end

#warningGoogle::Apis::ComputeV1::SubnetworksScopedWarning::Warning

An informational warning about unreachable scope Corresponds to the JSON property warning



62294
62295
62296
# File 'lib/google/apis/compute_v1/classes.rb', line 62294

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62301
62302
62303
62304
# File 'lib/google/apis/compute_v1/classes.rb', line 62301

def update!(**args)
  @scope_name = args[:scope_name] if args.key?(:scope_name)
  @warning = args[:warning] if args.key?(:warning)
end