Class: Google::Apis::ComputeV1::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksScopedWarning

Returns a new instance of SubnetworksScopedWarning.



61552
61553
61554
# File 'lib/google/apis/compute_v1/classes.rb', line 61552

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scope_nameString

Name of the scope containing this set of Subnetworks. Corresponds to the JSON property scopeName

Returns:

  • (String)


61545
61546
61547
# File 'lib/google/apis/compute_v1/classes.rb', line 61545

def scope_name
  @scope_name
end

#warningGoogle::Apis::ComputeV1::SubnetworksScopedWarning::Warning

An informational warning about unreachable scope Corresponds to the JSON property warning



61550
61551
61552
# File 'lib/google/apis/compute_v1/classes.rb', line 61550

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61557
61558
61559
61560
# File 'lib/google/apis/compute_v1/classes.rb', line 61557

def update!(**args)
  @scope_name = args[:scope_name] if args.key?(:scope_name)
  @warning = args[:warning] if args.key?(:warning)
end