Class: Google::Apis::ComputeV1::SubnetworksScopedWarning
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::SubnetworksScopedWarning
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#scope_name ⇒ String
Name of the scope containing this set of Subnetworks.
-
#warning ⇒ Google::Apis::ComputeV1::SubnetworksScopedWarning::Warning
An informational warning about unreachable scope Corresponds to the JSON property
warning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworksScopedWarning
constructor
A new instance of SubnetworksScopedWarning.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworksScopedWarning
Returns a new instance of SubnetworksScopedWarning.
60043 60044 60045 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#scope_name ⇒ String
Name of the scope containing this set of Subnetworks.
Corresponds to the JSON property scopeName
60036 60037 60038 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60036 def scope_name @scope_name end |
#warning ⇒ Google::Apis::ComputeV1::SubnetworksScopedWarning::Warning
An informational warning about unreachable scope
Corresponds to the JSON property warning
60041 60042 60043 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60041 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60048 60049 60050 60051 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60048 def update!(**args) @scope_name = args[:scope_name] if args.key?(:scope_name) @warning = args[:warning] if args.key?(:warning) end |