Class: Google::Apis::ComputeV1::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksScopedWarning

Returns a new instance of SubnetworksScopedWarning.



55224
55225
55226
# File 'lib/google/apis/compute_v1/classes.rb', line 55224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scope_nameString

Name of the scope containing this set of Subnetworks. Corresponds to the JSON property scopeName

Returns:

  • (String)


55217
55218
55219
# File 'lib/google/apis/compute_v1/classes.rb', line 55217

def scope_name
  @scope_name
end

#warningGoogle::Apis::ComputeV1::SubnetworksScopedWarning::Warning

An informational warning about unreachable scope Corresponds to the JSON property warning



55222
55223
55224
# File 'lib/google/apis/compute_v1/classes.rb', line 55222

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55229
55230
55231
55232
# File 'lib/google/apis/compute_v1/classes.rb', line 55229

def update!(**args)
  @scope_name = args[:scope_name] if args.key?(:scope_name)
  @warning = args[:warning] if args.key?(:warning)
end