Class: Google::Apis::ComputeV1::TargetGrpcProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Target gRPC Proxy resource. A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic. Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxy

Returns a new instance of TargetGrpcProxy.



60367
60368
60369
# File 'lib/google/apis/compute_v1/classes.rb', line 60367

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


60291
60292
60293
# File 'lib/google/apis/compute_v1/classes.rb', line 60291

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


60297
60298
60299
# File 'lib/google/apis/compute_v1/classes.rb', line 60297

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetGrpcProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetGrpcProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetGrpcProxy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


60309
60310
60311
# File 'lib/google/apis/compute_v1/classes.rb', line 60309

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


60316
60317
60318
# File 'lib/google/apis/compute_v1/classes.rb', line 60316

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


60322
60323
60324
# File 'lib/google/apis/compute_v1/classes.rb', line 60322

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


60333
60334
60335
# File 'lib/google/apis/compute_v1/classes.rb', line 60333

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60338
60339
60340
# File 'lib/google/apis/compute_v1/classes.rb', line 60338

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL with id for the resource. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


60343
60344
60345
# File 'lib/google/apis/compute_v1/classes.rb', line 60343

def self_link_with_id
  @self_link_with_id
end

#url_mapString

URL to the UrlMap resource that defines the mapping from URL to the BackendService. The protocol field in the BackendService must be set to GRPC. Corresponds to the JSON property urlMap

Returns:

  • (String)


60350
60351
60352
# File 'lib/google/apis/compute_v1/classes.rb', line 60350

def url_map
  @url_map
end

#validate_for_proxylessBoolean Also known as: validate_for_proxyless?

If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy. This will enable configuration checks on urlMap and its referenced BackendServices to not allow unsupported features. A gRPC application must use "xds:///" scheme in the target URI of the service it is connecting to. If false, indicates that the BackendServices referenced by the urlMap will be accessed by gRPC applications via a sidecar proxy. In this case, a gRPC application must not use "xds:///" scheme in the target URI of the service it is connecting to Corresponds to the JSON property validateForProxyless

Returns:

  • (Boolean)


60364
60365
60366
# File 'lib/google/apis/compute_v1/classes.rb', line 60364

def validate_for_proxyless
  @validate_for_proxyless
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60372
60373
60374
60375
60376
60377
60378
60379
60380
60381
60382
60383
# File 'lib/google/apis/compute_v1/classes.rb', line 60372

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @url_map = args[:url_map] if args.key?(:url_map)
  @validate_for_proxyless = args[:validate_for_proxyless] if args.key?(:validate_for_proxyless)
end