Class: Google::Apis::ComputeV1::TargetGrpcProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetGrpcProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetGrpcProxyList
constructor
A new instance of TargetGrpcProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetGrpcProxyList
Returns a new instance of TargetGrpcProxyList.
63510 63511 63512 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63477 63478 63479 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63477 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
Corresponds to the JSON property items
63482 63483 63484 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63482 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy
for target grpc proxies.
Corresponds to the JSON property kind
63488 63489 63490 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63488 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63498 63499 63500 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63498 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63503 63504 63505 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63503 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63508 63509 63510 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63508 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63515 63516 63517 63518 63519 63520 63521 63522 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63515 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |