Class: Google::Apis::ComputeV1::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



62667
62668
62669
# File 'lib/google/apis/compute_v1/classes.rb', line 62667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62634
62635
62636
# File 'lib/google/apis/compute_v1/classes.rb', line 62634

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



62639
62640
62641
# File 'lib/google/apis/compute_v1/classes.rb', line 62639

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


62645
62646
62647
# File 'lib/google/apis/compute_v1/classes.rb', line 62645

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62655
62656
62657
# File 'lib/google/apis/compute_v1/classes.rb', line 62655

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62660
62661
62662
# File 'lib/google/apis/compute_v1/classes.rb', line 62660

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62665
62666
62667
# File 'lib/google/apis/compute_v1/classes.rb', line 62665

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62672
62673
62674
62675
62676
62677
62678
62679
# File 'lib/google/apis/compute_v1/classes.rb', line 62672

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end