Class: Google::Apis::ComputeV1::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



62322
62323
62324
# File 'lib/google/apis/compute_v1/classes.rb', line 62322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62289
62290
62291
# File 'lib/google/apis/compute_v1/classes.rb', line 62289

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



62294
62295
62296
# File 'lib/google/apis/compute_v1/classes.rb', line 62294

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


62300
62301
62302
# File 'lib/google/apis/compute_v1/classes.rb', line 62300

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62310
62311
62312
# File 'lib/google/apis/compute_v1/classes.rb', line 62310

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62315
62316
62317
# File 'lib/google/apis/compute_v1/classes.rb', line 62315

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62320
62321
62322
# File 'lib/google/apis/compute_v1/classes.rb', line 62320

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62327
62328
62329
62330
62331
62332
62333
62334
# File 'lib/google/apis/compute_v1/classes.rb', line 62327

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end