Class: Google::Apis::ComputeV1::TargetGrpcProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetGrpcProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetGrpcProxyList
constructor
A new instance of TargetGrpcProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetGrpcProxyList
Returns a new instance of TargetGrpcProxyList.
61949 61950 61951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61949 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61916 61917 61918 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61916 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
Corresponds to the JSON property items
61921 61922 61923 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61921 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy
for target grpc proxies.
Corresponds to the JSON property kind
61927 61928 61929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61927 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61937 61938 61939 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61937 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
61942 61943 61944 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61942 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61947 61948 61949 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61947 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61954 61955 61956 61957 61958 61959 61960 61961 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61954 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |