Class: Google::Apis::ComputeV1::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



56810
56811
56812
# File 'lib/google/apis/compute_v1/classes.rb', line 56810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56777
56778
56779
# File 'lib/google/apis/compute_v1/classes.rb', line 56777

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



56782
56783
56784
# File 'lib/google/apis/compute_v1/classes.rb', line 56782

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


56788
56789
56790
# File 'lib/google/apis/compute_v1/classes.rb', line 56788

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56798
56799
56800
# File 'lib/google/apis/compute_v1/classes.rb', line 56798

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56803
56804
56805
# File 'lib/google/apis/compute_v1/classes.rb', line 56803

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56808
56809
56810
# File 'lib/google/apis/compute_v1/classes.rb', line 56808

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56815
56816
56817
56818
56819
56820
56821
56822
# File 'lib/google/apis/compute_v1/classes.rb', line 56815

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end