Class: Google::Apis::ComputeV1::TargetGrpcProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetGrpcProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetGrpcProxyList
constructor
A new instance of TargetGrpcProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetGrpcProxyList
Returns a new instance of TargetGrpcProxyList.
55607 55608 55609 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55574 55575 55576 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55574 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
Corresponds to the JSON property items
55579 55580 55581 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55579 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy
for target grpc proxies.
Corresponds to the JSON property kind
55585 55586 55587 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55585 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55595 55596 55597 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55595 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55600 55601 55602 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55600 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55605 55606 55607 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55605 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55612 55613 55614 55615 55616 55617 55618 55619 |
# File 'lib/google/apis/compute_v1/classes.rb', line 55612 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |