Class: Google::Apis::ComputeV1::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



34549
34550
34551
# File 'lib/google/apis/compute_v1/classes.rb', line 34549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34517
34518
34519
# File 'lib/google/apis/compute_v1/classes.rb', line 34517

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



34522
34523
34524
# File 'lib/google/apis/compute_v1/classes.rb', line 34522

def items
  @items
end

#kindString

[Output Only] Type of the resource. Always compute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


34528
34529
34530
# File 'lib/google/apis/compute_v1/classes.rb', line 34528

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34537
34538
34539
# File 'lib/google/apis/compute_v1/classes.rb', line 34537

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34542
34543
34544
# File 'lib/google/apis/compute_v1/classes.rb', line 34542

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34547
34548
34549
# File 'lib/google/apis/compute_v1/classes.rb', line 34547

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34554
34555
34556
34557
34558
34559
34560
34561
# File 'lib/google/apis/compute_v1/classes.rb', line 34554

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end