Class: Google::Apis::ComputeV1::TargetHttpProxy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetHttpProxy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Target HTTP Proxy resource. Google Compute Engine has two Target HTTP Proxy resources: * Global * Regional A target HTTP proxy is a component of GCP HTTP load balancers. * targetHttpProxies are used by external HTTP load balancers and Traffic Director. * regionTargetHttpProxies are used by internal HTTP load balancers. Forwarding rules reference a target HTTP proxy, and the target proxy then references a URL map. For more information, read Using Target Proxies and Forwarding rule concepts.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#name ⇒ String
Name of the resource.
-
#proxy_bind ⇒ Boolean
(also: #proxy_bind?)
This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set to INTERNAL_SELF_MANAGED.
-
#region ⇒ String
[Output Only] URL of the region where the regional Target HTTP Proxy resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#url_map ⇒ String
URL to the UrlMap resource that defines the mapping from URL to the BackendService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxy
constructor
A new instance of TargetHttpProxy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxy
Returns a new instance of TargetHttpProxy.
34805 34806 34807 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34805 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
34734 34735 34736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34734 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
34740 34741 34742 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34740 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a TargetHttpProxy. An up-to-date fingerprint must be provided in
order to patch/update the TargetHttpProxy; otherwise, the request will fail
with error 412 conditionNotMet. To see the latest fingerprint, make a get()
request to retrieve the TargetHttpProxy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
34751 34752 34753 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34751 def fingerprint @fingerprint end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
34757 34758 34759 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34757 def id @id end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetHttpProxy for target HTTP
proxies.
Corresponds to the JSON property kind
34763 34764 34765 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34763 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
34773 34774 34775 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34773 def name @name end |
#proxy_bind ⇒ Boolean Also known as: proxy_bind?
This field only applies when the forwarding rule that references this target
proxy has a loadBalancingScheme set to INTERNAL_SELF_MANAGED. When this field
is set to true, Envoy proxies set up inbound traffic interception and bind to
the IP address and port specified in the forwarding rule. This is generally
useful when using Traffic Director to configure Envoy as a gateway or middle
proxy (in other words, not a sidecar proxy). The Envoy proxy listens for
inbound requests and handles requests when it receives them. The default is
false.
Corresponds to the JSON property proxyBind
34785 34786 34787 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34785 def proxy_bind @proxy_bind end |
#region ⇒ String
[Output Only] URL of the region where the regional Target HTTP Proxy resides.
This field is not applicable to global Target HTTP Proxies.
Corresponds to the JSON property region
34792 34793 34794 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34792 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
34797 34798 34799 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34797 def self_link @self_link end |
#url_map ⇒ String
URL to the UrlMap resource that defines the mapping from URL to the
BackendService.
Corresponds to the JSON property urlMap
34803 34804 34805 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34803 def url_map @url_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34810 34811 34812 34813 34814 34815 34816 34817 34818 34819 34820 34821 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34810 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @url_map = args[:url_map] if args.key?(:url_map) end |