Class: Google::Apis::ComputeV1::TargetHttpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetHttpProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetHttpProxiesScopedList>
A list of TargetHttpProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyAggregatedList
constructor
A new instance of TargetHttpProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyAggregatedList
Returns a new instance of TargetHttpProxyAggregatedList.
62284 62285 62286 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62250 62251 62252 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62250 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetHttpProxiesScopedList>
A list of TargetHttpProxiesScopedList resources.
Corresponds to the JSON property items
62255 62256 62257 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62255 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetHttpProxyAggregatedList for lists of Target HTTP
Proxies.
Corresponds to the JSON property kind
62262 62263 62264 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62262 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62272 62273 62274 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62272 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62277 62278 62279 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62277 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
62282 62283 62284 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62282 def unreachables @unreachables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62289 62290 62291 62292 62293 62294 62295 62296 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62289 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) end |