Class: Google::Apis::ComputeV1::TargetHttpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of TargetHttpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyList

Returns a new instance of TargetHttpProxyList.



63083
63084
63085
# File 'lib/google/apis/compute_v1/classes.rb', line 63083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63050
63051
63052
# File 'lib/google/apis/compute_v1/classes.rb', line 63050

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetHttpProxy>

A list of TargetHttpProxy resources. Corresponds to the JSON property items



63055
63056
63057
# File 'lib/google/apis/compute_v1/classes.rb', line 63055

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpProxyList for lists of target HTTP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


63061
63062
63063
# File 'lib/google/apis/compute_v1/classes.rb', line 63061

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63071
63072
63073
# File 'lib/google/apis/compute_v1/classes.rb', line 63071

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63076
63077
63078
# File 'lib/google/apis/compute_v1/classes.rb', line 63076

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetHttpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63081
63082
63083
# File 'lib/google/apis/compute_v1/classes.rb', line 63081

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63088
63089
63090
63091
63092
63093
63094
63095
# File 'lib/google/apis/compute_v1/classes.rb', line 63088

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end