Class: Google::Apis::ComputeV1::TargetHttpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of TargetHttpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyList

Returns a new instance of TargetHttpProxyList.



62353
62354
62355
# File 'lib/google/apis/compute_v1/classes.rb', line 62353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62320
62321
62322
# File 'lib/google/apis/compute_v1/classes.rb', line 62320

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetHttpProxy>

A list of TargetHttpProxy resources. Corresponds to the JSON property items



62325
62326
62327
# File 'lib/google/apis/compute_v1/classes.rb', line 62325

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpProxyList for lists of target HTTP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


62331
62332
62333
# File 'lib/google/apis/compute_v1/classes.rb', line 62331

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62341
62342
62343
# File 'lib/google/apis/compute_v1/classes.rb', line 62341

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62346
62347
62348
# File 'lib/google/apis/compute_v1/classes.rb', line 62346

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetHttpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62351
62352
62353
# File 'lib/google/apis/compute_v1/classes.rb', line 62351

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62358
62359
62360
62361
62362
62363
62364
62365
# File 'lib/google/apis/compute_v1/classes.rb', line 62358

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end