Class: Google::Apis::ComputeV1::TargetHttpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetHttpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of TargetHttpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetHttpProxy>
A list of TargetHttpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyList
constructor
A new instance of TargetHttpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyList
Returns a new instance of TargetHttpProxyList.
62339 62340 62341 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62306 62307 62308 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62306 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetHttpProxy>
A list of TargetHttpProxy resources.
Corresponds to the JSON property items
62311 62312 62313 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62311 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpProxyList for lists
of target HTTP proxies.
Corresponds to the JSON property kind
62317 62318 62319 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62317 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62327 62328 62329 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62327 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62332 62333 62334 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62332 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62337 62338 62339 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62337 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62344 62345 62346 62347 62348 62349 62350 62351 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62344 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |