Class: Google::Apis::ComputeV1::TargetHttpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetHttpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of TargetHttpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetHttpProxy>
A list of TargetHttpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyList
constructor
A new instance of TargetHttpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyList
Returns a new instance of TargetHttpProxyList.
60830 60831 60832 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60797 60798 60799 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60797 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetHttpProxy>
A list of TargetHttpProxy resources.
Corresponds to the JSON property items
60802 60803 60804 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60802 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpProxyList for lists
of target HTTP proxies.
Corresponds to the JSON property kind
60808 60809 60810 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60808 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60818 60819 60820 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60818 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60823 60824 60825 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60823 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60828 60829 60830 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60828 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60835 60836 60837 60838 60839 60840 60841 60842 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60835 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |