Class: Google::Apis::ComputeV1::TargetHttpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A list of TargetHttpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyList

Returns a new instance of TargetHttpProxyList.



56011
56012
56013
# File 'lib/google/apis/compute_v1/classes.rb', line 56011

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55978
55979
55980
# File 'lib/google/apis/compute_v1/classes.rb', line 55978

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetHttpProxy>

A list of TargetHttpProxy resources. Corresponds to the JSON property items



55983
55984
55985
# File 'lib/google/apis/compute_v1/classes.rb', line 55983

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpProxyList for lists of target HTTP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


55989
55990
55991
# File 'lib/google/apis/compute_v1/classes.rb', line 55989

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55999
56000
56001
# File 'lib/google/apis/compute_v1/classes.rb', line 55999

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56004
56005
56006
# File 'lib/google/apis/compute_v1/classes.rb', line 56004

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetHttpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56009
56010
56011
# File 'lib/google/apis/compute_v1/classes.rb', line 56009

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56016
56017
56018
56019
56020
56021
56022
56023
# File 'lib/google/apis/compute_v1/classes.rb', line 56016

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end