Class: Google::Apis::ComputeV1::TargetHttpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetHttpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A list of TargetHttpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetHttpProxy>
A list of TargetHttpProxy resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyList
constructor
A new instance of TargetHttpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyList
Returns a new instance of TargetHttpProxyList.
34917 34918 34919 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34917 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
34885 34886 34887 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34885 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetHttpProxy>
A list of TargetHttpProxy resources.
Corresponds to the JSON property items
34890 34891 34892 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34890 def items @items end |
#kind ⇒ String
Type of resource. Always compute#targetHttpProxyList for lists of target HTTP
proxies.
Corresponds to the JSON property kind
34896 34897 34898 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34896 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
34905 34906 34907 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34905 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
34910 34911 34912 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34910 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
34915 34916 34917 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34915 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34922 34923 34924 34925 34926 34927 34928 34929 |
# File 'lib/google/apis/compute_v1/classes.rb', line 34922 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |