Class: Google::Apis::ComputeV1::TargetHttpsProxy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetHttpsProxy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Target HTTPS Proxy resource. Google Compute Engine has two Target HTTPS Proxy resources:
- Global
- Regional A target HTTPS proxy is a component of Google Cloud HTTPS load balancers.
- targetHttpsProxies are used by global external Application Load Balancers, classic Application Load Balancers, cross-region internal Application Load Balancers, and Traffic Director.
- regionTargetHttpsProxies are used by regional internal Application Load Balancers and regional external Application Load Balancers. Forwarding rules reference a target HTTPS proxy, and the target proxy then references a URL map. For more information, readUsing Target Proxies and Forwarding rule concepts.
Instance Attribute Summary collapse
-
#authorization_policy ⇒ String
Optional.
-
#certificate_map ⇒ String
URL of a certificate map that identifies a certificate map associated with the given target proxy.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#http_keep_alive_timeout_sec ⇒ Fixnum
Specifies how long to keep a connection open, after completing a response, while there is no matching traffic (in seconds).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#proxy_bind ⇒ Boolean
(also: #proxy_bind?)
This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
-
#quic_override ⇒ String
Specifies the QUIC override policy for this TargetHttpsProxy resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#server_tls_policy ⇒ String
Optional.
-
#ssl_certificates ⇒ Array<String>
URLs to SslCertificate resources that are used to authenticate connections between users and the load balancer.
-
#ssl_policy ⇒ String
URL of SslPolicy resource that will be associated with the TargetHttpsProxy resource.
-
#tls_early_data ⇒ String
Specifies whether TLS 1.3 0-RTT Data ("Early Data") should be accepted for this service.
-
#url_map ⇒ String
A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxy
constructor
A new instance of TargetHttpsProxy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxy
Returns a new instance of TargetHttpsProxy.
56476 56477 56478 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorization_policy ⇒ String
Optional. A URL referring to a networksecurity.AuthorizationPolicy resource
that describes how the proxy should authorize inbound traffic. If left
blank, access will not be restricted by an authorization policy.
Refer to the AuthorizationPolicy resource for additional
details.
authorizationPolicy only applies to a globalTargetHttpsProxy attached
toglobalForwardingRules with theloadBalancingScheme set to
INTERNAL_SELF_MANAGED.
Note: This field currently has no impact.
Corresponds to the JSON property authorizationPolicy
56283 56284 56285 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56283 def @authorization_policy end |
#certificate_map ⇒ String
URL of a certificate map that identifies a certificate map associated with
the given target proxy.
This field can only be set for Global external Application Load Balancer or
Classic Application Load Balancer. For other products use Certificate
Manager Certificates instead.
If set, sslCertificates will be ignored.
Accepted format is//certificatemanager.googleapis.com/projects/project/
locations/location/certificateMaps/resourceName.
Corresponds to the JSON property certificateMap
56295 56296 56297 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56295 def certificate_map @certificate_map end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
56301 56302 56303 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56301 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
56307 56308 56309 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56307 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a TargetHttpsProxy. An up-to-date fingerprint must
be provided in order to patch the TargetHttpsProxy; otherwise, the request
will fail with error 412 conditionNotMet. To see the latest
fingerprint, make a get() request to retrieve the
TargetHttpsProxy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
56319 56320 56321 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56319 def fingerprint @fingerprint end |
#http_keep_alive_timeout_sec ⇒ Fixnum
Specifies how long to keep a connection open, after completing a response,
while there is no matching traffic (in seconds). If an HTTP keep-alive is
not specified, a default value (610 seconds) will be used.
For global external Application Load Balancers, the minimum allowed value
is 5 seconds and the maximum allowed value is 1200 seconds.
For classic Application Load Balancers, this option is not supported.
Corresponds to the JSON property httpKeepAliveTimeoutSec
56329 56330 56331 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56329 def http_keep_alive_timeout_sec @http_keep_alive_timeout_sec end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
56335 56336 56337 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56335 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetHttpsProxy
for target HTTPS proxies.
Corresponds to the JSON property kind
56341 56342 56343 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56341 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
56352 56353 56354 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56352 def name @name end |
#proxy_bind ⇒ Boolean Also known as: proxy_bind?
This field only applies when the forwarding rule that references this
target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
When this field is set to true, Envoy proxies set up inbound
traffic interception and bind to the IP address and port specified in the
forwarding rule. This is generally useful when using Traffic Director to
configure Envoy as a gateway or middle proxy (in other words, not a
sidecar proxy). The Envoy proxy listens for inbound requests and handles
requests when it receives them.
The default is false.
Corresponds to the JSON property proxyBind
56365 56366 56367 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56365 def proxy_bind @proxy_bind end |
#quic_override ⇒ String
Specifies the QUIC override policy for this TargetHttpsProxy resource. This setting determines whether the load balancer attempts to negotiate QUIC with clients. You can specify NONE, ENABLE, orDISABLE.
- When quic-override is set to NONE, Google manages whether QUIC is used.
- When quic-override is set to ENABLE, the load balancer uses QUIC when possible.
- When quic-override is set to DISABLE, the load balancer doesn't use QUIC.
- If the quic-override flag is not specified,NONE is implied.
Corresponds to the JSON property
quicOverride
56382 56383 56384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56382 def quic_override @quic_override end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional
TargetHttpsProxy
resides. This field is not applicable to global TargetHttpsProxies.
Corresponds to the JSON property region
56389 56390 56391 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56389 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
56394 56395 56396 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56394 def self_link @self_link end |
#server_tls_policy ⇒ String
Optional. A URL referring to a networksecurity.ServerTlsPolicy resource
that describes how the proxy should authenticate inbound traffic.
serverTlsPolicy only applies to a globalTargetHttpsProxy attached
toglobalForwardingRules with theloadBalancingScheme set to
INTERNAL_SELF_MANAGED
or EXTERNAL orEXTERNAL_MANAGED or INTERNAL_MANAGED.
It also applies to a regional TargetHttpsProxy attached to
regional forwardingRules with theloadBalancingScheme set to EXTERNAL_MANAGED
orINTERNAL_MANAGED. For details whichServerTlsPolicy resources are accepted
withINTERNAL_SELF_MANAGED and which with EXTERNAL,INTERNAL_MANAGED,
EXTERNAL_MANAGEDloadBalancingScheme consult ServerTlsPolicy
documentation.
If left blank, communications are not encrypted.
Corresponds to the JSON property serverTlsPolicy
56411 56412 56413 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56411 def server_tls_policy @server_tls_policy end |
#ssl_certificates ⇒ Array<String>
URLs to SslCertificate resources that are used to authenticate connections between users and the load balancer. At least one SSL certificate must be specified. SslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED. The URLs should refer to a SSL Certificate resource or Certificate Manager Certificate resource. Mixing Classic Certificates and Certificate Manager Certificates is not allowed. Certificate Manager Certificates must include the certificatemanager API namespace. Using Certificate Manager Certificates in this field is not supported by Global external Application Load Balancer or Classic Application Load Balancer, use certificate_map instead. Currently, you may specify up to 15 Classic SSL Certificates or up to 100 Certificate Manager Certificates. Certificate Manager Certificates accepted formats are:
- //certificatemanager.googleapis.com/projects/
project/locations/location/certificates/resourceName. - https://certificatemanager.googleapis.com/v1alpha1/projects/`project`/
locations/
location/certificates/resourceName. Corresponds to the JSON propertysslCertificates
56434 56435 56436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56434 def ssl_certificates @ssl_certificates end |
#ssl_policy ⇒ String
URL of SslPolicy resource that will be associated with the TargetHttpsProxy
resource. If not set, the TargetHttpsProxy resource has no
SSL policy configured.
Corresponds to the JSON property sslPolicy
56441 56442 56443 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56441 def ssl_policy @ssl_policy end |
#tls_early_data ⇒ String
Specifies whether TLS 1.3 0-RTT Data ("Early Data") should be accepted
for this service. Early Data allows a TLS resumption handshake to include
the initial application payload (a HTTP request) alongside the handshake,
reducing the effective round trips to "zero". This applies to TLS 1.3
connections over TCP (HTTP/2) as well as over UDP (QUIC/h3).
This can improve application performance, especially on networks where
interruptions may be common, such as on mobile.
Requests with Early Data will have the "Early-Data" HTTP header set on
the request, with a value of "1", to allow the backend to determine whether
Early Data was included.
Note: TLS Early Data may allow requests to be replayed, as the data is
sent to the backend before the handshake has fully completed. Applications
that allow idempotent HTTP methods to make non-idempotent changes, such as
a GET request updating a database, should not accept Early Data on those
requests, and reject requests with the "Early-Data: 1" HTTP header by
returning a HTTP 425 (Too Early) status code, in order to remain RFC
compliant.
The default value is DISABLED.
Corresponds to the JSON property tlsEarlyData
56463 56464 56465 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56463 def tls_early_data @tls_early_data end |
#url_map ⇒ String
A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService. For example, the following are all valid URLs for specifying a URL map:
- https://www.googleapis.compute/v1/projects/project/global/urlMaps/url-map
- projects/project/global/urlMaps/url-map
- global/urlMaps/url-map
Corresponds to the JSON property
urlMap
56474 56475 56476 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56474 def url_map @url_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56481 56482 56483 56484 56485 56486 56487 56488 56489 56490 56491 56492 56493 56494 56495 56496 56497 56498 56499 56500 |
# File 'lib/google/apis/compute_v1/classes.rb', line 56481 def update!(**args) @authorization_policy = args[:authorization_policy] if args.key?(:authorization_policy) @certificate_map = args[:certificate_map] if args.key?(:certificate_map) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @http_keep_alive_timeout_sec = args[:http_keep_alive_timeout_sec] if args.key?(:http_keep_alive_timeout_sec) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind) @quic_override = args[:quic_override] if args.key?(:quic_override) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @server_tls_policy = args[:server_tls_policy] if args.key?(:server_tls_policy) @ssl_certificates = args[:ssl_certificates] if args.key?(:ssl_certificates) @ssl_policy = args[:ssl_policy] if args.key?(:ssl_policy) @tls_early_data = args[:tls_early_data] if args.key?(:tls_early_data) @url_map = args[:url_map] if args.key?(:url_map) end |