Class: Google::Apis::ComputeV1::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



64452
64453
64454
# File 'lib/google/apis/compute_v1/classes.rb', line 64452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64413
64414
64415
# File 'lib/google/apis/compute_v1/classes.rb', line 64413

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



64418
64419
64420
# File 'lib/google/apis/compute_v1/classes.rb', line 64418

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


64425
64426
64427
# File 'lib/google/apis/compute_v1/classes.rb', line 64425

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64435
64436
64437
# File 'lib/google/apis/compute_v1/classes.rb', line 64435

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64440
64441
64442
# File 'lib/google/apis/compute_v1/classes.rb', line 64440

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64445
64446
64447
# File 'lib/google/apis/compute_v1/classes.rb', line 64445

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64450
64451
64452
# File 'lib/google/apis/compute_v1/classes.rb', line 64450

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64457
64458
64459
64460
64461
64462
64463
64464
64465
# File 'lib/google/apis/compute_v1/classes.rb', line 64457

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end