Class: Google::Apis::ComputeV1::TargetHttpsProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetHttpsProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetHttpsProxiesScopedList>
A list of TargetHttpsProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetHttpsProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxyAggregatedList
constructor
A new instance of TargetHttpsProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxyAggregatedList
Returns a new instance of TargetHttpsProxyAggregatedList.
63223 63224 63225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63184 63185 63186 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63184 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetHttpsProxiesScopedList>
A list of TargetHttpsProxiesScopedList resources.
Corresponds to the JSON property items
63189 63190 63191 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63189 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetHttpsProxyAggregatedList for lists of Target
HTTP Proxies.
Corresponds to the JSON property kind
63196 63197 63198 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63196 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63206 63207 63208 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63206 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63211 63212 63213 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63211 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
63216 63217 63218 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63216 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetHttpsProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63221 63222 63223 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63221 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63228 63229 63230 63231 63232 63233 63234 63235 63236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63228 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |