Class: Google::Apis::ComputeV1::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



62877
62878
62879
# File 'lib/google/apis/compute_v1/classes.rb', line 62877

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62838
62839
62840
# File 'lib/google/apis/compute_v1/classes.rb', line 62838

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



62843
62844
62845
# File 'lib/google/apis/compute_v1/classes.rb', line 62843

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


62850
62851
62852
# File 'lib/google/apis/compute_v1/classes.rb', line 62850

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62860
62861
62862
# File 'lib/google/apis/compute_v1/classes.rb', line 62860

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62865
62866
62867
# File 'lib/google/apis/compute_v1/classes.rb', line 62865

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


62870
62871
62872
# File 'lib/google/apis/compute_v1/classes.rb', line 62870

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62875
62876
62877
# File 'lib/google/apis/compute_v1/classes.rb', line 62875

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62882
62883
62884
62885
62886
62887
62888
62889
62890
# File 'lib/google/apis/compute_v1/classes.rb', line 62882

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end