Class: Google::Apis::ComputeV1::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



56549
56550
56551
# File 'lib/google/apis/compute_v1/classes.rb', line 56549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56510
56511
56512
# File 'lib/google/apis/compute_v1/classes.rb', line 56510

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



56515
56516
56517
# File 'lib/google/apis/compute_v1/classes.rb', line 56515

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


56522
56523
56524
# File 'lib/google/apis/compute_v1/classes.rb', line 56522

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56532
56533
56534
# File 'lib/google/apis/compute_v1/classes.rb', line 56532

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56537
56538
56539
# File 'lib/google/apis/compute_v1/classes.rb', line 56537

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


56542
56543
56544
# File 'lib/google/apis/compute_v1/classes.rb', line 56542

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56547
56548
56549
# File 'lib/google/apis/compute_v1/classes.rb', line 56547

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56554
56555
56556
56557
56558
56559
56560
56561
56562
# File 'lib/google/apis/compute_v1/classes.rb', line 56554

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end