Class: Google::Apis::ComputeV1::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



35331
35332
35333
# File 'lib/google/apis/compute_v1/classes.rb', line 35331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35294
35295
35296
# File 'lib/google/apis/compute_v1/classes.rb', line 35294

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



35299
35300
35301
# File 'lib/google/apis/compute_v1/classes.rb', line 35299

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


35305
35306
35307
# File 'lib/google/apis/compute_v1/classes.rb', line 35305

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35314
35315
35316
# File 'lib/google/apis/compute_v1/classes.rb', line 35314

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35319
35320
35321
# File 'lib/google/apis/compute_v1/classes.rb', line 35319

def self_link
  @self_link
end

#unreachablesArray<String>

[Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35324
35325
35326
# File 'lib/google/apis/compute_v1/classes.rb', line 35324

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35329
35330
35331
# File 'lib/google/apis/compute_v1/classes.rb', line 35329

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35336
35337
35338
35339
35340
35341
35342
35343
35344
# File 'lib/google/apis/compute_v1/classes.rb', line 35336

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end