Class: Google::Apis::ComputeV1::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



64578
64579
64580
# File 'lib/google/apis/compute_v1/classes.rb', line 64578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64545
64546
64547
# File 'lib/google/apis/compute_v1/classes.rb', line 64545

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



64550
64551
64552
# File 'lib/google/apis/compute_v1/classes.rb', line 64550

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


64556
64557
64558
# File 'lib/google/apis/compute_v1/classes.rb', line 64556

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64566
64567
64568
# File 'lib/google/apis/compute_v1/classes.rb', line 64566

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64571
64572
64573
# File 'lib/google/apis/compute_v1/classes.rb', line 64571

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64576
64577
64578
# File 'lib/google/apis/compute_v1/classes.rb', line 64576

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64583
64584
64585
64586
64587
64588
64589
64590
# File 'lib/google/apis/compute_v1/classes.rb', line 64583

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end