Class: Google::Apis::ComputeV1::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



61494
61495
61496
# File 'lib/google/apis/compute_v1/classes.rb', line 61494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61461
61462
61463
# File 'lib/google/apis/compute_v1/classes.rb', line 61461

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



61466
61467
61468
# File 'lib/google/apis/compute_v1/classes.rb', line 61466

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


61472
61473
61474
# File 'lib/google/apis/compute_v1/classes.rb', line 61472

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61482
61483
61484
# File 'lib/google/apis/compute_v1/classes.rb', line 61482

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61487
61488
61489
# File 'lib/google/apis/compute_v1/classes.rb', line 61487

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61492
61493
61494
# File 'lib/google/apis/compute_v1/classes.rb', line 61492

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61499
61500
61501
61502
61503
61504
61505
61506
# File 'lib/google/apis/compute_v1/classes.rb', line 61499

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end