Class: Google::Apis::ComputeV1::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



57878
57879
57880
# File 'lib/google/apis/compute_v1/classes.rb', line 57878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57845
57846
57847
# File 'lib/google/apis/compute_v1/classes.rb', line 57845

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



57850
57851
57852
# File 'lib/google/apis/compute_v1/classes.rb', line 57850

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


57856
57857
57858
# File 'lib/google/apis/compute_v1/classes.rb', line 57856

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57866
57867
57868
# File 'lib/google/apis/compute_v1/classes.rb', line 57866

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57871
57872
57873
# File 'lib/google/apis/compute_v1/classes.rb', line 57871

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57876
57877
57878
# File 'lib/google/apis/compute_v1/classes.rb', line 57876

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57883
57884
57885
57886
57887
57888
57889
57890
# File 'lib/google/apis/compute_v1/classes.rb', line 57883

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end