Class: Google::Apis::ComputeV1::TargetHttpsProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetHttpsProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetHttpsProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxyList
constructor
A new instance of TargetHttpsProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxyList
Returns a new instance of TargetHttpsProxyList.
35450 35451 35452 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35418 35419 35420 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35418 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
Corresponds to the JSON property items
35423 35424 35425 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35423 def items @items end |
#kind ⇒ String
Type of resource. Always compute#targetHttpsProxyList for lists of target
HTTPS proxies.
Corresponds to the JSON property kind
35429 35430 35431 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35429 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35438 35439 35440 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35438 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35443 35444 35445 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35443 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35448 35449 35450 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35448 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35455 35456 35457 35458 35459 35460 35461 35462 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35455 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |