Class: Google::Apis::ComputeV1::TargetInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Target Instance resource. You can use a target instance to handle traffic for one or more forwarding rules, which is ideal for forwarding protocol traffic that is managed by a single source. For example, ESP, AH, TCP, or UDP. For more information, readTarget instances.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#instance ⇒ String
A URL to the virtual machine instance that handles traffic for this target instance.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#nat_policy ⇒ String
Must have a value of NO_NAT.
-
#network ⇒ String
The URL of the network this target instance uses to forward traffic.
-
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this target instance.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstance
constructor
A new instance of TargetInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstance
Returns a new instance of TargetInstance.
63191 63192 63193 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
63115 63116 63117 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63115 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
63121 63122 63123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63121 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
63127 63128 63129 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63127 def id @id end |
#instance ⇒ String
A URL to the virtual machine instance that handles traffic for this target instance. When creating a target instance, you can provide the fully-qualified URL or a valid partial URL to the desired virtual machine. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ instances/instance
- projects/project/zones/zone/instances/instance
- zones/zone/instances/instance
Corresponds to the JSON property
instance
63140 63141 63142 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63140 def instance @instance end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#
targetInstance for target instances.
Corresponds to the JSON property kind
63146 63147 63148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63146 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
63157 63158 63159 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63157 def name @name end |
#nat_policy ⇒ String
Must have a value of NO_NAT.
Protocol forwarding delivers packets while preserving the destination IP
address of the forwarding rule referencing the target instance.
Corresponds to the JSON property natPolicy
63164 63165 63166 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63164 def nat_policy @nat_policy end |
#network ⇒ String
The URL of the network this target instance uses to forward traffic.
If not specified, the traffic will be forwarded to the network that
the default network interface belongs to.
Corresponds to the JSON property network
63171 63172 63173 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63171 def network @network end |
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this
target instance.
Corresponds to the JSON property securityPolicy
63177 63178 63179 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63177 def security_policy @security_policy end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
63182 63183 63184 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63182 def self_link @self_link end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the target instance resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
63189 63190 63191 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63189 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63196 63197 63198 63199 63200 63201 63202 63203 63204 63205 63206 63207 63208 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63196 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @nat_policy = args[:nat_policy] if args.key?(:nat_policy) @network = args[:network] if args.key?(:network) @security_policy = args[:security_policy] if args.key?(:security_policy) @self_link = args[:self_link] if args.key?(:self_link) @zone = args[:zone] if args.key?(:zone) end |