Class: Google::Apis::ComputeV1::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
64866 64867 64868 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64829 64830 64831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64829 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
64834 64835 64836 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64834 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
64839 64840 64841 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64839 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64849 64850 64851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64849 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64854 64855 64856 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64854 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64859 64860 64861 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64859 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64864 64865 64866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64864 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64871 64872 64873 64874 64875 64876 64877 64878 64879 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64871 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |