Class: Google::Apis::ComputeV1::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
64816 64817 64818 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64779 64780 64781 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64779 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
64784 64785 64786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64784 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
64789 64790 64791 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64789 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64799 64800 64801 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64799 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64804 64805 64806 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64804 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64809 64810 64811 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64809 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64814 64815 64816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64814 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64821 64822 64823 64824 64825 64826 64827 64828 64829 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64821 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |