Class: Google::Apis::ComputeV1::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



63973
63974
63975
# File 'lib/google/apis/compute_v1/classes.rb', line 63973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63936
63937
63938
# File 'lib/google/apis/compute_v1/classes.rb', line 63936

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



63941
63942
63943
# File 'lib/google/apis/compute_v1/classes.rb', line 63941

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


63946
63947
63948
# File 'lib/google/apis/compute_v1/classes.rb', line 63946

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63956
63957
63958
# File 'lib/google/apis/compute_v1/classes.rb', line 63956

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63961
63962
63963
# File 'lib/google/apis/compute_v1/classes.rb', line 63961

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63966
63967
63968
# File 'lib/google/apis/compute_v1/classes.rb', line 63966

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63971
63972
63973
# File 'lib/google/apis/compute_v1/classes.rb', line 63971

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63978
63979
63980
63981
63982
63983
63984
63985
63986
# File 'lib/google/apis/compute_v1/classes.rb', line 63978

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end