Class: Google::Apis::ComputeV1::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



63587
63588
63589
# File 'lib/google/apis/compute_v1/classes.rb', line 63587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63550
63551
63552
# File 'lib/google/apis/compute_v1/classes.rb', line 63550

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



63555
63556
63557
# File 'lib/google/apis/compute_v1/classes.rb', line 63555

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


63560
63561
63562
# File 'lib/google/apis/compute_v1/classes.rb', line 63560

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63570
63571
63572
# File 'lib/google/apis/compute_v1/classes.rb', line 63570

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63575
63576
63577
# File 'lib/google/apis/compute_v1/classes.rb', line 63575

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63580
63581
63582
# File 'lib/google/apis/compute_v1/classes.rb', line 63580

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63585
63586
63587
# File 'lib/google/apis/compute_v1/classes.rb', line 63585

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63592
63593
63594
63595
63596
63597
63598
63599
63600
# File 'lib/google/apis/compute_v1/classes.rb', line 63592

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end