Class: Google::Apis::ComputeV1::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
63241 63242 63243 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63204 63205 63206 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63204 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
63209 63210 63211 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63209 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
63214 63215 63216 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63214 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63224 63225 63226 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63224 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63229 63230 63231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63229 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
63234 63235 63236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63234 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63239 63240 63241 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63239 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63246 63247 63248 63249 63250 63251 63252 63253 63254 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63246 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |