Class: Google::Apis::ComputeV1::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



61732
61733
61734
# File 'lib/google/apis/compute_v1/classes.rb', line 61732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61695
61696
61697
# File 'lib/google/apis/compute_v1/classes.rb', line 61695

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



61700
61701
61702
# File 'lib/google/apis/compute_v1/classes.rb', line 61700

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


61705
61706
61707
# File 'lib/google/apis/compute_v1/classes.rb', line 61705

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61715
61716
61717
# File 'lib/google/apis/compute_v1/classes.rb', line 61715

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61720
61721
61722
# File 'lib/google/apis/compute_v1/classes.rb', line 61720

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


61725
61726
61727
# File 'lib/google/apis/compute_v1/classes.rb', line 61725

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61730
61731
61732
# File 'lib/google/apis/compute_v1/classes.rb', line 61730

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61737
61738
61739
61740
61741
61742
61743
61744
61745
# File 'lib/google/apis/compute_v1/classes.rb', line 61737

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end