Class: Google::Apis::ComputeV1::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



58116
58117
58118
# File 'lib/google/apis/compute_v1/classes.rb', line 58116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58079
58080
58081
# File 'lib/google/apis/compute_v1/classes.rb', line 58079

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



58084
58085
58086
# File 'lib/google/apis/compute_v1/classes.rb', line 58084

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


58089
58090
58091
# File 'lib/google/apis/compute_v1/classes.rb', line 58089

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58099
58100
58101
# File 'lib/google/apis/compute_v1/classes.rb', line 58099

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58104
58105
58106
# File 'lib/google/apis/compute_v1/classes.rb', line 58104

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58109
58110
58111
# File 'lib/google/apis/compute_v1/classes.rb', line 58109

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58114
58115
58116
# File 'lib/google/apis/compute_v1/classes.rb', line 58114

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58121
58122
58123
58124
58125
58126
58127
58128
58129
# File 'lib/google/apis/compute_v1/classes.rb', line 58121

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end