Class: Google::Apis::ComputeV1::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
35666 35667 35668 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35666 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35630 35631 35632 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35630 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
35635 35636 35637 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35635 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
35640 35641 35642 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35640 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35649 35650 35651 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35649 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35654 35655 35656 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35654 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
35659 35660 35661 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35659 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35664 35665 35666 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35664 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35671 35672 35673 35674 35675 35676 35677 35678 35679 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35671 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |