Class: Google::Apis::ComputeV1::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetInstance resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
64098 64099 64100 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64066 64067 64068 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64066 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
64071 64072 64073 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64071 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
64076 64077 64078 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64076 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64086 64087 64088 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64086 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64091 64092 64093 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64091 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64096 64097 64098 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64096 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64103 64104 64105 64106 64107 64108 64109 64110 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64103 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |