Class: Google::Apis::ComputeV1::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



63753
63754
63755
# File 'lib/google/apis/compute_v1/classes.rb', line 63753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63721
63722
63723
# File 'lib/google/apis/compute_v1/classes.rb', line 63721

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



63726
63727
63728
# File 'lib/google/apis/compute_v1/classes.rb', line 63726

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


63731
63732
63733
# File 'lib/google/apis/compute_v1/classes.rb', line 63731

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63741
63742
63743
# File 'lib/google/apis/compute_v1/classes.rb', line 63741

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63746
63747
63748
# File 'lib/google/apis/compute_v1/classes.rb', line 63746

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63751
63752
63753
# File 'lib/google/apis/compute_v1/classes.rb', line 63751

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63758
63759
63760
63761
63762
63763
63764
63765
# File 'lib/google/apis/compute_v1/classes.rb', line 63758

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end