Class: Google::Apis::ComputeV1::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetInstance resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
63712 63713 63714 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63680 63681 63682 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63680 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
63685 63686 63687 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63685 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
63690 63691 63692 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63690 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63700 63701 63702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63700 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63705 63706 63707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63705 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63710 63711 63712 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63710 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63717 63718 63719 63720 63721 63722 63723 63724 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63717 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |