Class: Google::Apis::ComputeV1::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



63366
63367
63368
# File 'lib/google/apis/compute_v1/classes.rb', line 63366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63334
63335
63336
# File 'lib/google/apis/compute_v1/classes.rb', line 63334

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



63339
63340
63341
# File 'lib/google/apis/compute_v1/classes.rb', line 63339

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


63344
63345
63346
# File 'lib/google/apis/compute_v1/classes.rb', line 63344

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63354
63355
63356
# File 'lib/google/apis/compute_v1/classes.rb', line 63354

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63359
63360
63361
# File 'lib/google/apis/compute_v1/classes.rb', line 63359

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63364
63365
63366
# File 'lib/google/apis/compute_v1/classes.rb', line 63364

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63371
63372
63373
63374
63375
63376
63377
63378
# File 'lib/google/apis/compute_v1/classes.rb', line 63371

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end