Class: Google::Apis::ComputeV1::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



61857
61858
61859
# File 'lib/google/apis/compute_v1/classes.rb', line 61857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61825
61826
61827
# File 'lib/google/apis/compute_v1/classes.rb', line 61825

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



61830
61831
61832
# File 'lib/google/apis/compute_v1/classes.rb', line 61830

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


61835
61836
61837
# File 'lib/google/apis/compute_v1/classes.rb', line 61835

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61845
61846
61847
# File 'lib/google/apis/compute_v1/classes.rb', line 61845

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61850
61851
61852
# File 'lib/google/apis/compute_v1/classes.rb', line 61850

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61855
61856
61857
# File 'lib/google/apis/compute_v1/classes.rb', line 61855

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61862
61863
61864
61865
61866
61867
61868
61869
# File 'lib/google/apis/compute_v1/classes.rb', line 61862

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end