Class: Google::Apis::ComputeV1::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetInstance resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
58241 58242 58243 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58209 58210 58211 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58209 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
58214 58215 58216 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58214 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
58219 58220 58221 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58219 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58229 58230 58231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58229 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58234 58235 58236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58234 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58239 58240 58241 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58239 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58246 58247 58248 58249 58250 58251 58252 58253 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58246 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |