Class: Google::Apis::ComputeV1::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetInstance resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
57038 57039 57040 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57006 57007 57008 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57006 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
57011 57012 57013 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57011 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
57016 57017 57018 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57016 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57026 57027 57028 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57026 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57031 57032 57033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57031 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57036 57037 57038 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57036 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57043 57044 57045 57046 57047 57048 57049 57050 |
# File 'lib/google/apis/compute_v1/classes.rb', line 57043 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |