Class: Google::Apis::ComputeV1::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetInstance resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
35784 35785 35786 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35753 35754 35755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35753 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
35758 35759 35760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35758 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
35763 35764 35765 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35763 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35772 35773 35774 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35772 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35777 35778 35779 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35777 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetInstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35782 35783 35784 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35782 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35789 35790 35791 35792 35793 35794 35795 35796 |
# File 'lib/google/apis/compute_v1/classes.rb', line 35789 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |