Class: Google::Apis::ComputeV1::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



64480
64481
64482
# File 'lib/google/apis/compute_v1/classes.rb', line 64480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64441
64442
64443
# File 'lib/google/apis/compute_v1/classes.rb', line 64441

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>

A list of TargetPool resources. Corresponds to the JSON property items



64446
64447
64448
# File 'lib/google/apis/compute_v1/classes.rb', line 64446

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


64453
64454
64455
# File 'lib/google/apis/compute_v1/classes.rb', line 64453

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64463
64464
64465
# File 'lib/google/apis/compute_v1/classes.rb', line 64463

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64468
64469
64470
# File 'lib/google/apis/compute_v1/classes.rb', line 64468

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64473
64474
64475
# File 'lib/google/apis/compute_v1/classes.rb', line 64473

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetPoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64478
64479
64480
# File 'lib/google/apis/compute_v1/classes.rb', line 64478

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64485
64486
64487
64488
64489
64490
64491
64492
64493
# File 'lib/google/apis/compute_v1/classes.rb', line 64485

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end