Class: Google::Apis::ComputeV1::TargetPoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetPoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolAggregatedList
constructor
A new instance of TargetPoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolAggregatedList
Returns a new instance of TargetPoolAggregatedList.
64123 64124 64125 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64084 64085 64086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64084 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>
A list of TargetPool resources.
Corresponds to the JSON property items
64089 64090 64091 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64089 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetPoolAggregatedList for aggregated lists of
target pools.
Corresponds to the JSON property kind
64096 64097 64098 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64096 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64106 64107 64108 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64106 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64111 64112 64113 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64111 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64116 64117 64118 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64116 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64121 64122 64123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64121 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64128 64129 64130 64131 64132 64133 64134 64135 64136 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64128 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |