Class: Google::Apis::ComputeV1::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



63736
63737
63738
# File 'lib/google/apis/compute_v1/classes.rb', line 63736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63697
63698
63699
# File 'lib/google/apis/compute_v1/classes.rb', line 63697

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>

A list of TargetPool resources. Corresponds to the JSON property items



63702
63703
63704
# File 'lib/google/apis/compute_v1/classes.rb', line 63702

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


63709
63710
63711
# File 'lib/google/apis/compute_v1/classes.rb', line 63709

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63719
63720
63721
# File 'lib/google/apis/compute_v1/classes.rb', line 63719

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63724
63725
63726
# File 'lib/google/apis/compute_v1/classes.rb', line 63724

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63729
63730
63731
# File 'lib/google/apis/compute_v1/classes.rb', line 63729

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetPoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63734
63735
63736
# File 'lib/google/apis/compute_v1/classes.rb', line 63734

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63741
63742
63743
63744
63745
63746
63747
63748
63749
# File 'lib/google/apis/compute_v1/classes.rb', line 63741

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end