Class: Google::Apis::ComputeV1::TargetPoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetPoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolAggregatedList
constructor
A new instance of TargetPoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolAggregatedList
Returns a new instance of TargetPoolAggregatedList.
62227 62228 62229 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62188 62189 62190 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62188 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>
A list of TargetPool resources.
Corresponds to the JSON property items
62193 62194 62195 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62193 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetPoolAggregatedList for aggregated lists of
target pools.
Corresponds to the JSON property kind
62200 62201 62202 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62200 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62210 62211 62212 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62210 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62215 62216 62217 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62215 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
62220 62221 62222 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62220 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62225 62226 62227 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62225 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62232 62233 62234 62235 62236 62237 62238 62239 62240 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62232 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |