Class: Google::Apis::ComputeV1::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



57408
57409
57410
# File 'lib/google/apis/compute_v1/classes.rb', line 57408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57369
57370
57371
# File 'lib/google/apis/compute_v1/classes.rb', line 57369

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>

A list of TargetPool resources. Corresponds to the JSON property items



57374
57375
57376
# File 'lib/google/apis/compute_v1/classes.rb', line 57374

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


57381
57382
57383
# File 'lib/google/apis/compute_v1/classes.rb', line 57381

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57391
57392
57393
# File 'lib/google/apis/compute_v1/classes.rb', line 57391

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57396
57397
57398
# File 'lib/google/apis/compute_v1/classes.rb', line 57396

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


57401
57402
57403
# File 'lib/google/apis/compute_v1/classes.rb', line 57401

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetPoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57406
57407
57408
# File 'lib/google/apis/compute_v1/classes.rb', line 57406

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57413
57414
57415
57416
57417
57418
57419
57420
57421
# File 'lib/google/apis/compute_v1/classes.rb', line 57413

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end