Class: Google::Apis::ComputeV1::TargetPoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetPoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>
A list of TargetPool resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolAggregatedList
constructor
A new instance of TargetPoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolAggregatedList
Returns a new instance of TargetPoolAggregatedList.
36121 36122 36123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36084 36085 36086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36084 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>
A list of TargetPool resources.
Corresponds to the JSON property items
36089 36090 36091 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36089 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetPoolAggregatedList for
aggregated lists of target pools.
Corresponds to the JSON property kind
36095 36096 36097 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36095 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36104 36105 36106 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36104 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36109 36110 36111 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36109 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
36114 36115 36116 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36114 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36119 36120 36121 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36119 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36126 36127 36128 36129 36130 36131 36132 36133 36134 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36126 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |