Class: Google::Apis::ComputeV1::TargetPoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetPool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolList

Returns a new instance of TargetPoolList.



65464
65465
65466
# File 'lib/google/apis/compute_v1/classes.rb', line 65464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65431
65432
65433
# File 'lib/google/apis/compute_v1/classes.rb', line 65431

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetPool>

A list of TargetPool resources. Corresponds to the JSON property items



65436
65437
65438
# File 'lib/google/apis/compute_v1/classes.rb', line 65436

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#targetPoolList for lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


65442
65443
65444
# File 'lib/google/apis/compute_v1/classes.rb', line 65442

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65452
65453
65454
# File 'lib/google/apis/compute_v1/classes.rb', line 65452

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65457
65458
65459
# File 'lib/google/apis/compute_v1/classes.rb', line 65457

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetPoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65462
65463
65464
# File 'lib/google/apis/compute_v1/classes.rb', line 65462

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65469
65470
65471
65472
65473
65474
65475
65476
# File 'lib/google/apis/compute_v1/classes.rb', line 65469

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end