Class: Google::Apis::ComputeV1::TargetPoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetPool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolList

Returns a new instance of TargetPoolList.



64621
64622
64623
# File 'lib/google/apis/compute_v1/classes.rb', line 64621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64588
64589
64590
# File 'lib/google/apis/compute_v1/classes.rb', line 64588

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetPool>

A list of TargetPool resources. Corresponds to the JSON property items



64593
64594
64595
# File 'lib/google/apis/compute_v1/classes.rb', line 64593

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#targetPoolList for lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


64599
64600
64601
# File 'lib/google/apis/compute_v1/classes.rb', line 64599

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64609
64610
64611
# File 'lib/google/apis/compute_v1/classes.rb', line 64609

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64614
64615
64616
# File 'lib/google/apis/compute_v1/classes.rb', line 64614

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetPoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64619
64620
64621
# File 'lib/google/apis/compute_v1/classes.rb', line 64619

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64626
64627
64628
64629
64630
64631
64632
64633
# File 'lib/google/apis/compute_v1/classes.rb', line 64626

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end