Class: Google::Apis::ComputeV1::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetPoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetPool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetPoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolList
Returns a new instance of TargetPoolList.
64235 64236 64237 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64235 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64202 64203 64204 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64202 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
64207 64208 64209 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64207 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#targetPoolList
for lists of target pools.
Corresponds to the JSON property kind
64213 64214 64215 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64213 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64223 64224 64225 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64223 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64228 64229 64230 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64228 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetPoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64233 64234 64235 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64233 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64240 64241 64242 64243 64244 64245 64246 64247 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64240 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |