Class: Google::Apis::ComputeV1::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetPoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetPool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetPoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolList
Returns a new instance of TargetPoolList.
62380 62381 62382 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62347 62348 62349 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62347 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
62352 62353 62354 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62352 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#targetPoolList
for lists of target pools.
Corresponds to the JSON property kind
62358 62359 62360 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62358 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62368 62369 62370 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62368 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62373 62374 62375 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62373 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetPoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62378 62379 62380 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62378 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62385 62386 62387 62388 62389 62390 62391 62392 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62385 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |