Class: Google::Apis::ComputeV1::TargetPoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetPool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolList

Returns a new instance of TargetPoolList.



57561
57562
57563
# File 'lib/google/apis/compute_v1/classes.rb', line 57561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57528
57529
57530
# File 'lib/google/apis/compute_v1/classes.rb', line 57528

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetPool>

A list of TargetPool resources. Corresponds to the JSON property items



57533
57534
57535
# File 'lib/google/apis/compute_v1/classes.rb', line 57533

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#targetPoolList for lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


57539
57540
57541
# File 'lib/google/apis/compute_v1/classes.rb', line 57539

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57549
57550
57551
# File 'lib/google/apis/compute_v1/classes.rb', line 57549

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57554
57555
57556
# File 'lib/google/apis/compute_v1/classes.rb', line 57554

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetPoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57559
57560
57561
# File 'lib/google/apis/compute_v1/classes.rb', line 57559

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57566
57567
57568
57569
57570
57571
57572
57573
# File 'lib/google/apis/compute_v1/classes.rb', line 57566

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end