Class: Google::Apis::ComputeV1::TargetPoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetPool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolList

Returns a new instance of TargetPoolList.



36266
36267
36268
# File 'lib/google/apis/compute_v1/classes.rb', line 36266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36234
36235
36236
# File 'lib/google/apis/compute_v1/classes.rb', line 36234

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetPool>

A list of TargetPool resources. Corresponds to the JSON property items



36239
36240
36241
# File 'lib/google/apis/compute_v1/classes.rb', line 36239

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#targetPoolList for lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


36245
36246
36247
# File 'lib/google/apis/compute_v1/classes.rb', line 36245

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36254
36255
36256
# File 'lib/google/apis/compute_v1/classes.rb', line 36254

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36259
36260
36261
# File 'lib/google/apis/compute_v1/classes.rb', line 36259

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetPoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36264
36265
36266
# File 'lib/google/apis/compute_v1/classes.rb', line 36264

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36271
36272
36273
36274
36275
36276
36277
36278
# File 'lib/google/apis/compute_v1/classes.rb', line 36271

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end