Class: Google::Apis::ComputeV1::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetPoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetPool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::TargetPoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolList
Returns a new instance of TargetPoolList.
36266 36267 36268 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36234 36235 36236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36234 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
36239 36240 36241 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36239 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetPoolList for lists of
target pools.
Corresponds to the JSON property kind
36245 36246 36247 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36245 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36254 36255 36256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36254 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36259 36260 36261 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36259 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetPoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36264 36265 36266 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36264 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36271 36272 36273 36274 36275 36276 36277 36278 |
# File 'lib/google/apis/compute_v1/classes.rb', line 36271 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |