Class: Google::Apis::ComputeV1::TargetSslProxy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetSslProxy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Target SSL Proxy resource. A target SSL proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target SSL proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.
Instance Attribute Summary collapse
-
#certificate_map ⇒ String
URL of a certificate map that identifies a certificate map associated with the given target proxy.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#service ⇒ String
URL to the BackendService resource.
-
#ssl_certificates ⇒ Array<String>
URLs to SslCertificate resources that are used to authenticate connections to Backends.
-
#ssl_policy ⇒ String
URL of SslPolicy resource that will be associated with the TargetSslProxy resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetSslProxy
constructor
A new instance of TargetSslProxy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetSslProxy
Returns a new instance of TargetSslProxy.
65077 65078 65079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_map ⇒ String
URL of a certificate map that identifies a certificate map associated with
the given target proxy.
This field can only be set for global target proxies.
If set, sslCertificates will be ignored.
Accepted format is//certificatemanager.googleapis.com/projects/project/
locations/location/certificateMaps/resourceName.
Corresponds to the JSON property certificateMap
65007 65008 65009 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65007 def certificate_map @certificate_map end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
65013 65014 65015 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65013 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
65019 65020 65021 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65019 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
65025 65026 65027 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65025 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#targetSslProxy
for target SSL proxies.
Corresponds to the JSON property kind
65031 65032 65033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65031 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
65042 65043 65044 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65042 def name @name end |
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the
backend, either NONE or PROXY_V1. The default
is NONE.
Corresponds to the JSON property proxyHeader
65049 65050 65051 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65049 def proxy_header @proxy_header end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
65054 65055 65056 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65054 def self_link @self_link end |
#service ⇒ String
URL to the BackendService resource.
Corresponds to the JSON property service
65059 65060 65061 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65059 def service @service end |
#ssl_certificates ⇒ Array<String>
URLs to SslCertificate resources that are used to
authenticate connections to Backends. At least one SSL certificate
must be specified. Currently, you may specify up to 15 SSL certificates.
sslCertificates do not apply when the load balancing scheme is set to
INTERNAL_SELF_MANAGED.
Corresponds to the JSON property sslCertificates
65068 65069 65070 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65068 def ssl_certificates @ssl_certificates end |
#ssl_policy ⇒ String
URL of SslPolicy resource that will be associated with the TargetSslProxy
resource. If not set, the TargetSslProxy resource will not have any
SSL policy configured.
Corresponds to the JSON property sslPolicy
65075 65076 65077 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65075 def ssl_policy @ssl_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65082 65083 65084 65085 65086 65087 65088 65089 65090 65091 65092 65093 65094 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65082 def update!(**args) @certificate_map = args[:certificate_map] if args.key?(:certificate_map) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) @self_link = args[:self_link] if args.key?(:self_link) @service = args[:service] if args.key?(:service) @ssl_certificates = args[:ssl_certificates] if args.key?(:ssl_certificates) @ssl_policy = args[:ssl_policy] if args.key?(:ssl_policy) end |