Class: Google::Apis::ComputeV1::TargetSslProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Target SSL Proxy resource. A target SSL proxy is a component of a SSL Proxy load balancer. Global forwarding rules reference a target SSL proxy, and the target proxy then references an external backend service. For more information, read Using Target Proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxy

Returns a new instance of TargetSslProxy.



36669
36670
36671
# File 'lib/google/apis/compute_v1/classes.rb', line 36669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


36608
36609
36610
# File 'lib/google/apis/compute_v1/classes.rb', line 36608

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


36614
36615
36616
# File 'lib/google/apis/compute_v1/classes.rb', line 36614

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


36620
36621
36622
# File 'lib/google/apis/compute_v1/classes.rb', line 36620

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#targetSslProxy for target SSL proxies. Corresponds to the JSON property kind

Returns:

  • (String)


36626
36627
36628
# File 'lib/google/apis/compute_v1/classes.rb', line 36626

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


36636
36637
36638
# File 'lib/google/apis/compute_v1/classes.rb', line 36636

def name
  @name
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


36642
36643
36644
# File 'lib/google/apis/compute_v1/classes.rb', line 36642

def proxy_header
  @proxy_header
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36647
36648
36649
# File 'lib/google/apis/compute_v1/classes.rb', line 36647

def self_link
  @self_link
end

#serviceString

URL to the BackendService resource. Corresponds to the JSON property service

Returns:

  • (String)


36652
36653
36654
# File 'lib/google/apis/compute_v1/classes.rb', line 36652

def service
  @service
end

#ssl_certificatesArray<String>

URLs to SslCertificate resources that are used to authenticate connections to Backends. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates. sslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED. Corresponds to the JSON property sslCertificates

Returns:

  • (Array<String>)


36660
36661
36662
# File 'lib/google/apis/compute_v1/classes.rb', line 36660

def ssl_certificates
  @ssl_certificates
end

#ssl_policyString

URL of SslPolicy resource that will be associated with the TargetSslProxy resource. If not set, the TargetSslProxy resource will not have any SSL policy configured. Corresponds to the JSON property sslPolicy

Returns:

  • (String)


36667
36668
36669
# File 'lib/google/apis/compute_v1/classes.rb', line 36667

def ssl_policy
  @ssl_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36674
36675
36676
36677
36678
36679
36680
36681
36682
36683
36684
36685
# File 'lib/google/apis/compute_v1/classes.rb', line 36674

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service = args[:service] if args.key?(:service)
  @ssl_certificates = args[:ssl_certificates] if args.key?(:ssl_certificates)
  @ssl_policy = args[:ssl_policy] if args.key?(:ssl_policy)
end