Class: Google::Apis::ComputeV1::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



65148
65149
65150
# File 'lib/google/apis/compute_v1/classes.rb', line 65148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65116
65117
65118
# File 'lib/google/apis/compute_v1/classes.rb', line 65116

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



65121
65122
65123
# File 'lib/google/apis/compute_v1/classes.rb', line 65121

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


65126
65127
65128
# File 'lib/google/apis/compute_v1/classes.rb', line 65126

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65136
65137
65138
# File 'lib/google/apis/compute_v1/classes.rb', line 65136

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65141
65142
65143
# File 'lib/google/apis/compute_v1/classes.rb', line 65141

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65146
65147
65148
# File 'lib/google/apis/compute_v1/classes.rb', line 65146

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65153
65154
65155
65156
65157
65158
65159
65160
# File 'lib/google/apis/compute_v1/classes.rb', line 65153

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end