Class: Google::Apis::ComputeV1::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



64418
64419
64420
# File 'lib/google/apis/compute_v1/classes.rb', line 64418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64386
64387
64388
# File 'lib/google/apis/compute_v1/classes.rb', line 64386

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



64391
64392
64393
# File 'lib/google/apis/compute_v1/classes.rb', line 64391

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


64396
64397
64398
# File 'lib/google/apis/compute_v1/classes.rb', line 64396

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64406
64407
64408
# File 'lib/google/apis/compute_v1/classes.rb', line 64406

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64411
64412
64413
# File 'lib/google/apis/compute_v1/classes.rb', line 64411

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64416
64417
64418
# File 'lib/google/apis/compute_v1/classes.rb', line 64416

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64423
64424
64425
64426
64427
64428
64429
64430
# File 'lib/google/apis/compute_v1/classes.rb', line 64423

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end