Class: Google::Apis::ComputeV1::TargetSslProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetSslProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetSslProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetSslProxy>
A list of TargetSslProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetSslProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetSslProxyList
constructor
A new instance of TargetSslProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetSslProxyList
Returns a new instance of TargetSslProxyList.
64404 64405 64406 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64404 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64372 64373 64374 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64372 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetSslProxy>
A list of TargetSslProxy resources.
Corresponds to the JSON property items
64377 64378 64379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64377 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
64382 64383 64384 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64382 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64392 64393 64394 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64392 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64397 64398 64399 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64397 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetSslProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64402 64403 64404 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64402 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64409 64410 64411 64412 64413 64414 64415 64416 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64409 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |