Class: Google::Apis::ComputeV1::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



62895
62896
62897
# File 'lib/google/apis/compute_v1/classes.rb', line 62895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62863
62864
62865
# File 'lib/google/apis/compute_v1/classes.rb', line 62863

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



62868
62869
62870
# File 'lib/google/apis/compute_v1/classes.rb', line 62868

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


62873
62874
62875
# File 'lib/google/apis/compute_v1/classes.rb', line 62873

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62883
62884
62885
# File 'lib/google/apis/compute_v1/classes.rb', line 62883

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62888
62889
62890
# File 'lib/google/apis/compute_v1/classes.rb', line 62888

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62893
62894
62895
# File 'lib/google/apis/compute_v1/classes.rb', line 62893

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62900
62901
62902
62903
62904
62905
62906
62907
# File 'lib/google/apis/compute_v1/classes.rb', line 62900

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end