Class: Google::Apis::ComputeV1::TargetSslProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetSslProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetSslProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetSslProxy>
A list of TargetSslProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetSslProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetSslProxyList
constructor
A new instance of TargetSslProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetSslProxyList
Returns a new instance of TargetSslProxyList.
58076 58077 58078 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58044 58045 58046 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58044 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetSslProxy>
A list of TargetSslProxy resources.
Corresponds to the JSON property items
58049 58050 58051 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58049 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
58054 58055 58056 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58054 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58064 58065 58066 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58064 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58069 58070 58071 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58069 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetSslProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58074 58075 58076 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58074 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58081 58082 58083 58084 58085 58086 58087 58088 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58081 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |