Class: Google::Apis::ComputeV1::TargetTcpProxy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetTcpProxy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Target TCP Proxy resource. A target TCP proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target TCP proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#load_balancing_scheme ⇒ String
Specifies the type of load balancing scheme used by this target proxy.
-
#name ⇒ String
Name of the resource.
-
#proxy_bind ⇒ Boolean
(also: #proxy_bind?)
This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
-
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#service ⇒ String
URL to the BackendService resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxy
constructor
A new instance of TargetTcpProxy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxy
Returns a new instance of TargetTcpProxy.
65455 65456 65457 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
65381 65382 65383 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65381 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
65387 65388 65389 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65387 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
65393 65394 65395 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65393 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#targetTcpProxy
for target TCP proxies.
Corresponds to the JSON property kind
65399 65400 65401 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65399 def kind @kind end |
#load_balancing_scheme ⇒ String
Specifies the type of load balancing scheme used by this target proxy.
Corresponds to the JSON property loadBalancingScheme
65404 65405 65406 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65404 def load_balancing_scheme @load_balancing_scheme end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
65415 65416 65417 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65415 def name @name end |
#proxy_bind ⇒ Boolean Also known as: proxy_bind?
This field only applies when the forwarding rule that references this
target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
When this field is set to true, Envoy proxies set up inbound
traffic interception and bind to the IP address and port specified in the
forwarding rule. This is generally useful when using Traffic Director to
configure Envoy as a gateway or middle proxy (in other words, not a
sidecar proxy). The Envoy proxy listens for inbound requests and handles
requests when it receives them.
The default is false.
Corresponds to the JSON property proxyBind
65428 65429 65430 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65428 def proxy_bind @proxy_bind end |
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the
backend, either NONE or PROXY_V1. The default
is NONE.
Corresponds to the JSON property proxyHeader
65436 65437 65438 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65436 def proxy_header @proxy_header end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional TCP proxy
resides.
This field is not applicable to global TCP proxy.
Corresponds to the JSON property region
65443 65444 65445 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65443 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
65448 65449 65450 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65448 def self_link @self_link end |
#service ⇒ String
URL to the BackendService resource.
Corresponds to the JSON property service
65453 65454 65455 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65453 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65460 65461 65462 65463 65464 65465 65466 65467 65468 65469 65470 65471 65472 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65460 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme) @name = args[:name] if args.key?(:name) @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @service = args[:service] if args.key?(:service) end |