Class: Google::Apis::ComputeV1::TargetTcpProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Target TCP Proxy resource. A target TCP proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target TCP proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxy

Returns a new instance of TargetTcpProxy.



59581
59582
59583
# File 'lib/google/apis/compute_v1/classes.rb', line 59581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


59512
59513
59514
# File 'lib/google/apis/compute_v1/classes.rb', line 59512

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


59518
59519
59520
# File 'lib/google/apis/compute_v1/classes.rb', line 59518

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


59524
59525
59526
# File 'lib/google/apis/compute_v1/classes.rb', line 59524

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetTcpProxy for target TCP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


59530
59531
59532
# File 'lib/google/apis/compute_v1/classes.rb', line 59530

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


59541
59542
59543
# File 'lib/google/apis/compute_v1/classes.rb', line 59541

def name
  @name
end

#proxy_bindBoolean Also known as: proxy_bind?

This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false. Corresponds to the JSON property proxyBind

Returns:

  • (Boolean)


59554
59555
59556
# File 'lib/google/apis/compute_v1/classes.rb', line 59554

def proxy_bind
  @proxy_bind
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


59562
59563
59564
# File 'lib/google/apis/compute_v1/classes.rb', line 59562

def proxy_header
  @proxy_header
end

#regionString

Output only. [Output Only] URL of the region where the regional TCP proxy resides. This field is not applicable to global TCP proxy. Corresponds to the JSON property region

Returns:

  • (String)


59569
59570
59571
# File 'lib/google/apis/compute_v1/classes.rb', line 59569

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59574
59575
59576
# File 'lib/google/apis/compute_v1/classes.rb', line 59574

def self_link
  @self_link
end

#serviceString

URL to the BackendService resource. Corresponds to the JSON property service

Returns:

  • (String)


59579
59580
59581
# File 'lib/google/apis/compute_v1/classes.rb', line 59579

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
# File 'lib/google/apis/compute_v1/classes.rb', line 59586

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service = args[:service] if args.key?(:service)
end