Class: Google::Apis::ComputeV1::TargetTcpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetTcpProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
constructor
A new instance of TargetTcpProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
Returns a new instance of TargetTcpProxyAggregatedList.
66352 66353 66354 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66352 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66313 66314 66315 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66313 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
Corresponds to the JSON property items
66318 66319 66320 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66318 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetTcpProxyAggregatedList for lists of Target
TCP Proxies.
Corresponds to the JSON property kind
66325 66326 66327 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66325 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66335 66336 66337 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66335 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66340 66341 66342 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66340 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
66345 66346 66347 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66345 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66350 66351 66352 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66350 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66357 66358 66359 66360 66361 66362 66363 66364 66365 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66357 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |