Class: Google::Apis::ComputeV1::TargetTcpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyAggregatedList

Returns a new instance of TargetTcpProxyAggregatedList.



65123
65124
65125
# File 'lib/google/apis/compute_v1/classes.rb', line 65123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65084
65085
65086
# File 'lib/google/apis/compute_v1/classes.rb', line 65084

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetTcpProxiesScopedList>

A list of TargetTcpProxiesScopedList resources. Corresponds to the JSON property items



65089
65090
65091
# File 'lib/google/apis/compute_v1/classes.rb', line 65089

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetTcpProxyAggregatedList for lists of Target TCP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


65096
65097
65098
# File 'lib/google/apis/compute_v1/classes.rb', line 65096

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65106
65107
65108
# File 'lib/google/apis/compute_v1/classes.rb', line 65106

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65111
65112
65113
# File 'lib/google/apis/compute_v1/classes.rb', line 65111

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65116
65117
65118
# File 'lib/google/apis/compute_v1/classes.rb', line 65116

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetTcpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65121
65122
65123
# File 'lib/google/apis/compute_v1/classes.rb', line 65121

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65128
65129
65130
65131
65132
65133
65134
65135
65136
# File 'lib/google/apis/compute_v1/classes.rb', line 65128

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end