Class: Google::Apis::ComputeV1::TargetTcpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetTcpProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
constructor
A new instance of TargetTcpProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
Returns a new instance of TargetTcpProxyAggregatedList.
64785 64786 64787 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64746 64747 64748 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64746 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
Corresponds to the JSON property items
64751 64752 64753 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64751 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetTcpProxyAggregatedList for lists of Target
TCP Proxies.
Corresponds to the JSON property kind
64758 64759 64760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64758 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64768 64769 64770 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64768 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64773 64774 64775 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64773 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64778 64779 64780 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64778 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64783 64784 64785 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64783 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64790 64791 64792 64793 64794 64795 64796 64797 64798 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64790 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |