Class: Google::Apis::ComputeV1::TargetTcpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyAggregatedList

Returns a new instance of TargetTcpProxyAggregatedList.



63262
63263
63264
# File 'lib/google/apis/compute_v1/classes.rb', line 63262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63223
63224
63225
# File 'lib/google/apis/compute_v1/classes.rb', line 63223

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetTcpProxiesScopedList>

A list of TargetTcpProxiesScopedList resources. Corresponds to the JSON property items



63228
63229
63230
# File 'lib/google/apis/compute_v1/classes.rb', line 63228

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetTcpProxyAggregatedList for lists of Target TCP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


63235
63236
63237
# File 'lib/google/apis/compute_v1/classes.rb', line 63235

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63245
63246
63247
# File 'lib/google/apis/compute_v1/classes.rb', line 63245

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63250
63251
63252
# File 'lib/google/apis/compute_v1/classes.rb', line 63250

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63255
63256
63257
# File 'lib/google/apis/compute_v1/classes.rb', line 63255

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetTcpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63260
63261
63262
# File 'lib/google/apis/compute_v1/classes.rb', line 63260

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63267
63268
63269
63270
63271
63272
63273
63274
63275
# File 'lib/google/apis/compute_v1/classes.rb', line 63267

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end