Class: Google::Apis::ComputeV1::TargetTcpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetTcpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetTcpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetTcpProxy>
A list of TargetTcpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyList
constructor
A new instance of TargetTcpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyList
Returns a new instance of TargetTcpProxyList.
66477 66478 66479 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66445 66446 66447 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66445 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetTcpProxy>
A list of TargetTcpProxy resources.
Corresponds to the JSON property items
66450 66451 66452 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66450 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
66455 66456 66457 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66455 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66465 66466 66467 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66465 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66470 66471 66472 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66470 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66475 66476 66477 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66475 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66482 66483 66484 66485 66486 66487 66488 66489 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66482 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |