Class: Google::Apis::ComputeV1::TargetTcpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetTcpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetTcpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetTcpProxy>
A list of TargetTcpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyList
constructor
A new instance of TargetTcpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyList
Returns a new instance of TargetTcpProxyList.
65248 65249 65250 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65248 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
65216 65217 65218 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65216 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetTcpProxy>
A list of TargetTcpProxy resources.
Corresponds to the JSON property items
65221 65222 65223 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65221 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
65226 65227 65228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65226 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65236 65237 65238 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65236 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65241 65242 65243 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65241 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65246 65247 65248 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65246 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65253 65254 65255 65256 65257 65258 65259 65260 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65253 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |