Class: Google::Apis::ComputeV1::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



64910
64911
64912
# File 'lib/google/apis/compute_v1/classes.rb', line 64910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64878
64879
64880
# File 'lib/google/apis/compute_v1/classes.rb', line 64878

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



64883
64884
64885
# File 'lib/google/apis/compute_v1/classes.rb', line 64883

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


64888
64889
64890
# File 'lib/google/apis/compute_v1/classes.rb', line 64888

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64898
64899
64900
# File 'lib/google/apis/compute_v1/classes.rb', line 64898

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64903
64904
64905
# File 'lib/google/apis/compute_v1/classes.rb', line 64903

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64908
64909
64910
# File 'lib/google/apis/compute_v1/classes.rb', line 64908

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64915
64916
64917
64918
64919
64920
64921
64922
# File 'lib/google/apis/compute_v1/classes.rb', line 64915

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end