Class: Google::Apis::ComputeV1::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



64896
64897
64898
# File 'lib/google/apis/compute_v1/classes.rb', line 64896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64864
64865
64866
# File 'lib/google/apis/compute_v1/classes.rb', line 64864

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



64869
64870
64871
# File 'lib/google/apis/compute_v1/classes.rb', line 64869

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


64874
64875
64876
# File 'lib/google/apis/compute_v1/classes.rb', line 64874

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64884
64885
64886
# File 'lib/google/apis/compute_v1/classes.rb', line 64884

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64889
64890
64891
# File 'lib/google/apis/compute_v1/classes.rb', line 64889

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64894
64895
64896
# File 'lib/google/apis/compute_v1/classes.rb', line 64894

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64901
64902
64903
64904
64905
64906
64907
64908
# File 'lib/google/apis/compute_v1/classes.rb', line 64901

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end