Class: Google::Apis::ComputeV1::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



63387
63388
63389
# File 'lib/google/apis/compute_v1/classes.rb', line 63387

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63355
63356
63357
# File 'lib/google/apis/compute_v1/classes.rb', line 63355

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



63360
63361
63362
# File 'lib/google/apis/compute_v1/classes.rb', line 63360

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


63365
63366
63367
# File 'lib/google/apis/compute_v1/classes.rb', line 63365

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63375
63376
63377
# File 'lib/google/apis/compute_v1/classes.rb', line 63375

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63380
63381
63382
# File 'lib/google/apis/compute_v1/classes.rb', line 63380

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63385
63386
63387
# File 'lib/google/apis/compute_v1/classes.rb', line 63385

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63392
63393
63394
63395
63396
63397
63398
63399
# File 'lib/google/apis/compute_v1/classes.rb', line 63392

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end