Class: Google::Apis::ComputeV1::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



59771
59772
59773
# File 'lib/google/apis/compute_v1/classes.rb', line 59771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59739
59740
59741
# File 'lib/google/apis/compute_v1/classes.rb', line 59739

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



59744
59745
59746
# File 'lib/google/apis/compute_v1/classes.rb', line 59744

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


59749
59750
59751
# File 'lib/google/apis/compute_v1/classes.rb', line 59749

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59759
59760
59761
# File 'lib/google/apis/compute_v1/classes.rb', line 59759

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59764
59765
59766
# File 'lib/google/apis/compute_v1/classes.rb', line 59764

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59769
59770
59771
# File 'lib/google/apis/compute_v1/classes.rb', line 59769

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59776
59777
59778
59779
59780
59781
59782
59783
# File 'lib/google/apis/compute_v1/classes.rb', line 59776

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end