Class: Google::Apis::ComputeV1::TargetVpnGateway

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Target VPN Gateway resource. The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read thethe Cloud VPN Overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGateway

Returns a new instance of TargetVpnGateway.



65441
65442
65443
# File 'lib/google/apis/compute_v1/classes.rb', line 65441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


65344
65345
65346
# File 'lib/google/apis/compute_v1/classes.rb', line 65344

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


65350
65351
65352
# File 'lib/google/apis/compute_v1/classes.rb', line 65350

def description
  @description
end

#forwarding_rulesArray<String>

[Output Only] A list of URLs to the ForwardingRule resources. ForwardingRules are created usingcompute.forwardingRules.insert and associated with a VPN gateway. Corresponds to the JSON property forwardingRules

Returns:

  • (Array<String>)


65358
65359
65360
# File 'lib/google/apis/compute_v1/classes.rb', line 65358

def forwarding_rules
  @forwarding_rules
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


65364
65365
65366
# File 'lib/google/apis/compute_v1/classes.rb', line 65364

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


65370
65371
65372
# File 'lib/google/apis/compute_v1/classes.rb', line 65370

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this TargetVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a TargetVpnGateway. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


65383
65384
65385
# File 'lib/google/apis/compute_v1/classes.rb', line 65383

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


65390
65391
65392
# File 'lib/google/apis/compute_v1/classes.rb', line 65390

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


65401
65402
65403
# File 'lib/google/apis/compute_v1/classes.rb', line 65401

def name
  @name
end

#networkString

URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created. Corresponds to the JSON property network

Returns:

  • (String)


65407
65408
65409
# File 'lib/google/apis/compute_v1/classes.rb', line 65407

def network
  @network
end

#paramsGoogle::Apis::ComputeV1::TargetVpnGatewayParams

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload. Corresponds to the JSON property params



65414
65415
65416
# File 'lib/google/apis/compute_v1/classes.rb', line 65414

def params
  @params
end

#regionString

[Output Only] URL of the region where the target VPN gateway resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


65421
65422
65423
# File 'lib/google/apis/compute_v1/classes.rb', line 65421

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65426
65427
65428
# File 'lib/google/apis/compute_v1/classes.rb', line 65426

def self_link
  @self_link
end

#statusString

[Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING. Corresponds to the JSON property status

Returns:

  • (String)


65432
65433
65434
# File 'lib/google/apis/compute_v1/classes.rb', line 65432

def status
  @status
end

#tunnelsArray<String>

[Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are created using the compute.vpntunnels.insert method and associated with a VPN gateway. Corresponds to the JSON property tunnels

Returns:

  • (Array<String>)


65439
65440
65441
# File 'lib/google/apis/compute_v1/classes.rb', line 65439

def tunnels
  @tunnels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65446
65447
65448
65449
65450
65451
65452
65453
65454
65455
65456
65457
65458
65459
65460
65461
# File 'lib/google/apis/compute_v1/classes.rb', line 65446

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @tunnels = args[:tunnels] if args.key?(:tunnels)
end