Class: Google::Apis::ComputeV1::TargetVpnGateway

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Target VPN Gateway resource. The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read thethe Cloud VPN Overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGateway

Returns a new instance of TargetVpnGateway.



65089
65090
65091
# File 'lib/google/apis/compute_v1/classes.rb', line 65089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


64992
64993
64994
# File 'lib/google/apis/compute_v1/classes.rb', line 64992

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


64998
64999
65000
# File 'lib/google/apis/compute_v1/classes.rb', line 64998

def description
  @description
end

#forwarding_rulesArray<String>

[Output Only] A list of URLs to the ForwardingRule resources. ForwardingRules are created usingcompute.forwardingRules.insert and associated with a VPN gateway. Corresponds to the JSON property forwardingRules

Returns:

  • (Array<String>)


65006
65007
65008
# File 'lib/google/apis/compute_v1/classes.rb', line 65006

def forwarding_rules
  @forwarding_rules
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


65012
65013
65014
# File 'lib/google/apis/compute_v1/classes.rb', line 65012

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


65018
65019
65020
# File 'lib/google/apis/compute_v1/classes.rb', line 65018

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this TargetVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a TargetVpnGateway. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


65031
65032
65033
# File 'lib/google/apis/compute_v1/classes.rb', line 65031

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


65038
65039
65040
# File 'lib/google/apis/compute_v1/classes.rb', line 65038

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


65049
65050
65051
# File 'lib/google/apis/compute_v1/classes.rb', line 65049

def name
  @name
end

#networkString

URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created. Corresponds to the JSON property network

Returns:

  • (String)


65055
65056
65057
# File 'lib/google/apis/compute_v1/classes.rb', line 65055

def network
  @network
end

#paramsGoogle::Apis::ComputeV1::TargetVpnGatewayParams

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload. Corresponds to the JSON property params



65062
65063
65064
# File 'lib/google/apis/compute_v1/classes.rb', line 65062

def params
  @params
end

#regionString

[Output Only] URL of the region where the target VPN gateway resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


65069
65070
65071
# File 'lib/google/apis/compute_v1/classes.rb', line 65069

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65074
65075
65076
# File 'lib/google/apis/compute_v1/classes.rb', line 65074

def self_link
  @self_link
end

#statusString

[Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING. Corresponds to the JSON property status

Returns:

  • (String)


65080
65081
65082
# File 'lib/google/apis/compute_v1/classes.rb', line 65080

def status
  @status
end

#tunnelsArray<String>

[Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are created using the compute.vpntunnels.insert method and associated with a VPN gateway. Corresponds to the JSON property tunnels

Returns:

  • (Array<String>)


65087
65088
65089
# File 'lib/google/apis/compute_v1/classes.rb', line 65087

def tunnels
  @tunnels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65094
65095
65096
65097
65098
65099
65100
65101
65102
65103
65104
65105
65106
65107
65108
65109
# File 'lib/google/apis/compute_v1/classes.rb', line 65094

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @tunnels = args[:tunnels] if args.key?(:tunnels)
end