Class: Google::Apis::ComputeV1::TargetVpnGateway
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetVpnGateway
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Target VPN Gateway resource. The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read thethe Cloud VPN Overview.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#forwarding_rules ⇒ Array<String>
[Output Only] A list of URLs to the ForwardingRule resources.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this TargetVpnGateway, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
URL of the network to which this VPN gateway is attached.
-
#params ⇒ Google::Apis::ComputeV1::TargetVpnGatewayParams
Input only.
-
#region ⇒ String
[Output Only] URL of the region where the target VPN gateway resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING.
-
#tunnels ⇒ Array<String>
[Output Only] A list of URLs to VpnTunnel resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGateway
constructor
A new instance of TargetVpnGateway.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGateway
Returns a new instance of TargetVpnGateway.
59964 59965 59966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
59867 59868 59869 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59867 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
59873 59874 59875 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59873 def description @description end |
#forwarding_rules ⇒ Array<String>
[Output Only] A list of URLs to the ForwardingRule resources.
ForwardingRules are created usingcompute.forwardingRules.insert and associated
with a VPN
gateway.
Corresponds to the JSON property forwardingRules
59881 59882 59883 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59881 def forwarding_rules @forwarding_rules end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
59887 59888 59889 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59887 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
59893 59894 59895 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59893 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this TargetVpnGateway, which
is essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a TargetVpnGateway.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
59906 59907 59908 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59906 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
59913 59914 59915 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59913 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
59924 59925 59926 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59924 def name @name end |
#network ⇒ String
URL of the network to which this VPN gateway is attached. Provided by the
client when the VPN gateway is created.
Corresponds to the JSON property network
59930 59931 59932 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59930 def network @network end |
#params ⇒ Google::Apis::ComputeV1::TargetVpnGatewayParams
Input only. [Input Only] Additional params passed with the request, but not
persisted
as part of resource payload.
Corresponds to the JSON property params
59937 59938 59939 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59937 def params @params end |
#region ⇒ String
[Output Only] URL of the region where the target VPN gateway resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
59944 59945 59946 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59944 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
59949 59950 59951 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59949 def self_link @self_link end |
#status ⇒ String
[Output Only] The status of the VPN gateway,
which can be one of the following: CREATING, READY, FAILED, or DELETING.
Corresponds to the JSON property status
59955 59956 59957 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59955 def status @status end |
#tunnels ⇒ Array<String>
[Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are
created using the compute.vpntunnels.insert method and
associated with a VPN gateway.
Corresponds to the JSON property tunnels
59962 59963 59964 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59962 def tunnels @tunnels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59969 59970 59971 59972 59973 59974 59975 59976 59977 59978 59979 59980 59981 59982 59983 59984 |
# File 'lib/google/apis/compute_v1/classes.rb', line 59969 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @tunnels = args[:tunnels] if args.key?(:tunnels) end |