Class: Google::Apis::ComputeV1::TargetVpnGateway
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetVpnGateway
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Target VPN Gateway resource. The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read thethe Cloud VPN Overview.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#forwarding_rules ⇒ Array<String>
[Output Only] A list of URLs to the ForwardingRule resources.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this TargetVpnGateway, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
URL of the network to which this VPN gateway is attached.
-
#region ⇒ String
[Output Only] URL of the region where the target VPN gateway resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING.
-
#tunnels ⇒ Array<String>
[Output Only] A list of URLs to VpnTunnel resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGateway
constructor
A new instance of TargetVpnGateway.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGateway
Returns a new instance of TargetVpnGateway.
58754 58755 58756 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58754 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
58664 58665 58666 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58664 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
58670 58671 58672 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58670 def description @description end |
#forwarding_rules ⇒ Array<String>
[Output Only] A list of URLs to the ForwardingRule resources.
ForwardingRules are created usingcompute.forwardingRules.insert and associated
with a VPN
gateway.
Corresponds to the JSON property forwardingRules
58678 58679 58680 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58678 def forwarding_rules @forwarding_rules end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
58684 58685 58686 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58684 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
58690 58691 58692 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58690 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this TargetVpnGateway, which
is essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a TargetVpnGateway.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
58703 58704 58705 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58703 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
58710 58711 58712 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58710 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
58721 58722 58723 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58721 def name @name end |
#network ⇒ String
URL of the network to which this VPN gateway is attached. Provided by the
client when the VPN gateway is created.
Corresponds to the JSON property network
58727 58728 58729 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58727 def network @network end |
#region ⇒ String
[Output Only] URL of the region where the target VPN gateway resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
58734 58735 58736 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58734 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
58739 58740 58741 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58739 def self_link @self_link end |
#status ⇒ String
[Output Only] The status of the VPN gateway,
which can be one of the following: CREATING, READY, FAILED, or DELETING.
Corresponds to the JSON property status
58745 58746 58747 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58745 def status @status end |
#tunnels ⇒ Array<String>
[Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are
created using the compute.vpntunnels.insert method and
associated with a VPN gateway.
Corresponds to the JSON property tunnels
58752 58753 58754 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58752 def tunnels @tunnels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58759 58760 58761 58762 58763 58764 58765 58766 58767 58768 58769 58770 58771 58772 58773 |
# File 'lib/google/apis/compute_v1/classes.rb', line 58759 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @tunnels = args[:tunnels] if args.key?(:tunnels) end |