Class: Google::Apis::ComputeV1::TargetVpnGateway
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetVpnGateway
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Target VPN Gateway resource. The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read the the Cloud VPN Overview.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#forwarding_rules ⇒ Array<String>
[Output Only] A list of URLs to the ForwardingRule resources.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
URL of the network to which this VPN gateway is attached.
-
#region ⇒ String
[Output Only] URL of the region where the target VPN gateway resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING.
-
#tunnels ⇒ Array<String>
[Output Only] A list of URLs to VpnTunnel resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGateway
constructor
A new instance of TargetVpnGateway.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGateway
Returns a new instance of TargetVpnGateway.
37124 37125 37126 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
37057 37058 37059 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37057 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
37063 37064 37065 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37063 def description @description end |
#forwarding_rules ⇒ Array<String>
[Output Only] A list of URLs to the ForwardingRule resources. ForwardingRules
are created using compute.forwardingRules.insert and associated with a VPN
gateway.
Corresponds to the JSON property forwardingRules
37070 37071 37072 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37070 def forwarding_rules @forwarding_rules end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
37076 37077 37078 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37076 def id @id end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetVpnGateway for target VPN
gateways.
Corresponds to the JSON property kind
37082 37083 37084 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37082 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
37092 37093 37094 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37092 def name @name end |
#network ⇒ String
URL of the network to which this VPN gateway is attached. Provided by the
client when the VPN gateway is created.
Corresponds to the JSON property network
37098 37099 37100 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37098 def network @network end |
#region ⇒ String
[Output Only] URL of the region where the target VPN gateway resides. You must
specify this field as part of the HTTP request URL. It is not settable as a
field in the request body.
Corresponds to the JSON property region
37105 37106 37107 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37105 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
37110 37111 37112 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37110 def self_link @self_link end |
#status ⇒ String
[Output Only] The status of the VPN gateway, which can be one of the following:
CREATING, READY, FAILED, or DELETING.
Corresponds to the JSON property status
37116 37117 37118 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37116 def status @status end |
#tunnels ⇒ Array<String>
[Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are created
using the compute.vpntunnels.insert method and associated with a VPN gateway.
Corresponds to the JSON property tunnels
37122 37123 37124 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37122 def tunnels @tunnels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37129 37130 37131 37132 37133 37134 37135 37136 37137 37138 37139 37140 37141 |
# File 'lib/google/apis/compute_v1/classes.rb', line 37129 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @tunnels = args[:tunnels] if args.key?(:tunnels) end |