Class: Google::Apis::ComputeV1::TargetVpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetVpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetVpnGatewaysScopedList>
A list of TargetVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetVpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayAggregatedList
constructor
A new instance of TargetVpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayAggregatedList
Returns a new instance of TargetVpnGatewayAggregatedList.
65509 65510 65511 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
65471 65472 65473 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65471 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetVpnGatewaysScopedList>
A list of TargetVpnGateway resources.
Corresponds to the JSON property items
65476 65477 65478 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65476 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
65482 65483 65484 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65482 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65492 65493 65494 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65492 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65497 65498 65499 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65497 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
65502 65503 65504 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65502 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::TargetVpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65507 65508 65509 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65507 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65514 65515 65516 65517 65518 65519 65520 65521 65522 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65514 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |