Class: Google::Apis::ComputeV1::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



65171
65172
65173
# File 'lib/google/apis/compute_v1/classes.rb', line 65171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65133
65134
65135
# File 'lib/google/apis/compute_v1/classes.rb', line 65133

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



65138
65139
65140
# File 'lib/google/apis/compute_v1/classes.rb', line 65138

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


65144
65145
65146
# File 'lib/google/apis/compute_v1/classes.rb', line 65144

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65154
65155
65156
# File 'lib/google/apis/compute_v1/classes.rb', line 65154

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65159
65160
65161
# File 'lib/google/apis/compute_v1/classes.rb', line 65159

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65164
65165
65166
# File 'lib/google/apis/compute_v1/classes.rb', line 65164

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65169
65170
65171
# File 'lib/google/apis/compute_v1/classes.rb', line 65169

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65176
65177
65178
65179
65180
65181
65182
65183
65184
# File 'lib/google/apis/compute_v1/classes.rb', line 65176

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end