Class: Google::Apis::ComputeV1::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



63648
63649
63650
# File 'lib/google/apis/compute_v1/classes.rb', line 63648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63610
63611
63612
# File 'lib/google/apis/compute_v1/classes.rb', line 63610

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



63615
63616
63617
# File 'lib/google/apis/compute_v1/classes.rb', line 63615

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


63621
63622
63623
# File 'lib/google/apis/compute_v1/classes.rb', line 63621

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63631
63632
63633
# File 'lib/google/apis/compute_v1/classes.rb', line 63631

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63636
63637
63638
# File 'lib/google/apis/compute_v1/classes.rb', line 63636

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63641
63642
63643
# File 'lib/google/apis/compute_v1/classes.rb', line 63641

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63646
63647
63648
# File 'lib/google/apis/compute_v1/classes.rb', line 63646

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63653
63654
63655
63656
63657
63658
63659
63660
63661
# File 'lib/google/apis/compute_v1/classes.rb', line 63653

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end