Class: Google::Apis::ComputeV1::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



58821
58822
58823
# File 'lib/google/apis/compute_v1/classes.rb', line 58821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58783
58784
58785
# File 'lib/google/apis/compute_v1/classes.rb', line 58783

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



58788
58789
58790
# File 'lib/google/apis/compute_v1/classes.rb', line 58788

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


58794
58795
58796
# File 'lib/google/apis/compute_v1/classes.rb', line 58794

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58804
58805
58806
# File 'lib/google/apis/compute_v1/classes.rb', line 58804

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58809
58810
58811
# File 'lib/google/apis/compute_v1/classes.rb', line 58809

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58814
58815
58816
# File 'lib/google/apis/compute_v1/classes.rb', line 58814

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58819
58820
58821
# File 'lib/google/apis/compute_v1/classes.rb', line 58819

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58826
58827
58828
58829
58830
58831
58832
58833
58834
# File 'lib/google/apis/compute_v1/classes.rb', line 58826

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end