Class: Google::Apis::ComputeV1::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



37188
37189
37190
# File 'lib/google/apis/compute_v1/classes.rb', line 37188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37151
37152
37153
# File 'lib/google/apis/compute_v1/classes.rb', line 37151

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



37156
37157
37158
# File 'lib/google/apis/compute_v1/classes.rb', line 37156

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


37162
37163
37164
# File 'lib/google/apis/compute_v1/classes.rb', line 37162

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37171
37172
37173
# File 'lib/google/apis/compute_v1/classes.rb', line 37171

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37176
37177
37178
# File 'lib/google/apis/compute_v1/classes.rb', line 37176

def self_link
  @self_link
end

#unreachablesArray<String>

[Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


37181
37182
37183
# File 'lib/google/apis/compute_v1/classes.rb', line 37181

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37186
37187
37188
# File 'lib/google/apis/compute_v1/classes.rb', line 37186

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37193
37194
37195
37196
37197
37198
37199
37200
37201
# File 'lib/google/apis/compute_v1/classes.rb', line 37193

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end