Class: Google::Apis::ComputeV1::TargetVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetVpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayList

Returns a new instance of TargetVpnGatewayList.



66864
66865
66866
# File 'lib/google/apis/compute_v1/classes.rb', line 66864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66831
66832
66833
# File 'lib/google/apis/compute_v1/classes.rb', line 66831

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetVpnGateway>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



66836
66837
66838
# File 'lib/google/apis/compute_v1/classes.rb', line 66836

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


66842
66843
66844
# File 'lib/google/apis/compute_v1/classes.rb', line 66842

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66852
66853
66854
# File 'lib/google/apis/compute_v1/classes.rb', line 66852

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66857
66858
66859
# File 'lib/google/apis/compute_v1/classes.rb', line 66857

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66862
66863
66864
# File 'lib/google/apis/compute_v1/classes.rb', line 66862

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66869
66870
66871
66872
66873
66874
66875
66876
# File 'lib/google/apis/compute_v1/classes.rb', line 66869

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end