Class: Google::Apis::ComputeV1::TargetVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetVpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetVpnGateway>
A list of TargetVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayList
constructor
A new instance of TargetVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayList
Returns a new instance of TargetVpnGatewayList.
66021 66022 66023 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
65988 65989 65990 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65988 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetVpnGateway>
A list of TargetVpnGateway resources.
Corresponds to the JSON property items
65993 65994 65995 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65993 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
65999 66000 66001 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65999 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66009 66010 66011 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66009 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66014 66015 66016 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66014 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66019 66020 66021 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66019 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66026 66027 66028 66029 66030 66031 66032 66033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66026 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |