Class: Google::Apis::ComputeV1::TargetVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetVpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayList

Returns a new instance of TargetVpnGatewayList.



65297
65298
65299
# File 'lib/google/apis/compute_v1/classes.rb', line 65297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65264
65265
65266
# File 'lib/google/apis/compute_v1/classes.rb', line 65264

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetVpnGateway>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



65269
65270
65271
# File 'lib/google/apis/compute_v1/classes.rb', line 65269

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


65275
65276
65277
# File 'lib/google/apis/compute_v1/classes.rb', line 65275

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65285
65286
65287
# File 'lib/google/apis/compute_v1/classes.rb', line 65285

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65290
65291
65292
# File 'lib/google/apis/compute_v1/classes.rb', line 65290

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65295
65296
65297
# File 'lib/google/apis/compute_v1/classes.rb', line 65295

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65302
65303
65304
65305
65306
65307
65308
65309
# File 'lib/google/apis/compute_v1/classes.rb', line 65302

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end