Class: Google::Apis::ComputeV1::TargetVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of TargetVpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayList

Returns a new instance of TargetVpnGatewayList.



65283
65284
65285
# File 'lib/google/apis/compute_v1/classes.rb', line 65283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65250
65251
65252
# File 'lib/google/apis/compute_v1/classes.rb', line 65250

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::TargetVpnGateway>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



65255
65256
65257
# File 'lib/google/apis/compute_v1/classes.rb', line 65255

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


65261
65262
65263
# File 'lib/google/apis/compute_v1/classes.rb', line 65261

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65271
65272
65273
# File 'lib/google/apis/compute_v1/classes.rb', line 65271

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65276
65277
65278
# File 'lib/google/apis/compute_v1/classes.rb', line 65276

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::TargetVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65281
65282
65283
# File 'lib/google/apis/compute_v1/classes.rb', line 65281

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65288
65289
65290
65291
65292
65293
65294
65295
# File 'lib/google/apis/compute_v1/classes.rb', line 65288

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end