Class: Google::Apis::ComputeV1::TcpHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpHealthCheck

Returns a new instance of TcpHealthCheck.



62471
62472
62473
# File 'lib/google/apis/compute_v1/classes.rb', line 62471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

The TCP port number to which the health check prober sends packets. The default value is 80. Valid values are 1 through65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


62414
62415
62416
# File 'lib/google/apis/compute_v1/classes.rb', line 62414

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


62419
62420
62421
# File 'lib/google/apis/compute_v1/classes.rb', line 62419

def port_name
  @port_name
end

#port_specificationString

Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Corresponds to the JSON property portSpecification

Returns:

  • (String)


62446
62447
62448
# File 'lib/google/apis/compute_v1/classes.rb', line 62446

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


62453
62454
62455
# File 'lib/google/apis/compute_v1/classes.rb', line 62453

def proxy_header
  @proxy_header
end

#requestString

Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection. Corresponds to the JSON property request

Returns:

  • (String)


62459
62460
62461
# File 'lib/google/apis/compute_v1/classes.rb', line 62459

def request
  @request
end

#responseString

Creates a content-based TCP health check. In addition to establishing a TCP connection, you can configure the health check to pass only when the backend sends this exact response ASCII string, up to 1024 bytes in length. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria- protocol-ssl-tcp Corresponds to the JSON property response

Returns:

  • (String)


62469
62470
62471
# File 'lib/google/apis/compute_v1/classes.rb', line 62469

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62476
62477
62478
62479
62480
62481
62482
62483
# File 'lib/google/apis/compute_v1/classes.rb', line 62476

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request = args[:request] if args.key?(:request)
  @response = args[:response] if args.key?(:response)
end