Class: Google::Apis::ComputeV1::TestFailure
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TestFailure
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyactualRedirectResponseCode. -
#actual_service ⇒ String
BackendService or BackendBucket returned by load balancer.
-
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyexpectedRedirectResponseCode. -
#expected_service ⇒ String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
-
#headers ⇒ Array<Google::Apis::ComputeV1::UrlMapTestHeader>
HTTP headers of the request.
-
#host ⇒ String
Host portion of the URL.
-
#path ⇒ String
Path portion including query parameters in the URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestFailure
constructor
A new instance of TestFailure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestFailure
Returns a new instance of TestFailure.
66302 66303 66304 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property actualOutputUrl
66255 66256 66257 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66255 def actual_output_url @actual_output_url end |
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property actualRedirectResponseCode
66261 66262 66263 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66261 def actual_redirect_response_code @actual_redirect_response_code end |
#actual_service ⇒ String
BackendService or BackendBucket returned by load
balancer.
Corresponds to the JSON property actualService
66267 66268 66269 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66267 def actual_service @actual_service end |
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property expectedOutputUrl
66273 66274 66275 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66273 def expected_output_url @expected_output_url end |
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property expectedRedirectResponseCode
66279 66280 66281 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66279 def expected_redirect_response_code @expected_redirect_response_code end |
#expected_service ⇒ String
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
Corresponds to the JSON property expectedService
66285 66286 66287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66285 def expected_service @expected_service end |
#headers ⇒ Array<Google::Apis::ComputeV1::UrlMapTestHeader>
HTTP headers of the request.
Corresponds to the JSON property headers
66290 66291 66292 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66290 def headers @headers end |
#host ⇒ String
Host portion of the URL.
Corresponds to the JSON property host
66295 66296 66297 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66295 def host @host end |
#path ⇒ String
Path portion including query parameters in the URL.
Corresponds to the JSON property path
66300 66301 66302 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66300 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66307 66308 66309 66310 66311 66312 66313 66314 66315 66316 66317 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66307 def update!(**args) @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url) @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code) @actual_service = args[:actual_service] if args.key?(:actual_service) @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url) @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code) @expected_service = args[:expected_service] if args.key?(:expected_service) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) end |