Class: Google::Apis::ComputeV1::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



66290
66291
66292
# File 'lib/google/apis/compute_v1/classes.rb', line 66290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


66243
66244
66245
# File 'lib/google/apis/compute_v1/classes.rb', line 66243

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


66249
66250
66251
# File 'lib/google/apis/compute_v1/classes.rb', line 66249

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


66255
66256
66257
# File 'lib/google/apis/compute_v1/classes.rb', line 66255

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


66261
66262
66263
# File 'lib/google/apis/compute_v1/classes.rb', line 66261

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


66267
66268
66269
# File 'lib/google/apis/compute_v1/classes.rb', line 66267

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


66273
66274
66275
# File 'lib/google/apis/compute_v1/classes.rb', line 66273

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeV1::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



66278
66279
66280
# File 'lib/google/apis/compute_v1/classes.rb', line 66278

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


66283
66284
66285
# File 'lib/google/apis/compute_v1/classes.rb', line 66283

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


66288
66289
66290
# File 'lib/google/apis/compute_v1/classes.rb', line 66288

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66295
66296
66297
66298
66299
66300
66301
66302
66303
66304
66305
# File 'lib/google/apis/compute_v1/classes.rb', line 66295

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end