Class: Google::Apis::ComputeV1::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



65904
65905
65906
# File 'lib/google/apis/compute_v1/classes.rb', line 65904

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


65857
65858
65859
# File 'lib/google/apis/compute_v1/classes.rb', line 65857

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


65863
65864
65865
# File 'lib/google/apis/compute_v1/classes.rb', line 65863

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


65869
65870
65871
# File 'lib/google/apis/compute_v1/classes.rb', line 65869

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


65875
65876
65877
# File 'lib/google/apis/compute_v1/classes.rb', line 65875

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


65881
65882
65883
# File 'lib/google/apis/compute_v1/classes.rb', line 65881

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


65887
65888
65889
# File 'lib/google/apis/compute_v1/classes.rb', line 65887

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeV1::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



65892
65893
65894
# File 'lib/google/apis/compute_v1/classes.rb', line 65892

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


65897
65898
65899
# File 'lib/google/apis/compute_v1/classes.rb', line 65897

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


65902
65903
65904
# File 'lib/google/apis/compute_v1/classes.rb', line 65902

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65909
65910
65911
65912
65913
65914
65915
65916
65917
65918
65919
# File 'lib/google/apis/compute_v1/classes.rb', line 65909

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end