Class: Google::Apis::ComputeV1::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



65566
65567
65568
# File 'lib/google/apis/compute_v1/classes.rb', line 65566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


65519
65520
65521
# File 'lib/google/apis/compute_v1/classes.rb', line 65519

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


65525
65526
65527
# File 'lib/google/apis/compute_v1/classes.rb', line 65525

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


65531
65532
65533
# File 'lib/google/apis/compute_v1/classes.rb', line 65531

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


65537
65538
65539
# File 'lib/google/apis/compute_v1/classes.rb', line 65537

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


65543
65544
65545
# File 'lib/google/apis/compute_v1/classes.rb', line 65543

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


65549
65550
65551
# File 'lib/google/apis/compute_v1/classes.rb', line 65549

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeV1::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



65554
65555
65556
# File 'lib/google/apis/compute_v1/classes.rb', line 65554

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


65559
65560
65561
# File 'lib/google/apis/compute_v1/classes.rb', line 65559

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


65564
65565
65566
# File 'lib/google/apis/compute_v1/classes.rb', line 65564

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65571
65572
65573
65574
65575
65576
65577
65578
65579
65580
65581
# File 'lib/google/apis/compute_v1/classes.rb', line 65571

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end