Class: Google::Apis::ComputeV1::TestFailure
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TestFailure
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyactualRedirectResponseCode. -
#actual_service ⇒ String
BackendService or BackendBucket returned by load balancer.
-
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyexpectedRedirectResponseCode. -
#expected_service ⇒ String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
-
#headers ⇒ Array<Google::Apis::ComputeV1::UrlMapTestHeader>
HTTP headers of the request.
-
#host ⇒ String
Host portion of the URL.
-
#path ⇒ String
Path portion including query parameters in the URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestFailure
constructor
A new instance of TestFailure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestFailure
Returns a new instance of TestFailure.
65552 65553 65554 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property actualOutputUrl
65505 65506 65507 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65505 def actual_output_url @actual_output_url end |
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property actualRedirectResponseCode
65511 65512 65513 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65511 def actual_redirect_response_code @actual_redirect_response_code end |
#actual_service ⇒ String
BackendService or BackendBucket returned by load
balancer.
Corresponds to the JSON property actualService
65517 65518 65519 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65517 def actual_service @actual_service end |
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property expectedOutputUrl
65523 65524 65525 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65523 def expected_output_url @expected_output_url end |
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property expectedRedirectResponseCode
65529 65530 65531 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65529 def expected_redirect_response_code @expected_redirect_response_code end |
#expected_service ⇒ String
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
Corresponds to the JSON property expectedService
65535 65536 65537 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65535 def expected_service @expected_service end |
#headers ⇒ Array<Google::Apis::ComputeV1::UrlMapTestHeader>
HTTP headers of the request.
Corresponds to the JSON property headers
65540 65541 65542 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65540 def headers @headers end |
#host ⇒ String
Host portion of the URL.
Corresponds to the JSON property host
65545 65546 65547 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65545 def host @host end |
#path ⇒ String
Path portion including query parameters in the URL.
Corresponds to the JSON property path
65550 65551 65552 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65550 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65557 65558 65559 65560 65561 65562 65563 65564 65565 65566 65567 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65557 def update!(**args) @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url) @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code) @actual_service = args[:actual_service] if args.key?(:actual_service) @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url) @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code) @expected_service = args[:expected_service] if args.key?(:expected_service) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) end |