Class: Google::Apis::ComputeV1::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



37531
37532
37533
# File 'lib/google/apis/compute_v1/classes.rb', line 37531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


37485
37486
37487
# File 'lib/google/apis/compute_v1/classes.rb', line 37485

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


37491
37492
37493
# File 'lib/google/apis/compute_v1/classes.rb', line 37491

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


37496
37497
37498
# File 'lib/google/apis/compute_v1/classes.rb', line 37496

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


37502
37503
37504
# File 'lib/google/apis/compute_v1/classes.rb', line 37502

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


37508
37509
37510
# File 'lib/google/apis/compute_v1/classes.rb', line 37508

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


37514
37515
37516
# File 'lib/google/apis/compute_v1/classes.rb', line 37514

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeV1::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



37519
37520
37521
# File 'lib/google/apis/compute_v1/classes.rb', line 37519

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


37524
37525
37526
# File 'lib/google/apis/compute_v1/classes.rb', line 37524

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


37529
37530
37531
# File 'lib/google/apis/compute_v1/classes.rb', line 37529

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37536
37537
37538
37539
37540
37541
37542
37543
37544
37545
37546
# File 'lib/google/apis/compute_v1/classes.rb', line 37536

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end