Class: Google::Apis::ComputeV1::UpcomingMaintenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Upcoming Maintenance notification information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpcomingMaintenance

Returns a new instance of UpcomingMaintenance.



65698
65699
65700
# File 'lib/google/apis/compute_v1/classes.rb', line 65698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_rescheduleBoolean Also known as: can_reschedule?

Indicates if the maintenance can be customer triggered. Corresponds to the JSON property canReschedule

Returns:

  • (Boolean)


65656
65657
65658
# File 'lib/google/apis/compute_v1/classes.rb', line 65656

def can_reschedule
  @can_reschedule
end

#latest_window_start_timeString

The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format. Corresponds to the JSON property latestWindowStartTime

Returns:

  • (String)


65663
65664
65665
# File 'lib/google/apis/compute_v1/classes.rb', line 65663

def latest_window_start_time
  @latest_window_start_time
end

#maintenance_on_shutdownBoolean Also known as: maintenance_on_shutdown?

Indicates whether the UpcomingMaintenance will be triggered on VM shutdown. Corresponds to the JSON property maintenanceOnShutdown

Returns:

  • (Boolean)


65668
65669
65670
# File 'lib/google/apis/compute_v1/classes.rb', line 65668

def maintenance_on_shutdown
  @maintenance_on_shutdown
end

#maintenance_reasonsArray<String>

The reasons for the maintenance. Only valid for vms. Corresponds to the JSON property maintenanceReasons

Returns:

  • (Array<String>)


65674
65675
65676
# File 'lib/google/apis/compute_v1/classes.rb', line 65674

def maintenance_reasons
  @maintenance_reasons
end

#maintenance_statusString

Corresponds to the JSON property maintenanceStatus

Returns:

  • (String)


65679
65680
65681
# File 'lib/google/apis/compute_v1/classes.rb', line 65679

def maintenance_status
  @maintenance_status
end

#typeString

Defines the type of maintenance. Corresponds to the JSON property type

Returns:

  • (String)


65684
65685
65686
# File 'lib/google/apis/compute_v1/classes.rb', line 65684

def type
  @type
end

#window_end_timeString

The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowEndTime

Returns:

  • (String)


65690
65691
65692
# File 'lib/google/apis/compute_v1/classes.rb', line 65690

def window_end_time
  @window_end_time
end

#window_start_timeString

The current start time of the maintenance window. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowStartTime

Returns:

  • (String)


65696
65697
65698
# File 'lib/google/apis/compute_v1/classes.rb', line 65696

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65703
65704
65705
65706
65707
65708
65709
65710
65711
65712
# File 'lib/google/apis/compute_v1/classes.rb', line 65703

def update!(**args)
  @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule)
  @latest_window_start_time = args[:latest_window_start_time] if args.key?(:latest_window_start_time)
  @maintenance_on_shutdown = args[:maintenance_on_shutdown] if args.key?(:maintenance_on_shutdown)
  @maintenance_reasons = args[:maintenance_reasons] if args.key?(:maintenance_reasons)
  @maintenance_status = args[:maintenance_status] if args.key?(:maintenance_status)
  @type = args[:type] if args.key?(:type)
  @window_end_time = args[:window_end_time] if args.key?(:window_end_time)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end