Class: Google::Apis::ComputeV1::UpcomingMaintenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Upcoming Maintenance notification information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpcomingMaintenance

Returns a new instance of UpcomingMaintenance.



60559
60560
60561
# File 'lib/google/apis/compute_v1/classes.rb', line 60559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_rescheduleBoolean Also known as: can_reschedule?

Indicates if the maintenance can be customer triggered. Corresponds to the JSON property canReschedule

Returns:

  • (Boolean)


60517
60518
60519
# File 'lib/google/apis/compute_v1/classes.rb', line 60517

def can_reschedule
  @can_reschedule
end

#latest_window_start_timeString

The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format. Corresponds to the JSON property latestWindowStartTime

Returns:

  • (String)


60524
60525
60526
# File 'lib/google/apis/compute_v1/classes.rb', line 60524

def latest_window_start_time
  @latest_window_start_time
end

#maintenance_on_shutdownBoolean Also known as: maintenance_on_shutdown?

Indicates whether the UpcomingMaintenance will be triggered on VM shutdown. Corresponds to the JSON property maintenanceOnShutdown

Returns:

  • (Boolean)


60529
60530
60531
# File 'lib/google/apis/compute_v1/classes.rb', line 60529

def maintenance_on_shutdown
  @maintenance_on_shutdown
end

#maintenance_reasonsArray<String>

The reasons for the maintenance. Only valid for vms. Corresponds to the JSON property maintenanceReasons

Returns:

  • (Array<String>)


60535
60536
60537
# File 'lib/google/apis/compute_v1/classes.rb', line 60535

def maintenance_reasons
  @maintenance_reasons
end

#maintenance_statusString

Corresponds to the JSON property maintenanceStatus

Returns:

  • (String)


60540
60541
60542
# File 'lib/google/apis/compute_v1/classes.rb', line 60540

def maintenance_status
  @maintenance_status
end

#typeString

Defines the type of maintenance. Corresponds to the JSON property type

Returns:

  • (String)


60545
60546
60547
# File 'lib/google/apis/compute_v1/classes.rb', line 60545

def type
  @type
end

#window_end_timeString

The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowEndTime

Returns:

  • (String)


60551
60552
60553
# File 'lib/google/apis/compute_v1/classes.rb', line 60551

def window_end_time
  @window_end_time
end

#window_start_timeString

The current start time of the maintenance window. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowStartTime

Returns:

  • (String)


60557
60558
60559
# File 'lib/google/apis/compute_v1/classes.rb', line 60557

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60564
60565
60566
60567
60568
60569
60570
60571
60572
60573
# File 'lib/google/apis/compute_v1/classes.rb', line 60564

def update!(**args)
  @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule)
  @latest_window_start_time = args[:latest_window_start_time] if args.key?(:latest_window_start_time)
  @maintenance_on_shutdown = args[:maintenance_on_shutdown] if args.key?(:maintenance_on_shutdown)
  @maintenance_reasons = args[:maintenance_reasons] if args.key?(:maintenance_reasons)
  @maintenance_status = args[:maintenance_status] if args.key?(:maintenance_status)
  @type = args[:type] if args.key?(:type)
  @window_end_time = args[:window_end_time] if args.key?(:window_end_time)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end