Class: Google::Apis::ComputeV1::UrlMap

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a URL Map resource. Compute Engine has two URL Map resources:

  • Global
  • Regional A URL map resource is a component of certain types of cloud load balancers and Traffic Director:
  • urlMaps are used by global external Application Load Balancers, classic Application Load Balancers, and cross-region internal Application Load Balancers.
  • regionUrlMaps are used by internal Application Load Balancers, regional external Application Load Balancers and regional internal Application Load Balancers. For a list of supported URL map features by the load balancer type, see the Load balancing features: Routing and traffic management table. For a list of supported URL map features for Traffic Director, see the Traffic Director features: Routing and traffic management table. This resource defines mappings from hostnames and URL paths to either a backend service or a backend bucket. To use the global urlMaps resource, the backend service must have a loadBalancingScheme of either EXTERNAL,EXTERNAL_MANAGED, or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the backend service must have aloadBalancingScheme of INTERNAL_MANAGED. For more information, read URL Map Concepts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMap

Returns a new instance of UrlMap.



65855
65856
65857
# File 'lib/google/apis/compute_v1/classes.rb', line 65855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


65733
65734
65735
# File 'lib/google/apis/compute_v1/classes.rb', line 65733

def creation_timestamp
  @creation_timestamp
end

#default_custom_error_response_policyGoogle::Apis::ComputeV1::CustomErrorResponsePolicy

Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error. Corresponds to the JSON property defaultCustomErrorResponsePolicy



65739
65740
65741
# File 'lib/google/apis/compute_v1/classes.rb', line 65739

def default_custom_error_response_policy
  @default_custom_error_response_policy
end

#default_route_actionGoogle::Apis::ComputeV1::HttpRouteAction

defaultRouteAction takes effect when none of the hostRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. URL maps for classic Application Load Balancers only support the urlRewrite action within defaultRouteAction. defaultRouteAction has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property defaultRouteAction



65754
65755
65756
# File 'lib/google/apis/compute_v1/classes.rb', line 65754

def default_route_action
  @default_route_action
end

#default_serviceString

The full or partial URL of the defaultService resource to which traffic is directed if none of the hostRules match. If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. defaultService has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property defaultService

Returns:

  • (String)


65768
65769
65770
# File 'lib/google/apis/compute_v1/classes.rb', line 65768

def default_service
  @default_service
end

#default_url_redirectGoogle::Apis::ComputeV1::HttpRedirectAction

Specifies settings for an HTTP redirect. Corresponds to the JSON property defaultUrlRedirect



65773
65774
65775
# File 'lib/google/apis/compute_v1/classes.rb', line 65773

def default_url_redirect
  @default_url_redirect
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


65779
65780
65781
# File 'lib/google/apis/compute_v1/classes.rb', line 65779

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field is ignored when inserting a UrlMap. An up-to-date fingerprint must be provided in order to update the UrlMap, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a UrlMap. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


65791
65792
65793
# File 'lib/google/apis/compute_v1/classes.rb', line 65791

def fingerprint
  @fingerprint
end

#header_actionGoogle::Apis::ComputeV1::HttpHeaderAction

The request and response header transformations that take effect before the request is passed along to the selected backendService. Corresponds to the JSON property headerAction



65797
65798
65799
# File 'lib/google/apis/compute_v1/classes.rb', line 65797

def header_action
  @header_action
end

#host_rulesArray<Google::Apis::ComputeV1::HostRule>

The list of host rules to use against the URL. Corresponds to the JSON property hostRules



65802
65803
65804
# File 'lib/google/apis/compute_v1/classes.rb', line 65802

def host_rules
  @host_rules
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


65808
65809
65810
# File 'lib/google/apis/compute_v1/classes.rb', line 65808

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#urlMaps for url maps. Corresponds to the JSON property kind

Returns:

  • (String)


65814
65815
65816
# File 'lib/google/apis/compute_v1/classes.rb', line 65814

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


65825
65826
65827
# File 'lib/google/apis/compute_v1/classes.rb', line 65825

def name
  @name
end

#path_matchersArray<Google::Apis::ComputeV1::PathMatcher>

The list of named PathMatchers to use against the URL. Corresponds to the JSON property pathMatchers



65830
65831
65832
# File 'lib/google/apis/compute_v1/classes.rb', line 65830

def path_matchers
  @path_matchers
end

#regionString

Output only. [Output Only] URL of the region where the regional URL map resides. This field is not applicable to global URL maps. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


65839
65840
65841
# File 'lib/google/apis/compute_v1/classes.rb', line 65839

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65844
65845
65846
# File 'lib/google/apis/compute_v1/classes.rb', line 65844

def self_link
  @self_link
end

#testsArray<Google::Apis::ComputeV1::UrlMapTest>

The list of expected URL mapping tests. Request to update theUrlMap succeeds only if all test cases pass. You can specify a maximum of 100 tests per UrlMap. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property tests



65853
65854
65855
# File 'lib/google/apis/compute_v1/classes.rb', line 65853

def tests
  @tests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65860
65861
65862
65863
65864
65865
65866
65867
65868
65869
65870
65871
65872
65873
65874
65875
65876
65877
# File 'lib/google/apis/compute_v1/classes.rb', line 65860

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_custom_error_response_policy = args[:default_custom_error_response_policy] if args.key?(:default_custom_error_response_policy)
  @default_route_action = args[:default_route_action] if args.key?(:default_route_action)
  @default_service = args[:default_service] if args.key?(:default_service)
  @default_url_redirect = args[:default_url_redirect] if args.key?(:default_url_redirect)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @header_action = args[:header_action] if args.key?(:header_action)
  @host_rules = args[:host_rules] if args.key?(:host_rules)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @path_matchers = args[:path_matchers] if args.key?(:path_matchers)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @tests = args[:tests] if args.key?(:tests)
end