Class: Google::Apis::ComputeV1::UrlMap
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UrlMap
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a URL Map resource. Compute Engine has two URL Map resources:
- Global
- Regional A URL map resource is a component of certain types of cloud load balancers and Traffic Director:
- urlMaps are used by global external Application Load Balancers, classic Application Load Balancers, and cross-region internal Application Load Balancers.
- regionUrlMaps are used by internal Application Load Balancers, regional external Application Load Balancers and regional internal Application Load Balancers. For a list of supported URL map features by the load balancer type, see the Load balancing features: Routing and traffic management table. For a list of supported URL map features for Traffic Director, see the Traffic Director features: Routing and traffic management table. This resource defines mappings from hostnames and URL paths to either a backend service or a backend bucket. To use the global urlMaps resource, the backend service must have a loadBalancingScheme of either EXTERNAL,EXTERNAL_MANAGED, or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the backend service must have aloadBalancingScheme of INTERNAL_MANAGED. For more information, read URL Map Concepts.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#default_custom_error_response_policy ⇒ Google::Apis::ComputeV1::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.
-
#default_route_action ⇒ Google::Apis::ComputeV1::HttpRouteAction
defaultRouteAction takes effect when none of the hostRules match.
-
#default_service ⇒ String
The full or partial URL of the defaultService resource to which traffic is directed if none of the hostRules match.
-
#default_url_redirect ⇒ Google::Apis::ComputeV1::HttpRedirectAction
Specifies settings for an HTTP redirect.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#header_action ⇒ Google::Apis::ComputeV1::HttpHeaderAction
The request and response header transformations that take effect before the request is passed along to the selected backendService.
-
#host_rules ⇒ Array<Google::Apis::ComputeV1::HostRule>
The list of host rules to use against the URL.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#path_matchers ⇒ Array<Google::Apis::ComputeV1::PathMatcher>
The list of named PathMatchers to use against the URL.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#tests ⇒ Array<Google::Apis::ComputeV1::UrlMapTest>
The list of expected URL mapping tests.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMap
constructor
A new instance of UrlMap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMap
Returns a new instance of UrlMap.
60730 60731 60732 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
60608 60609 60610 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60608 def @creation_timestamp end |
#default_custom_error_response_policy ⇒ Google::Apis::ComputeV1::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the
backend service or backend bucket responds with an error.
Corresponds to the JSON property defaultCustomErrorResponsePolicy
60614 60615 60616 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60614 def default_custom_error_response_policy @default_custom_error_response_policy end |
#default_route_action ⇒ Google::Apis::ComputeV1::HttpRouteAction
defaultRouteAction takes effect when none of the
hostRules match. The load balancer performs advanced routing
actions, such as URL rewrites and header transformations, before forwarding
the request to the selected backend.
Only one of defaultUrlRedirect, defaultService
or defaultRouteAction.weightedBackendService can be set.
URL maps for classic Application Load Balancers only support
the urlRewrite action within defaultRouteAction.
defaultRouteAction has no effect when the URL map is bound
to a target gRPC proxy that has the validateForProxyless field
set to true.
Corresponds to the JSON property defaultRouteAction
60629 60630 60631 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60629 def default_route_action @default_route_action end |
#default_service ⇒ String
The full or partial URL of the defaultService resource to
which traffic is directed if none of the hostRules match.
If defaultRouteAction is also specified, advanced
routing actions, such as URL rewrites, take effect before sending the
request to the backend.
Only one of defaultUrlRedirect, defaultService
or defaultRouteAction.weightedBackendService can be set.
defaultService has no effect when the URL map is bound
to a target gRPC proxy that has the validateForProxyless field
set to true.
Corresponds to the JSON property defaultService
60643 60644 60645 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60643 def default_service @default_service end |
#default_url_redirect ⇒ Google::Apis::ComputeV1::HttpRedirectAction
Specifies settings for an HTTP redirect.
Corresponds to the JSON property defaultUrlRedirect
60648 60649 60650 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60648 def default_url_redirect @default_url_redirect end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
60654 60655 60656 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60654 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field is ignored when
inserting a UrlMap. An up-to-date fingerprint must be provided
in order to update the UrlMap, otherwise the request will
fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a UrlMap.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
60666 60667 60668 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60666 def fingerprint @fingerprint end |
#header_action ⇒ Google::Apis::ComputeV1::HttpHeaderAction
The request and response header transformations that take effect before
the request is passed along to the selected backendService.
Corresponds to the JSON property headerAction
60672 60673 60674 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60672 def header_action @header_action end |
#host_rules ⇒ Array<Google::Apis::ComputeV1::HostRule>
The list of host rules to use against the URL.
Corresponds to the JSON property hostRules
60677 60678 60679 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60677 def host_rules @host_rules end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
60683 60684 60685 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60683 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#urlMaps for
url maps.
Corresponds to the JSON property kind
60689 60690 60691 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60689 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
60700 60701 60702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60700 def name @name end |
#path_matchers ⇒ Array<Google::Apis::ComputeV1::PathMatcher>
The list of named PathMatchers to use against the URL.
Corresponds to the JSON property pathMatchers
60705 60706 60707 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60705 def path_matchers @path_matchers end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional URL map
resides.
This field is not applicable to global URL maps.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
60714 60715 60716 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60714 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
60719 60720 60721 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60719 def self_link @self_link end |
#tests ⇒ Array<Google::Apis::ComputeV1::UrlMapTest>
The list of expected URL mapping tests. Request to update theUrlMap succeeds
only if all test cases pass. You can specify a
maximum of 100 tests per UrlMap.
Not supported when the URL map is bound to a target gRPC proxy that
has validateForProxyless field set to true.
Corresponds to the JSON property tests
60728 60729 60730 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60728 def tests @tests end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60735 60736 60737 60738 60739 60740 60741 60742 60743 60744 60745 60746 60747 60748 60749 60750 60751 60752 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60735 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_custom_error_response_policy = args[:default_custom_error_response_policy] if args.key?(:default_custom_error_response_policy) @default_route_action = args[:default_route_action] if args.key?(:default_route_action) @default_service = args[:default_service] if args.key?(:default_service) @default_url_redirect = args[:default_url_redirect] if args.key?(:default_url_redirect) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @header_action = args[:header_action] if args.key?(:header_action) @host_rules = args[:host_rules] if args.key?(:host_rules) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @path_matchers = args[:path_matchers] if args.key?(:path_matchers) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @tests = args[:tests] if args.key?(:tests) end |