Class: Google::Apis::ComputeV1::UrlMap

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a URL Map resource. Compute Engine has two URL Map resources: * Global * Regional A URL map resource is a component of certain types of cloud load balancers and Traffic Director: * urlMaps are used by external HTTP(S) load balancers and Traffic Director. * regionUrlMaps are used by internal HTTP(S) load balancers. For a list of supported URL map features by the load balancer type, see the Load balancing features: Routing and traffic management table. For a list of supported URL map features for Traffic Director, see the Traffic Director features: Routing and traffic management table. This resource defines mappings from hostnames and URL paths to either a backend service or a backend bucket. To use the global urlMaps resource, the backend service must have a loadBalancingScheme of either EXTERNAL or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the backend service must have a loadBalancingScheme of INTERNAL_MANAGED. For more information, read URL Map Concepts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMap

Returns a new instance of UrlMap.



37742
37743
37744
# File 'lib/google/apis/compute_v1/classes.rb', line 37742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


37634
37635
37636
# File 'lib/google/apis/compute_v1/classes.rb', line 37634

def creation_timestamp
  @creation_timestamp
end

#default_route_actionGoogle::Apis::ComputeV1::HttpRouteAction

defaultRouteAction takes effect when none of the hostRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. If defaultRouteAction specifies any weightedBackendServices, defaultService must not be set. Conversely if defaultService is set, defaultRouteAction cannot contain any weightedBackendServices. Only one of defaultRouteAction or defaultUrlRedirect must be set. UrlMaps for external HTTP(S) load balancers support only the urlRewrite action within defaultRouteAction. defaultRouteAction has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property defaultRouteAction



37648
37649
37650
# File 'lib/google/apis/compute_v1/classes.rb', line 37648

def default_route_action
  @default_route_action
end

#default_serviceString

The full or partial URL of the defaultService resource to which traffic is directed if none of the hostRules match. If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. However, if defaultService is specified, defaultRouteAction cannot contain any weightedBackendServices. Conversely, if routeAction specifies any weightedBackendServices, service must not be specified. Only one of defaultService, defaultUrlRedirect , or defaultRouteAction.weightedBackendService must be set. defaultService has no effect when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property defaultService

Returns:

  • (String)


37662
37663
37664
# File 'lib/google/apis/compute_v1/classes.rb', line 37662

def default_service
  @default_service
end

#default_url_redirectGoogle::Apis::ComputeV1::HttpRedirectAction

Specifies settings for an HTTP redirect. Corresponds to the JSON property defaultUrlRedirect



37667
37668
37669
# File 'lib/google/apis/compute_v1/classes.rb', line 37667

def default_url_redirect
  @default_url_redirect
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


37673
37674
37675
# File 'lib/google/apis/compute_v1/classes.rb', line 37673

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field is ignored when inserting a UrlMap. An up-to-date fingerprint must be provided in order to update the UrlMap, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a UrlMap. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


37683
37684
37685
# File 'lib/google/apis/compute_v1/classes.rb', line 37683

def fingerprint
  @fingerprint
end

#header_actionGoogle::Apis::ComputeV1::HttpHeaderAction

The request and response header transformations that take effect before the request is passed along to the selected backendService. Corresponds to the JSON property headerAction



37689
37690
37691
# File 'lib/google/apis/compute_v1/classes.rb', line 37689

def header_action
  @header_action
end

#host_rulesArray<Google::Apis::ComputeV1::HostRule>

The list of host rules to use against the URL. Corresponds to the JSON property hostRules



37694
37695
37696
# File 'lib/google/apis/compute_v1/classes.rb', line 37694

def host_rules
  @host_rules
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


37700
37701
37702
# File 'lib/google/apis/compute_v1/classes.rb', line 37700

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#urlMaps for url maps. Corresponds to the JSON property kind

Returns:

  • (String)


37705
37706
37707
# File 'lib/google/apis/compute_v1/classes.rb', line 37705

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a- z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


37715
37716
37717
# File 'lib/google/apis/compute_v1/classes.rb', line 37715

def name
  @name
end

#path_matchersArray<Google::Apis::ComputeV1::PathMatcher>

The list of named PathMatchers to use against the URL. Corresponds to the JSON property pathMatchers



37720
37721
37722
# File 'lib/google/apis/compute_v1/classes.rb', line 37720

def path_matchers
  @path_matchers
end

#regionString

[Output Only] URL of the region where the regional URL map resides. This field is not applicable to global URL maps. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


37727
37728
37729
# File 'lib/google/apis/compute_v1/classes.rb', line 37727

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37732
37733
37734
# File 'lib/google/apis/compute_v1/classes.rb', line 37732

def self_link
  @self_link
end

#testsArray<Google::Apis::ComputeV1::UrlMapTest>

The list of expected URL mapping tests. Request to update the UrlMap succeeds only if all test cases pass. You can specify a maximum of 100 tests per UrlMap. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property tests



37740
37741
37742
# File 'lib/google/apis/compute_v1/classes.rb', line 37740

def tests
  @tests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37747
37748
37749
37750
37751
37752
37753
37754
37755
37756
37757
37758
37759
37760
37761
37762
37763
# File 'lib/google/apis/compute_v1/classes.rb', line 37747

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_route_action = args[:default_route_action] if args.key?(:default_route_action)
  @default_service = args[:default_service] if args.key?(:default_service)
  @default_url_redirect = args[:default_url_redirect] if args.key?(:default_url_redirect)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @header_action = args[:header_action] if args.key?(:header_action)
  @host_rules = args[:host_rules] if args.key?(:host_rules)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @path_matchers = args[:path_matchers] if args.key?(:path_matchers)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @tests = args[:tests] if args.key?(:tests)
end