Class: Google::Apis::ComputeV1::UrlMapList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of UrlMap resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapList

Returns a new instance of UrlMapList.



66695
66696
66697
# File 'lib/google/apis/compute_v1/classes.rb', line 66695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66663
66664
66665
# File 'lib/google/apis/compute_v1/classes.rb', line 66663

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::UrlMap>

A list of UrlMap resources. Corresponds to the JSON property items



66668
66669
66670
# File 'lib/google/apis/compute_v1/classes.rb', line 66668

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


66673
66674
66675
# File 'lib/google/apis/compute_v1/classes.rb', line 66673

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66683
66684
66685
# File 'lib/google/apis/compute_v1/classes.rb', line 66683

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66688
66689
66690
# File 'lib/google/apis/compute_v1/classes.rb', line 66688

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::UrlMapList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66693
66694
66695
# File 'lib/google/apis/compute_v1/classes.rb', line 66693

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66700
66701
66702
66703
66704
66705
66706
66707
# File 'lib/google/apis/compute_v1/classes.rb', line 66700

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end