Class: Google::Apis::ComputeV1::UrlMapList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UrlMapList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of UrlMap resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::UrlMap>
A list of UrlMap resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::UrlMapList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapList
constructor
A new instance of UrlMapList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapList
Returns a new instance of UrlMapList.
66297 66298 66299 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66265 66266 66267 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66265 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::UrlMap>
A list of UrlMap resources.
Corresponds to the JSON property items
66270 66271 66272 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66270 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
66275 66276 66277 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66275 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66285 66286 66287 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66285 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66290 66291 66292 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66290 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::UrlMapList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66295 66296 66297 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66295 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66302 66303 66304 66305 66306 66307 66308 66309 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66302 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |