Class: Google::Apis::ComputeV1::UrlMapList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of UrlMap resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapList

Returns a new instance of UrlMapList.



59551
59552
59553
# File 'lib/google/apis/compute_v1/classes.rb', line 59551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59519
59520
59521
# File 'lib/google/apis/compute_v1/classes.rb', line 59519

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::UrlMap>

A list of UrlMap resources. Corresponds to the JSON property items



59524
59525
59526
# File 'lib/google/apis/compute_v1/classes.rb', line 59524

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


59529
59530
59531
# File 'lib/google/apis/compute_v1/classes.rb', line 59529

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59539
59540
59541
# File 'lib/google/apis/compute_v1/classes.rb', line 59539

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59544
59545
59546
# File 'lib/google/apis/compute_v1/classes.rb', line 59544

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::UrlMapList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59549
59550
59551
# File 'lib/google/apis/compute_v1/classes.rb', line 59549

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59556
59557
59558
59559
59560
59561
59562
59563
# File 'lib/google/apis/compute_v1/classes.rb', line 59556

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end