Class: Google::Apis::ComputeV1::UrlMapList::Warning::Datum
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UrlMapList::Warning::Datum
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
[Output Only] A key that provides more detail on the warning being returned.
-
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Datum
constructor
A new instance of Datum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Datum
Returns a new instance of Datum.
60866 60867 60868 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
[Output Only] A key that provides more detail on the warning being
returned. For example, for warnings where there are no results in a list
request for a particular zone, this key might be scope and
the key value might be the zone name. Other examples might be a key
indicating a deprecated resource and a suggested replacement, or a
warning about invalid network settings (for example, if an instance
attempts to perform IP forwarding but is not enabled for IP forwarding).
Corresponds to the JSON property key
60859 60860 60861 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60859 def key @key end |
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Corresponds to the JSON property value
60864 60865 60866 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60864 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60871 60872 60873 60874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60871 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |