Class: Google::Apis::ComputeV1::UrlMapTest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UrlMapTest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Message for the expected URL mappings.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of this test case.
-
#expected_output_url ⇒ String
The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ Fixnum
For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response.
-
#headers ⇒ Array<Google::Apis::ComputeV1::UrlMapTestHeader>
HTTP headers for this request.
-
#host ⇒ String
Host portion of the URL.
-
#path ⇒ String
Path portion of the URL.
-
#service ⇒ String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapTest
constructor
A new instance of UrlMapTest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapTest
Returns a new instance of UrlMapTest.
66849 66850 66851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Description of this test case.
Corresponds to the JSON property description
66794 66795 66796 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66794 def description @description end |
#expected_output_url ⇒ String
The expected output URL evaluated by the load balancer
containing the scheme, host, path and query parameters.
For rules that forward requests to backends, the test passes only
whenexpectedOutputUrl matches the request forwarded by
the load balancer to backends. For rules with urlRewrite,
the test verifies that the forwarded request matcheshostRewrite and
pathPrefixRewrite in theurlRewrite action. When service is specified,
expectedOutputUrls scheme is ignored.
For rules with urlRedirect, the test passes only ifexpectedOutputUrl matches
the URL in the load balancer's
redirect response. If urlRedirect specifieshttps_redirect, the test passes
only if the scheme inexpectedOutputUrl is also set to HTTPS.
If urlRedirect specifies strip_query, the test
passes only if expectedOutputUrl does not contain any query
parameters.
expectedOutputUrl is optional whenservice is specified.
Corresponds to the JSON propertyexpectedOutputUrl`
66814 66815 66816 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66814 def expected_output_url @expected_output_url end |
#expected_redirect_response_code ⇒ Fixnum
For rules with urlRedirect, the test passes only
ifexpectedRedirectResponseCode matches the HTTP status code in
load balancer's redirect response.
expectedRedirectResponseCode cannot be set whenservice is set.
Corresponds to the JSON property expectedRedirectResponseCode
66822 66823 66824 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66822 def expected_redirect_response_code @expected_redirect_response_code end |
#headers ⇒ Array<Google::Apis::ComputeV1::UrlMapTestHeader>
HTTP headers for this request. If headers contains
a host header, then host must also match the header value.
Corresponds to the JSON property headers
66828 66829 66830 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66828 def headers @headers end |
#host ⇒ String
Host portion of the URL. If headers contains a host header,
then host must also match the header value.
Corresponds to the JSON property host
66834 66835 66836 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66834 def host @host end |
#path ⇒ String
Path portion of the URL.
Corresponds to the JSON property path
66839 66840 66841 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66839 def path @path end |
#service ⇒ String
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
The service field cannot
be set if expectedRedirectResponseCode is set.
Corresponds to the JSON property service
66847 66848 66849 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66847 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66854 66855 66856 66857 66858 66859 66860 66861 66862 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66854 def update!(**args) @description = args[:description] if args.key?(:description) @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url) @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) @service = args[:service] if args.key?(:service) end |