Class: Google::Apis::ComputeV1::UrlMapTest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Message for the expected URL mappings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapTest

Returns a new instance of UrlMapTest.



66085
66086
66087
# File 'lib/google/apis/compute_v1/classes.rb', line 66085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of this test case. Corresponds to the JSON property description

Returns:

  • (String)


66030
66031
66032
# File 'lib/google/apis/compute_v1/classes.rb', line 66030

def description
  @description
end

#expected_output_urlString

The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters. For rules that forward requests to backends, the test passes only whenexpectedOutputUrl matches the request forwarded by the load balancer to backends. For rules with urlRewrite, the test verifies that the forwarded request matcheshostRewrite and pathPrefixRewrite in theurlRewrite action. When service is specified, expectedOutputUrls scheme is ignored. For rules with urlRedirect, the test passes only ifexpectedOutputUrl matches the URL in the load balancer's redirect response. If urlRedirect specifieshttps_redirect, the test passes only if the scheme inexpectedOutputUrl is also set to HTTPS. If urlRedirect specifies strip_query, the test passes only if expectedOutputUrl does not contain any query parameters. expectedOutputUrl is optional whenservice is specified. Corresponds to the JSON propertyexpectedOutputUrl`

Returns:

  • (String)


66050
66051
66052
# File 'lib/google/apis/compute_v1/classes.rb', line 66050

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response. expectedRedirectResponseCode cannot be set whenservice is set. Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


66058
66059
66060
# File 'lib/google/apis/compute_v1/classes.rb', line 66058

def expected_redirect_response_code
  @expected_redirect_response_code
end

#headersArray<Google::Apis::ComputeV1::UrlMapTestHeader>

HTTP headers for this request. If headers contains a host header, then host must also match the header value. Corresponds to the JSON property headers



66064
66065
66066
# File 'lib/google/apis/compute_v1/classes.rb', line 66064

def headers
  @headers
end

#hostString

Host portion of the URL. If headers contains a host header, then host must also match the header value. Corresponds to the JSON property host

Returns:

  • (String)


66070
66071
66072
# File 'lib/google/apis/compute_v1/classes.rb', line 66070

def host
  @host
end

#pathString

Path portion of the URL. Corresponds to the JSON property path

Returns:

  • (String)


66075
66076
66077
# File 'lib/google/apis/compute_v1/classes.rb', line 66075

def path
  @path
end

#serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. The service field cannot be set if expectedRedirectResponseCode is set. Corresponds to the JSON property service

Returns:

  • (String)


66083
66084
66085
# File 'lib/google/apis/compute_v1/classes.rb', line 66083

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66090
66091
66092
66093
66094
66095
66096
66097
66098
# File 'lib/google/apis/compute_v1/classes.rb', line 66090

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
  @service = args[:service] if args.key?(:service)
end