Class: Google::Apis::ComputeV1::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
67868 67869 67870 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
67831 67832 67833 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67831 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
67836 67837 67838 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67836 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
67841 67842 67843 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67841 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67851 67852 67853 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67851 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67856 67857 67858 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67856 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67861 67862 67863 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67861 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67866 67867 67868 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67866 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67873 67874 67875 67876 67877 67878 67879 67880 67881 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67873 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |