Class: Google::Apis::ComputeV1::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



66987
66988
66989
# File 'lib/google/apis/compute_v1/classes.rb', line 66987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66950
66951
66952
# File 'lib/google/apis/compute_v1/classes.rb', line 66950

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



66955
66956
66957
# File 'lib/google/apis/compute_v1/classes.rb', line 66955

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


66960
66961
66962
# File 'lib/google/apis/compute_v1/classes.rb', line 66960

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66970
66971
66972
# File 'lib/google/apis/compute_v1/classes.rb', line 66970

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66975
66976
66977
# File 'lib/google/apis/compute_v1/classes.rb', line 66975

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66980
66981
66982
# File 'lib/google/apis/compute_v1/classes.rb', line 66980

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66985
66986
66987
# File 'lib/google/apis/compute_v1/classes.rb', line 66985

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66992
66993
66994
66995
66996
66997
66998
66999
67000
# File 'lib/google/apis/compute_v1/classes.rb', line 66992

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end