Class: Google::Apis::ComputeV1::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



66975
66976
66977
# File 'lib/google/apis/compute_v1/classes.rb', line 66975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66938
66939
66940
# File 'lib/google/apis/compute_v1/classes.rb', line 66938

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



66943
66944
66945
# File 'lib/google/apis/compute_v1/classes.rb', line 66943

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


66948
66949
66950
# File 'lib/google/apis/compute_v1/classes.rb', line 66948

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66958
66959
66960
# File 'lib/google/apis/compute_v1/classes.rb', line 66958

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66963
66964
66965
# File 'lib/google/apis/compute_v1/classes.rb', line 66963

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66968
66969
66970
# File 'lib/google/apis/compute_v1/classes.rb', line 66968

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66973
66974
66975
# File 'lib/google/apis/compute_v1/classes.rb', line 66973

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66980
66981
66982
66983
66984
66985
66986
66987
66988
# File 'lib/google/apis/compute_v1/classes.rb', line 66980

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end