Class: Google::Apis::ComputeV1::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



66589
66590
66591
# File 'lib/google/apis/compute_v1/classes.rb', line 66589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66552
66553
66554
# File 'lib/google/apis/compute_v1/classes.rb', line 66552

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



66557
66558
66559
# File 'lib/google/apis/compute_v1/classes.rb', line 66557

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


66562
66563
66564
# File 'lib/google/apis/compute_v1/classes.rb', line 66562

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66572
66573
66574
# File 'lib/google/apis/compute_v1/classes.rb', line 66572

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66577
66578
66579
# File 'lib/google/apis/compute_v1/classes.rb', line 66577

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66582
66583
66584
# File 'lib/google/apis/compute_v1/classes.rb', line 66582

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66587
66588
66589
# File 'lib/google/apis/compute_v1/classes.rb', line 66587

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66594
66595
66596
66597
66598
66599
66600
66601
66602
# File 'lib/google/apis/compute_v1/classes.rb', line 66594

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end