Class: Google::Apis::ComputeV1::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



66225
66226
66227
# File 'lib/google/apis/compute_v1/classes.rb', line 66225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66188
66189
66190
# File 'lib/google/apis/compute_v1/classes.rb', line 66188

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



66193
66194
66195
# File 'lib/google/apis/compute_v1/classes.rb', line 66193

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


66198
66199
66200
# File 'lib/google/apis/compute_v1/classes.rb', line 66198

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66208
66209
66210
# File 'lib/google/apis/compute_v1/classes.rb', line 66208

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66213
66214
66215
# File 'lib/google/apis/compute_v1/classes.rb', line 66213

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66218
66219
66220
# File 'lib/google/apis/compute_v1/classes.rb', line 66218

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66223
66224
66225
# File 'lib/google/apis/compute_v1/classes.rb', line 66223

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66230
66231
66232
66233
66234
66235
66236
66237
66238
# File 'lib/google/apis/compute_v1/classes.rb', line 66230

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end