Class: Google::Apis::ComputeV1::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



66211
66212
66213
# File 'lib/google/apis/compute_v1/classes.rb', line 66211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66174
66175
66176
# File 'lib/google/apis/compute_v1/classes.rb', line 66174

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



66179
66180
66181
# File 'lib/google/apis/compute_v1/classes.rb', line 66179

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


66184
66185
66186
# File 'lib/google/apis/compute_v1/classes.rb', line 66184

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66194
66195
66196
# File 'lib/google/apis/compute_v1/classes.rb', line 66194

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66199
66200
66201
# File 'lib/google/apis/compute_v1/classes.rb', line 66199

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66204
66205
66206
# File 'lib/google/apis/compute_v1/classes.rb', line 66204

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66209
66210
66211
# File 'lib/google/apis/compute_v1/classes.rb', line 66209

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66216
66217
66218
66219
66220
66221
66222
66223
66224
# File 'lib/google/apis/compute_v1/classes.rb', line 66216

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end