Class: Google::Apis::ComputeV1::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
64702 64703 64704 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64665 64666 64667 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64665 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
64670 64671 64672 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64670 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
64675 64676 64677 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64675 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64685 64686 64687 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64685 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64690 64691 64692 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64690 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64695 64696 64697 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64695 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64700 64701 64702 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64700 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64707 64708 64709 64710 64711 64712 64713 64714 64715 |
# File 'lib/google/apis/compute_v1/classes.rb', line 64707 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |