Class: Google::Apis::ComputeV1::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
61086 61087 61088 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61049 61050 61051 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61049 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
61054 61055 61056 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61054 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
61059 61060 61061 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61059 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61069 61070 61071 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61069 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
61074 61075 61076 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61074 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
61079 61080 61081 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61079 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61084 61085 61086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61084 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61091 61092 61093 61094 61095 61096 61097 61098 61099 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61091 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |