Class: Google::Apis::ComputeV1::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
38084 38085 38086 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38048 38049 38050 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38048 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
38053 38054 38055 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38053 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
38058 38059 38060 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38058 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38067 38068 38069 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38067 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38072 38073 38074 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38072 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
38077 38078 38079 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38077 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38082 38083 38084 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38082 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38089 38090 38091 38092 38093 38094 38095 38096 38097 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38089 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |