Class: Google::Apis::ComputeV1::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ Array<Google::Apis::ComputeV1::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
68364 68365 68366 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
68315 68316 68317 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68315 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
68320 68321 68322 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68320 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableSubnetworksAggregatedList for aggregated lists
of usable subnetworks.
Corresponds to the JSON property kind
68327 68328 68329 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68327 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which
still should be used to get the
next page of results.
Corresponds to the JSON property nextPageToken
68340 68341 68342 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68340 def next_page_token @next_page_token end |
#scoped_warnings ⇒ Array<Google::Apis::ComputeV1::SubnetworksScopedWarning>
Output only. [Output Only] Informational warning messages for failures
encountered from
scopes.
Corresponds to the JSON property scopedWarnings
68347 68348 68349 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68347 def scoped_warnings @scoped_warnings end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
68352 68353 68354 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68352 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
68357 68358 68359 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68357 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
68362 68363 68364 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68362 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68369 68370 68371 68372 68373 68374 68375 68376 68377 68378 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68369 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |