Class: Google::Apis::ComputeV1::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ Array<Google::Apis::ComputeV1::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
67483 67484 67485 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
67434 67435 67436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67434 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
67439 67440 67441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67439 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableSubnetworksAggregatedList for aggregated lists
of usable subnetworks.
Corresponds to the JSON property kind
67446 67447 67448 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67446 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which
still should be used to get the
next page of results.
Corresponds to the JSON property nextPageToken
67459 67460 67461 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67459 def next_page_token @next_page_token end |
#scoped_warnings ⇒ Array<Google::Apis::ComputeV1::SubnetworksScopedWarning>
Output only. [Output Only] Informational warning messages for failures
encountered from
scopes.
Corresponds to the JSON property scopedWarnings
67466 67467 67468 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67466 def scoped_warnings @scoped_warnings end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67471 67472 67473 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67471 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67476 67477 67478 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67476 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67481 67482 67483 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67481 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67488 67489 67490 67491 67492 67493 67494 67495 67496 67497 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67488 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |