Class: Google::Apis::ComputeV1::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ Array<Google::Apis::ComputeV1::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
67085 67086 67087 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
67036 67037 67038 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67036 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
67041 67042 67043 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67041 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableSubnetworksAggregatedList for aggregated lists
of usable subnetworks.
Corresponds to the JSON property kind
67048 67049 67050 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67048 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which
still should be used to get the
next page of results.
Corresponds to the JSON property nextPageToken
67061 67062 67063 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67061 def next_page_token @next_page_token end |
#scoped_warnings ⇒ Array<Google::Apis::ComputeV1::SubnetworksScopedWarning>
Output only. [Output Only] Informational warning messages for failures
encountered from
scopes.
Corresponds to the JSON property scopedWarnings
67068 67069 67070 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67068 def scoped_warnings @scoped_warnings end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67073 67074 67075 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67073 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67078 67079 67080 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67078 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67083 67084 67085 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67083 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67090 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |