Class: Google::Apis::ComputeV1::UsableSubnetworksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetworksAggregatedList

Returns a new instance of UsableSubnetworksAggregatedList.



66721
66722
66723
# File 'lib/google/apis/compute_v1/classes.rb', line 66721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66672
66673
66674
# File 'lib/google/apis/compute_v1/classes.rb', line 66672

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::UsableSubnetwork>

[Output] A list of usable subnetwork URLs. Corresponds to the JSON property items



66677
66678
66679
# File 'lib/google/apis/compute_v1/classes.rb', line 66677

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableSubnetworksAggregatedList for aggregated lists of usable subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


66684
66685
66686
# File 'lib/google/apis/compute_v1/classes.rb', line 66684

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66697
66698
66699
# File 'lib/google/apis/compute_v1/classes.rb', line 66697

def next_page_token
  @next_page_token
end

#scoped_warningsArray<Google::Apis::ComputeV1::SubnetworksScopedWarning>

Output only. [Output Only] Informational warning messages for failures encountered from scopes. Corresponds to the JSON property scopedWarnings



66704
66705
66706
# File 'lib/google/apis/compute_v1/classes.rb', line 66704

def scoped_warnings
  @scoped_warnings
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66709
66710
66711
# File 'lib/google/apis/compute_v1/classes.rb', line 66709

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66714
66715
66716
# File 'lib/google/apis/compute_v1/classes.rb', line 66714

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66719
66720
66721
# File 'lib/google/apis/compute_v1/classes.rb', line 66719

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66726
66727
66728
66729
66730
66731
66732
66733
66734
66735
# File 'lib/google/apis/compute_v1/classes.rb', line 66726

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end