Class: Google::Apis::ComputeV1::UsableSubnetworksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetworksAggregatedList

Returns a new instance of UsableSubnetworksAggregatedList.



60338
60339
60340
# File 'lib/google/apis/compute_v1/classes.rb', line 60338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60289
60290
60291
# File 'lib/google/apis/compute_v1/classes.rb', line 60289

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::UsableSubnetwork>

[Output] A list of usable subnetwork URLs. Corresponds to the JSON property items



60294
60295
60296
# File 'lib/google/apis/compute_v1/classes.rb', line 60294

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableSubnetworksAggregatedList for aggregated lists of usable subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


60301
60302
60303
# File 'lib/google/apis/compute_v1/classes.rb', line 60301

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60314
60315
60316
# File 'lib/google/apis/compute_v1/classes.rb', line 60314

def next_page_token
  @next_page_token
end

#scoped_warningsArray<Google::Apis::ComputeV1::SubnetworksScopedWarning>

Output only. [Output Only] Informational warning messages for failures encountered from scopes. Corresponds to the JSON property scopedWarnings



60321
60322
60323
# File 'lib/google/apis/compute_v1/classes.rb', line 60321

def scoped_warnings
  @scoped_warnings
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60326
60327
60328
# File 'lib/google/apis/compute_v1/classes.rb', line 60326

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


60331
60332
60333
# File 'lib/google/apis/compute_v1/classes.rb', line 60331

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



60336
60337
60338
# File 'lib/google/apis/compute_v1/classes.rb', line 60336

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60343
60344
60345
60346
60347
60348
60349
60350
60351
60352
# File 'lib/google/apis/compute_v1/classes.rb', line 60343

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end