Class: Google::Apis::ComputeV1::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
38459 38460 38461 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
38425 38426 38427 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38425 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
38430 38431 38432 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38430 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#usableSubnetworksAggregatedList
for aggregated lists of usable subnetworks.
Corresponds to the JSON property kind
38436 38437 38438 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38436 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results. In special cases listUsable may return 0
subnetworks and nextPageToken which still should be used to get the next page
of results.
Corresponds to the JSON property nextPageToken
38447 38448 38449 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38447 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38452 38453 38454 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38452 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38457 38458 38459 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38457 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38464 38465 38466 38467 38468 38469 38470 38471 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38464 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |