Class: Google::Apis::ComputeV1::UsageExportLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsageExportLocation

Returns a new instance of UsageExportLocation.



66819
66820
66821
# File 'lib/google/apis/compute_v1/classes.rb', line 66819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_nameString

The name of an existing bucket in Cloud Storage where the usage report object is stored. The Google Service Account is granted write access to this bucket. This can either be the bucket name by itself, such asexample- bucket, or the bucket name with gs:// or https://storage.googleapis.com/ in front of it, such as gs://example-bucket. Corresponds to the JSON property bucketName

Returns:

  • (String)


66807
66808
66809
# File 'lib/google/apis/compute_v1/classes.rb', line 66807

def bucket_name
  @bucket_name
end

#report_name_prefixString

An optional prefix for the name of the usage report object stored inbucketName. If not supplied, defaults tousage_gce. The report is stored as a CSV file namedreport_name_prefix_gce_YYYYMMDD.csv whereYYYYMMDD is the day of the usage according to Pacific Time. If you supply a prefix, it should conform to Cloud Storageobject naming conventions. Corresponds to the JSON property reportNamePrefix

Returns:

  • (String)


66817
66818
66819
# File 'lib/google/apis/compute_v1/classes.rb', line 66817

def report_name_prefix
  @report_name_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66824
66825
66826
66827
# File 'lib/google/apis/compute_v1/classes.rb', line 66824

def update!(**args)
  @bucket_name = args[:bucket_name] if args.key?(:bucket_name)
  @report_name_prefix = args[:report_name_prefix] if args.key?(:report_name_prefix)
end