Class: Google::Apis::ComputeV1::UsageExportLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsageExportLocation

Returns a new instance of UsageExportLocation.



61694
61695
61696
# File 'lib/google/apis/compute_v1/classes.rb', line 61694

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_nameString

The name of an existing bucket in Cloud Storage where the usage report object is stored. The Google Service Account is granted write access to this bucket. This can either be the bucket name by itself, such asexample- bucket, or the bucket name with gs:// or https://storage.googleapis.com/ in front of it, such as gs://example-bucket. Corresponds to the JSON property bucketName

Returns:

  • (String)


61682
61683
61684
# File 'lib/google/apis/compute_v1/classes.rb', line 61682

def bucket_name
  @bucket_name
end

#report_name_prefixString

An optional prefix for the name of the usage report object stored inbucketName. If not supplied, defaults tousage_gce. The report is stored as a CSV file namedreport_name_prefix_gce_YYYYMMDD.csv whereYYYYMMDD is the day of the usage according to Pacific Time. If you supply a prefix, it should conform to Cloud Storageobject naming conventions. Corresponds to the JSON property reportNamePrefix

Returns:

  • (String)


61692
61693
61694
# File 'lib/google/apis/compute_v1/classes.rb', line 61692

def report_name_prefix
  @report_name_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61699
61700
61701
61702
# File 'lib/google/apis/compute_v1/classes.rb', line 61699

def update!(**args)
  @bucket_name = args[:bucket_name] if args.key?(:bucket_name)
  @report_name_prefix = args[:report_name_prefix] if args.key?(:report_name_prefix)
end