Class: Google::Apis::ComputeV1::UsageExportLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::UsageExportLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The name of an existing bucket in Cloud Storage where the usage report object is stored.
-
#report_name_prefix ⇒ String
An optional prefix for the name of the usage report object stored inbucketName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsageExportLocation
constructor
A new instance of UsageExportLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsageExportLocation
Returns a new instance of UsageExportLocation.
60450 60451 60452 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_name ⇒ String
The name of an existing bucket in Cloud Storage where the usage report
object is stored. The Google Service Account is granted write access to
this bucket. This can either be the bucket name by itself, such asexample-
bucket, or the bucket name with gs://
or https://storage.googleapis.com/ in front of it, such
as gs://example-bucket.
Corresponds to the JSON property bucketName
60438 60439 60440 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60438 def bucket_name @bucket_name end |
#report_name_prefix ⇒ String
An optional prefix for the name of the usage report object stored inbucketName.
If not supplied, defaults tousage_gce. The report is stored as a CSV file
namedreport_name_prefix_gce_YYYYMMDD.csv whereYYYYMMDD is the day of the usage
according to Pacific Time.
If you supply a prefix, it should conform to Cloud Storageobject naming
conventions.
Corresponds to the JSON property reportNamePrefix
60448 60449 60450 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60448 def report_name_prefix @report_name_prefix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60455 60456 60457 60458 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60455 def update!(**args) @bucket_name = args[:bucket_name] if args.key?(:bucket_name) @report_name_prefix = args[:report_name_prefix] if args.key?(:report_name_prefix) end |