Class: Google::Apis::ComputeV1::UsageExportLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsageExportLocation

Returns a new instance of UsageExportLocation.



38561
38562
38563
# File 'lib/google/apis/compute_v1/classes.rb', line 38561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_nameString

The name of an existing bucket in Cloud Storage where the usage report object is stored. The Google Service Account is granted write access to this bucket. This can either be the bucket name by itself, such as example-bucket, or the bucket name with gs:// or https://storage.googleapis.com/ in front of it, such as gs://example-bucket. Corresponds to the JSON property bucketName

Returns:

  • (String)


38550
38551
38552
# File 'lib/google/apis/compute_v1/classes.rb', line 38550

def bucket_name
  @bucket_name
end

#report_name_prefixString

An optional prefix for the name of the usage report object stored in bucketName. If not supplied, defaults to usage_gce. The report is stored as a CSV file named report_name_prefix_gce_YYYYMMDD.csv where YYYYMMDD is the day of the usage according to Pacific Time. If you supply a prefix, it should conform to Cloud Storage object naming conventions. Corresponds to the JSON property reportNamePrefix

Returns:

  • (String)


38559
38560
38561
# File 'lib/google/apis/compute_v1/classes.rb', line 38559

def report_name_prefix
  @report_name_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38566
38567
38568
38569
# File 'lib/google/apis/compute_v1/classes.rb', line 38566

def update!(**args)
  @bucket_name = args[:bucket_name] if args.key?(:bucket_name)
  @report_name_prefix = args[:report_name_prefix] if args.key?(:report_name_prefix)
end