Class: Google::Apis::ComputeV1::VmEndpointNatMappingsInterfaceNatMappings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmEndpointNatMappingsInterfaceNatMappings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contain information of Nat mapping for an interface of this endpoint.
Instance Attribute Summary collapse
-
#drain_nat_ip_port_ranges ⇒ Array<String>
Output only.
-
#nat_ip_port_ranges ⇒ Array<String>
Output only.
-
#num_total_drain_nat_ports ⇒ Fixnum
Output only.
-
#num_total_nat_ports ⇒ Fixnum
Output only.
-
#rule_mappings ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>
Output only.
-
#source_alias_ip_range ⇒ String
Output only.
-
#source_virtual_ip ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappings
constructor
A new instance of VmEndpointNatMappingsInterfaceNatMappings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappings
Returns a new instance of VmEndpointNatMappingsInterfaceNatMappings.
61782 61783 61784 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61782 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drain_nat_ip_port_ranges ⇒ Array<String>
Output only. List of all drain IP:port-range mappings assigned to this
interface.
These ranges are inclusive, that is, both the first and the last
ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
"1.1.1.1:2234-2234"].
Corresponds to the JSON property drainNatIpPortRanges
61741 61742 61743 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61741 def drain_nat_ip_port_ranges @drain_nat_ip_port_ranges end |
#nat_ip_port_ranges ⇒ Array<String>
Output only. A list of all IP:port-range mappings assigned to this interface.
These ranges are inclusive, that is, both the first and the last
ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
"1.1.1.1:2234-2234"].
Corresponds to the JSON property natIpPortRanges
61749 61750 61751 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61749 def nat_ip_port_ranges @nat_ip_port_ranges end |
#num_total_drain_nat_ports ⇒ Fixnum
Output only. Total number of drain ports across all NAT IPs allocated to this
interface. It equals to the aggregated port number in the field
drain_nat_ip_port_ranges.
Corresponds to the JSON property numTotalDrainNatPorts
61756 61757 61758 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61756 def num_total_drain_nat_ports @num_total_drain_nat_ports end |
#num_total_nat_ports ⇒ Fixnum
Output only. Total number of ports across all NAT IPs allocated to this
interface.
It equals to the aggregated port number in the field nat_ip_port_ranges.
Corresponds to the JSON property numTotalNatPorts
61763 61764 61765 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61763 def num_total_nat_ports @num_total_nat_ports end |
#rule_mappings ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>
Output only. Information about mappings provided by rules in this NAT.
Corresponds to the JSON property ruleMappings
61768 61769 61770 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61768 def rule_mappings @rule_mappings end |
#source_alias_ip_range ⇒ String
Output only. Alias IP range for this interface endpoint.
It will be a private (RFC 1918) IP range.
Examples: "10.33.4.55/32", or "192.168.5.0/24".
Corresponds to the JSON property sourceAliasIpRange
61775 61776 61777 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61775 def source_alias_ip_range @source_alias_ip_range end |
#source_virtual_ip ⇒ String
Output only. Primary IP of the VM for this NIC.
Corresponds to the JSON property sourceVirtualIp
61780 61781 61782 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61780 def source_virtual_ip @source_virtual_ip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61787 61788 61789 61790 61791 61792 61793 61794 61795 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61787 def update!(**args) @drain_nat_ip_port_ranges = args[:drain_nat_ip_port_ranges] if args.key?(:drain_nat_ip_port_ranges) @nat_ip_port_ranges = args[:nat_ip_port_ranges] if args.key?(:nat_ip_port_ranges) @num_total_drain_nat_ports = args[:num_total_drain_nat_ports] if args.key?(:num_total_drain_nat_ports) @num_total_nat_ports = args[:num_total_nat_ports] if args.key?(:num_total_nat_ports) @rule_mappings = args[:rule_mappings] if args.key?(:rule_mappings) @source_alias_ip_range = args[:source_alias_ip_range] if args.key?(:source_alias_ip_range) @source_virtual_ip = args[:source_virtual_ip] if args.key?(:source_virtual_ip) end |