Class: Google::Apis::ComputeV1::VmEndpointNatMappingsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of VmEndpointNatMappings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsList

Returns a new instance of VmEndpointNatMappingsList.



68631
68632
68633
# File 'lib/google/apis/compute_v1/classes.rb', line 68631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68597
68598
68599
# File 'lib/google/apis/compute_v1/classes.rb', line 68597

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


68604
68605
68606
# File 'lib/google/apis/compute_v1/classes.rb', line 68604

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68614
68615
68616
# File 'lib/google/apis/compute_v1/classes.rb', line 68614

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::VmEndpointNatMappings>

[Output Only] A list of Nat mapping information of VM endpoints. Corresponds to the JSON property result



68619
68620
68621
# File 'lib/google/apis/compute_v1/classes.rb', line 68619

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68624
68625
68626
# File 'lib/google/apis/compute_v1/classes.rb', line 68624

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::VmEndpointNatMappingsList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68629
68630
68631
# File 'lib/google/apis/compute_v1/classes.rb', line 68629

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68636
68637
68638
68639
68640
68641
68642
68643
# File 'lib/google/apis/compute_v1/classes.rb', line 68636

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end