Class: Google::Apis::ComputeV1::VmEndpointNatMappingsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of VmEndpointNatMappings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsList

Returns a new instance of VmEndpointNatMappingsList.



67800
67801
67802
# File 'lib/google/apis/compute_v1/classes.rb', line 67800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67766
67767
67768
# File 'lib/google/apis/compute_v1/classes.rb', line 67766

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


67773
67774
67775
# File 'lib/google/apis/compute_v1/classes.rb', line 67773

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67783
67784
67785
# File 'lib/google/apis/compute_v1/classes.rb', line 67783

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::VmEndpointNatMappings>

[Output Only] A list of Nat mapping information of VM endpoints. Corresponds to the JSON property result



67788
67789
67790
# File 'lib/google/apis/compute_v1/classes.rb', line 67788

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67793
67794
67795
# File 'lib/google/apis/compute_v1/classes.rb', line 67793

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::VmEndpointNatMappingsList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67798
67799
67800
# File 'lib/google/apis/compute_v1/classes.rb', line 67798

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67805
67806
67807
67808
67809
67810
67811
67812
# File 'lib/google/apis/compute_v1/classes.rb', line 67805

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end