Class: Google::Apis::ComputeV1::VmEndpointNatMappingsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmEndpointNatMappingsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of VmEndpointNatMappings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsList
constructor
A new instance of VmEndpointNatMappingsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsList
Returns a new instance of VmEndpointNatMappingsList.
67038 67039 67040 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
67004 67005 67006 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67004 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
vmEndpointNatMappingsList for lists of Nat mappings of
VM endpoints.
Corresponds to the JSON property kind
67011 67012 67013 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67011 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67021 67022 67023 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67021 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
Corresponds to the JSON property result
67026 67027 67028 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67026 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67031 67032 67033 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67031 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67036 67037 67038 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67036 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67043 67044 67045 67046 67047 67048 67049 67050 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67043 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |