Class: Google::Apis::ComputeV1::VmEndpointNatMappingsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmEndpointNatMappingsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of VmEndpointNatMappings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsList
constructor
A new instance of VmEndpointNatMappingsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsList
Returns a new instance of VmEndpointNatMappingsList.
65515 65516 65517 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
65481 65482 65483 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65481 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
vmEndpointNatMappingsList for lists of Nat mappings of
VM endpoints.
Corresponds to the JSON property kind
65488 65489 65490 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65488 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65498 65499 65500 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65498 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
Corresponds to the JSON property result
65503 65504 65505 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65503 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65508 65509 65510 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65508 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65513 65514 65515 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65513 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65520 65521 65522 65523 65524 65525 65526 65527 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65520 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |