Class: Google::Apis::ComputeV1::VmEndpointNatMappingsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of VmEndpointNatMappings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsList

Returns a new instance of VmEndpointNatMappingsList.



61899
61900
61901
# File 'lib/google/apis/compute_v1/classes.rb', line 61899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61865
61866
61867
# File 'lib/google/apis/compute_v1/classes.rb', line 61865

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


61872
61873
61874
# File 'lib/google/apis/compute_v1/classes.rb', line 61872

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61882
61883
61884
# File 'lib/google/apis/compute_v1/classes.rb', line 61882

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeV1::VmEndpointNatMappings>

[Output Only] A list of Nat mapping information of VM endpoints. Corresponds to the JSON property result



61887
61888
61889
# File 'lib/google/apis/compute_v1/classes.rb', line 61887

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61892
61893
61894
# File 'lib/google/apis/compute_v1/classes.rb', line 61892

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::VmEndpointNatMappingsList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61897
61898
61899
# File 'lib/google/apis/compute_v1/classes.rb', line 61897

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61904
61905
61906
61907
61908
61909
61910
61911
# File 'lib/google/apis/compute_v1/classes.rb', line 61904

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end