Class: Google::Apis::ComputeV1::VmEndpointNatMappingsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmEndpointNatMappingsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of VmEndpointNatMappings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsList
constructor
A new instance of VmEndpointNatMappingsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsList
Returns a new instance of VmEndpointNatMappingsList.
60655 60656 60657 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
60621 60622 60623 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60621 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
vmEndpointNatMappingsList for lists of Nat mappings of
VM endpoints.
Corresponds to the JSON property kind
60628 60629 60630 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60628 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60638 60639 60640 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60638 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
Corresponds to the JSON property result
60643 60644 60645 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60643 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60648 60649 60650 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60648 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60653 60654 60655 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60653 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60660 60661 60662 60663 60664 60665 60666 60667 |
# File 'lib/google/apis/compute_v1/classes.rb', line 60660 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |