Class: Google::Apis::ComputeV1::VmEndpointNatMappingsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmEndpointNatMappingsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of VmEndpointNatMappings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeV1::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsList
constructor
A new instance of VmEndpointNatMappingsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsList
Returns a new instance of VmEndpointNatMappingsList.
38693 38694 38695 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
38661 38662 38663 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38661 def id @id end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#vmEndpointNatMappingsList for
lists of Nat mappings of VM endpoints.
Corresponds to the JSON property kind
38667 38668 38669 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38667 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38676 38677 38678 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38676 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeV1::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
Corresponds to the JSON property result
38681 38682 38683 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38681 def result @result end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38686 38687 38688 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38686 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38691 38692 38693 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38691 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38698 38699 38700 38701 38702 38703 38704 38705 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38698 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |