Class: Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response for the aggregated list of VM extension policies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse
constructor
A new instance of VmExtensionPolicyAggregatedListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse
Returns a new instance of VmExtensionPolicyAggregatedListResponse.
68989 68990 68991 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
68945 68946 68947 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68945 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
68950 68951 68952 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68950 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
Corresponds to the JSON property items
68955 68956 68957 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68955 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
VmExtensionPolicyAggregatedList for lists of
VmExtensionPolicies.
Corresponds to the JSON property kind
68962 68963 68964 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68962 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
68972 68973 68974 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68972 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
68977 68978 68979 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68977 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
68982 68983 68984 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68982 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
68987 68988 68989 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68987 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68994 68995 68996 68997 68998 68999 69000 69001 69002 69003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68994 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |