Class: Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response for the aggregated list of VM extension policies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse

Returns a new instance of VmExtensionPolicyAggregatedListResponse.



68146
68147
68148
# File 'lib/google/apis/compute_v1/classes.rb', line 68146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


68102
68103
68104
# File 'lib/google/apis/compute_v1/classes.rb', line 68102

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68107
68108
68109
# File 'lib/google/apis/compute_v1/classes.rb', line 68107

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



68112
68113
68114
# File 'lib/google/apis/compute_v1/classes.rb', line 68112

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


68119
68120
68121
# File 'lib/google/apis/compute_v1/classes.rb', line 68119

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68129
68130
68131
# File 'lib/google/apis/compute_v1/classes.rb', line 68129

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68134
68135
68136
# File 'lib/google/apis/compute_v1/classes.rb', line 68134

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68139
68140
68141
# File 'lib/google/apis/compute_v1/classes.rb', line 68139

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68144
68145
68146
# File 'lib/google/apis/compute_v1/classes.rb', line 68144

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
# File 'lib/google/apis/compute_v1/classes.rb', line 68151

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end