Class: Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response for the aggregated list of VM extension policies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse
constructor
A new instance of VmExtensionPolicyAggregatedListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse
Returns a new instance of VmExtensionPolicyAggregatedListResponse.
67760 67761 67762 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
67716 67717 67718 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67716 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
67721 67722 67723 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67721 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
Corresponds to the JSON property items
67726 67727 67728 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67726 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
VmExtensionPolicyAggregatedList for lists of
VmExtensionPolicies.
Corresponds to the JSON property kind
67733 67734 67735 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67733 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67743 67744 67745 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67743 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67748 67749 67750 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67748 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67753 67754 67755 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67753 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67758 67759 67760 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67758 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67765 67766 67767 67768 67769 67770 67771 67772 67773 67774 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67765 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |