Class: Google::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response for the aggregated list of VM extension policies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse

Returns a new instance of VmExtensionPolicyAggregatedListResponse.



67396
67397
67398
# File 'lib/google/apis/compute_v1/classes.rb', line 67396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


67352
67353
67354
# File 'lib/google/apis/compute_v1/classes.rb', line 67352

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67357
67358
67359
# File 'lib/google/apis/compute_v1/classes.rb', line 67357

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



67362
67363
67364
# File 'lib/google/apis/compute_v1/classes.rb', line 67362

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


67369
67370
67371
# File 'lib/google/apis/compute_v1/classes.rb', line 67369

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67379
67380
67381
# File 'lib/google/apis/compute_v1/classes.rb', line 67379

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67384
67385
67386
# File 'lib/google/apis/compute_v1/classes.rb', line 67384

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67389
67390
67391
# File 'lib/google/apis/compute_v1/classes.rb', line 67389

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67394
67395
67396
# File 'lib/google/apis/compute_v1/classes.rb', line 67394

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67401
67402
67403
67404
67405
67406
67407
67408
67409
67410
# File 'lib/google/apis/compute_v1/classes.rb', line 67401

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end