Class: Google::Apis::ComputeV1::VmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeV1::VmExtensionPolicy>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyList
constructor
A new instance of VmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyList
Returns a new instance of VmExtensionPolicyList.
67978 67979 67980 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. [Output Only] Fingerprint of this resource. A hash of the
contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
67934 67935 67936 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67934 def etag @etag end |
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
67940 67941 67942 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67940 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::VmExtensionPolicy>
Output only. [Output Only] A list of VM extension policy resources.
Corresponds to the JSON property items
67945 67946 67947 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67945 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
67950 67951 67952 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67950 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67961 67962 67963 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67961 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67966 67967 67968 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67966 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67971 67972 67973 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67971 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
67976 67977 67978 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67976 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67983 67984 67985 67986 67987 67988 67989 67990 67991 67992 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67983 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |