Class: Google::Apis::ComputeV1::VmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeV1::VmExtensionPolicy>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyList
constructor
A new instance of VmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyList
Returns a new instance of VmExtensionPolicyList.
67614 67615 67616 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. [Output Only] Fingerprint of this resource. A hash of the
contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
67570 67571 67572 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67570 def etag @etag end |
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
67576 67577 67578 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67576 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::VmExtensionPolicy>
Output only. [Output Only] A list of VM extension policy resources.
Corresponds to the JSON property items
67581 67582 67583 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67581 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
67586 67587 67588 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67586 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67597 67598 67599 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67597 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67602 67603 67604 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67602 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67607 67608 67609 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67607 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
67612 67613 67614 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67612 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67619 67620 67621 67622 67623 67624 67625 67626 67627 67628 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67619 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |