Class: Google::Apis::ComputeV1::VmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeV1::VmExtensionPolicy>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyList
constructor
A new instance of VmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyList
Returns a new instance of VmExtensionPolicyList.
65856 65857 65858 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. [Output Only] Fingerprint of this resource. A hash of the
contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
65812 65813 65814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65812 def etag @etag end |
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
65818 65819 65820 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65818 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::VmExtensionPolicy>
Output only. [Output Only] A list of VM extension policy resources.
Corresponds to the JSON property items
65823 65824 65825 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65823 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
65828 65829 65830 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65828 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65839 65840 65841 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65839 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65844 65845 65846 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65844 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
65849 65850 65851 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65849 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::VmExtensionPolicyList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
65854 65855 65856 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65854 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65861 65862 65863 65864 65865 65866 65867 65868 65869 65870 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65861 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |