Class: Google::Apis::ComputeV1::VpnGateway

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a HA VPN gateway. HA VPN is a high-availability (HA) Cloud VPN solution that lets you securely connect your on-premises network to your Google Cloud Virtual Private Cloud network through an IPsec VPN connection in a single region. For more information about Cloud HA VPN solutions, see Cloud VPN topologies .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGateway

Returns a new instance of VpnGateway.



67794
67795
67796
# File 'lib/google/apis/compute_v1/classes.rb', line 67794

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


67700
67701
67702
# File 'lib/google/apis/compute_v1/classes.rb', line 67700

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


67706
67707
67708
# File 'lib/google/apis/compute_v1/classes.rb', line 67706

def description
  @description
end

#gateway_ip_versionString

The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not specified, IPV4 will be used. Corresponds to the JSON property gatewayIpVersion

Returns:

  • (String)


67712
67713
67714
# File 'lib/google/apis/compute_v1/classes.rb', line 67712

def gateway_ip_version
  @gateway_ip_version
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


67719
67720
67721
# File 'lib/google/apis/compute_v1/classes.rb', line 67719

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


67725
67726
67727
# File 'lib/google/apis/compute_v1/classes.rb', line 67725

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this VpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a VpnGateway. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


67738
67739
67740
# File 'lib/google/apis/compute_v1/classes.rb', line 67738

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


67745
67746
67747
# File 'lib/google/apis/compute_v1/classes.rb', line 67745

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


67756
67757
67758
# File 'lib/google/apis/compute_v1/classes.rb', line 67756

def name
  @name
end

#networkString

URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created. Corresponds to the JSON property network

Returns:

  • (String)


67762
67763
67764
# File 'lib/google/apis/compute_v1/classes.rb', line 67762

def network
  @network
end

#paramsGoogle::Apis::ComputeV1::VpnGatewayParams

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload. Corresponds to the JSON property params



67769
67770
67771
# File 'lib/google/apis/compute_v1/classes.rb', line 67769

def params
  @params
end

#regionString

Output only. [Output Only] URL of the region where the VPN gateway resides. Corresponds to the JSON property region

Returns:

  • (String)


67774
67775
67776
# File 'lib/google/apis/compute_v1/classes.rb', line 67774

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67779
67780
67781
# File 'lib/google/apis/compute_v1/classes.rb', line 67779

def self_link
  @self_link
end

#stack_typeString

The stack type for this VPN gateway to identify the IP protocols that are enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified, IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. Corresponds to the JSON property stackType

Returns:

  • (String)


67787
67788
67789
# File 'lib/google/apis/compute_v1/classes.rb', line 67787

def stack_type
  @stack_type
end

#vpn_interfacesArray<Google::Apis::ComputeV1::VpnGatewayVpnGatewayInterface>

The list of VPN interfaces associated with this VPN gateway. Corresponds to the JSON property vpnInterfaces



67792
67793
67794
# File 'lib/google/apis/compute_v1/classes.rb', line 67792

def vpn_interfaces
  @vpn_interfaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67799
67800
67801
67802
67803
67804
67805
67806
67807
67808
67809
67810
67811
67812
67813
67814
# File 'lib/google/apis/compute_v1/classes.rb', line 67799

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @gateway_ip_version = args[:gateway_ip_version] if args.key?(:gateway_ip_version)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @vpn_interfaces = args[:vpn_interfaces] if args.key?(:vpn_interfaces)
end