Class: Google::Apis::ComputeV1::VpnGateway
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnGateway
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a HA VPN gateway. HA VPN is a high-availability (HA) Cloud VPN solution that lets you securely connect your on-premises network to your Google Cloud Virtual Private Cloud network through an IPsec VPN connection in a single region. For more information about Cloud HA VPN solutions, see Cloud VPN topologies .
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#gateway_ip_version ⇒ String
The IP family of the gateway IPs for the HA-VPN gateway interfaces.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this VpnGateway, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
URL of the network to which this VPN gateway is attached.
-
#params ⇒ Google::Apis::ComputeV1::VpnGatewayParams
Input only.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#stack_type ⇒ String
The stack type for this VPN gateway to identify the IP protocols that are enabled.
-
#vpn_interfaces ⇒ Array<Google::Apis::ComputeV1::VpnGatewayVpnGatewayInterface>
The list of VPN interfaces associated with this VPN gateway.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGateway
constructor
A new instance of VpnGateway.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGateway
Returns a new instance of VpnGateway.
66050 66051 66052 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
65956 65957 65958 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65956 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
65962 65963 65964 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65962 def description @description end |
#gateway_ip_version ⇒ String
The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not
specified, IPV4 will be used.
Corresponds to the JSON property gatewayIpVersion
65968 65969 65970 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65968 def gateway_ip_version @gateway_ip_version end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
65975 65976 65977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65975 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
65981 65982 65983 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65981 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this VpnGateway, which
is essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a VpnGateway.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
65994 65995 65996 |
# File 'lib/google/apis/compute_v1/classes.rb', line 65994 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
66001 66002 66003 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66001 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
66012 66013 66014 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66012 def name @name end |
#network ⇒ String
URL of the network to which this VPN gateway is attached. Provided by the
client when the VPN gateway is created.
Corresponds to the JSON property network
66018 66019 66020 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66018 def network @network end |
#params ⇒ Google::Apis::ComputeV1::VpnGatewayParams
Input only. [Input Only] Additional params passed with the request, but not
persisted
as part of resource payload.
Corresponds to the JSON property params
66025 66026 66027 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66025 def params @params end |
#region ⇒ String
Output only. [Output Only] URL of the region where the VPN gateway resides.
Corresponds to the JSON property region
66030 66031 66032 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66030 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
66035 66036 66037 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66035 def self_link @self_link end |
#stack_type ⇒ String
The stack type for this VPN gateway to identify the IP protocols that are
enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,
IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the
gateway IP version isIPV6.
Corresponds to the JSON property stackType
66043 66044 66045 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66043 def stack_type @stack_type end |
#vpn_interfaces ⇒ Array<Google::Apis::ComputeV1::VpnGatewayVpnGatewayInterface>
The list of VPN interfaces associated with this VPN gateway.
Corresponds to the JSON property vpnInterfaces
66048 66049 66050 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66048 def vpn_interfaces @vpn_interfaces end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66055 66056 66057 66058 66059 66060 66061 66062 66063 66064 66065 66066 66067 66068 66069 66070 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66055 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @gateway_ip_version = args[:gateway_ip_version] if args.key?(:gateway_ip_version) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @stack_type = args[:stack_type] if args.key?(:stack_type) @vpn_interfaces = args[:vpn_interfaces] if args.key?(:vpn_interfaces) end |