Class: Google::Apis::ComputeV1::VpnGateway
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnGateway
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a HA VPN gateway. HA VPN is a high-availability (HA) Cloud VPN solution that lets you securely connect your on-premises network to your Google Cloud Virtual Private Cloud network through an IPsec VPN connection in a single region. For more information about Cloud HA VPN solutions, see Cloud VPN topologies .
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this VpnGateway, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
URL of the network to which this VPN gateway is attached.
-
#region ⇒ String
[Output Only] URL of the region where the VPN gateway resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#stack_type ⇒ String
The stack type for this VPN gateway to identify the IP protocols that are enabled.
-
#vpn_interfaces ⇒ Array<Google::Apis::ComputeV1::VpnGatewayVpnGatewayInterface>
The list of VPN interfaces associated with this VPN gateway.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGateway
constructor
A new instance of VpnGateway.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGateway
Returns a new instance of VpnGateway.
38858 38859 38860 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
38783 38784 38785 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38783 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
38789 38790 38791 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38789 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
38795 38796 38797 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38795 def id @id end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.
Corresponds to the JSON property kind
38800 38801 38802 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38800 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this VpnGateway, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after every
request to modify or update labels. You must always provide an up-to-date
fingerprint hash in order to update or change labels, otherwise the request
will fail with error 412 conditionNotMet. To see the latest fingerprint, make
a get() request to retrieve an VpnGateway.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
38812 38813 38814 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38812 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by the setLabels
method. Each label key/value pair must comply with RFC1035. Label values may
be empty.
Corresponds to the JSON property labels
38819 38820 38821 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38819 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
38829 38830 38831 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38829 def name @name end |
#network ⇒ String
URL of the network to which this VPN gateway is attached. Provided by the
client when the VPN gateway is created.
Corresponds to the JSON property network
38835 38836 38837 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38835 def network @network end |
#region ⇒ String
[Output Only] URL of the region where the VPN gateway resides.
Corresponds to the JSON property region
38840 38841 38842 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38840 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
38845 38846 38847 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38845 def self_link @self_link end |
#stack_type ⇒ String
The stack type for this VPN gateway to identify the IP protocols that are
enabled. If not specified, IPV4_ONLY will be used.
Corresponds to the JSON property stackType
38851 38852 38853 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38851 def stack_type @stack_type end |
#vpn_interfaces ⇒ Array<Google::Apis::ComputeV1::VpnGatewayVpnGatewayInterface>
The list of VPN interfaces associated with this VPN gateway.
Corresponds to the JSON property vpnInterfaces
38856 38857 38858 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38856 def vpn_interfaces @vpn_interfaces end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38863 38864 38865 38866 38867 38868 38869 38870 38871 38872 38873 38874 38875 38876 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38863 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @stack_type = args[:stack_type] if args.key?(:stack_type) @vpn_interfaces = args[:vpn_interfaces] if args.key?(:vpn_interfaces) end |