Class: Google::Apis::ComputeV1::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



69469
69470
69471
# File 'lib/google/apis/compute_v1/classes.rb', line 69469

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69431
69432
69433
# File 'lib/google/apis/compute_v1/classes.rb', line 69431

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



69436
69437
69438
# File 'lib/google/apis/compute_v1/classes.rb', line 69436

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


69442
69443
69444
# File 'lib/google/apis/compute_v1/classes.rb', line 69442

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69452
69453
69454
# File 'lib/google/apis/compute_v1/classes.rb', line 69452

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69457
69458
69459
# File 'lib/google/apis/compute_v1/classes.rb', line 69457

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69462
69463
69464
# File 'lib/google/apis/compute_v1/classes.rb', line 69462

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69467
69468
69469
# File 'lib/google/apis/compute_v1/classes.rb', line 69467

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69474
69475
69476
69477
69478
69479
69480
69481
69482
# File 'lib/google/apis/compute_v1/classes.rb', line 69474

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end