Class: Google::Apis::ComputeV1::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayAggregatedList
constructor
A new instance of VpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayAggregatedList
Returns a new instance of VpnGatewayAggregatedList.
68626 68627 68628 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
68588 68589 68590 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68588 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>
A list of VpnGateway resources.
Corresponds to the JSON property items
68593 68594 68595 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68593 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
68599 68600 68601 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68599 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
68609 68610 68611 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68609 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
68614 68615 68616 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68614 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
68619 68620 68621 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68619 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
68624 68625 68626 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68624 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68631 68632 68633 68634 68635 68636 68637 68638 68639 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68631 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |