Class: Google::Apis::ComputeV1::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



68281
68282
68283
# File 'lib/google/apis/compute_v1/classes.rb', line 68281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68243
68244
68245
# File 'lib/google/apis/compute_v1/classes.rb', line 68243

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



68248
68249
68250
# File 'lib/google/apis/compute_v1/classes.rb', line 68248

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


68254
68255
68256
# File 'lib/google/apis/compute_v1/classes.rb', line 68254

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68264
68265
68266
# File 'lib/google/apis/compute_v1/classes.rb', line 68264

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68269
68270
68271
# File 'lib/google/apis/compute_v1/classes.rb', line 68269

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68274
68275
68276
# File 'lib/google/apis/compute_v1/classes.rb', line 68274

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68279
68280
68281
# File 'lib/google/apis/compute_v1/classes.rb', line 68279

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68286
68287
68288
68289
68290
68291
68292
68293
68294
# File 'lib/google/apis/compute_v1/classes.rb', line 68286

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end