Class: Google::Apis::ComputeV1::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



68240
68241
68242
# File 'lib/google/apis/compute_v1/classes.rb', line 68240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68202
68203
68204
# File 'lib/google/apis/compute_v1/classes.rb', line 68202

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



68207
68208
68209
# File 'lib/google/apis/compute_v1/classes.rb', line 68207

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


68213
68214
68215
# File 'lib/google/apis/compute_v1/classes.rb', line 68213

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68223
68224
68225
# File 'lib/google/apis/compute_v1/classes.rb', line 68223

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68228
68229
68230
# File 'lib/google/apis/compute_v1/classes.rb', line 68228

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68233
68234
68235
# File 'lib/google/apis/compute_v1/classes.rb', line 68233

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68238
68239
68240
# File 'lib/google/apis/compute_v1/classes.rb', line 68238

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68245
68246
68247
68248
68249
68250
68251
68252
68253
# File 'lib/google/apis/compute_v1/classes.rb', line 68245

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end