Class: Google::Apis::ComputeV1::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayAggregatedList
constructor
A new instance of VpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayAggregatedList
Returns a new instance of VpnGatewayAggregatedList.
62159 62160 62161 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62121 62122 62123 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62121 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>
A list of VpnGateway resources.
Corresponds to the JSON property items
62126 62127 62128 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62126 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
62132 62133 62134 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62132 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62142 62143 62144 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62142 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62147 62148 62149 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62147 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
62152 62153 62154 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62152 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62157 62158 62159 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62157 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62164 62165 62166 62167 62168 62169 62170 62171 62172 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62164 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |