Class: Google::Apis::ComputeV1::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



60907
60908
60909
# File 'lib/google/apis/compute_v1/classes.rb', line 60907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60869
60870
60871
# File 'lib/google/apis/compute_v1/classes.rb', line 60869

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



60874
60875
60876
# File 'lib/google/apis/compute_v1/classes.rb', line 60874

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


60880
60881
60882
# File 'lib/google/apis/compute_v1/classes.rb', line 60880

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60890
60891
60892
# File 'lib/google/apis/compute_v1/classes.rb', line 60890

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60895
60896
60897
# File 'lib/google/apis/compute_v1/classes.rb', line 60895

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


60900
60901
60902
# File 'lib/google/apis/compute_v1/classes.rb', line 60900

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



60905
60906
60907
# File 'lib/google/apis/compute_v1/classes.rb', line 60905

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60912
60913
60914
60915
60916
60917
60918
60919
60920
# File 'lib/google/apis/compute_v1/classes.rb', line 60912

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end