Class: Google::Apis::ComputeV1::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>
A list of VpnGateway resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeV1::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayAggregatedList
constructor
A new instance of VpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayAggregatedList
Returns a new instance of VpnGatewayAggregatedList.
38922 38923 38924 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38922 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38886 38887 38888 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38886 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::VpnGatewaysScopedList>
A list of VpnGateway resources.
Corresponds to the JSON property items
38891 38892 38893 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38891 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.
Corresponds to the JSON property kind
38896 38897 38898 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38896 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38905 38906 38907 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38905 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38910 38911 38912 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38910 def self_link @self_link end |
#unreachables ⇒ Array<String>
[Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
38915 38916 38917 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38915 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38920 38921 38922 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38920 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38927 38928 38929 38930 38931 38932 38933 38934 38935 |
# File 'lib/google/apis/compute_v1/classes.rb', line 38927 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |