Class: Google::Apis::ComputeV1::VpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of VpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayList

Returns a new instance of VpnGatewayList.



69595
69596
69597
# File 'lib/google/apis/compute_v1/classes.rb', line 69595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69562
69563
69564
# File 'lib/google/apis/compute_v1/classes.rb', line 69562

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::VpnGateway>

A list of VpnGateway resources. Corresponds to the JSON property items



69567
69568
69569
# File 'lib/google/apis/compute_v1/classes.rb', line 69567

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


69573
69574
69575
# File 'lib/google/apis/compute_v1/classes.rb', line 69573

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69583
69584
69585
# File 'lib/google/apis/compute_v1/classes.rb', line 69583

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69588
69589
69590
# File 'lib/google/apis/compute_v1/classes.rb', line 69588

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::VpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69593
69594
69595
# File 'lib/google/apis/compute_v1/classes.rb', line 69593

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69600
69601
69602
69603
69604
69605
69606
69607
# File 'lib/google/apis/compute_v1/classes.rb', line 69600

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end