Class: Google::Apis::ComputeV1::VpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of VpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayList

Returns a new instance of VpnGatewayList.



66244
66245
66246
# File 'lib/google/apis/compute_v1/classes.rb', line 66244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66211
66212
66213
# File 'lib/google/apis/compute_v1/classes.rb', line 66211

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::VpnGateway>

A list of VpnGateway resources. Corresponds to the JSON property items



66216
66217
66218
# File 'lib/google/apis/compute_v1/classes.rb', line 66216

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


66222
66223
66224
# File 'lib/google/apis/compute_v1/classes.rb', line 66222

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66232
66233
66234
# File 'lib/google/apis/compute_v1/classes.rb', line 66232

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66237
66238
66239
# File 'lib/google/apis/compute_v1/classes.rb', line 66237

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::VpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66242
66243
66244
# File 'lib/google/apis/compute_v1/classes.rb', line 66242

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66249
66250
66251
66252
66253
66254
66255
66256
# File 'lib/google/apis/compute_v1/classes.rb', line 66249

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end