Class: Google::Apis::ComputeV1::VpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of VpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::VpnGateway>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayList
constructor
A new instance of VpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayList
Returns a new instance of VpnGatewayList.
66244 66245 66246 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66211 66212 66213 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66211 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::VpnGateway>
A list of VpnGateway resources.
Corresponds to the JSON property items
66216 66217 66218 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66216 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
66222 66223 66224 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66222 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66232 66233 66234 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66232 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66237 66238 66239 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66237 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::VpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66242 66243 66244 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66242 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66249 66250 66251 66252 66253 66254 66255 66256 |
# File 'lib/google/apis/compute_v1/classes.rb', line 66249 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |