Class: Google::Apis::ComputeV1::VpnGatewayStatusHighAvailabilityRequirementState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayStatusHighAvailabilityRequirementState

Returns a new instance of VpnGatewayStatusHighAvailabilityRequirementState.



66398
66399
66400
# File 'lib/google/apis/compute_v1/classes.rb', line 66398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Corresponds to the JSON property state

Returns:

  • (String)


66389
66390
66391
# File 'lib/google/apis/compute_v1/classes.rb', line 66389

def state
  @state
end

#unsatisfied_reasonString

Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE. Corresponds to the JSON property unsatisfiedReason

Returns:

  • (String)


66396
66397
66398
# File 'lib/google/apis/compute_v1/classes.rb', line 66396

def unsatisfied_reason
  @unsatisfied_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66403
66404
66405
66406
# File 'lib/google/apis/compute_v1/classes.rb', line 66403

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @unsatisfied_reason = args[:unsatisfied_reason] if args.key?(:unsatisfied_reason)
end