Class: Google::Apis::ComputeV1::VpnGatewayStatusVpnConnection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnGatewayStatusVpnConnection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A VPN connection contains all VPN tunnels connected from this VpnGateway to the same peer gateway. The peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.
Instance Attribute Summary collapse
-
#peer_external_gateway ⇒ String
Output only.
-
#peer_gcp_gateway ⇒ String
Output only.
-
#state ⇒ Google::Apis::ComputeV1::VpnGatewayStatusHighAvailabilityRequirementState
Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.
-
#tunnels ⇒ Array<Google::Apis::ComputeV1::VpnGatewayStatusTunnel>
List of VPN tunnels that are in this VPN connection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayStatusVpnConnection
constructor
A new instance of VpnGatewayStatusVpnConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayStatusVpnConnection
Returns a new instance of VpnGatewayStatusVpnConnection.
61233 61234 61235 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#peer_external_gateway ⇒ String
Output only. URL reference to the peer external VPN gateways to which the VPN
tunnels
in this VPN connection are connected.
This field is mutually exclusive with peer_gcp_gateway.
Corresponds to the JSON property peerExternalGateway
61212 61213 61214 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61212 def peer_external_gateway @peer_external_gateway end |
#peer_gcp_gateway ⇒ String
Output only. URL reference to the peer side VPN gateways to which the VPN
tunnels in
this VPN connection are connected.
This field is mutually exclusive with peer_gcp_gateway.
Corresponds to the JSON property peerGcpGateway
61220 61221 61222 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61220 def peer_gcp_gateway @peer_gcp_gateway end |
#state ⇒ Google::Apis::ComputeV1::VpnGatewayStatusHighAvailabilityRequirementState
Describes the high availability requirement state for the VPN connection
between this Cloud VPN gateway and a peer gateway.
Corresponds to the JSON property state
61226 61227 61228 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61226 def state @state end |
#tunnels ⇒ Array<Google::Apis::ComputeV1::VpnGatewayStatusTunnel>
List of VPN tunnels that are in this VPN connection.
Corresponds to the JSON property tunnels
61231 61232 61233 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61231 def tunnels @tunnels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61238 61239 61240 61241 61242 61243 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61238 def update!(**args) @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway) @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway) @state = args[:state] if args.key?(:state) @tunnels = args[:tunnels] if args.key?(:tunnels) end |