Class: Google::Apis::ComputeV1::VpnGatewayVpnGatewayInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A VPN gateway interface.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayVpnGatewayInterface

Returns a new instance of VpnGatewayVpnGatewayInterface.



69042
69043
69044
# File 'lib/google/apis/compute_v1/classes.rb', line 69042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. [Output Only] Numeric identifier for this VPN interface associated with the VPN gateway. Corresponds to the JSON property id

Returns:

  • (Fixnum)


69006
69007
69008
# File 'lib/google/apis/compute_v1/classes.rb', line 69006

def id
  @id
end

#interconnect_attachmentString

URL of the VLAN attachment (interconnectAttachment) resource for this VPN gateway interface. When the value of this field is present, the VPN gateway is used for HA VPN over Cloud Interconnect; all egress or ingress traffic for this VPN gateway interface goes through the specified VLAN attachment resource. Corresponds to the JSON property interconnectAttachment

Returns:

  • (String)


69015
69016
69017
# File 'lib/google/apis/compute_v1/classes.rb', line 69015

def interconnect_attachment
  @interconnect_attachment
end

#ip_addressString

Output only. [Output Only] IP address for this VPN interface associated with the VPN gateway. The IP address could be either a regional external IP address or a regional internal IP address. The two IP addresses for a VPN gateway must be all regional external or regional internal IP addresses. There cannot be a mix of regional external IP addresses and regional internal IP addresses. For HA VPN over Cloud Interconnect, the IP addresses for both interfaces could either be regional internal IP addresses or regional external IP addresses. For regular (non HA VPN over Cloud Interconnect) HA VPN tunnels, the IP address must be a regional external IP address. Corresponds to the JSON property ipAddress

Returns:

  • (String)


69031
69032
69033
# File 'lib/google/apis/compute_v1/classes.rb', line 69031

def ip_address
  @ip_address
end

#ipv6_addressString

Output only. [Output Only] IPv6 address for this VPN interface associated with the VPN gateway. The IPv6 address must be a regional external IPv6 address. The format is RFC 5952 format (e.g. 2001:db8::2d9:51:0:0). Corresponds to the JSON property ipv6Address

Returns:

  • (String)


69040
69041
69042
# File 'lib/google/apis/compute_v1/classes.rb', line 69040

def ipv6_address
  @ipv6_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69047
69048
69049
69050
69051
69052
# File 'lib/google/apis/compute_v1/classes.rb', line 69047

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @interconnect_attachment = args[:interconnect_attachment] if args.key?(:interconnect_attachment)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
end