Class: Google::Apis::ComputeV1::VpnTunnel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Cloud VPN Tunnel resource. For more information about VPN, read the the Cloud VPN Overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnel

Returns a new instance of VpnTunnel.



69048
69049
69050
# File 'lib/google/apis/compute_v1/classes.rb', line 69048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cipher_suiteGoogle::Apis::ComputeV1::VpnTunnelCipherSuite

User specified list of ciphers to use for the phase 1 and phase 2 of the IKE protocol. Corresponds to the JSON property cipherSuite



68836
68837
68838
# File 'lib/google/apis/compute_v1/classes.rb', line 68836

def cipher_suite
  @cipher_suite
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


68842
68843
68844
# File 'lib/google/apis/compute_v1/classes.rb', line 68842

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


68848
68849
68850
# File 'lib/google/apis/compute_v1/classes.rb', line 68848

def description
  @description
end

#detailed_statusString

[Output Only] Detailed status message for the VPN tunnel. Corresponds to the JSON property detailedStatus

Returns:

  • (String)


68853
68854
68855
# File 'lib/google/apis/compute_v1/classes.rb', line 68853

def detailed_status
  @detailed_status
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


68859
68860
68861
# File 'lib/google/apis/compute_v1/classes.rb', line 68859

def id
  @id
end

#ike_versionFixnum

IKE protocol version to use when establishing the VPN tunnel with the peer VPN gateway. Acceptable IKE versions are 1 or 2. The default version is 2. Corresponds to the JSON property ikeVersion

Returns:

  • (Fixnum)


68866
68867
68868
# File 'lib/google/apis/compute_v1/classes.rb', line 68866

def ike_version
  @ike_version
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


68872
68873
68874
# File 'lib/google/apis/compute_v1/classes.rb', line 68872

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this VpnTunnel, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a VpnTunnel. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


68885
68886
68887
# File 'lib/google/apis/compute_v1/classes.rb', line 68885

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


68892
68893
68894
# File 'lib/google/apis/compute_v1/classes.rb', line 68892

def labels
  @labels
end

#local_traffic_selectorArray<String>

Local traffic selector to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges must be disjoint. Only IPv4 is supported for Classic VPN tunnels. This field is output only for HA VPN tunnels. Corresponds to the JSON property localTrafficSelector

Returns:

  • (Array<String>)


68901
68902
68903
# File 'lib/google/apis/compute_v1/classes.rb', line 68901

def local_traffic_selector
  @local_traffic_selector
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


68912
68913
68914
# File 'lib/google/apis/compute_v1/classes.rb', line 68912

def name
  @name
end

#paramsGoogle::Apis::ComputeV1::VpnTunnelParams

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload. Corresponds to the JSON property params



68919
68920
68921
# File 'lib/google/apis/compute_v1/classes.rb', line 68919

def params
  @params
end

#peer_external_gatewayString

URL of the peer side external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field is exclusive with the field peerGcpGateway. Corresponds to the JSON property peerExternalGateway

Returns:

  • (String)


68927
68928
68929
# File 'lib/google/apis/compute_v1/classes.rb', line 68927

def peer_external_gateway
  @peer_external_gateway
end

#peer_external_gateway_interfaceFixnum

The interface ID of the external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. Possible values are: 0, 1, 2, 3. The number of IDs in use depends on the external VPN gateway redundancy type. Corresponds to the JSON property peerExternalGatewayInterface

Returns:

  • (Fixnum)


68935
68936
68937
# File 'lib/google/apis/compute_v1/classes.rb', line 68935

def peer_external_gateway_interface
  @peer_external_gateway_interface
end

#peer_gcp_gatewayString

URL of the peer side HA VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field can be used when creating highly available VPN from VPC network to VPC network, the field is exclusive with the field peerExternalGateway. If provided, the VPN tunnel will automatically use the same vpnGatewayInterface ID in the peer Google Cloud VPN gateway. Corresponds to the JSON property peerGcpGateway

Returns:

  • (String)


68945
68946
68947
# File 'lib/google/apis/compute_v1/classes.rb', line 68945

def peer_gcp_gateway
  @peer_gcp_gateway
end

#peer_ipString

IP address of the peer VPN gateway. Only IPv4 is supported. This field can be set only for Classic VPN tunnels. Corresponds to the JSON property peerIp

Returns:

  • (String)


68951
68952
68953
# File 'lib/google/apis/compute_v1/classes.rb', line 68951

def peer_ip
  @peer_ip
end

#regionString

[Output Only] URL of the region where the VPN tunnel resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


68958
68959
68960
# File 'lib/google/apis/compute_v1/classes.rb', line 68958

def region
  @region
end

#remote_traffic_selectorArray<String>

Remote traffic selectors to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges should be disjoint. Only IPv4 is supported for Classic VPN tunnels. This field is output only for HA VPN tunnels. Corresponds to the JSON property remoteTrafficSelector

Returns:

  • (Array<String>)


68967
68968
68969
# File 'lib/google/apis/compute_v1/classes.rb', line 68967

def remote_traffic_selector
  @remote_traffic_selector
end

#routerString

URL of the router resource to be used for dynamic routing. Corresponds to the JSON property router

Returns:

  • (String)


68972
68973
68974
# File 'lib/google/apis/compute_v1/classes.rb', line 68972

def router
  @router
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68977
68978
68979
# File 'lib/google/apis/compute_v1/classes.rb', line 68977

def self_link
  @self_link
end

#shared_secretString

Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway. Corresponds to the JSON property sharedSecret

Returns:

  • (String)


68983
68984
68985
# File 'lib/google/apis/compute_v1/classes.rb', line 68983

def shared_secret
  @shared_secret
end

#shared_secret_hashString

Hash of the shared secret. Corresponds to the JSON property sharedSecretHash

Returns:

  • (String)


68988
68989
68990
# File 'lib/google/apis/compute_v1/classes.rb', line 68988

def shared_secret_hash
  @shared_secret_hash
end

#statusString

[Output Only] The status of the VPN tunnel, which can be one of the following:

  • PROVISIONING: Resource is being allocated for the VPN tunnel.
  • WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route resources are needed to setup the VPN tunnel.
  • FIRST_HANDSHAKE: Successful first handshake with the peer VPN.
  • ESTABLISHED: Secure session is successfully established with the peer VPN.
  • NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS
  • AUTHORIZATION_ERROR: Auth error (for example, bad shared secret).
  • NEGOTIATION_FAILURE: Handshake failed.
  • DEPROVISIONING: Resources are being deallocated for the VPN tunnel.
  • FAILED: Tunnel creation has failed and the tunnel is not ready to be used.
  • NO_INCOMING_PACKETS: No incoming packets from peer.
  • REJECTED: Tunnel configuration was rejected, can be result of being denied access.
  • ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all required resources.
  • STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for Classic VPN tunnels or the project is in frozen state.
  • PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably behind NAT.
  • TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not allowed for an HA-VPN tunnel. Corresponds to the JSON property status

Returns:

  • (String)


69024
69025
69026
# File 'lib/google/apis/compute_v1/classes.rb', line 69024

def status
  @status
end

#target_vpn_gatewayString

URL of the Target VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created. This field can be set only for Classic VPN tunnels. Corresponds to the JSON property targetVpnGateway

Returns:

  • (String)


69031
69032
69033
# File 'lib/google/apis/compute_v1/classes.rb', line 69031

def target_vpn_gateway
  @target_vpn_gateway
end

#vpn_gatewayString

URL of the VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created. This must be used (instead of target_vpn_gateway) if a High Availability VPN gateway resource is created. Corresponds to the JSON property vpnGateway

Returns:

  • (String)


69039
69040
69041
# File 'lib/google/apis/compute_v1/classes.rb', line 69039

def vpn_gateway
  @vpn_gateway
end

#vpn_gateway_interfaceFixnum

The interface ID of the VPN gateway with which this VPN tunnel is associated. Possible values are: 0, 1. Corresponds to the JSON property vpnGatewayInterface

Returns:

  • (Fixnum)


69046
69047
69048
# File 'lib/google/apis/compute_v1/classes.rb', line 69046

def vpn_gateway_interface
  @vpn_gateway_interface
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69053
69054
69055
69056
69057
69058
69059
69060
69061
69062
69063
69064
69065
69066
69067
69068
69069
69070
69071
69072
69073
69074
69075
69076
69077
69078
69079
69080
# File 'lib/google/apis/compute_v1/classes.rb', line 69053

def update!(**args)
  @cipher_suite = args[:cipher_suite] if args.key?(:cipher_suite)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @detailed_status = args[:detailed_status] if args.key?(:detailed_status)
  @id = args[:id] if args.key?(:id)
  @ike_version = args[:ike_version] if args.key?(:ike_version)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @local_traffic_selector = args[:local_traffic_selector] if args.key?(:local_traffic_selector)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway)
  @peer_external_gateway_interface = args[:peer_external_gateway_interface] if args.key?(:peer_external_gateway_interface)
  @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway)
  @peer_ip = args[:peer_ip] if args.key?(:peer_ip)
  @region = args[:region] if args.key?(:region)
  @remote_traffic_selector = args[:remote_traffic_selector] if args.key?(:remote_traffic_selector)
  @router = args[:router] if args.key?(:router)
  @self_link = args[:self_link] if args.key?(:self_link)
  @shared_secret = args[:shared_secret] if args.key?(:shared_secret)
  @shared_secret_hash = args[:shared_secret_hash] if args.key?(:shared_secret_hash)
  @status = args[:status] if args.key?(:status)
  @target_vpn_gateway = args[:target_vpn_gateway] if args.key?(:target_vpn_gateway)
  @vpn_gateway = args[:vpn_gateway] if args.key?(:vpn_gateway)
  @vpn_gateway_interface = args[:vpn_gateway_interface] if args.key?(:vpn_gateway_interface)
end