Class: Google::Apis::ComputeV1::VpnTunnel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Cloud VPN Tunnel resource. For more information about VPN, read the the Cloud VPN Overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnel

Returns a new instance of VpnTunnel.



69007
69008
69009
# File 'lib/google/apis/compute_v1/classes.rb', line 69007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cipher_suiteGoogle::Apis::ComputeV1::VpnTunnelCipherSuite

User specified list of ciphers to use for the phase 1 and phase 2 of the IKE protocol. Corresponds to the JSON property cipherSuite



68795
68796
68797
# File 'lib/google/apis/compute_v1/classes.rb', line 68795

def cipher_suite
  @cipher_suite
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


68801
68802
68803
# File 'lib/google/apis/compute_v1/classes.rb', line 68801

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


68807
68808
68809
# File 'lib/google/apis/compute_v1/classes.rb', line 68807

def description
  @description
end

#detailed_statusString

[Output Only] Detailed status message for the VPN tunnel. Corresponds to the JSON property detailedStatus

Returns:

  • (String)


68812
68813
68814
# File 'lib/google/apis/compute_v1/classes.rb', line 68812

def detailed_status
  @detailed_status
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


68818
68819
68820
# File 'lib/google/apis/compute_v1/classes.rb', line 68818

def id
  @id
end

#ike_versionFixnum

IKE protocol version to use when establishing the VPN tunnel with the peer VPN gateway. Acceptable IKE versions are 1 or 2. The default version is 2. Corresponds to the JSON property ikeVersion

Returns:

  • (Fixnum)


68825
68826
68827
# File 'lib/google/apis/compute_v1/classes.rb', line 68825

def ike_version
  @ike_version
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


68831
68832
68833
# File 'lib/google/apis/compute_v1/classes.rb', line 68831

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this VpnTunnel, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a VpnTunnel. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


68844
68845
68846
# File 'lib/google/apis/compute_v1/classes.rb', line 68844

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


68851
68852
68853
# File 'lib/google/apis/compute_v1/classes.rb', line 68851

def labels
  @labels
end

#local_traffic_selectorArray<String>

Local traffic selector to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges must be disjoint. Only IPv4 is supported for Classic VPN tunnels. This field is output only for HA VPN tunnels. Corresponds to the JSON property localTrafficSelector

Returns:

  • (Array<String>)


68860
68861
68862
# File 'lib/google/apis/compute_v1/classes.rb', line 68860

def local_traffic_selector
  @local_traffic_selector
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


68871
68872
68873
# File 'lib/google/apis/compute_v1/classes.rb', line 68871

def name
  @name
end

#paramsGoogle::Apis::ComputeV1::VpnTunnelParams

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload. Corresponds to the JSON property params



68878
68879
68880
# File 'lib/google/apis/compute_v1/classes.rb', line 68878

def params
  @params
end

#peer_external_gatewayString

URL of the peer side external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field is exclusive with the field peerGcpGateway. Corresponds to the JSON property peerExternalGateway

Returns:

  • (String)


68886
68887
68888
# File 'lib/google/apis/compute_v1/classes.rb', line 68886

def peer_external_gateway
  @peer_external_gateway
end

#peer_external_gateway_interfaceFixnum

The interface ID of the external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. Possible values are: 0, 1, 2, 3. The number of IDs in use depends on the external VPN gateway redundancy type. Corresponds to the JSON property peerExternalGatewayInterface

Returns:

  • (Fixnum)


68894
68895
68896
# File 'lib/google/apis/compute_v1/classes.rb', line 68894

def peer_external_gateway_interface
  @peer_external_gateway_interface
end

#peer_gcp_gatewayString

URL of the peer side HA VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field can be used when creating highly available VPN from VPC network to VPC network, the field is exclusive with the field peerExternalGateway. If provided, the VPN tunnel will automatically use the same vpnGatewayInterface ID in the peer Google Cloud VPN gateway. Corresponds to the JSON property peerGcpGateway

Returns:

  • (String)


68904
68905
68906
# File 'lib/google/apis/compute_v1/classes.rb', line 68904

def peer_gcp_gateway
  @peer_gcp_gateway
end

#peer_ipString

IP address of the peer VPN gateway. Only IPv4 is supported. This field can be set only for Classic VPN tunnels. Corresponds to the JSON property peerIp

Returns:

  • (String)


68910
68911
68912
# File 'lib/google/apis/compute_v1/classes.rb', line 68910

def peer_ip
  @peer_ip
end

#regionString

[Output Only] URL of the region where the VPN tunnel resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


68917
68918
68919
# File 'lib/google/apis/compute_v1/classes.rb', line 68917

def region
  @region
end

#remote_traffic_selectorArray<String>

Remote traffic selectors to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges should be disjoint. Only IPv4 is supported for Classic VPN tunnels. This field is output only for HA VPN tunnels. Corresponds to the JSON property remoteTrafficSelector

Returns:

  • (Array<String>)


68926
68927
68928
# File 'lib/google/apis/compute_v1/classes.rb', line 68926

def remote_traffic_selector
  @remote_traffic_selector
end

#routerString

URL of the router resource to be used for dynamic routing. Corresponds to the JSON property router

Returns:

  • (String)


68931
68932
68933
# File 'lib/google/apis/compute_v1/classes.rb', line 68931

def router
  @router
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68936
68937
68938
# File 'lib/google/apis/compute_v1/classes.rb', line 68936

def self_link
  @self_link
end

#shared_secretString

Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway. Corresponds to the JSON property sharedSecret

Returns:

  • (String)


68942
68943
68944
# File 'lib/google/apis/compute_v1/classes.rb', line 68942

def shared_secret
  @shared_secret
end

#shared_secret_hashString

Hash of the shared secret. Corresponds to the JSON property sharedSecretHash

Returns:

  • (String)


68947
68948
68949
# File 'lib/google/apis/compute_v1/classes.rb', line 68947

def shared_secret_hash
  @shared_secret_hash
end

#statusString

[Output Only] The status of the VPN tunnel, which can be one of the following:

  • PROVISIONING: Resource is being allocated for the VPN tunnel.
  • WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route resources are needed to setup the VPN tunnel.
  • FIRST_HANDSHAKE: Successful first handshake with the peer VPN.
  • ESTABLISHED: Secure session is successfully established with the peer VPN.
  • NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS
  • AUTHORIZATION_ERROR: Auth error (for example, bad shared secret).
  • NEGOTIATION_FAILURE: Handshake failed.
  • DEPROVISIONING: Resources are being deallocated for the VPN tunnel.
  • FAILED: Tunnel creation has failed and the tunnel is not ready to be used.
  • NO_INCOMING_PACKETS: No incoming packets from peer.
  • REJECTED: Tunnel configuration was rejected, can be result of being denied access.
  • ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all required resources.
  • STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for Classic VPN tunnels or the project is in frozen state.
  • PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably behind NAT.
  • TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not allowed for an HA-VPN tunnel. Corresponds to the JSON property status

Returns:

  • (String)


68983
68984
68985
# File 'lib/google/apis/compute_v1/classes.rb', line 68983

def status
  @status
end

#target_vpn_gatewayString

URL of the Target VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created. This field can be set only for Classic VPN tunnels. Corresponds to the JSON property targetVpnGateway

Returns:

  • (String)


68990
68991
68992
# File 'lib/google/apis/compute_v1/classes.rb', line 68990

def target_vpn_gateway
  @target_vpn_gateway
end

#vpn_gatewayString

URL of the VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created. This must be used (instead of target_vpn_gateway) if a High Availability VPN gateway resource is created. Corresponds to the JSON property vpnGateway

Returns:

  • (String)


68998
68999
69000
# File 'lib/google/apis/compute_v1/classes.rb', line 68998

def vpn_gateway
  @vpn_gateway
end

#vpn_gateway_interfaceFixnum

The interface ID of the VPN gateway with which this VPN tunnel is associated. Possible values are: 0, 1. Corresponds to the JSON property vpnGatewayInterface

Returns:

  • (Fixnum)


69005
69006
69007
# File 'lib/google/apis/compute_v1/classes.rb', line 69005

def vpn_gateway_interface
  @vpn_gateway_interface
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69012
69013
69014
69015
69016
69017
69018
69019
69020
69021
69022
69023
69024
69025
69026
69027
69028
69029
69030
69031
69032
69033
69034
69035
69036
69037
69038
69039
# File 'lib/google/apis/compute_v1/classes.rb', line 69012

def update!(**args)
  @cipher_suite = args[:cipher_suite] if args.key?(:cipher_suite)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @detailed_status = args[:detailed_status] if args.key?(:detailed_status)
  @id = args[:id] if args.key?(:id)
  @ike_version = args[:ike_version] if args.key?(:ike_version)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @local_traffic_selector = args[:local_traffic_selector] if args.key?(:local_traffic_selector)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway)
  @peer_external_gateway_interface = args[:peer_external_gateway_interface] if args.key?(:peer_external_gateway_interface)
  @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway)
  @peer_ip = args[:peer_ip] if args.key?(:peer_ip)
  @region = args[:region] if args.key?(:region)
  @remote_traffic_selector = args[:remote_traffic_selector] if args.key?(:remote_traffic_selector)
  @router = args[:router] if args.key?(:router)
  @self_link = args[:self_link] if args.key?(:self_link)
  @shared_secret = args[:shared_secret] if args.key?(:shared_secret)
  @shared_secret_hash = args[:shared_secret_hash] if args.key?(:shared_secret_hash)
  @status = args[:status] if args.key?(:status)
  @target_vpn_gateway = args[:target_vpn_gateway] if args.key?(:target_vpn_gateway)
  @vpn_gateway = args[:vpn_gateway] if args.key?(:vpn_gateway)
  @vpn_gateway_interface = args[:vpn_gateway_interface] if args.key?(:vpn_gateway_interface)
end