Class: Google::Apis::ComputeV1::VpnTunnel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Represents a Cloud VPN Tunnel resource. For more information about VPN, read the the Cloud VPN Overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnel

Returns a new instance of VpnTunnel.



62926
62927
62928
# File 'lib/google/apis/compute_v1/classes.rb', line 62926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cipher_suiteGoogle::Apis::ComputeV1::VpnTunnelCipherSuite

User specified list of ciphers to use for the phase 1 and phase 2 of the IKE protocol. Corresponds to the JSON property cipherSuite



62714
62715
62716
# File 'lib/google/apis/compute_v1/classes.rb', line 62714

def cipher_suite
  @cipher_suite
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


62720
62721
62722
# File 'lib/google/apis/compute_v1/classes.rb', line 62720

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


62726
62727
62728
# File 'lib/google/apis/compute_v1/classes.rb', line 62726

def description
  @description
end

#detailed_statusString

[Output Only] Detailed status message for the VPN tunnel. Corresponds to the JSON property detailedStatus

Returns:

  • (String)


62731
62732
62733
# File 'lib/google/apis/compute_v1/classes.rb', line 62731

def detailed_status
  @detailed_status
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


62737
62738
62739
# File 'lib/google/apis/compute_v1/classes.rb', line 62737

def id
  @id
end

#ike_versionFixnum

IKE protocol version to use when establishing the VPN tunnel with the peer VPN gateway. Acceptable IKE versions are 1 or 2. The default version is 2. Corresponds to the JSON property ikeVersion

Returns:

  • (Fixnum)


62744
62745
62746
# File 'lib/google/apis/compute_v1/classes.rb', line 62744

def ike_version
  @ike_version
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


62750
62751
62752
# File 'lib/google/apis/compute_v1/classes.rb', line 62750

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this VpnTunnel, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a VpnTunnel. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


62763
62764
62765
# File 'lib/google/apis/compute_v1/classes.rb', line 62763

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


62770
62771
62772
# File 'lib/google/apis/compute_v1/classes.rb', line 62770

def labels
  @labels
end

#local_traffic_selectorArray<String>

Local traffic selector to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges must be disjoint. Only IPv4 is supported for Classic VPN tunnels. This field is output only for HA VPN tunnels. Corresponds to the JSON property localTrafficSelector

Returns:

  • (Array<String>)


62779
62780
62781
# File 'lib/google/apis/compute_v1/classes.rb', line 62779

def local_traffic_selector
  @local_traffic_selector
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


62790
62791
62792
# File 'lib/google/apis/compute_v1/classes.rb', line 62790

def name
  @name
end

#paramsGoogle::Apis::ComputeV1::VpnTunnelParams

Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload. Corresponds to the JSON property params



62797
62798
62799
# File 'lib/google/apis/compute_v1/classes.rb', line 62797

def params
  @params
end

#peer_external_gatewayString

URL of the peer side external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field is exclusive with the field peerGcpGateway. Corresponds to the JSON property peerExternalGateway

Returns:

  • (String)


62805
62806
62807
# File 'lib/google/apis/compute_v1/classes.rb', line 62805

def peer_external_gateway
  @peer_external_gateway
end

#peer_external_gateway_interfaceFixnum

The interface ID of the external VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. Possible values are: 0, 1, 2, 3. The number of IDs in use depends on the external VPN gateway redundancy type. Corresponds to the JSON property peerExternalGatewayInterface

Returns:

  • (Fixnum)


62813
62814
62815
# File 'lib/google/apis/compute_v1/classes.rb', line 62813

def peer_external_gateway_interface
  @peer_external_gateway_interface
end

#peer_gcp_gatewayString

URL of the peer side HA VPN gateway to which this VPN tunnel is connected. Provided by the client when the VPN tunnel is created. This field can be used when creating highly available VPN from VPC network to VPC network, the field is exclusive with the field peerExternalGateway. If provided, the VPN tunnel will automatically use the same vpnGatewayInterface ID in the peer Google Cloud VPN gateway. Corresponds to the JSON property peerGcpGateway

Returns:

  • (String)


62823
62824
62825
# File 'lib/google/apis/compute_v1/classes.rb', line 62823

def peer_gcp_gateway
  @peer_gcp_gateway
end

#peer_ipString

IP address of the peer VPN gateway. Only IPv4 is supported. This field can be set only for Classic VPN tunnels. Corresponds to the JSON property peerIp

Returns:

  • (String)


62829
62830
62831
# File 'lib/google/apis/compute_v1/classes.rb', line 62829

def peer_ip
  @peer_ip
end

#regionString

[Output Only] URL of the region where the VPN tunnel resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


62836
62837
62838
# File 'lib/google/apis/compute_v1/classes.rb', line 62836

def region
  @region
end

#remote_traffic_selectorArray<String>

Remote traffic selectors to use when establishing the VPN tunnel with the peer VPN gateway. The value should be a CIDR formatted string, for example: 192.168.0.0/16. The ranges should be disjoint. Only IPv4 is supported for Classic VPN tunnels. This field is output only for HA VPN tunnels. Corresponds to the JSON property remoteTrafficSelector

Returns:

  • (Array<String>)


62845
62846
62847
# File 'lib/google/apis/compute_v1/classes.rb', line 62845

def remote_traffic_selector
  @remote_traffic_selector
end

#routerString

URL of the router resource to be used for dynamic routing. Corresponds to the JSON property router

Returns:

  • (String)


62850
62851
62852
# File 'lib/google/apis/compute_v1/classes.rb', line 62850

def router
  @router
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62855
62856
62857
# File 'lib/google/apis/compute_v1/classes.rb', line 62855

def self_link
  @self_link
end

#shared_secretString

Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway. Corresponds to the JSON property sharedSecret

Returns:

  • (String)


62861
62862
62863
# File 'lib/google/apis/compute_v1/classes.rb', line 62861

def shared_secret
  @shared_secret
end

#shared_secret_hashString

Hash of the shared secret. Corresponds to the JSON property sharedSecretHash

Returns:

  • (String)


62866
62867
62868
# File 'lib/google/apis/compute_v1/classes.rb', line 62866

def shared_secret_hash
  @shared_secret_hash
end

#statusString

[Output Only] The status of the VPN tunnel, which can be one of the following:

  • PROVISIONING: Resource is being allocated for the VPN tunnel.
  • WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route resources are needed to setup the VPN tunnel.
  • FIRST_HANDSHAKE: Successful first handshake with the peer VPN.
  • ESTABLISHED: Secure session is successfully established with the peer VPN.
  • NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS
  • AUTHORIZATION_ERROR: Auth error (for example, bad shared secret).
  • NEGOTIATION_FAILURE: Handshake failed.
  • DEPROVISIONING: Resources are being deallocated for the VPN tunnel.
  • FAILED: Tunnel creation has failed and the tunnel is not ready to be used.
  • NO_INCOMING_PACKETS: No incoming packets from peer.
  • REJECTED: Tunnel configuration was rejected, can be result of being denied access.
  • ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all required resources.
  • STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for Classic VPN tunnels or the project is in frozen state.
  • PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably behind NAT.
  • TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not allowed for an HA-VPN tunnel. Corresponds to the JSON property status

Returns:

  • (String)


62902
62903
62904
# File 'lib/google/apis/compute_v1/classes.rb', line 62902

def status
  @status
end

#target_vpn_gatewayString

URL of the Target VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created. This field can be set only for Classic VPN tunnels. Corresponds to the JSON property targetVpnGateway

Returns:

  • (String)


62909
62910
62911
# File 'lib/google/apis/compute_v1/classes.rb', line 62909

def target_vpn_gateway
  @target_vpn_gateway
end

#vpn_gatewayString

URL of the VPN gateway with which this VPN tunnel is associated. Provided by the client when the VPN tunnel is created. This must be used (instead of target_vpn_gateway) if a High Availability VPN gateway resource is created. Corresponds to the JSON property vpnGateway

Returns:

  • (String)


62917
62918
62919
# File 'lib/google/apis/compute_v1/classes.rb', line 62917

def vpn_gateway
  @vpn_gateway
end

#vpn_gateway_interfaceFixnum

The interface ID of the VPN gateway with which this VPN tunnel is associated. Possible values are: 0, 1. Corresponds to the JSON property vpnGatewayInterface

Returns:

  • (Fixnum)


62924
62925
62926
# File 'lib/google/apis/compute_v1/classes.rb', line 62924

def vpn_gateway_interface
  @vpn_gateway_interface
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
62944
62945
62946
62947
62948
62949
62950
62951
62952
62953
62954
62955
62956
62957
62958
# File 'lib/google/apis/compute_v1/classes.rb', line 62931

def update!(**args)
  @cipher_suite = args[:cipher_suite] if args.key?(:cipher_suite)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @detailed_status = args[:detailed_status] if args.key?(:detailed_status)
  @id = args[:id] if args.key?(:id)
  @ike_version = args[:ike_version] if args.key?(:ike_version)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @local_traffic_selector = args[:local_traffic_selector] if args.key?(:local_traffic_selector)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway)
  @peer_external_gateway_interface = args[:peer_external_gateway_interface] if args.key?(:peer_external_gateway_interface)
  @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway)
  @peer_ip = args[:peer_ip] if args.key?(:peer_ip)
  @region = args[:region] if args.key?(:region)
  @remote_traffic_selector = args[:remote_traffic_selector] if args.key?(:remote_traffic_selector)
  @router = args[:router] if args.key?(:router)
  @self_link = args[:self_link] if args.key?(:self_link)
  @shared_secret = args[:shared_secret] if args.key?(:shared_secret)
  @shared_secret_hash = args[:shared_secret_hash] if args.key?(:shared_secret_hash)
  @status = args[:status] if args.key?(:status)
  @target_vpn_gateway = args[:target_vpn_gateway] if args.key?(:target_vpn_gateway)
  @vpn_gateway = args[:vpn_gateway] if args.key?(:vpn_gateway)
  @vpn_gateway_interface = args[:vpn_gateway_interface] if args.key?(:vpn_gateway_interface)
end