Class: Google::Apis::ComputeV1::VpnTunnel
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnTunnel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Represents a Cloud VPN Tunnel resource. For more information about VPN, read the the Cloud VPN Overview.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#detailed_status ⇒ String
[Output Only] Detailed status message for the VPN tunnel.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#ike_version ⇒ Fixnum
IKE protocol version to use when establishing the VPN tunnel with the peer VPN gateway.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#local_traffic_selector ⇒ Array<String>
Local traffic selector to use when establishing the VPN tunnel with the peer VPN gateway.
-
#name ⇒ String
Name of the resource.
-
#peer_external_gateway ⇒ String
URL of the peer side external VPN gateway to which this VPN tunnel is connected.
-
#peer_external_gateway_interface ⇒ Fixnum
The interface ID of the external VPN gateway to which this VPN tunnel is connected.
-
#peer_gcp_gateway ⇒ String
URL of the peer side HA GCP VPN gateway to which this VPN tunnel is connected.
-
#peer_ip ⇒ String
IP address of the peer VPN gateway.
-
#region ⇒ String
[Output Only] URL of the region where the VPN tunnel resides.
-
#remote_traffic_selector ⇒ Array<String>
Remote traffic selectors to use when establishing the VPN tunnel with the peer VPN gateway.
-
#router ⇒ String
URL of the router resource to be used for dynamic routing.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#shared_secret ⇒ String
Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway.
-
#shared_secret_hash ⇒ String
Hash of the shared secret.
-
#status ⇒ String
[Output Only] The status of the VPN tunnel, which can be one of the following: - PROVISIONING: Resource is being allocated for the VPN tunnel.
-
#target_vpn_gateway ⇒ String
URL of the Target VPN gateway with which this VPN tunnel is associated.
-
#vpn_gateway ⇒ String
URL of the VPN gateway with which this VPN tunnel is associated.
-
#vpn_gateway_interface ⇒ Fixnum
The interface ID of the VPN gateway with which this VPN tunnel is associated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnel
constructor
A new instance of VpnTunnel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnel
Returns a new instance of VpnTunnel.
39555 39556 39557 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
39405 39406 39407 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39405 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
39411 39412 39413 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39411 def description @description end |
#detailed_status ⇒ String
[Output Only] Detailed status message for the VPN tunnel.
Corresponds to the JSON property detailedStatus
39416 39417 39418 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39416 def detailed_status @detailed_status end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
39422 39423 39424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39422 def id @id end |
#ike_version ⇒ Fixnum
IKE protocol version to use when establishing the VPN tunnel with the peer VPN
gateway. Acceptable IKE versions are 1 or 2. The default version is 2.
Corresponds to the JSON property ikeVersion
39428 39429 39430 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39428 def ike_version @ike_version end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels.
Corresponds to the JSON property kind
39433 39434 39435 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39433 def kind @kind end |
#local_traffic_selector ⇒ Array<String>
Local traffic selector to use when establishing the VPN tunnel with the peer
VPN gateway. The value should be a CIDR formatted string, for example: 192.168.
0.0/16. The ranges must be disjoint. Only IPv4 is supported.
Corresponds to the JSON property localTrafficSelector
39440 39441 39442 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39440 def local_traffic_selector @local_traffic_selector end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression [a-z]([-a-
z0-9]*[a-z0-9])? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
39450 39451 39452 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39450 def name @name end |
#peer_external_gateway ⇒ String
URL of the peer side external VPN gateway to which this VPN tunnel is
connected. Provided by the client when the VPN tunnel is created. This field
is exclusive with the field peerGcpGateway.
Corresponds to the JSON property peerExternalGateway
39457 39458 39459 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39457 def peer_external_gateway @peer_external_gateway end |
#peer_external_gateway_interface ⇒ Fixnum
The interface ID of the external VPN gateway to which this VPN tunnel is
connected. Provided by the client when the VPN tunnel is created.
Corresponds to the JSON property peerExternalGatewayInterface
39463 39464 39465 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39463 def peer_external_gateway_interface @peer_external_gateway_interface end |
#peer_gcp_gateway ⇒ String
URL of the peer side HA GCP VPN gateway to which this VPN tunnel is connected.
Provided by the client when the VPN tunnel is created. This field can be used
when creating highly available VPN from VPC network to VPC network, the field
is exclusive with the field peerExternalGateway. If provided, the VPN tunnel
will automatically use the same vpnGatewayInterface ID in the peer GCP VPN
gateway.
Corresponds to the JSON property peerGcpGateway
39473 39474 39475 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39473 def peer_gcp_gateway @peer_gcp_gateway end |
#peer_ip ⇒ String
IP address of the peer VPN gateway. Only IPv4 is supported.
Corresponds to the JSON property peerIp
39478 39479 39480 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39478 def peer_ip @peer_ip end |
#region ⇒ String
[Output Only] URL of the region where the VPN tunnel resides. You must specify
this field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
39485 39486 39487 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39485 def region @region end |
#remote_traffic_selector ⇒ Array<String>
Remote traffic selectors to use when establishing the VPN tunnel with the peer
VPN gateway. The value should be a CIDR formatted string, for example: 192.168.
0.0/16. The ranges should be disjoint. Only IPv4 is supported.
Corresponds to the JSON property remoteTrafficSelector
39492 39493 39494 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39492 def remote_traffic_selector @remote_traffic_selector end |
#router ⇒ String
URL of the router resource to be used for dynamic routing.
Corresponds to the JSON property router
39497 39498 39499 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39497 def router @router end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
39502 39503 39504 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39502 def self_link @self_link end |
#shared_secret ⇒ String
Shared secret used to set the secure session between the Cloud VPN gateway and
the peer VPN gateway.
Corresponds to the JSON property sharedSecret
39508 39509 39510 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39508 def shared_secret @shared_secret end |
#shared_secret_hash ⇒ String
Hash of the shared secret.
Corresponds to the JSON property sharedSecretHash
39513 39514 39515 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39513 def shared_secret_hash @shared_secret_hash end |
#status ⇒ String
[Output Only] The status of the VPN tunnel, which can be one of the following:
- PROVISIONING: Resource is being allocated for the VPN tunnel. -
WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the
user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route
resources are needed to setup the VPN tunnel. - FIRST_HANDSHAKE: Successful
first handshake with the peer VPN. - ESTABLISHED: Secure session is
successfully established with the peer VPN. - NETWORK_ERROR: Deprecated,
replaced by NO_INCOMING_PACKETS - AUTHORIZATION_ERROR: Auth error (for example,
bad shared secret). - NEGOTIATION_FAILURE: Handshake failed. - DEPROVISIONING:
Resources are being deallocated for the VPN tunnel. - FAILED: Tunnel creation
has failed and the tunnel is not ready to be used. - NO_INCOMING_PACKETS: No
incoming packets from peer. - REJECTED: Tunnel configuration was rejected, can
be result of being denied access. - ALLOCATING_RESOURCES: Cloud VPN is in the
process of allocating all required resources. - STOPPED: Tunnel is stopped due
to its Forwarding Rules being deleted for Classic VPN tunnels or the project
is in frozen state. - PEER_IDENTITY_MISMATCH: Peer identity does not match
peer IP, probably behind NAT. - TS_NARROWING_NOT_ALLOWED: Traffic selector
narrowing not allowed for an HA-VPN tunnel.
Corresponds to the JSON property
status
39535 39536 39537 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39535 def status @status end |
#target_vpn_gateway ⇒ String
URL of the Target VPN gateway with which this VPN tunnel is associated.
Provided by the client when the VPN tunnel is created.
Corresponds to the JSON property targetVpnGateway
39541 39542 39543 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39541 def target_vpn_gateway @target_vpn_gateway end |
#vpn_gateway ⇒ String
URL of the VPN gateway with which this VPN tunnel is associated. Provided by
the client when the VPN tunnel is created. This must be used (instead of
target_vpn_gateway) if a High Availability VPN gateway resource is created.
Corresponds to the JSON property vpnGateway
39548 39549 39550 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39548 def vpn_gateway @vpn_gateway end |
#vpn_gateway_interface ⇒ Fixnum
The interface ID of the VPN gateway with which this VPN tunnel is associated.
Corresponds to the JSON property vpnGatewayInterface
39553 39554 39555 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39553 def vpn_gateway_interface @vpn_gateway_interface end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39560 39561 39562 39563 39564 39565 39566 39567 39568 39569 39570 39571 39572 39573 39574 39575 39576 39577 39578 39579 39580 39581 39582 39583 |
# File 'lib/google/apis/compute_v1/classes.rb', line 39560 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @detailed_status = args[:detailed_status] if args.key?(:detailed_status) @id = args[:id] if args.key?(:id) @ike_version = args[:ike_version] if args.key?(:ike_version) @kind = args[:kind] if args.key?(:kind) @local_traffic_selector = args[:local_traffic_selector] if args.key?(:local_traffic_selector) @name = args[:name] if args.key?(:name) @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway) @peer_external_gateway_interface = args[:peer_external_gateway_interface] if args.key?(:peer_external_gateway_interface) @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway) @peer_ip = args[:peer_ip] if args.key?(:peer_ip) @region = args[:region] if args.key?(:region) @remote_traffic_selector = args[:remote_traffic_selector] if args.key?(:remote_traffic_selector) @router = args[:router] if args.key?(:router) @self_link = args[:self_link] if args.key?(:self_link) @shared_secret = args[:shared_secret] if args.key?(:shared_secret) @shared_secret_hash = args[:shared_secret_hash] if args.key?(:shared_secret_hash) @status = args[:status] if args.key?(:status) @target_vpn_gateway = args[:target_vpn_gateway] if args.key?(:target_vpn_gateway) @vpn_gateway = args[:vpn_gateway] if args.key?(:vpn_gateway) @vpn_gateway_interface = args[:vpn_gateway_interface] if args.key?(:vpn_gateway_interface) end |