Class: Google::Apis::ComputeV1::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



69128
69129
69130
# File 'lib/google/apis/compute_v1/classes.rb', line 69128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69090
69091
69092
# File 'lib/google/apis/compute_v1/classes.rb', line 69090

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



69095
69096
69097
# File 'lib/google/apis/compute_v1/classes.rb', line 69095

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


69101
69102
69103
# File 'lib/google/apis/compute_v1/classes.rb', line 69101

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69111
69112
69113
# File 'lib/google/apis/compute_v1/classes.rb', line 69111

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69116
69117
69118
# File 'lib/google/apis/compute_v1/classes.rb', line 69116

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69121
69122
69123
# File 'lib/google/apis/compute_v1/classes.rb', line 69121

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69126
69127
69128
# File 'lib/google/apis/compute_v1/classes.rb', line 69126

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69133
69134
69135
69136
69137
69138
69139
69140
69141
# File 'lib/google/apis/compute_v1/classes.rb', line 69133

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end