Class: Google::Apis::ComputeV1::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



69087
69088
69089
# File 'lib/google/apis/compute_v1/classes.rb', line 69087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69049
69050
69051
# File 'lib/google/apis/compute_v1/classes.rb', line 69049

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



69054
69055
69056
# File 'lib/google/apis/compute_v1/classes.rb', line 69054

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


69060
69061
69062
# File 'lib/google/apis/compute_v1/classes.rb', line 69060

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69070
69071
69072
# File 'lib/google/apis/compute_v1/classes.rb', line 69070

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69075
69076
69077
# File 'lib/google/apis/compute_v1/classes.rb', line 69075

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69080
69081
69082
# File 'lib/google/apis/compute_v1/classes.rb', line 69080

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69085
69086
69087
# File 'lib/google/apis/compute_v1/classes.rb', line 69085

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69092
69093
69094
69095
69096
69097
69098
69099
69100
# File 'lib/google/apis/compute_v1/classes.rb', line 69092

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end