Class: Google::Apis::ComputeV1::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



68723
68724
68725
# File 'lib/google/apis/compute_v1/classes.rb', line 68723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68685
68686
68687
# File 'lib/google/apis/compute_v1/classes.rb', line 68685

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



68690
68691
68692
# File 'lib/google/apis/compute_v1/classes.rb', line 68690

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


68696
68697
68698
# File 'lib/google/apis/compute_v1/classes.rb', line 68696

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68706
68707
68708
# File 'lib/google/apis/compute_v1/classes.rb', line 68706

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68711
68712
68713
# File 'lib/google/apis/compute_v1/classes.rb', line 68711

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68716
68717
68718
# File 'lib/google/apis/compute_v1/classes.rb', line 68716

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68721
68722
68723
# File 'lib/google/apis/compute_v1/classes.rb', line 68721

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68728
68729
68730
68731
68732
68733
68734
68735
68736
# File 'lib/google/apis/compute_v1/classes.rb', line 68728

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end