Class: Google::Apis::ComputeV1::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



63006
63007
63008
# File 'lib/google/apis/compute_v1/classes.rb', line 63006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62968
62969
62970
# File 'lib/google/apis/compute_v1/classes.rb', line 62968

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



62973
62974
62975
# File 'lib/google/apis/compute_v1/classes.rb', line 62973

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


62979
62980
62981
# File 'lib/google/apis/compute_v1/classes.rb', line 62979

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62989
62990
62991
# File 'lib/google/apis/compute_v1/classes.rb', line 62989

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62994
62995
62996
# File 'lib/google/apis/compute_v1/classes.rb', line 62994

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


62999
63000
63001
# File 'lib/google/apis/compute_v1/classes.rb', line 62999

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63004
63005
63006
# File 'lib/google/apis/compute_v1/classes.rb', line 63004

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63011
63012
63013
63014
63015
63016
63017
63018
63019
# File 'lib/google/apis/compute_v1/classes.rb', line 63011

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end