Class: Google::Apis::ComputeV1::VpnTunnelList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of VpnTunnel resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelList

Returns a new instance of VpnTunnelList.



70467
70468
70469
# File 'lib/google/apis/compute_v1/classes.rb', line 70467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70434
70435
70436
# File 'lib/google/apis/compute_v1/classes.rb', line 70434

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::VpnTunnel>

A list of VpnTunnel resources. Corresponds to the JSON property items



70439
70440
70441
# File 'lib/google/apis/compute_v1/classes.rb', line 70439

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


70445
70446
70447
# File 'lib/google/apis/compute_v1/classes.rb', line 70445

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70455
70456
70457
# File 'lib/google/apis/compute_v1/classes.rb', line 70455

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70460
70461
70462
# File 'lib/google/apis/compute_v1/classes.rb', line 70460

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::VpnTunnelList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70465
70466
70467
# File 'lib/google/apis/compute_v1/classes.rb', line 70465

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70472
70473
70474
70475
70476
70477
70478
70479
# File 'lib/google/apis/compute_v1/classes.rb', line 70472

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end