Class: Google::Apis::ComputeV1::VpnTunnelList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of VpnTunnel resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelList

Returns a new instance of VpnTunnelList.



69636
69637
69638
# File 'lib/google/apis/compute_v1/classes.rb', line 69636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69603
69604
69605
# File 'lib/google/apis/compute_v1/classes.rb', line 69603

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::VpnTunnel>

A list of VpnTunnel resources. Corresponds to the JSON property items



69608
69609
69610
# File 'lib/google/apis/compute_v1/classes.rb', line 69608

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


69614
69615
69616
# File 'lib/google/apis/compute_v1/classes.rb', line 69614

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69624
69625
69626
# File 'lib/google/apis/compute_v1/classes.rb', line 69624

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69629
69630
69631
# File 'lib/google/apis/compute_v1/classes.rb', line 69629

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::VpnTunnelList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69634
69635
69636
# File 'lib/google/apis/compute_v1/classes.rb', line 69634

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69641
69642
69643
69644
69645
69646
69647
69648
# File 'lib/google/apis/compute_v1/classes.rb', line 69641

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end