Class: Google::Apis::ComputeV1::VpnTunnelList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnTunnelList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of VpnTunnel resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::VpnTunnel>
A list of VpnTunnel resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VpnTunnelList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelList
constructor
A new instance of VpnTunnelList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelList
Returns a new instance of VpnTunnelList.
68874 68875 68876 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
68841 68842 68843 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68841 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::VpnTunnel>
A list of VpnTunnel resources.
Corresponds to the JSON property items
68846 68847 68848 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68846 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnTunnel for
VPN tunnels.
Corresponds to the JSON property kind
68852 68853 68854 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68852 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
68862 68863 68864 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68862 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
68867 68868 68869 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68867 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::VpnTunnelList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
68872 68873 68874 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68872 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68879 68880 68881 68882 68883 68884 68885 68886 |
# File 'lib/google/apis/compute_v1/classes.rb', line 68879 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |