Class: Google::Apis::ComputeV1::VpnTunnelList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::VpnTunnelList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of VpnTunnel resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::VpnTunnel>
A list of VpnTunnel resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::VpnTunnelList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelList
constructor
A new instance of VpnTunnelList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelList
Returns a new instance of VpnTunnelList.
61865 61866 61867 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61865 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61832 61833 61834 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61832 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::VpnTunnel>
A list of VpnTunnel resources.
Corresponds to the JSON property items
61837 61838 61839 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61837 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnTunnel for
VPN tunnels.
Corresponds to the JSON property kind
61843 61844 61845 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61843 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61853 61854 61855 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61853 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
61858 61859 61860 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61858 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::VpnTunnelList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61863 61864 61865 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61863 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61870 61871 61872 61873 61874 61875 61876 61877 |
# File 'lib/google/apis/compute_v1/classes.rb', line 61870 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |