Class: Google::Apis::ComputeV1::VpnTunnelList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of VpnTunnel resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelList

Returns a new instance of VpnTunnelList.



39747
39748
39749
# File 'lib/google/apis/compute_v1/classes.rb', line 39747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39716
39717
39718
# File 'lib/google/apis/compute_v1/classes.rb', line 39716

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::VpnTunnel>

A list of VpnTunnel resources. Corresponds to the JSON property items



39721
39722
39723
# File 'lib/google/apis/compute_v1/classes.rb', line 39721

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


39726
39727
39728
# File 'lib/google/apis/compute_v1/classes.rb', line 39726

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39735
39736
39737
# File 'lib/google/apis/compute_v1/classes.rb', line 39735

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39740
39741
39742
# File 'lib/google/apis/compute_v1/classes.rb', line 39740

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::VpnTunnelList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39745
39746
39747
# File 'lib/google/apis/compute_v1/classes.rb', line 39745

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39752
39753
39754
39755
39756
39757
39758
39759
# File 'lib/google/apis/compute_v1/classes.rb', line 39752

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end