Class: Google::Apis::ComputeV1::WafExpressionSet
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::WafExpressionSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#aliases ⇒ Array<String>
A list of alternate IDs.
-
#expressions ⇒ Array<Google::Apis::ComputeV1::WafExpressionSetExpression>
List of available expressions.
-
#id ⇒ String
Google specified expression set ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WafExpressionSet
constructor
A new instance of WafExpressionSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WafExpressionSet
Returns a new instance of WafExpressionSet.
63465 63466 63467 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aliases ⇒ Array<String>
A list of alternate IDs. The format should be:
- E.g. XSS-stable
Generic suffix like "stable" is particularly useful if a policy
likes to avail newer set of expressions without having to change
the policy.
A given alias name can't be used for more than one entity set.
Corresponds to the JSON property
aliases
63451 63452 63453 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63451 def aliases @aliases end |
#expressions ⇒ Array<Google::Apis::ComputeV1::WafExpressionSetExpression>
List of available expressions.
Corresponds to the JSON property expressions
63456 63457 63458 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63456 def expressions @expressions end |
#id ⇒ String
Google specified expression set ID. The format should be:
- E.g. XSS-20170329
required
Corresponds to the JSON property
id
63463 63464 63465 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63463 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63470 63471 63472 63473 63474 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63470 def update!(**args) @aliases = args[:aliases] if args.key?(:aliases) @expressions = args[:expressions] if args.key?(:expressions) @id = args[:id] if args.key?(:id) end |