Class: Google::Apis::ComputeV1::WafExpressionSetExpression

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WafExpressionSetExpression

Returns a new instance of WafExpressionSetExpression.



69966
69967
69968
# File 'lib/google/apis/compute_v1/classes.rb', line 69966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Expression ID should uniquely identify the origin of the expression. E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set version 2.9.1 rule id 973337. The ID could be used to determine the individual attack definition that has been detected. It could also be used to exclude it from the policy in case of false positive. required Corresponds to the JSON property id

Returns:

  • (String)


69957
69958
69959
# File 'lib/google/apis/compute_v1/classes.rb', line 69957

def id
  @id
end

#sensitivityFixnum

The sensitivity value associated with the WAF rule ID. This corresponds to the ModSecurity paranoia level, ranging from 1 to 4. 0 is reserved for opt-in only rules. Corresponds to the JSON property sensitivity

Returns:

  • (Fixnum)


69964
69965
69966
# File 'lib/google/apis/compute_v1/classes.rb', line 69964

def sensitivity
  @sensitivity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69971
69972
69973
69974
# File 'lib/google/apis/compute_v1/classes.rb', line 69971

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @sensitivity = args[:sensitivity] if args.key?(:sensitivity)
end