Class: Google::Apis::ComputeV1::WafExpressionSetExpression

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WafExpressionSetExpression

Returns a new instance of WafExpressionSetExpression.



39965
39966
39967
# File 'lib/google/apis/compute_v1/classes.rb', line 39965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Expression ID should uniquely identify the origin of the expression. E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set version 2.9.1 rule id 973337. The ID could be used to determine the individual attack definition that has been detected. It could also be used to exclude it from the policy in case of false positive. required Corresponds to the JSON property id

Returns:

  • (String)


39963
39964
39965
# File 'lib/google/apis/compute_v1/classes.rb', line 39963

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39970
39971
39972
# File 'lib/google/apis/compute_v1/classes.rb', line 39970

def update!(**args)
  @id = args[:id] if args.key?(:id)
end