Class: Google::Apis::ComputeV1::WireGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::WireGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A resource that represents a group of redundant wires.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Indicates whether the wires in the wire group are enabled.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of the wire group.
-
#endpoints ⇒ Hash<String,Google::Apis::ComputeV1::WireGroupEndpoint>
A map that contains the logical endpoints of the wire group.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#self_link ⇒ String
Output only.
-
#topology ⇒ Google::Apis::ComputeV1::WireGroupTopology
Topology details for the wire group.
-
#wire_properties ⇒ Google::Apis::ComputeV1::WireProperties
The properties of a wire.
-
#wires ⇒ Array<Google::Apis::ComputeV1::Wire>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroup
constructor
A new instance of WireGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroup
Returns a new instance of WireGroup.
69423 69424 69425 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Indicates whether the wires in the wire group are enabled. When false, the
wires in the wire group are disabled. When true and when
there is simultaneously no wire-specific override of adminEnabled to
false, a given wire is enabled. Defaults to true.
Corresponds to the JSON property adminEnabled
69349 69350 69351 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69349 def admin_enabled @admin_enabled end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
69356 69357 69358 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69356 def @creation_timestamp end |
#description ⇒ String
An optional description of the wire group.
Corresponds to the JSON property description
69361 69362 69363 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69361 def description @description end |
#endpoints ⇒ Hash<String,Google::Apis::ComputeV1::WireGroupEndpoint>
A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:
- Key: an RFC1035 user-specified label.
- Value: an Endpoint object.
Corresponds to the JSON property
endpoints
69370 69371 69372 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69370 def endpoints @endpoints end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
69377 69378 69379 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69377 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
69383 69384 69385 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69383 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
69394 69395 69396 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69394 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. [Output Only] Indicates whether there are wire changes yet to be
processed.
Corresponds to the JSON property reconciling
69400 69401 69402 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69400 def reconciling @reconciling end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
69406 69407 69408 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69406 def self_link @self_link end |
#topology ⇒ Google::Apis::ComputeV1::WireGroupTopology
Topology details for the wire group.
Corresponds to the JSON property topology
69411 69412 69413 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69411 def topology @topology end |
#wire_properties ⇒ Google::Apis::ComputeV1::WireProperties
The properties of a wire.
Corresponds to the JSON property wireProperties
69416 69417 69418 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69416 def wire_properties @wire_properties end |
#wires ⇒ Array<Google::Apis::ComputeV1::Wire>
Output only. The single/redundant wire(s) managed by the wire group.
Corresponds to the JSON property wires
69421 69422 69423 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69421 def wires @wires end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69428 69429 69430 69431 69432 69433 69434 69435 69436 69437 69438 69439 69440 69441 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69428 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @endpoints = args[:endpoints] if args.key?(:endpoints) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @self_link = args[:self_link] if args.key?(:self_link) @topology = args[:topology] if args.key?(:topology) @wire_properties = args[:wire_properties] if args.key?(:wire_properties) @wires = args[:wires] if args.key?(:wires) end |