Class: Google::Apis::ComputeV1::WireGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::WireGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
A resource that represents a group of redundant wires.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Indicates whether the wires in the wire group are enabled.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of the wire group.
-
#endpoints ⇒ Hash<String,Google::Apis::ComputeV1::WireGroupEndpoint>
A map that contains the logical endpoints of the wire group.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#self_link ⇒ String
Output only.
-
#topology ⇒ Google::Apis::ComputeV1::WireGroupTopology
Topology details for the wire group.
-
#wire_properties ⇒ Google::Apis::ComputeV1::WireProperties
The properties of a wire.
-
#wires ⇒ Array<Google::Apis::ComputeV1::Wire>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroup
constructor
A new instance of WireGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroup
Returns a new instance of WireGroup.
67679 67680 67681 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Indicates whether the wires in the wire group are enabled. When false, the
wires in the wire group are disabled. When true and when
there is simultaneously no wire-specific override of adminEnabled to
false, a given wire is enabled. Defaults to true.
Corresponds to the JSON property adminEnabled
67605 67606 67607 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67605 def admin_enabled @admin_enabled end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
67612 67613 67614 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67612 def @creation_timestamp end |
#description ⇒ String
An optional description of the wire group.
Corresponds to the JSON property description
67617 67618 67619 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67617 def description @description end |
#endpoints ⇒ Hash<String,Google::Apis::ComputeV1::WireGroupEndpoint>
A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:
- Key: an RFC1035 user-specified label.
- Value: an Endpoint object.
Corresponds to the JSON property
endpoints
67626 67627 67628 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67626 def endpoints @endpoints end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
67633 67634 67635 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67633 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
67639 67640 67641 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67639 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
67650 67651 67652 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67650 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. [Output Only] Indicates whether there are wire changes yet to be
processed.
Corresponds to the JSON property reconciling
67656 67657 67658 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67656 def reconciling @reconciling end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
67662 67663 67664 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67662 def self_link @self_link end |
#topology ⇒ Google::Apis::ComputeV1::WireGroupTopology
Topology details for the wire group.
Corresponds to the JSON property topology
67667 67668 67669 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67667 def topology @topology end |
#wire_properties ⇒ Google::Apis::ComputeV1::WireProperties
The properties of a wire.
Corresponds to the JSON property wireProperties
67672 67673 67674 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67672 def wire_properties @wire_properties end |
#wires ⇒ Array<Google::Apis::ComputeV1::Wire>
Output only. The single/redundant wire(s) managed by the wire group.
Corresponds to the JSON property wires
67677 67678 67679 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67677 def wires @wires end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67684 67685 67686 67687 67688 67689 67690 67691 67692 67693 67694 67695 67696 67697 |
# File 'lib/google/apis/compute_v1/classes.rb', line 67684 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @endpoints = args[:endpoints] if args.key?(:endpoints) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @self_link = args[:self_link] if args.key?(:self_link) @topology = args[:topology] if args.key?(:topology) @wire_properties = args[:wire_properties] if args.key?(:wire_properties) @wires = args[:wires] if args.key?(:wires) end |