Class: Google::Apis::ComputeV1::WireGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

A resource that represents a group of redundant wires.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroup

Returns a new instance of WireGroup.



63720
63721
63722
# File 'lib/google/apis/compute_v1/classes.rb', line 63720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Indicates whether the wires in the wire group are enabled. When false, the wires in the wire group are disabled. When true and when there is simultaneously no wire-specific override of adminEnabled to false, a given wire is enabled. Defaults to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


63646
63647
63648
# File 'lib/google/apis/compute_v1/classes.rb', line 63646

def admin_enabled
  @admin_enabled
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


63653
63654
63655
# File 'lib/google/apis/compute_v1/classes.rb', line 63653

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of the wire group. Corresponds to the JSON property description

Returns:

  • (String)


63658
63659
63660
# File 'lib/google/apis/compute_v1/classes.rb', line 63658

def description
  @description
end

#endpointsHash<String,Google::Apis::ComputeV1::WireGroupEndpoint>

A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:

  • Key: an RFC1035 user-specified label.
  • Value: an Endpoint object. Corresponds to the JSON property endpoints


63667
63668
63669
# File 'lib/google/apis/compute_v1/classes.rb', line 63667

def endpoints
  @endpoints
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


63674
63675
63676
# File 'lib/google/apis/compute_v1/classes.rb', line 63674

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


63680
63681
63682
# File 'lib/google/apis/compute_v1/classes.rb', line 63680

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


63691
63692
63693
# File 'lib/google/apis/compute_v1/classes.rb', line 63691

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. [Output Only] Indicates whether there are wire changes yet to be processed. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


63697
63698
63699
# File 'lib/google/apis/compute_v1/classes.rb', line 63697

def reconciling
  @reconciling
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63703
63704
63705
# File 'lib/google/apis/compute_v1/classes.rb', line 63703

def self_link
  @self_link
end

#topologyGoogle::Apis::ComputeV1::WireGroupTopology

Topology details for the wire group. Corresponds to the JSON property topology



63708
63709
63710
# File 'lib/google/apis/compute_v1/classes.rb', line 63708

def topology
  @topology
end

#wire_propertiesGoogle::Apis::ComputeV1::WireProperties

The properties of a wire. Corresponds to the JSON property wireProperties



63713
63714
63715
# File 'lib/google/apis/compute_v1/classes.rb', line 63713

def wire_properties
  @wire_properties
end

#wiresArray<Google::Apis::ComputeV1::Wire>

Output only. The single/redundant wire(s) managed by the wire group. Corresponds to the JSON property wires

Returns:



63718
63719
63720
# File 'lib/google/apis/compute_v1/classes.rb', line 63718

def wires
  @wires
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63725
63726
63727
63728
63729
63730
63731
63732
63733
63734
63735
63736
63737
63738
# File 'lib/google/apis/compute_v1/classes.rb', line 63725

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @topology = args[:topology] if args.key?(:topology)
  @wire_properties = args[:wire_properties] if args.key?(:wire_properties)
  @wires = args[:wires] if args.key?(:wires)
end