Class: Google::Apis::ComputeV1::WireGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::WireGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response for the list request.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::WireGroup>
A list of wire group resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::WireGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupList
constructor
A new instance of WireGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupList
Returns a new instance of WireGroupList.
71180 71181 71182 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71180 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
71136 71137 71138 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71136 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71141 71142 71143 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71141 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::WireGroup>
A list of wire group resources.
Corresponds to the JSON property items
71146 71147 71148 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71146 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
71152 71153 71154 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71152 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71162 71163 71164 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71162 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71167 71168 71169 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71167 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
71173 71174 71175 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71173 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::WireGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71178 71179 71180 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71178 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71185 71186 71187 71188 71189 71190 71191 71192 71193 71194 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71185 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |