Class: Google::Apis::ComputeV1::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



70349
70350
70351
# File 'lib/google/apis/compute_v1/classes.rb', line 70349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


70305
70306
70307
# File 'lib/google/apis/compute_v1/classes.rb', line 70305

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70310
70311
70312
# File 'lib/google/apis/compute_v1/classes.rb', line 70310

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



70315
70316
70317
# File 'lib/google/apis/compute_v1/classes.rb', line 70315

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


70321
70322
70323
# File 'lib/google/apis/compute_v1/classes.rb', line 70321

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70331
70332
70333
# File 'lib/google/apis/compute_v1/classes.rb', line 70331

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70336
70337
70338
# File 'lib/google/apis/compute_v1/classes.rb', line 70336

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70342
70343
70344
# File 'lib/google/apis/compute_v1/classes.rb', line 70342

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70347
70348
70349
# File 'lib/google/apis/compute_v1/classes.rb', line 70347

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70354
70355
70356
70357
70358
70359
70360
70361
70362
70363
# File 'lib/google/apis/compute_v1/classes.rb', line 70354

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end