Class: Google::Apis::ComputeV1::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



69992
69993
69994
# File 'lib/google/apis/compute_v1/classes.rb', line 69992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


69948
69949
69950
# File 'lib/google/apis/compute_v1/classes.rb', line 69948

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69953
69954
69955
# File 'lib/google/apis/compute_v1/classes.rb', line 69953

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



69958
69959
69960
# File 'lib/google/apis/compute_v1/classes.rb', line 69958

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


69964
69965
69966
# File 'lib/google/apis/compute_v1/classes.rb', line 69964

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69974
69975
69976
# File 'lib/google/apis/compute_v1/classes.rb', line 69974

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69979
69980
69981
# File 'lib/google/apis/compute_v1/classes.rb', line 69979

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69985
69986
69987
# File 'lib/google/apis/compute_v1/classes.rb', line 69985

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69990
69991
69992
# File 'lib/google/apis/compute_v1/classes.rb', line 69990

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69997
69998
69999
70000
70001
70002
70003
70004
70005
70006
# File 'lib/google/apis/compute_v1/classes.rb', line 69997

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end