Class: Google::Apis::ComputeV1::WireGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::WireGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response for the list request.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::WireGroup>
A list of wire group resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::WireGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupList
constructor
A new instance of WireGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupList
Returns a new instance of WireGroupList.
69992 69993 69994 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
69948 69949 69950 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69948 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69953 69954 69955 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69953 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::WireGroup>
A list of wire group resources.
Corresponds to the JSON property items
69958 69959 69960 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69958 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
69964 69965 69966 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69964 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69974 69975 69976 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69974 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69979 69980 69981 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69979 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
69985 69986 69987 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69985 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::WireGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69990 69991 69992 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69990 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 |
# File 'lib/google/apis/compute_v1/classes.rb', line 69997 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |