Class: Google::Apis::ComputeV1::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



69587
69588
69589
# File 'lib/google/apis/compute_v1/classes.rb', line 69587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


69543
69544
69545
# File 'lib/google/apis/compute_v1/classes.rb', line 69543

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69548
69549
69550
# File 'lib/google/apis/compute_v1/classes.rb', line 69548

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



69553
69554
69555
# File 'lib/google/apis/compute_v1/classes.rb', line 69553

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


69559
69560
69561
# File 'lib/google/apis/compute_v1/classes.rb', line 69559

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69569
69570
69571
# File 'lib/google/apis/compute_v1/classes.rb', line 69569

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69574
69575
69576
# File 'lib/google/apis/compute_v1/classes.rb', line 69574

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69580
69581
69582
# File 'lib/google/apis/compute_v1/classes.rb', line 69580

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69585
69586
69587
# File 'lib/google/apis/compute_v1/classes.rb', line 69585

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69592
69593
69594
69595
69596
69597
69598
69599
69600
69601
# File 'lib/google/apis/compute_v1/classes.rb', line 69592

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end