Class: Google::Apis::ComputeV1::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



69573
69574
69575
# File 'lib/google/apis/compute_v1/classes.rb', line 69573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


69529
69530
69531
# File 'lib/google/apis/compute_v1/classes.rb', line 69529

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69534
69535
69536
# File 'lib/google/apis/compute_v1/classes.rb', line 69534

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



69539
69540
69541
# File 'lib/google/apis/compute_v1/classes.rb', line 69539

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


69545
69546
69547
# File 'lib/google/apis/compute_v1/classes.rb', line 69545

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69555
69556
69557
# File 'lib/google/apis/compute_v1/classes.rb', line 69555

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69560
69561
69562
# File 'lib/google/apis/compute_v1/classes.rb', line 69560

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69566
69567
69568
# File 'lib/google/apis/compute_v1/classes.rb', line 69566

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69571
69572
69573
# File 'lib/google/apis/compute_v1/classes.rb', line 69571

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69578
69579
69580
69581
69582
69583
69584
69585
69586
69587
# File 'lib/google/apis/compute_v1/classes.rb', line 69578

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end