Class: Google::Apis::ComputeV1::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



67829
67830
67831
# File 'lib/google/apis/compute_v1/classes.rb', line 67829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


67785
67786
67787
# File 'lib/google/apis/compute_v1/classes.rb', line 67785

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67790
67791
67792
# File 'lib/google/apis/compute_v1/classes.rb', line 67790

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



67795
67796
67797
# File 'lib/google/apis/compute_v1/classes.rb', line 67795

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


67801
67802
67803
# File 'lib/google/apis/compute_v1/classes.rb', line 67801

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67811
67812
67813
# File 'lib/google/apis/compute_v1/classes.rb', line 67811

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67816
67817
67818
# File 'lib/google/apis/compute_v1/classes.rb', line 67816

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67822
67823
67824
# File 'lib/google/apis/compute_v1/classes.rb', line 67822

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeV1::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67827
67828
67829
# File 'lib/google/apis/compute_v1/classes.rb', line 67827

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67834
67835
67836
67837
67838
67839
67840
67841
67842
67843
# File 'lib/google/apis/compute_v1/classes.rb', line 67834

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end