Class: Google::Apis::ComputeV1::WireGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::WireGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response for the list request.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::WireGroup>
A list of wire group resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::WireGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupList
constructor
A new instance of WireGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupList
Returns a new instance of WireGroupList.
63870 63871 63872 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
63826 63827 63828 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63826 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63831 63832 63833 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63831 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::WireGroup>
A list of wire group resources.
Corresponds to the JSON property items
63836 63837 63838 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63836 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
63842 63843 63844 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63842 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63852 63853 63854 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63852 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63857 63858 63859 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63857 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
63863 63864 63865 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63863 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::WireGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63868 63869 63870 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63868 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63875 63876 63877 63878 63879 63880 63881 63882 63883 63884 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63875 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |