Class: Google::Apis::ComputeV1::WireGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::WireGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Response for the list request.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::WireGroup>
A list of wire group resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::WireGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupList
constructor
A new instance of WireGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupList
Returns a new instance of WireGroupList.
62546 62547 62548 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
62502 62503 62504 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62502 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62507 62508 62509 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62507 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::WireGroup>
A list of wire group resources.
Corresponds to the JSON property items
62512 62513 62514 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62512 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
62518 62519 62520 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62518 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62528 62529 62530 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62528 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62533 62534 62535 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62533 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
62539 62540 62541 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62539 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeV1::WireGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62544 62545 62546 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62544 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62551 62552 62553 62554 62555 62556 62557 62558 62559 62560 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62551 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |