Class: Google::Apis::ComputeV1::WireProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The properties of a wire.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireProperties

Returns a new instance of WireProperties.



69753
69754
69755
# File 'lib/google/apis/compute_v1/classes.rb', line 69753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bandwidth_allocationString

The configuration of the bandwidth allocation, one of the following:

  • ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
  • SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures one unmetered bandwidth allocation for the wire group. The unmetered bandwidth is divided equally across each wire in the group, but dynamic throttling reallocates unused unmetered bandwidth from unused or underused wires to other wires in the group. Corresponds to the JSON property bandwidthAllocation

Returns:

  • (String)


69735
69736
69737
# File 'lib/google/apis/compute_v1/classes.rb', line 69735

def bandwidth_allocation
  @bandwidth_allocation
end

#bandwidth_unmeteredFixnum

The unmetered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0. Corresponds to the JSON property bandwidthUnmetered

Returns:

  • (Fixnum)


69741
69742
69743
# File 'lib/google/apis/compute_v1/classes.rb', line 69741

def bandwidth_unmetered
  @bandwidth_unmetered
end

#fault_responseString

Response when a fault is detected in a pseudowire:

  • NONE: default.
  • DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires. Corresponds to the JSON property faultResponse

Returns:

  • (String)


69751
69752
69753
# File 'lib/google/apis/compute_v1/classes.rb', line 69751

def fault_response
  @fault_response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69758
69759
69760
69761
69762
# File 'lib/google/apis/compute_v1/classes.rb', line 69758

def update!(**args)
  @bandwidth_allocation = args[:bandwidth_allocation] if args.key?(:bandwidth_allocation)
  @bandwidth_unmetered = args[:bandwidth_unmetered] if args.key?(:bandwidth_unmetered)
  @fault_response = args[:fault_response] if args.key?(:fault_response)
end