Class: Google::Apis::ComputeV1::WireProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

The properties of a wire.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireProperties

Returns a new instance of WireProperties.



62712
62713
62714
# File 'lib/google/apis/compute_v1/classes.rb', line 62712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bandwidth_allocationString

The configuration of the bandwidth allocation, one of the following:

  • ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
  • SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures one unmetered bandwidth allocation for the wire group. The unmetered bandwidth is divided equally across each wire in the group, but dynamic throttling reallocates unused unmetered bandwidth from unused or underused wires to other wires in the group. Corresponds to the JSON property bandwidthAllocation

Returns:

  • (String)


62694
62695
62696
# File 'lib/google/apis/compute_v1/classes.rb', line 62694

def bandwidth_allocation
  @bandwidth_allocation
end

#bandwidth_unmeteredFixnum

The unmetered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0. Corresponds to the JSON property bandwidthUnmetered

Returns:

  • (Fixnum)


62700
62701
62702
# File 'lib/google/apis/compute_v1/classes.rb', line 62700

def bandwidth_unmetered
  @bandwidth_unmetered
end

#fault_responseString

Response when a fault is detected in a pseudowire:

  • NONE: default.
  • DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires. Corresponds to the JSON property faultResponse

Returns:

  • (String)


62710
62711
62712
# File 'lib/google/apis/compute_v1/classes.rb', line 62710

def fault_response
  @fault_response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62717
62718
62719
62720
62721
# File 'lib/google/apis/compute_v1/classes.rb', line 62717

def update!(**args)
  @bandwidth_allocation = args[:bandwidth_allocation] if args.key?(:bandwidth_allocation)
  @bandwidth_unmetered = args[:bandwidth_unmetered] if args.key?(:bandwidth_unmetered)
  @fault_response = args[:fault_response] if args.key?(:fault_response)
end