Class: Google::Apis::ComputeV1::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
71424 71425 71426 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71391 71392 71393 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71391 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
71396 71397 71398 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71396 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
71402 71403 71404 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71402 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71412 71413 71414 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71412 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71417 71418 71419 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71417 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71422 71423 71424 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71422 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71429 71430 71431 71432 71433 71434 71435 71436 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71429 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |