Class: Google::Apis::ComputeV1::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
70236 70237 70238 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
70203 70204 70205 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70203 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
70208 70209 70210 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70208 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
70214 70215 70216 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70214 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
70224 70225 70226 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70224 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
70229 70230 70231 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70229 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
70234 70235 70236 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70234 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70241 70242 70243 70244 70245 70246 70247 70248 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70241 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |