Class: Google::Apis::ComputeV1::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
70195 70196 70197 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
70162 70163 70164 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70162 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
70167 70168 70169 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70167 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
70173 70174 70175 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70173 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
70183 70184 70185 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70183 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
70188 70189 70190 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70188 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
70193 70194 70195 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70193 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70200 70201 70202 70203 70204 70205 70206 70207 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70200 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |