Class: Google::Apis::ComputeV1::XpnHostList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpnHostList

Returns a new instance of XpnHostList.



69817
69818
69819
# File 'lib/google/apis/compute_v1/classes.rb', line 69817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69784
69785
69786
# File 'lib/google/apis/compute_v1/classes.rb', line 69784

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Project>

[Output Only] A list of shared VPC host project URLs. Corresponds to the JSON property items



69789
69790
69791
# File 'lib/google/apis/compute_v1/classes.rb', line 69789

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#xpnHostList for lists of shared VPC hosts. Corresponds to the JSON property kind

Returns:

  • (String)


69795
69796
69797
# File 'lib/google/apis/compute_v1/classes.rb', line 69795

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69805
69806
69807
# File 'lib/google/apis/compute_v1/classes.rb', line 69805

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69810
69811
69812
# File 'lib/google/apis/compute_v1/classes.rb', line 69810

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::XpnHostList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69815
69816
69817
# File 'lib/google/apis/compute_v1/classes.rb', line 69815

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69822
69823
69824
69825
69826
69827
69828
69829
# File 'lib/google/apis/compute_v1/classes.rb', line 69822

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end