Class: Google::Apis::ComputeV1::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
71668 71669 71670 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71636 71637 71638 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71636 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Zone>
A list of Zone resources.
Corresponds to the JSON property items
71641 71642 71643 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71641 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
71646 71647 71648 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71646 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71656 71657 71658 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71656 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71661 71662 71663 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71661 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71666 71667 71668 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71666 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71673 71674 71675 71676 71677 71678 71679 71680 |
# File 'lib/google/apis/compute_v1/classes.rb', line 71673 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |