Class: Google::Apis::ComputeV1::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



70825
70826
70827
# File 'lib/google/apis/compute_v1/classes.rb', line 70825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70793
70794
70795
# File 'lib/google/apis/compute_v1/classes.rb', line 70793

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Zone>

A list of Zone resources. Corresponds to the JSON property items

Returns:



70798
70799
70800
# File 'lib/google/apis/compute_v1/classes.rb', line 70798

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


70803
70804
70805
# File 'lib/google/apis/compute_v1/classes.rb', line 70803

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70813
70814
70815
# File 'lib/google/apis/compute_v1/classes.rb', line 70813

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70818
70819
70820
# File 'lib/google/apis/compute_v1/classes.rb', line 70818

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70823
70824
70825
# File 'lib/google/apis/compute_v1/classes.rb', line 70823

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70830
70831
70832
70833
70834
70835
70836
70837
# File 'lib/google/apis/compute_v1/classes.rb', line 70830

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end