Class: Google::Apis::ComputeV1::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
70480 70481 70482 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70480 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
70448 70449 70450 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70448 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Zone>
A list of Zone resources.
Corresponds to the JSON property items
70453 70454 70455 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70453 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
70458 70459 70460 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70458 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
70468 70469 70470 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70468 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
70473 70474 70475 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70473 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
70478 70479 70480 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70478 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70485 70486 70487 70488 70489 70490 70491 70492 |
# File 'lib/google/apis/compute_v1/classes.rb', line 70485 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |