Class: Google::Apis::ComputeV1::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



70069
70070
70071
# File 'lib/google/apis/compute_v1/classes.rb', line 70069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70037
70038
70039
# File 'lib/google/apis/compute_v1/classes.rb', line 70037

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Zone>

A list of Zone resources. Corresponds to the JSON property items

Returns:



70042
70043
70044
# File 'lib/google/apis/compute_v1/classes.rb', line 70042

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


70047
70048
70049
# File 'lib/google/apis/compute_v1/classes.rb', line 70047

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70057
70058
70059
# File 'lib/google/apis/compute_v1/classes.rb', line 70057

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70062
70063
70064
# File 'lib/google/apis/compute_v1/classes.rb', line 70062

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70067
70068
70069
# File 'lib/google/apis/compute_v1/classes.rb', line 70067

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70074
70075
70076
70077
70078
70079
70080
70081
# File 'lib/google/apis/compute_v1/classes.rb', line 70074

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end