Class: Google::Apis::ComputeV1::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



70055
70056
70057
# File 'lib/google/apis/compute_v1/classes.rb', line 70055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70023
70024
70025
# File 'lib/google/apis/compute_v1/classes.rb', line 70023

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Zone>

A list of Zone resources. Corresponds to the JSON property items

Returns:



70028
70029
70030
# File 'lib/google/apis/compute_v1/classes.rb', line 70028

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


70033
70034
70035
# File 'lib/google/apis/compute_v1/classes.rb', line 70033

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70043
70044
70045
# File 'lib/google/apis/compute_v1/classes.rb', line 70043

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70048
70049
70050
# File 'lib/google/apis/compute_v1/classes.rb', line 70048

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeV1::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70053
70054
70055
# File 'lib/google/apis/compute_v1/classes.rb', line 70053

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70060
70061
70062
70063
70064
70065
70066
70067
# File 'lib/google/apis/compute_v1/classes.rb', line 70060

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end