Class: Google::Apis::ComputeV1::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeV1::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeV1::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
63002 63003 63004 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62970 62971 62972 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62970 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Zone>
A list of Zone resources.
Corresponds to the JSON property items
62975 62976 62977 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62975 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
62980 62981 62982 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62980 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62990 62991 62992 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62990 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62995 62996 62997 |
# File 'lib/google/apis/compute_v1/classes.rb', line 62995 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeV1::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63000 63001 63002 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63000 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63007 63008 63009 63010 63011 63012 63013 63014 |
# File 'lib/google/apis/compute_v1/classes.rb', line 63007 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |