Class: Google::Apis::ComputeV1::ZoneSetLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_v1/classes.rb,
lib/google/apis/compute_v1/representations.rb,
lib/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneSetLabelsRequest

Returns a new instance of ZoneSetLabelsRequest.



70563
70564
70565
# File 'lib/google/apis/compute_v1/classes.rb', line 70563

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#label_fingerprintString

The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


70556
70557
70558
# File 'lib/google/apis/compute_v1/classes.rb', line 70556

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

The labels to set for this resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


70561
70562
70563
# File 'lib/google/apis/compute_v1/classes.rb', line 70561

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70568
70569
70570
70571
# File 'lib/google/apis/compute_v1/classes.rb', line 70568

def update!(**args)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
end